pub struct Hosts { /* private fields */ }Available on crate feature
hosts only.Expand description
Implements a client for the Google Compute Engine API.
Example
async fn sample(
) -> anyhow::Result<()> {
let client = Hosts::builder().build().await?;
// use `client` to make requests to the Google Compute Engine API.
Ok(())
}Service Description
Service for the hosts resource.
Configuration
To configure Hosts use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://compute.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured with Private Google Access with VPC Service Controls) may want to override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
Hosts holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap Hosts in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl Hosts
impl Hosts
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for Hosts.
let client = Hosts::builder().build().await?;Sourcepub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: Hosts + 'static,
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: Hosts + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn get_version(&self) -> GetVersion
pub fn get_version(&self) -> GetVersion
Allows customers to get SBOM versions of a host.
Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Retrieves the specified zone-specific Operations resource.