pub struct RegionBackendBuckets { /* private fields */ }region-backend-buckets only.Expand description
Implements a client for the Google Compute Engine API.
Example
async fn sample(
) -> anyhow::Result<()> {
let client = RegionBackendBuckets::builder().build().await?;
// use `client` to make requests to the Google Compute Engine API.
Ok(())
}Service Description
Service for the regionBackendBuckets resource.
Configuration
To configure RegionBackendBuckets use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://compute.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
RegionBackendBuckets holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap RegionBackendBuckets in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl RegionBackendBuckets
impl RegionBackendBuckets
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for RegionBackendBuckets.
let client = RegionBackendBuckets::builder().build().await?;Sourcepub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: RegionBackendBuckets + 'static,
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: RegionBackendBuckets + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn get_iam_policy(&self) -> GetIamPolicy
pub fn get_iam_policy(&self) -> GetIamPolicy
Gets the access control policy for a resource. May be empty if no such policy or resource exists.
Sourcepub fn insert(&self) -> Insert
pub fn insert(&self) -> Insert
Creates a RegionBackendBucket in the specified project in the given scope using the parameters that are included in the request.
Sourcepub fn list(&self) -> List
pub fn list(&self) -> List
Retrieves the list of BackendBucket resources available to the specified project in the given region.
Sourcepub fn list_usable(&self) -> ListUsable
pub fn list_usable(&self) -> ListUsable
Retrieves a list of all usable backend buckets in the specified project in the given region.
Sourcepub fn patch(&self) -> Patch
pub fn patch(&self) -> Patch
Updates the specified BackendBucket resource with the data included in the request. This method supportsPATCH semantics and uses theJSON merge patch format and processing rules.
Sourcepub fn set_iam_policy(&self) -> SetIamPolicy
pub fn set_iam_policy(&self) -> SetIamPolicy
Sets the access control policy on the specified resource. Replaces any existing policy.
Sourcepub fn test_iam_permissions(&self) -> TestIamPermissions
pub fn test_iam_permissions(&self) -> TestIamPermissions
Returns permissions that a caller has on the specified resource.
Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Retrieves the specified region-specific Operations resource.