pub struct RegionHealthAggregationPolicies { /* private fields */ }region-health-aggregation-policies only.Expand description
Implements a client for the Google Compute Engine API.
Example
let client = RegionHealthAggregationPolicies::builder().build().await?;
// use `client` to make requests to the Google Compute Engine API.Service Description
Service for the regionHealthAggregationPolicies resource.
Configuration
To configure RegionHealthAggregationPolicies use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://compute.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
RegionHealthAggregationPolicies holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap RegionHealthAggregationPolicies in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl RegionHealthAggregationPolicies
impl RegionHealthAggregationPolicies
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for RegionHealthAggregationPolicies.
let client = RegionHealthAggregationPolicies::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: RegionHealthAggregationPolicies + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: RegionHealthAggregationPolicies + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn aggregated_list(&self) -> AggregatedList
pub fn aggregated_list(&self) -> AggregatedList
Retrieves the list of all HealthAggregationPolicy resources, regional and global, available to the specified project.
To prevent failure, it is recommended that you set the
returnPartialSuccess parameter to true.
Sourcepub fn delete(&self) -> Delete
pub fn delete(&self) -> Delete
Deletes the specified HealthAggregationPolicy in the given region.
Sourcepub fn get(&self) -> Get
pub fn get(&self) -> Get
Returns the specified HealthAggregationPolicy resource in the given region.
Sourcepub fn insert(&self) -> Insert
pub fn insert(&self) -> Insert
Create a HealthAggregationPolicy in the specified project in the given region using the parameters that are included in the request.
Sourcepub fn list(&self) -> List
pub fn list(&self) -> List
Lists the HealthAggregationPolicies for a project in the given region.
Sourcepub fn patch(&self) -> Patch
pub fn patch(&self) -> Patch
Updates the specified regional HealthAggregationPolicy resource with the data included in the request. This method supportsPATCH semantics and uses theJSON merge patch format and processing rules.
Sourcepub fn test_iam_permissions(&self) -> TestIamPermissions
pub fn test_iam_permissions(&self) -> TestIamPermissions
Returns permissions that a caller has on the specified resource.
Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Retrieves the specified region-specific Operations resource.