pub struct RegionInstanceGroupManagerResizeRequests { /* private fields */ }region-instance-group-manager-resize-requests only.Expand description
Implements a client for the Google Compute Engine API.
Example
let client = RegionInstanceGroupManagerResizeRequests::builder().build().await?;
// use `client` to make requests to the Google Compute Engine API.Service Description
Service for the regionInstanceGroupManagerResizeRequests resource.
Configuration
To configure RegionInstanceGroupManagerResizeRequests use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://compute.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
RegionInstanceGroupManagerResizeRequests holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap RegionInstanceGroupManagerResizeRequests in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl RegionInstanceGroupManagerResizeRequests
impl RegionInstanceGroupManagerResizeRequests
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for RegionInstanceGroupManagerResizeRequests.
let client = RegionInstanceGroupManagerResizeRequests::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: RegionInstanceGroupManagerResizeRequests + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: RegionInstanceGroupManagerResizeRequests + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn cancel(&self) -> Cancel
pub fn cancel(&self) -> Cancel
Cancels the specified resize request. Cancelled resize request no longer waits for the resources to be provisioned. Cancel is only possible for requests that are in accepted state.
Sourcepub fn delete(&self) -> Delete
pub fn delete(&self) -> Delete
Deletes the specified, inactive resize request. Requests that are still active cannot be deleted. Deleting request does not delete instances that were provisioned previously.
Sourcepub fn insert(&self) -> Insert
pub fn insert(&self) -> Insert
Creates a new Resize Request that starts provisioning VMs immediately or queues VM creation.
Sourcepub fn list(&self) -> List
pub fn list(&self) -> List
Retrieves a list of Resize Requests that are contained in the managed instance group.
Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Retrieves the specified region-specific Operations resource.