pub struct RegionInstantSnapshotGroups { /* private fields */ }region-instant-snapshot-groups only.Expand description
Implements a client for the Google Compute Engine API.
Example
async fn sample(
) -> anyhow::Result<()> {
let client = RegionInstantSnapshotGroups::builder().build().await?;
// use `client` to make requests to the Google Compute Engine API.
Ok(())
}Service Description
Service for the regionInstantSnapshotGroups resource.
Configuration
To configure RegionInstantSnapshotGroups use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://compute.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
RegionInstantSnapshotGroups holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap RegionInstantSnapshotGroups in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl RegionInstantSnapshotGroups
impl RegionInstantSnapshotGroups
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for RegionInstantSnapshotGroups.
let client = RegionInstantSnapshotGroups::builder().build().await?;Sourcepub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: RegionInstantSnapshotGroups + 'static,
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: RegionInstantSnapshotGroups + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn get(&self) -> Get
pub fn get(&self) -> Get
returns the specified InstantSnapshotGroup resource in the specified region.
Sourcepub fn get_iam_policy(&self) -> GetIamPolicy
pub fn get_iam_policy(&self) -> GetIamPolicy
Gets the access control policy for a resource. May be empty if no such policy or resource exists.
Sourcepub fn list(&self) -> List
pub fn list(&self) -> List
retrieves the list of InstantSnapshotGroup resources contained within the specified region.
Sourcepub fn set_iam_policy(&self) -> SetIamPolicy
pub fn set_iam_policy(&self) -> SetIamPolicy
Sets the access control policy on the specified resource. Replaces any existing policy.
Sourcepub fn test_iam_permissions(&self) -> TestIamPermissions
pub fn test_iam_permissions(&self) -> TestIamPermissions
Returns permissions that a caller has on the specified resource.
Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Retrieves the specified region-specific Operations resource.