pub struct RegionSnapshots { /* private fields */ }region-snapshots only.Expand description
Implements a client for the Google Compute Engine API.
Example
async fn sample(
) -> anyhow::Result<()> {
let client = RegionSnapshots::builder().build().await?;
// use `client` to make requests to the Google Compute Engine API.
Ok(())
}Service Description
Service for the regionSnapshots resource.
Configuration
To configure RegionSnapshots use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://compute.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
RegionSnapshots holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap RegionSnapshots in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl RegionSnapshots
impl RegionSnapshots
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for RegionSnapshots.
let client = RegionSnapshots::builder().build().await?;Sourcepub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: RegionSnapshots + 'static,
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: RegionSnapshots + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn delete(&self) -> Delete
pub fn delete(&self) -> Delete
Deletes the specified Snapshot resource. Keep in mind that deleting a single snapshot might not necessarily delete all the data on that snapshot. If any data on the snapshot that is marked for deletion is needed for subsequent snapshots, the data will be moved to the next corresponding snapshot.
For more information, seeDeleting snapshots.
Sourcepub fn get_iam_policy(&self) -> GetIamPolicy
pub fn get_iam_policy(&self) -> GetIamPolicy
Gets the access control policy for a resource. May be empty if no such policy or resource exists.
Sourcepub fn insert(&self) -> Insert
pub fn insert(&self) -> Insert
Creates a snapshot in the specified region using the data included in the request.
Sourcepub fn list(&self) -> List
pub fn list(&self) -> List
Retrieves the list of Snapshot resources contained within the specified region.
Sourcepub fn set_iam_policy(&self) -> SetIamPolicy
pub fn set_iam_policy(&self) -> SetIamPolicy
Sets the access control policy on the specified resource. Replaces any existing policy.
Sourcepub fn set_labels(&self) -> SetLabels
pub fn set_labels(&self) -> SetLabels
Sets the labels on a regional snapshot. To learn more about labels, read the Labeling Resources documentation.
Sourcepub fn test_iam_permissions(&self) -> TestIamPermissions
pub fn test_iam_permissions(&self) -> TestIamPermissions
Returns permissions that a caller has on the specified resource.
Sourcepub fn update_kms_key(&self) -> UpdateKmsKey
pub fn update_kms_key(&self) -> UpdateKmsKey
Rotates the customer-managed encryption key to the latest version for the specified snapshot.
Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Retrieves the specified region-specific Operations resource.