pub struct Routes { /* private fields */ }routes only.Expand description
Implements a client for the Google Compute Engine API.
Example
async fn sample(
) -> anyhow::Result<()> {
let client = Routes::builder().build().await?;
// use `client` to make requests to the Google Compute Engine API.
Ok(())
}Service Description
Service for the routes resource.
Configuration
To configure Routes use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://compute.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured with Private Google Access with VPC Service Controls) may want to override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
Routes holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap Routes in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl Routes
impl Routes
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for Routes.
let client = Routes::builder().build().await?;Sourcepub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: Routes + 'static,
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: Routes + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn insert(&self) -> Insert
pub fn insert(&self) -> Insert
Creates a Route resource in the specified project using the data included in the request.
Sourcepub fn list(&self) -> List
pub fn list(&self) -> List
Retrieves the list of Route resources available to the specified project.
Sourcepub fn test_iam_permissions(&self) -> TestIamPermissions
pub fn test_iam_permissions(&self) -> TestIamPermissions
Returns permissions that a caller has on the specified resource.
Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Retrieves the specified Operations resource.