pub struct StoragePoolTypes { /* private fields */ }storage-pool-types only.Expand description
Implements a client for the Google Compute Engine API.
Example
let client = StoragePoolTypes::builder().build().await?;
// use `client` to make requests to the Google Compute Engine API.Service Description
Service for the storagePoolTypes resource.
Configuration
To configure StoragePoolTypes use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://compute.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
StoragePoolTypes holds a connection pool internally, it is advised to
create one and the reuse it. You do not need to wrap StoragePoolTypes in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl StoragePoolTypes
impl StoragePoolTypes
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for StoragePoolTypes.
let client = StoragePoolTypes::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: StoragePoolTypes + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: StoragePoolTypes + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn aggregated_list(&self) -> AggregatedList
pub fn aggregated_list(&self) -> AggregatedList
Retrieves an aggregated list of storage pool types.
To prevent failure, Google recommends that you set the
returnPartialSuccess parameter to true.