pub struct Zones { /* private fields */ }Available on crate feature
zones only.Expand description
Implements a client for the Google Compute Engine API.
Example
async fn sample(
) -> anyhow::Result<()> {
let client = Zones::builder().build().await?;
// use `client` to make requests to the Google Compute Engine API.
Ok(())
}Service Description
Service for the zones resource.
Configuration
To configure Zones use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://compute.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured with Private Google Access with VPC Service Controls) may want to override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
Zones holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap Zones in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl Zones
impl Zones
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for Zones.
let client = Zones::builder().build().await?;Trait Implementations