#[non_exhaustive]pub enum PredictiveMethod {
None,
OptimizeAvailability,
UnknownValue(UnknownValue),
}Available on crate features
autoscalers or region-autoscalers only.Expand description
The enumerated type for the predictiveMethod field.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
None
No predictive method is used. The autoscaler scales the group to meet current demand based on real-time metrics
OptimizeAvailability
Predictive autoscaling improves availability by monitoring daily and weekly load patterns and scaling out ahead of anticipated demand.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using PredictiveMethod::value or PredictiveMethod::name.
Implementations