#[non_exhaustive]pub enum BalancingMode {
Connection,
CustomMetrics,
InFlight,
Rate,
Utilization,
UnknownValue(UnknownValue),
}backend-services or region-backend-services only.Expand description
The enumerated type for the balancingMode field.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Connection
Balance based on the number of simultaneous connections.
CustomMetrics
Based on custom defined and reported metrics.
InFlight
Balance based on the number of in-flight requests.
Rate
Balance based on requests per second (RPS).
Utilization
Balance based on the backend utilization.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using BalancingMode::value or BalancingMode::name.
Implementations