#[non_exhaustive]pub enum TrafficDuration {
Long,
Short,
Unspecified,
UnknownValue(UnknownValue),
}Available on crate features
backend-services or region-backend-services only.Expand description
The enumerated type for the trafficDuration field.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Long
Most of the requests are expected to take more than multiple seconds to finish.
Short
Most requests are expected to finish with a sub-second latency.
Unspecified
Traffic duration is unspecified.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using TrafficDuration::value or TrafficDuration::name.
Implementations