#[non_exhaustive]pub enum Protocol {
Grpc,
H2C,
Http,
Http2,
Https,
Ssl,
Tcp,
Udp,
Unspecified,
UnknownValue(UnknownValue),
}Available on crate features
backend-services or region-backend-services only.Expand description
The enumerated type for the protocol field.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Grpc
gRPC (available for Traffic Director).
H2C
HTTP2 over cleartext
Http
Http2
HTTP/2 with SSL.
Https
Ssl
TCP proxying with SSL.
Tcp
TCP proxying or TCP pass-through.
Udp
UDP.
Unspecified
If a Backend Service has UNSPECIFIED as its protocol, it can be used with any L3/L4 Forwarding Rules.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using Protocol::value or Protocol::name.
Implementations