This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
New values appearing in future releases of the client library, and
New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some
guidelines.
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Automatically cache static content, including common image formats,
media (video and audio), and web assets (JavaScript and CSS).
Requests and responses that are marked as uncacheable, as well as
dynamic content (including HTML), will not be cached.
Cache all content, ignoring any “private”, “no-store” or “no-cache”
directives in Cache-Control response headers.
Warning: this may result in Cloud CDN caching private,
per-user (user identifiable) content.
Requires the origin to set valid caching headers to cache content.
Responses without these headers will not be cached at the edge, and will
require a full trip to the origin on every request, potentially impacting
performance and increasing load on the origin server.