#[non_exhaustive]pub enum ReservationMode {
Calendar,
Default,
Unspecified,
UnknownValue(UnknownValue),
}Available on crate feature
future-reservations only.Expand description
The enumerated type for the reservationMode field.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Calendar
The delivered reservations will delivered at specified start time and terminated at specified end time along with terminating the VMs running on it.
Default
The delivered reservations do not terminate VMs at the end of reservations. This is default mode.
Unspecified
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using ReservationMode::value or ReservationMode::name.
Implementations