#[non_exhaustive]pub struct GetVersionRequest {
pub association: String,
pub host: String,
pub project: String,
pub request_id: Option<String>,
pub zone: String,
pub body: Option<HostsGetVersionRequest>,
/* private fields */
}Available on crate feature
hosts only.Expand description
Synthetic request message for the getVersion() method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.association: StringThe parent resource association for the Host. This field specifies the hierarchical context (e.g., reservation, block, sub-block) when accessing the host.
host: StringThe name of the host, formatted as RFC1035 or a resource ID number.
project: StringProject ID for this request.
request_id: Option<String>An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
zone: StringName of the zone for this request. Zone name should conform to RFC1035.
body: Option<HostsGetVersionRequest>Synthetic request body field for the getVersion() method.
Implementations
Sourceimpl GetVersionRequest
impl GetVersionRequest
Sourcepub fn set_association<T: Into<String>>(self, v: T) -> Self
pub fn set_association<T: Into<String>>(self, v: T) -> Self
Sets the value of association.
Example
ⓘ
let x = GetVersionRequest::new().set_association("example");Sourcepub fn set_project<T: Into<String>>(self, v: T) -> Self
pub fn set_project<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_request_id<T>(self, v: T) -> Self
pub fn set_request_id<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_request_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_request_id<T>(self, v: Option<T>) -> Self
Sets or clears the value of request_id.
Example
ⓘ
let x = GetVersionRequest::new().set_or_clear_request_id(Some("example"));
let x = GetVersionRequest::new().set_or_clear_request_id(None::<String>);Sourcepub fn set_body<T>(self, v: T) -> Selfwhere
T: Into<HostsGetVersionRequest>,
pub fn set_body<T>(self, v: T) -> Selfwhere
T: Into<HostsGetVersionRequest>,
Sourcepub fn set_or_clear_body<T>(self, v: Option<T>) -> Selfwhere
T: Into<HostsGetVersionRequest>,
pub fn set_or_clear_body<T>(self, v: Option<T>) -> Selfwhere
T: Into<HostsGetVersionRequest>,