#[non_exhaustive]pub struct UpdateRequest {
pub https_health_check: String,
pub project: String,
pub request_id: Option<String>,
pub body: Option<HttpsHealthCheck>,
/* private fields */
}https-health-checks only.Expand description
Synthetic request message for the update() method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.https_health_check: StringName of the HttpsHealthCheck resource to update.
project: StringProject ID for this request.
request_id: Option<String>An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
body: Option<HttpsHealthCheck>Synthetic request body field for the update() method.
Implementations
Sourceimpl UpdateRequest
impl UpdateRequest
Sourcepub fn set_https_health_check<T: Into<String>>(self, v: T) -> Self
pub fn set_https_health_check<T: Into<String>>(self, v: T) -> Self
Sets the value of https_health_check.
Example
let x = UpdateRequest::new().set_https_health_check("example");Sourcepub fn set_project<T: Into<String>>(self, v: T) -> Self
pub fn set_project<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_request_id<T>(self, v: T) -> Self
pub fn set_request_id<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_request_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_request_id<T>(self, v: Option<T>) -> Self
Sets or clears the value of request_id.
Example
let x = UpdateRequest::new().set_or_clear_request_id(Some("example"));
let x = UpdateRequest::new().set_or_clear_request_id(None::<String>);Sourcepub fn set_body<T>(self, v: T) -> Selfwhere
T: Into<HttpsHealthCheck>,
pub fn set_body<T>(self, v: T) -> Selfwhere
T: Into<HttpsHealthCheck>,
Sourcepub fn set_or_clear_body<T>(self, v: Option<T>) -> Selfwhere
T: Into<HttpsHealthCheck>,
pub fn set_or_clear_body<T>(self, v: Option<T>) -> Selfwhere
T: Into<HttpsHealthCheck>,