#[non_exhaustive]pub struct RawDisk {
pub container_type: Option<ContainerType>,
pub sha_1_checksum: Option<String>,
pub source: Option<String>,
/* private fields */
}image-family-views or images only.Expand description
The message type for the rawDisk field.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.container_type: Option<ContainerType>The format used to encode and transmit the block device, which should beTAR. This is just a container and transmission format and not a runtime format. Provided by the client when the disk image is created.
sha_1_checksum: Option<String>[Deprecated] This field is deprecated. An optional SHA1 checksum of the disk image before unpackaging provided by the client when the disk image is created.
source: Option<String>The full Google Cloud Storage URL or Artifact Registry path where the raw disk image archive is stored. The following are valid formats:
- https://storage.googleapis.com/bucket_name/image_archive_name
- https://storage.googleapis.com/bucket_name/folder_name/image_archive_name
- projects/project/locations/location/repositories/repo/packages/package/versions/version_id
- projects/project/locations/location/repositories/repo/packages/package/versions/version_id@dirsum_sha256:hex_value
In order to create an image, you must provide the full or partial URL of one of the following:
- The rawDisk.source URL
- The sourceDisk URL
- The sourceImage URL
- The sourceSnapshot URL
Implementations
Sourceimpl RawDisk
impl RawDisk
Sourcepub fn set_container_type<T>(self, v: T) -> Selfwhere
T: Into<ContainerType>,
pub fn set_container_type<T>(self, v: T) -> Selfwhere
T: Into<ContainerType>,
Sets the value of container_type.
Example
use google_cloud_compute_v1::model::image::raw_disk::ContainerType;
let x0 = RawDisk::new().set_container_type(ContainerType::Tar);Sourcepub fn set_or_clear_container_type<T>(self, v: Option<T>) -> Selfwhere
T: Into<ContainerType>,
pub fn set_or_clear_container_type<T>(self, v: Option<T>) -> Selfwhere
T: Into<ContainerType>,
Sets or clears the value of container_type.
Example
use google_cloud_compute_v1::model::image::raw_disk::ContainerType;
let x0 = RawDisk::new().set_or_clear_container_type(Some(ContainerType::Tar));
let x_none = RawDisk::new().set_or_clear_container_type(None::<ContainerType>);Sourcepub fn set_sha_1_checksum<T>(self, v: T) -> Self
👎Deprecated
pub fn set_sha_1_checksum<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_sha_1_checksum<T>(self, v: Option<T>) -> Self
👎Deprecated
pub fn set_or_clear_sha_1_checksum<T>(self, v: Option<T>) -> Self
Sets or clears the value of sha_1_checksum.
Example
let x = RawDisk::new().set_or_clear_sha_1_checksum(Some("example"));
let x = RawDisk::new().set_or_clear_sha_1_checksum(None::<String>);Sourcepub fn set_source<T>(self, v: T) -> Self
pub fn set_source<T>(self, v: T) -> Self