#[non_exhaustive]pub enum PrivateIpv6GoogleAccess {
EnableBidirectionalAccessToGoogle,
EnableOutboundVmAccessToGoogle,
InheritFromSubnetwork,
UnknownValue(UnknownValue),
}instances only.Expand description
The enumerated type for the privateIpv6GoogleAccess field.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
EnableBidirectionalAccessToGoogle
Bidirectional private IPv6 access to/from Google services. If specified, the subnetwork who is attached to the instance’s default network interface will be assigned an internal IPv6 prefix if it doesn’t have before.
EnableOutboundVmAccessToGoogle
Outbound private IPv6 access from VMs in this subnet to Google services. If specified, the subnetwork who is attached to the instance’s default network interface will be assigned an internal IPv6 prefix if it doesn’t have before.
InheritFromSubnetwork
Each network interface inherits PrivateIpv6GoogleAccess from its subnetwork.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using PrivateIpv6GoogleAccess::value or PrivateIpv6GoogleAccess::name.
Implementations