#[non_exhaustive]pub enum LocalSsdEncryptionMode {
EphemeralKeyEncryption,
Unspecified,
StandardEncryption,
UnknownValue(UnknownValue),
}instance-templates or instances or machine-images or region-instance-templates or region-instances only.Expand description
The enumerated type for the localSsdEncryptionMode field.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
EphemeralKeyEncryption
The given VM will opt-in for using ephemeral key for encryption of Local SSDs. The Local SSDs will not be able to recover data in case of VM crash.
Unspecified
The given VM will be encrypted using keys managed by the cloud infrastructure and the keys will be deleted when the VM is deleted.
StandardEncryption
The given VM will be encrypted using keys managed by the cloud infrastructure and the keys will be deleted when the VM is deleted.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using LocalSsdEncryptionMode::value or LocalSsdEncryptionMode::name.
Implementations