#[non_exhaustive]pub struct AddResourcePoliciesRequest {
pub instance: String,
pub project: String,
pub request_id: Option<String>,
pub zone: String,
pub body: Option<InstancesAddResourcePoliciesRequest>,
/* private fields */
}instances only.Expand description
Synthetic request message for the addResourcePolicies() method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.instance: StringThe instance name for this request.
project: StringProject ID for this request.
request_id: Option<String>An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
zone: StringThe name of the zone for this request.
body: Option<InstancesAddResourcePoliciesRequest>Synthetic request body field for the addResourcePolicies() method.
Implementations
Sourceimpl AddResourcePoliciesRequest
impl AddResourcePoliciesRequest
Sourcepub fn set_instance<T: Into<String>>(self, v: T) -> Self
pub fn set_instance<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_project<T: Into<String>>(self, v: T) -> Self
pub fn set_project<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_request_id<T>(self, v: T) -> Self
pub fn set_request_id<T>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = AddResourcePoliciesRequest::new().set_request_id("example");Sourcepub fn set_or_clear_request_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_request_id<T>(self, v: Option<T>) -> Self
Sets or clears the value of request_id.
Example
let x = AddResourcePoliciesRequest::new().set_or_clear_request_id(Some("example"));
let x = AddResourcePoliciesRequest::new().set_or_clear_request_id(None::<String>);Sourcepub fn set_body<T>(self, v: T) -> Selfwhere
T: Into<InstancesAddResourcePoliciesRequest>,
pub fn set_body<T>(self, v: T) -> Selfwhere
T: Into<InstancesAddResourcePoliciesRequest>,
Sourcepub fn set_or_clear_body<T>(self, v: Option<T>) -> Selfwhere
T: Into<InstancesAddResourcePoliciesRequest>,
pub fn set_or_clear_body<T>(self, v: Option<T>) -> Selfwhere
T: Into<InstancesAddResourcePoliciesRequest>,
Sets or clears the value of body.
Example
use google_cloud_compute_v1::model::InstancesAddResourcePoliciesRequest;
let x = AddResourcePoliciesRequest::new().set_or_clear_body(Some(InstancesAddResourcePoliciesRequest::default()/* use setters */));
let x = AddResourcePoliciesRequest::new().set_or_clear_body(None::<InstancesAddResourcePoliciesRequest>);Trait Implementations
Sourceimpl Clone for AddResourcePoliciesRequest
impl Clone for AddResourcePoliciesRequest
Sourcefn clone(&self) -> AddResourcePoliciesRequest
fn clone(&self) -> AddResourcePoliciesRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for AddResourcePoliciesRequest
impl Debug for AddResourcePoliciesRequest
Sourceimpl Default for AddResourcePoliciesRequest
impl Default for AddResourcePoliciesRequest
Sourcefn default() -> AddResourcePoliciesRequest
fn default() -> AddResourcePoliciesRequest
impl StructuralPartialEq for AddResourcePoliciesRequest