#[non_exhaustive]pub struct SetMetadataRequest {
pub instance: String,
pub project: String,
pub request_id: Option<String>,
pub zone: String,
pub body: Option<Metadata>,
/* private fields */
}instances only.Expand description
Synthetic request message for the setMetadata() method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.instance: StringName of the instance scoping this request.
project: StringProject ID for this request.
request_id: Option<String>An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
zone: StringThe name of the zone for this request.
body: Option<Metadata>Synthetic request body field for the setMetadata() method.
Implementations
Sourceimpl SetMetadataRequest
impl SetMetadataRequest
Sourcepub fn set_instance<T: Into<String>>(self, v: T) -> Self
pub fn set_instance<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_project<T: Into<String>>(self, v: T) -> Self
pub fn set_project<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_request_id<T>(self, v: T) -> Self
pub fn set_request_id<T>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = SetMetadataRequest::new().set_request_id("example");Sourcepub fn set_or_clear_request_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_request_id<T>(self, v: Option<T>) -> Self
Sets or clears the value of request_id.
Example
let x = SetMetadataRequest::new().set_or_clear_request_id(Some("example"));
let x = SetMetadataRequest::new().set_or_clear_request_id(None::<String>);Sourcepub fn set_or_clear_body<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_body<T>(self, v: Option<T>) -> Self