Enum State Copy item path Source #[non_exhaustive]
pub enum State {
Active,
Defunct,
PartnerRequestReceived,
PendingCustomer,
PendingPartner,
Unspecified,
Unprovisioned,
UnknownValue(UnknownValue),
}Available on crate feature interconnect-attachments only.
Expand description The enumerated type for the state field.
 Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
New values appearing in future releases of the client library, and
New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some
guidelines.
This enum is marked as non-exhaustive Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Indicates that attachment has been turned up and is ready to use.
The attachment was deleted externally and is no longer functional.
This could be because the associated Interconnect was wiped out,
or because the other side of a Partner attachment was deleted.
A PARTNER attachment is in the process of provisioning after a
PARTNER_PROVIDER attachment was created that references it.
PARTNER or PARTNER_PROVIDER attachment that is waiting for the customer
to activate.
A newly created PARTNER attachment that has not yet been configured on
the Partner side.
Indicates that attachment is not ready to use yet, because turnup is not
complete.
If set, the enum was initialized with an unknown value.
Applications can examine the value using State::value or
State::name .
Gets the enum value.
Returns None if the enum contains an unknown value deserialized from
the string representation of enums.
Gets the enum value as a string.
Returns None if the enum contains an unknown value deserialized from
the integer representation of enums.
Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more Returns the “default value” for a type.
Read more Deserialize this value from the given Serde deserializer.
Read more Formats the value using the given formatter.
Read more Converts to this type from the input type.
Converts to this type from the input type.
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Serialize this value into the given Serde serializer.
Read more Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more Returns the argument unchanged.
Attaches the provided
Context to this type, returning a
WithContext
wrapper.
Read more Attaches the current
Context to this type, returning a
WithContext
wrapper.
Read more Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more Converts the given value to a
String.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.