#[non_exhaustive]pub enum BundleOperationalStatus {
Down,
Up,
UnknownValue(UnknownValue),
}interconnect-groups or interconnects only.Expand description
The enumerated type for the bundleOperationalStatus field.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Down
If bundleAggregationType is LACP: LACP is not established and/or all links in the bundle have DOWN operational status. If bundleAggregationType is STATIC: one or more links in the bundle has DOWN operational status.
Up
If bundleAggregationType is LACP: LACP is established and at least one link in the bundle has UP operational status. If bundleAggregationType is STATIC: all links in the bundle (typically just one) have UP operational status.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using BundleOperationalStatus::value or BundleOperationalStatus::name.
Implementations