#[non_exhaustive]pub enum UpdateStrategy {
Consensus,
Independent,
Unspecified,
UnknownValue(UnknownValue),
}networks only.Expand description
The enumerated type for the updateStrategy field.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Consensus
Updates are reflected in the local peering but aren’t applied to the peering connection until a complementary change is made to the matching peering. To delete a peering with the consensus update strategy, both the peerings must request the deletion of the peering before the peering can be deleted.
Independent
In this mode, changes to the peering configuration can be unilaterally altered by changing either side of the peering. This is the default value if the field is unspecified.
Unspecified
Peerings with update strategy UNSPECIFIED are created with update strategy INDEPENDENT.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using UpdateStrategy::value or UpdateStrategy::name.
Implementations