#[non_exhaustive]pub enum MaintenancePolicy {
Default,
Unspecified,
MigrateWithinNodeGroup,
RestartInPlace,
UnknownValue(UnknownValue),
}node-groups only.Expand description
The enumerated type for the maintenancePolicy field.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Default
Allow the node and corresponding instances to retain default maintenance behavior.
Unspecified
MigrateWithinNodeGroup
When maintenance must be done on a node, the instances on that node will be moved to other nodes in the group. Instances with onHostMaintenance = MIGRATE will live migrate to their destinations while instances with onHostMaintenance = TERMINATE will terminate and then restart on their destination nodes if automaticRestart = true.
RestartInPlace
Instances in this group will restart on the same node when maintenance has completed. Instances must have onHostMaintenance = TERMINATE, and they will only restart if automaticRestart = true.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using MaintenancePolicy::value or MaintenancePolicy::name.
Implementations