#[non_exhaustive]pub enum DefaultNetworkTier {
FixedStandard,
Premium,
Standard,
StandardOverridesFixedStandard,
UnknownValue(UnknownValue),
}projects only.Expand description
The enumerated type for the defaultNetworkTier field.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
FixedStandard
Public internet quality with fixed bandwidth.
Premium
High quality, Google-grade network tier, support for all networking products.
Standard
Public internet quality, only limited support for other networking products.
StandardOverridesFixedStandard
(Output only) Temporary tier for FIXED_STANDARD when fixed standard tier is expired or not configured.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using DefaultNetworkTier::value or DefaultNetworkTier::name.
Implementations