#[non_exhaustive]pub struct GetVersionRequest {
pub parent_name: String,
pub project: String,
pub request_id: Option<String>,
pub reservation_sub_block: String,
pub zone: String,
pub body: Option<ReservationSubBlocksGetVersionRequest>,
/* private fields */
}reservation-sub-blocks only.Expand description
Synthetic request message for the getVersion() method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent_name: StringThe name of the parent reservation and parent block. In the format of reservations/{reservation_name}/reservationBlocks/{reservation_block_name}
project: StringProject ID for this request.
request_id: Option<String>An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
reservation_sub_block: StringThe name of the reservation subBlock. Name should conform to RFC1035 or be a resource ID.
zone: StringName of the zone for this request. Zone name should conform to RFC1035.
body: Option<ReservationSubBlocksGetVersionRequest>Synthetic request body field for the getVersion() method.
Implementations
Sourceimpl GetVersionRequest
impl GetVersionRequest
pub fn new() -> Self
Sourcepub fn set_parent_name<T: Into<String>>(self, v: T) -> Self
pub fn set_parent_name<T: Into<String>>(self, v: T) -> Self
Sets the value of parent_name.
Example
let x = GetVersionRequest::new().set_parent_name("example");Sourcepub fn set_project<T: Into<String>>(self, v: T) -> Self
pub fn set_project<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_request_id<T>(self, v: T) -> Self
pub fn set_request_id<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_request_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_request_id<T>(self, v: Option<T>) -> Self
Sets or clears the value of request_id.
Example
let x = GetVersionRequest::new().set_or_clear_request_id(Some("example"));
let x = GetVersionRequest::new().set_or_clear_request_id(None::<String>);Sourcepub fn set_reservation_sub_block<T: Into<String>>(self, v: T) -> Self
pub fn set_reservation_sub_block<T: Into<String>>(self, v: T) -> Self
Sets the value of reservation_sub_block.
Example
let x = GetVersionRequest::new().set_reservation_sub_block("example");Sourcepub fn set_body<T>(self, v: T) -> Selfwhere
T: Into<ReservationSubBlocksGetVersionRequest>,
pub fn set_body<T>(self, v: T) -> Selfwhere
T: Into<ReservationSubBlocksGetVersionRequest>,
Sourcepub fn set_or_clear_body<T>(self, v: Option<T>) -> Selfwhere
T: Into<ReservationSubBlocksGetVersionRequest>,
pub fn set_or_clear_body<T>(self, v: Option<T>) -> Selfwhere
T: Into<ReservationSubBlocksGetVersionRequest>,
Sets or clears the value of body.
Example
use google_cloud_compute_v1::model::ReservationSubBlocksGetVersionRequest;
let x = GetVersionRequest::new().set_or_clear_body(Some(ReservationSubBlocksGetVersionRequest::default()/* use setters */));
let x = GetVersionRequest::new().set_or_clear_body(None::<ReservationSubBlocksGetVersionRequest>);Trait Implementations
Sourceimpl Clone for GetVersionRequest
impl Clone for GetVersionRequest
Sourcefn clone(&self) -> GetVersionRequest
fn clone(&self) -> GetVersionRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more