#[non_exhaustive]pub enum State {
Show 19 variants
Cancelled,
Cancelling,
CancelFailed,
Completed,
CompleteFailed,
Completing,
Failed,
Paused,
PauseFailed,
Pausing,
Processing,
Ready,
Resuming,
RollbackWaveFailed,
RollingBack,
Unspecified,
Uninitialized,
WaveFailed,
UnknownValue(UnknownValue),
}rollouts only.Expand description
The enumerated type for the state field.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Cancelled
The rollout is in a failure terminal state.
Cancelling
The rollout is being cancelled.
CancelFailed
An attempted cancel operation was unsuccessful.
Completed
The rollout is in a successful terminal state.
CompleteFailed
An attempted complete operation was unsuccessful.
Completing
The rollout is being marked as completed.
Failed
The rollout completed with failures.
Paused
The rollout is paused.
PauseFailed
An attempted pause operation was unsuccessful.
Pausing
The rollout is being paused.
Processing
A wave is being processed by the product.
Ready
The rollout has been successfully initialized and is ready to start.
Resuming
The rollout is being resumed after being paused.
RollbackWaveFailed
An attempted rollback operation failed to complete successfully.
RollingBack
A wave rollback is in progress for this rollout.
Unspecified
Undefined default state. Should never be exposed to users.
Uninitialized
The rollout has been created but is not yet ready to be started.
WaveFailed
The product failed to process the wave.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using State::value or State::name.