#[non_exhaustive]pub struct PauseRequest {
pub etag: Option<String>,
pub project: String,
pub request_id: Option<String>,
pub rollout: String,
/* private fields */
}rollouts only.Expand description
Synthetic request message for the pause() method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.etag: Option<String>The etag of the Rollout. If this is provided, the request will only succeed if the etag matches the current etag of the Rollout.
project: StringRequired. Project ID for this request.
request_id: Option<String>An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
rollout: StringRequired. Name of the Rollout resource to pause.
Implementations
Sourceimpl PauseRequest
impl PauseRequest
Sourcepub fn set_or_clear_etag<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_etag<T>(self, v: Option<T>) -> Self
Sourcepub fn set_project<T: Into<String>>(self, v: T) -> Self
pub fn set_project<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_request_id<T>(self, v: T) -> Self
pub fn set_request_id<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_request_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_request_id<T>(self, v: Option<T>) -> Self
Sets or clears the value of request_id.
Example
let x = PauseRequest::new().set_or_clear_request_id(Some("example"));
let x = PauseRequest::new().set_or_clear_request_id(None::<String>);Trait Implementations
Sourceimpl Clone for PauseRequest
impl Clone for PauseRequest
Sourcefn clone(&self) -> PauseRequest
fn clone(&self) -> PauseRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for PauseRequest
impl Debug for PauseRequest
Sourceimpl Default for PauseRequest
impl Default for PauseRequest
Sourcefn default() -> PauseRequest
fn default() -> PauseRequest
Sourceimpl PartialEq for PauseRequest
impl PartialEq for PauseRequest
Sourcefn eq(&self, other: &PauseRequest) -> bool
fn eq(&self, other: &PauseRequest) -> bool
self and other values to be equal, and is used by ==.