#[non_exhaustive]pub struct AWSV4Signature {
pub access_key: Option<String>,
pub access_key_id: Option<String>,
pub access_key_version: Option<String>,
pub origin_region: Option<String>,
/* private fields */
}backend-services or region-backend-services only.Expand description
Contains the configurations necessary to generate a signature for access to private storage buckets that support Signature Version 4 for authentication. The service name for generating the authentication header will always default to ‘s3’.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.access_key: Option<String>The access key used for s3 bucket authentication. Required for updating or creating a backend that uses AWS v4 signature authentication, but will not be returned as part of the configuration when queried with a REST API GET request.
@InputOnly
access_key_id: Option<String>The identifier of an access key used for s3 bucket authentication.
access_key_version: Option<String>The optional version identifier for the access key. You can use this to keep track of different iterations of your access key.
origin_region: Option<String>The name of the cloud region of your origin. This is a free-form field with the name of the region your cloud uses to host your origin. For example, “us-east-1” for AWS or “us-ashburn-1” for OCI.
Implementations
Sourceimpl AWSV4Signature
impl AWSV4Signature
Sourcepub fn set_access_key<T>(self, v: T) -> Self
pub fn set_access_key<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_access_key<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_access_key<T>(self, v: Option<T>) -> Self
Sets or clears the value of access_key.
Example
let x = AWSV4Signature::new().set_or_clear_access_key(Some("example"));
let x = AWSV4Signature::new().set_or_clear_access_key(None::<String>);Sourcepub fn set_access_key_id<T>(self, v: T) -> Self
pub fn set_access_key_id<T>(self, v: T) -> Self
Sets the value of access_key_id.
Example
let x = AWSV4Signature::new().set_access_key_id("example");Sourcepub fn set_or_clear_access_key_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_access_key_id<T>(self, v: Option<T>) -> Self
Sets or clears the value of access_key_id.
Example
let x = AWSV4Signature::new().set_or_clear_access_key_id(Some("example"));
let x = AWSV4Signature::new().set_or_clear_access_key_id(None::<String>);Sourcepub fn set_access_key_version<T>(self, v: T) -> Self
pub fn set_access_key_version<T>(self, v: T) -> Self
Sets the value of access_key_version.
Example
let x = AWSV4Signature::new().set_access_key_version("example");Sourcepub fn set_or_clear_access_key_version<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_access_key_version<T>(self, v: Option<T>) -> Self
Sets or clears the value of access_key_version.
Example
let x = AWSV4Signature::new().set_or_clear_access_key_version(Some("example"));
let x = AWSV4Signature::new().set_or_clear_access_key_version(None::<String>);Sourcepub fn set_origin_region<T>(self, v: T) -> Self
pub fn set_origin_region<T>(self, v: T) -> Self
Sets the value of origin_region.
Example
let x = AWSV4Signature::new().set_origin_region("example");Sourcepub fn set_or_clear_origin_region<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_origin_region<T>(self, v: Option<T>) -> Self
Sets or clears the value of origin_region.
Example
let x = AWSV4Signature::new().set_or_clear_origin_region(Some("example"));
let x = AWSV4Signature::new().set_or_clear_origin_region(None::<String>);Trait Implementations
Sourceimpl Clone for AWSV4Signature
impl Clone for AWSV4Signature
Sourcefn clone(&self) -> AWSV4Signature
fn clone(&self) -> AWSV4Signature
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for AWSV4Signature
impl Debug for AWSV4Signature
Sourceimpl Default for AWSV4Signature
impl Default for AWSV4Signature
Sourcefn default() -> AWSV4Signature
fn default() -> AWSV4Signature
Sourceimpl Message for AWSV4Signature
impl Message for AWSV4Signature
Sourceimpl PartialEq for AWSV4Signature
impl PartialEq for AWSV4Signature
impl StructuralPartialEq for AWSV4Signature