#[non_exhaustive]pub struct BackendBackendOrchestrationInfo {
pub resource_uri: Option<String>,
/* private fields */
}Available on crate features
backend-services or region-backend-services only.Expand description
A message containing information about the resource or system that manages the backend.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resource_uri: Option<String>The URI of the resource or system that manages the backend.
Implementations
Sourceimpl BackendBackendOrchestrationInfo
impl BackendBackendOrchestrationInfo
pub fn new() -> Self
Sourcepub fn set_resource_uri<T>(self, v: T) -> Self
pub fn set_resource_uri<T>(self, v: T) -> Self
Sets the value of resource_uri.
Example
ⓘ
let x = BackendBackendOrchestrationInfo::new().set_resource_uri("example");Sourcepub fn set_or_clear_resource_uri<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_resource_uri<T>(self, v: Option<T>) -> Self
Sets or clears the value of resource_uri.
Example
ⓘ
let x = BackendBackendOrchestrationInfo::new().set_or_clear_resource_uri(Some("example"));
let x = BackendBackendOrchestrationInfo::new().set_or_clear_resource_uri(None::<String>);Trait Implementations
Sourceimpl Clone for BackendBackendOrchestrationInfo
impl Clone for BackendBackendOrchestrationInfo
Sourcefn clone(&self) -> BackendBackendOrchestrationInfo
fn clone(&self) -> BackendBackendOrchestrationInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for BackendBackendOrchestrationInfo
impl Default for BackendBackendOrchestrationInfo
Sourcefn default() -> BackendBackendOrchestrationInfo
fn default() -> BackendBackendOrchestrationInfo
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for BackendBackendOrchestrationInfo
impl PartialEq for BackendBackendOrchestrationInfo
Sourcefn eq(&self, other: &BackendBackendOrchestrationInfo) -> bool
fn eq(&self, other: &BackendBackendOrchestrationInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for BackendBackendOrchestrationInfo