BackendBucket

Struct BackendBucket 

#[non_exhaustive]
pub struct BackendBucket {
Show 16 fields pub bucket_name: Option<String>, pub cdn_policy: Option<BackendBucketCdnPolicy>, pub compression_mode: Option<CompressionMode>, pub creation_timestamp: Option<String>, pub custom_response_headers: Vec<String>, pub description: Option<String>, pub edge_security_policy: Option<String>, pub enable_cdn: Option<bool>, pub id: Option<u64>, pub kind: Option<String>, pub load_balancing_scheme: Option<LoadBalancingScheme>, pub name: Option<String>, pub params: Option<BackendBucketParams>, pub region: Option<String>, pub self_link: Option<String>, pub used_by: Vec<BackendBucketUsedBy>, /* private fields */
}
Available on crate features backend-buckets or region-backend-buckets only.
Represents a Cloud Storage Bucket resource.

This Cloud Storage bucket resource is referenced by a URL map of a load balancer. For more information, readBackend Buckets.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
bucket_name: Option<String>

Cloud Storage bucket name.

cdn_policy: Option<BackendBucketCdnPolicy>

Cloud CDN configuration for this BackendBucket.

compression_mode: Option<CompressionMode>

Compress text responses using Brotli or gzip compression, based on the client’s Accept-Encoding header.

creation_timestamp: Option<String>

[Output Only] Creation timestamp inRFC3339 text format.

custom_response_headers: Vec<String>

Headers that the Application Load Balancer should add to proxied responses.

description: Option<String>

An optional textual description of the resource; provided by the client when the resource is created.

edge_security_policy: Option<String>

[Output Only] The resource URL for the edge security policy associated with this backend bucket.

enable_cdn: Option<bool>

If true, enable Cloud CDN for this BackendBucket.

id: Option<u64>

[Output Only] Unique identifier for the resource; defined by the server.

kind: Option<String>

Output only. Type of the resource.

load_balancing_scheme: Option<LoadBalancingScheme>

The value can only be INTERNAL_MANAGED for cross-region internal layer 7 load balancer.

If loadBalancingScheme is not specified, the backend bucket can be used by classic global external load balancers, or global application external load balancers, or both.

name: Option<String>

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.

params: Option<BackendBucketParams>

Input only. [Input Only] Additional params passed with the request, but not persisted as part of resource payload.

region: Option<String>

Output only. [Output Only] URL of the region where the regional backend bucket resides. This field is not applicable to global backend buckets. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.

self_link: Option<String>

[Output Only] Server-defined URL for the resource.

used_by: Vec<BackendBucketUsedBy>

Output only. [Output Only] List of resources referencing that backend bucket.

Implementations

Source

impl BackendBucket

pub fn new() -> Self

Creates a new default instance.

pub fn set_bucket_name<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of bucket_name.

Example
let x = BackendBucket::new().set_bucket_name("example");
pub fn set_or_clear_bucket_name<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of bucket_name.

Example
let x = BackendBucket::new().set_or_clear_bucket_name(Some("example"));
let x = BackendBucket::new().set_or_clear_bucket_name(None::<String>);
pub fn set_cdn_policy<T>(self, v: T) -> Self

Sets the value of cdn_policy.

Example
use google_cloud_compute_v1::model::BackendBucketCdnPolicy;
let x = BackendBucket::new().set_cdn_policy(BackendBucketCdnPolicy::default()/* use setters */);
pub fn set_or_clear_cdn_policy<T>(self, v: Option<T>) -> Self

Sets or clears the value of cdn_policy.

Example
use google_cloud_compute_v1::model::BackendBucketCdnPolicy;
let x = BackendBucket::new().set_or_clear_cdn_policy(Some(BackendBucketCdnPolicy::default()/* use setters */));
let x = BackendBucket::new().set_or_clear_cdn_policy(None::<BackendBucketCdnPolicy>);
pub fn set_compression_mode<T>(self, v: T) -> Self

Sets the value of compression_mode.

Example
use google_cloud_compute_v1::model::backend_bucket::CompressionMode;
let x0 = BackendBucket::new().set_compression_mode(CompressionMode::Disabled);
pub fn set_or_clear_compression_mode<T>(self, v: Option<T>) -> Self

Sets or clears the value of compression_mode.

Example
use google_cloud_compute_v1::model::backend_bucket::CompressionMode;
let x0 = BackendBucket::new().set_or_clear_compression_mode(Some(CompressionMode::Disabled));
let x_none = BackendBucket::new().set_or_clear_compression_mode(None::<CompressionMode>);
pub fn set_creation_timestamp<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of creation_timestamp.

Example
let x = BackendBucket::new().set_creation_timestamp("example");
pub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of creation_timestamp.

Example
let x = BackendBucket::new().set_or_clear_creation_timestamp(Some("example"));
let x = BackendBucket::new().set_or_clear_creation_timestamp(None::<String>);
pub fn set_custom_response_headers<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of custom_response_headers.

Example
let x = BackendBucket::new().set_custom_response_headers(["a", "b", "c"]);
pub fn set_description<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of description.

Example
let x = BackendBucket::new().set_description("example");
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of description.

Example
let x = BackendBucket::new().set_or_clear_description(Some("example"));
let x = BackendBucket::new().set_or_clear_description(None::<String>);
pub fn set_edge_security_policy<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of edge_security_policy.

Example
let x = BackendBucket::new().set_edge_security_policy("example");
pub fn set_or_clear_edge_security_policy<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of edge_security_policy.

Example
let x = BackendBucket::new().set_or_clear_edge_security_policy(Some("example"));
let x = BackendBucket::new().set_or_clear_edge_security_policy(None::<String>);
pub fn set_enable_cdn<T>(self, v: T) -> Self
where T: Into<bool>,

Sets the value of enable_cdn.

Example
let x = BackendBucket::new().set_enable_cdn(true);
pub fn set_or_clear_enable_cdn<T>(self, v: Option<T>) -> Self
where T: Into<bool>,

Sets or clears the value of enable_cdn.

Example
let x = BackendBucket::new().set_or_clear_enable_cdn(Some(false));
let x = BackendBucket::new().set_or_clear_enable_cdn(None::<bool>);
pub fn set_id<T>(self, v: T) -> Self
where T: Into<u64>,

Sets the value of id.

Example
let x = BackendBucket::new().set_id(42_u32);
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
where T: Into<u64>,

Sets or clears the value of id.

Example
let x = BackendBucket::new().set_or_clear_id(Some(42_u32));
let x = BackendBucket::new().set_or_clear_id(None::<u32>);
pub fn set_kind<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of kind.

Example
let x = BackendBucket::new().set_kind("example");
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of kind.

Example
let x = BackendBucket::new().set_or_clear_kind(Some("example"));
let x = BackendBucket::new().set_or_clear_kind(None::<String>);
pub fn set_load_balancing_scheme<T>(self, v: T) -> Self

Sets the value of load_balancing_scheme.

Example
use google_cloud_compute_v1::model::backend_bucket::LoadBalancingScheme;
let x0 = BackendBucket::new().set_load_balancing_scheme(LoadBalancingScheme::InternalManaged);
pub fn set_or_clear_load_balancing_scheme<T>(self, v: Option<T>) -> Self

Sets or clears the value of load_balancing_scheme.

Example
use google_cloud_compute_v1::model::backend_bucket::LoadBalancingScheme;
let x0 = BackendBucket::new().set_or_clear_load_balancing_scheme(Some(LoadBalancingScheme::InternalManaged));
let x_none = BackendBucket::new().set_or_clear_load_balancing_scheme(None::<LoadBalancingScheme>);
pub fn set_name<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of name.

Example
let x = BackendBucket::new().set_name("example");
pub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of name.

Example
let x = BackendBucket::new().set_or_clear_name(Some("example"));
let x = BackendBucket::new().set_or_clear_name(None::<String>);
pub fn set_params<T>(self, v: T) -> Self

Sets the value of params.

Example
use google_cloud_compute_v1::model::BackendBucketParams;
let x = BackendBucket::new().set_params(BackendBucketParams::default()/* use setters */);
pub fn set_or_clear_params<T>(self, v: Option<T>) -> Self

Sets or clears the value of params.

Example
use google_cloud_compute_v1::model::BackendBucketParams;
let x = BackendBucket::new().set_or_clear_params(Some(BackendBucketParams::default()/* use setters */));
let x = BackendBucket::new().set_or_clear_params(None::<BackendBucketParams>);
pub fn set_region<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of region.

Example
let x = BackendBucket::new().set_region("example");
pub fn set_or_clear_region<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of region.

Example
let x = BackendBucket::new().set_or_clear_region(Some("example"));
let x = BackendBucket::new().set_or_clear_region(None::<String>);

Sets the value of self_link.

Example
let x = BackendBucket::new().set_self_link("example");

Sets or clears the value of self_link.

Example
let x = BackendBucket::new().set_or_clear_self_link(Some("example"));
let x = BackendBucket::new().set_or_clear_self_link(None::<String>);
pub fn set_used_by<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<BackendBucketUsedBy>,

Sets the value of used_by.

Example
use google_cloud_compute_v1::model::BackendBucketUsedBy;
let x = BackendBucket::new()
    .set_used_by([
        BackendBucketUsedBy::default()/* use setters */,
        BackendBucketUsedBy::default()/* use (different) setters */,
    ]);