#[non_exhaustive]pub struct BackendBucketListUsable {
pub id: Option<String>,
pub items: Vec<BackendBucket>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
pub self_link: Option<String>,
pub warning: Option<Warning>,
/* private fields */
}backend-buckets or region-backend-buckets only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>[Output Only] Unique identifier for the resource; defined by the server.
items: Vec<BackendBucket>A list of BackendBucket resources.
kind: Option<String>Output only. [Output Only] Type of resource. Alwayscompute#usableBackendBucketList for lists of usable backend buckets.
next_page_token: Option<String>[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
self_link: Option<String>Output only. [Output Only] Server-defined URL for this resource.
warning: Option<Warning>[Output Only] Informational warning message.
Implementations
Sourceimpl BackendBucketListUsable
impl BackendBucketListUsable
Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_next_page_token<T>(self, v: T) -> Self
pub fn set_next_page_token<T>(self, v: T) -> Self
Sets the value of next_page_token.
Example
let x = BackendBucketListUsable::new().set_next_page_token("example");Sourcepub fn set_or_clear_next_page_token<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_next_page_token<T>(self, v: Option<T>) -> Self
Sets or clears the value of next_page_token.
Example
let x = BackendBucketListUsable::new().set_or_clear_next_page_token(Some("example"));
let x = BackendBucketListUsable::new().set_or_clear_next_page_token(None::<String>);Sourcepub fn set_self_link<T>(self, v: T) -> Self
pub fn set_self_link<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
Sourcepub fn set_warning<T>(self, v: T) -> Self
pub fn set_warning<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self
Sets or clears the value of warning.
Example
use google_cloud_compute_v1::model::backend_bucket_list_usable::Warning;
let x = BackendBucketListUsable::new().set_or_clear_warning(Some(Warning::default()/* use setters */));
let x = BackendBucketListUsable::new().set_or_clear_warning(None::<Warning>);Trait Implementations
Sourceimpl Clone for BackendBucketListUsable
impl Clone for BackendBucketListUsable
Sourcefn clone(&self) -> BackendBucketListUsable
fn clone(&self) -> BackendBucketListUsable
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for BackendBucketListUsable
impl Debug for BackendBucketListUsable
Sourceimpl Default for BackendBucketListUsable
impl Default for BackendBucketListUsable
Sourcefn default() -> BackendBucketListUsable
fn default() -> BackendBucketListUsable
Sourceimpl Message for BackendBucketListUsable
impl Message for BackendBucketListUsable
Sourceimpl PartialEq for BackendBucketListUsable
impl PartialEq for BackendBucketListUsable
impl StructuralPartialEq for BackendBucketListUsable