#[non_exhaustive]pub struct BackendServiceLocalityLoadBalancingPolicyConfigPolicy {
pub name: Option<Name>,
/* private fields */
}Available on crate features
backend-services or region-backend-services only.Expand description
The configuration for a built-in load balancing policy.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<Name>The name of a locality load-balancing policy. Valid values include ROUND_ROBIN and, for Java clients, LEAST_REQUEST. For information about these values, see the description of localityLbPolicy.
Do not specify the same policy more than once for a backend. If you do, the configuration is rejected.
Implementations
Sourceimpl BackendServiceLocalityLoadBalancingPolicyConfigPolicy
impl BackendServiceLocalityLoadBalancingPolicyConfigPolicy
Sourcepub fn set_name<T>(self, v: T) -> Self
pub fn set_name<T>(self, v: T) -> Self
Sets the value of name.
Example
ⓘ
use google_cloud_compute_v1::model::backend_service_locality_load_balancing_policy_config_policy::Name;
let x0 = BackendServiceLocalityLoadBalancingPolicyConfigPolicy::new().set_name(Name::LeastRequest);
let x1 = BackendServiceLocalityLoadBalancingPolicyConfigPolicy::new().set_name(Name::Maglev);
let x2 = BackendServiceLocalityLoadBalancingPolicyConfigPolicy::new().set_name(Name::OriginalDestination);Sourcepub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
Sets or clears the value of name.
Example
ⓘ
use google_cloud_compute_v1::model::backend_service_locality_load_balancing_policy_config_policy::Name;
let x0 = BackendServiceLocalityLoadBalancingPolicyConfigPolicy::new().set_or_clear_name(Some(Name::LeastRequest));
let x1 = BackendServiceLocalityLoadBalancingPolicyConfigPolicy::new().set_or_clear_name(Some(Name::Maglev));
let x2 = BackendServiceLocalityLoadBalancingPolicyConfigPolicy::new().set_or_clear_name(Some(Name::OriginalDestination));
let x_none = BackendServiceLocalityLoadBalancingPolicyConfigPolicy::new().set_or_clear_name(None::<Name>);Trait Implementations
Sourceimpl Clone for BackendServiceLocalityLoadBalancingPolicyConfigPolicy
impl Clone for BackendServiceLocalityLoadBalancingPolicyConfigPolicy
Sourcefn clone(&self) -> BackendServiceLocalityLoadBalancingPolicyConfigPolicy
fn clone(&self) -> BackendServiceLocalityLoadBalancingPolicyConfigPolicy
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for BackendServiceLocalityLoadBalancingPolicyConfigPolicy
impl Default for BackendServiceLocalityLoadBalancingPolicyConfigPolicy
Sourcefn default() -> BackendServiceLocalityLoadBalancingPolicyConfigPolicy
fn default() -> BackendServiceLocalityLoadBalancingPolicyConfigPolicy
Returns the “default value” for a type. Read more
impl StructuralPartialEq for BackendServiceLocalityLoadBalancingPolicyConfigPolicy