#[non_exhaustive]pub struct BulkInsertDiskResource {
pub instant_snapshot_group_parameters: Option<InstantSnapshotGroupParameters>,
pub snapshot_group_parameters: Option<SnapshotGroupParameters>,
pub source_consistency_group_policy: Option<String>,
/* private fields */
}Available on crate features
disks or region-disks only.Expand description
A transient resource used in compute.disks.bulkInsert and compute.regionDisks.bulkInsert. It is only used to process requests and is not persisted.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.instant_snapshot_group_parameters: Option<InstantSnapshotGroupParameters>The parameters for the instant snapshot group.
snapshot_group_parameters: Option<SnapshotGroupParameters>The parameters for the snapshot group. The usage of snapshot group feature is restricted.
source_consistency_group_policy: Option<String>The URL of the DiskConsistencyGroupPolicy for the group of disks to clone. This may be a full or partial URL, such as:
- https://www.googleapis.com/compute/v1/projects/project/regions/region/resourcePolicies/resourcePolicy
- projects/project/regions/region/resourcePolicies/resourcePolicy
- regions/region/resourcePolicies/resourcePolicyImplementations
Sourceimpl BulkInsertDiskResource
impl BulkInsertDiskResource
Sourcepub fn set_instant_snapshot_group_parameters<T>(self, v: T) -> Selfwhere
T: Into<InstantSnapshotGroupParameters>,
pub fn set_instant_snapshot_group_parameters<T>(self, v: T) -> Selfwhere
T: Into<InstantSnapshotGroupParameters>,
Sets the value of instant_snapshot_group_parameters.
Example
ⓘ
use google_cloud_compute_v1::model::InstantSnapshotGroupParameters;
let x = BulkInsertDiskResource::new().set_instant_snapshot_group_parameters(InstantSnapshotGroupParameters::default()/* use setters */);Sourcepub fn set_or_clear_instant_snapshot_group_parameters<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<InstantSnapshotGroupParameters>,
pub fn set_or_clear_instant_snapshot_group_parameters<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<InstantSnapshotGroupParameters>,
Sets or clears the value of instant_snapshot_group_parameters.
Example
ⓘ
use google_cloud_compute_v1::model::InstantSnapshotGroupParameters;
let x = BulkInsertDiskResource::new().set_or_clear_instant_snapshot_group_parameters(Some(InstantSnapshotGroupParameters::default()/* use setters */));
let x = BulkInsertDiskResource::new().set_or_clear_instant_snapshot_group_parameters(None::<InstantSnapshotGroupParameters>);Sourcepub fn set_snapshot_group_parameters<T>(self, v: T) -> Selfwhere
T: Into<SnapshotGroupParameters>,
pub fn set_snapshot_group_parameters<T>(self, v: T) -> Selfwhere
T: Into<SnapshotGroupParameters>,
Sets the value of snapshot_group_parameters.
Example
ⓘ
use google_cloud_compute_v1::model::SnapshotGroupParameters;
let x = BulkInsertDiskResource::new().set_snapshot_group_parameters(SnapshotGroupParameters::default()/* use setters */);Sourcepub fn set_or_clear_snapshot_group_parameters<T>(self, v: Option<T>) -> Selfwhere
T: Into<SnapshotGroupParameters>,
pub fn set_or_clear_snapshot_group_parameters<T>(self, v: Option<T>) -> Selfwhere
T: Into<SnapshotGroupParameters>,
Sets or clears the value of snapshot_group_parameters.
Example
ⓘ
use google_cloud_compute_v1::model::SnapshotGroupParameters;
let x = BulkInsertDiskResource::new().set_or_clear_snapshot_group_parameters(Some(SnapshotGroupParameters::default()/* use setters */));
let x = BulkInsertDiskResource::new().set_or_clear_snapshot_group_parameters(None::<SnapshotGroupParameters>);Sourcepub fn set_source_consistency_group_policy<T>(self, v: T) -> Self
pub fn set_source_consistency_group_policy<T>(self, v: T) -> Self
Sets the value of source_consistency_group_policy.
Example
ⓘ
let x = BulkInsertDiskResource::new().set_source_consistency_group_policy("example");Sourcepub fn set_or_clear_source_consistency_group_policy<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_source_consistency_group_policy<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of source_consistency_group_policy.
Example
ⓘ
let x = BulkInsertDiskResource::new().set_or_clear_source_consistency_group_policy(Some("example"));
let x = BulkInsertDiskResource::new().set_or_clear_source_consistency_group_policy(None::<String>);Trait Implementations
Sourceimpl Clone for BulkInsertDiskResource
impl Clone for BulkInsertDiskResource
Sourcefn clone(&self) -> BulkInsertDiskResource
fn clone(&self) -> BulkInsertDiskResource
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BulkInsertDiskResource
impl Debug for BulkInsertDiskResource
Sourceimpl Default for BulkInsertDiskResource
impl Default for BulkInsertDiskResource
Sourcefn default() -> BulkInsertDiskResource
fn default() -> BulkInsertDiskResource
Returns the “default value” for a type. Read more
Sourceimpl Message for BulkInsertDiskResource
impl Message for BulkInsertDiskResource
Sourceimpl PartialEq for BulkInsertDiskResource
impl PartialEq for BulkInsertDiskResource
Sourcefn eq(&self, other: &BulkInsertDiskResource) -> bool
fn eq(&self, other: &BulkInsertDiskResource) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for BulkInsertDiskResource