#[non_exhaustive]pub struct BulkInsertOperationStatus {
pub created_vm_count: Option<i32>,
pub deleted_vm_count: Option<i32>,
pub failed_to_create_vm_count: Option<i32>,
pub status: Option<Status>,
pub target_vm_count: Option<i32>,
/* private fields */
}addresses or autoscalers or backend-buckets or backend-services or cross-site-networks or disks or external-vpn-gateways or firewall-policies or firewalls or forwarding-rules or future-reservations or global-addresses or global-forwarding-rules or global-network-endpoint-groups or global-operations or global-organization-operations or global-public-delegated-prefixes or global-vm-extension-policies or health-checks or http-health-checks or https-health-checks or images or instance-group-manager-resize-requests or instance-group-managers or instance-groups or instance-settings or instance-templates or instances or instant-snapshot-groups or instant-snapshots or interconnect-attachment-groups or interconnect-attachments or interconnect-groups or interconnects or licenses or machine-images or network-attachments or network-edge-security-services or network-endpoint-groups or network-firewall-policies or networks or node-groups or node-templates or organization-security-policies or packet-mirrorings or preview-features or projects or public-advertised-prefixes or public-delegated-prefixes or region-autoscalers or region-backend-buckets or region-backend-services or region-commitments or region-composite-health-checks or region-disks or region-health-aggregation-policies or region-health-check-services or region-health-checks or region-health-sources or region-instance-group-manager-resize-requests or region-instance-group-managers or region-instance-groups or region-instance-templates or region-instances or region-instant-snapshot-groups or region-instant-snapshots or region-network-endpoint-groups or region-network-firewall-policies or region-notification-endpoints or region-operations or region-security-policies or region-snapshot-settings or region-snapshots or region-ssl-certificates or region-ssl-policies or region-target-http-proxies or region-target-https-proxies or region-target-tcp-proxies or region-url-maps or reservation-blocks or reservation-slots or reservation-sub-blocks or reservations or resource-policies or rollout-plans or rollouts or routers or routes or security-policies or service-attachments or snapshot-settings or snapshots or ssl-certificates or ssl-policies or storage-pools or subnetworks or target-grpc-proxies or target-http-proxies or target-https-proxies or target-instances or target-pools or target-ssl-proxies or target-tcp-proxies or target-vpn-gateways or url-maps or vpn-gateways or vpn-tunnels or wire-groups or zone-operations or zone-vm-extension-policies only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.created_vm_count: Option<i32>[Output Only] Count of VMs successfully created so far.
deleted_vm_count: Option<i32>[Output Only] Count of VMs that got deleted during rollback.
failed_to_create_vm_count: Option<i32>[Output Only] Count of VMs that started creating but encountered an error.
status: Option<Status>[Output Only] Creation status of BulkInsert operation - information if the flow is rolling forward or rolling back.
target_vm_count: Option<i32>[Output Only] Count of VMs originally planned to be created.
Implementations
Sourceimpl BulkInsertOperationStatus
impl BulkInsertOperationStatus
Sourcepub fn set_created_vm_count<T>(self, v: T) -> Self
pub fn set_created_vm_count<T>(self, v: T) -> Self
Sets the value of created_vm_count.
Example
let x = BulkInsertOperationStatus::new().set_created_vm_count(42);Sourcepub fn set_or_clear_created_vm_count<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_created_vm_count<T>(self, v: Option<T>) -> Self
Sets or clears the value of created_vm_count.
Example
let x = BulkInsertOperationStatus::new().set_or_clear_created_vm_count(Some(42));
let x = BulkInsertOperationStatus::new().set_or_clear_created_vm_count(None::<i32>);Sourcepub fn set_deleted_vm_count<T>(self, v: T) -> Self
pub fn set_deleted_vm_count<T>(self, v: T) -> Self
Sets the value of deleted_vm_count.
Example
let x = BulkInsertOperationStatus::new().set_deleted_vm_count(42);Sourcepub fn set_or_clear_deleted_vm_count<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_deleted_vm_count<T>(self, v: Option<T>) -> Self
Sets or clears the value of deleted_vm_count.
Example
let x = BulkInsertOperationStatus::new().set_or_clear_deleted_vm_count(Some(42));
let x = BulkInsertOperationStatus::new().set_or_clear_deleted_vm_count(None::<i32>);Sourcepub fn set_failed_to_create_vm_count<T>(self, v: T) -> Self
pub fn set_failed_to_create_vm_count<T>(self, v: T) -> Self
Sets the value of failed_to_create_vm_count.
Example
let x = BulkInsertOperationStatus::new().set_failed_to_create_vm_count(42);Sourcepub fn set_or_clear_failed_to_create_vm_count<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_failed_to_create_vm_count<T>(self, v: Option<T>) -> Self
Sets or clears the value of failed_to_create_vm_count.
Example
let x = BulkInsertOperationStatus::new().set_or_clear_failed_to_create_vm_count(Some(42));
let x = BulkInsertOperationStatus::new().set_or_clear_failed_to_create_vm_count(None::<i32>);Sourcepub fn set_status<T>(self, v: T) -> Self
pub fn set_status<T>(self, v: T) -> Self
Sets the value of status.
Example
use google_cloud_compute_v1::model::bulk_insert_operation_status::Status;
let x0 = BulkInsertOperationStatus::new().set_status(Status::Done);
let x1 = BulkInsertOperationStatus::new().set_status(Status::RollingBack);
let x2 = BulkInsertOperationStatus::new().set_status(Status::Unspecified);Sourcepub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
Sets or clears the value of status.
Example
use google_cloud_compute_v1::model::bulk_insert_operation_status::Status;
let x0 = BulkInsertOperationStatus::new().set_or_clear_status(Some(Status::Done));
let x1 = BulkInsertOperationStatus::new().set_or_clear_status(Some(Status::RollingBack));
let x2 = BulkInsertOperationStatus::new().set_or_clear_status(Some(Status::Unspecified));
let x_none = BulkInsertOperationStatus::new().set_or_clear_status(None::<Status>);Sourcepub fn set_target_vm_count<T>(self, v: T) -> Self
pub fn set_target_vm_count<T>(self, v: T) -> Self
Sets the value of target_vm_count.
Example
let x = BulkInsertOperationStatus::new().set_target_vm_count(42);Sourcepub fn set_or_clear_target_vm_count<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_target_vm_count<T>(self, v: Option<T>) -> Self
Sets or clears the value of target_vm_count.
Example
let x = BulkInsertOperationStatus::new().set_or_clear_target_vm_count(Some(42));
let x = BulkInsertOperationStatus::new().set_or_clear_target_vm_count(None::<i32>);Trait Implementations
Sourceimpl Clone for BulkInsertOperationStatus
impl Clone for BulkInsertOperationStatus
Sourcefn clone(&self) -> BulkInsertOperationStatus
fn clone(&self) -> BulkInsertOperationStatus
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for BulkInsertOperationStatus
impl Debug for BulkInsertOperationStatus
Sourceimpl Default for BulkInsertOperationStatus
impl Default for BulkInsertOperationStatus
Sourcefn default() -> BulkInsertOperationStatus
fn default() -> BulkInsertOperationStatus
Sourceimpl Message for BulkInsertOperationStatus
impl Message for BulkInsertOperationStatus
impl StructuralPartialEq for BulkInsertOperationStatus