CachePolicy

Struct CachePolicy 

#[non_exhaustive]
pub struct CachePolicy { pub cache_bypass_request_header_names: Vec<String>, pub cache_key_policy: Option<CachePolicyCacheKeyPolicy>, pub cache_mode: Option<CacheMode>, pub client_ttl: Option<Duration>, pub default_ttl: Option<Duration>, pub max_ttl: Option<Duration>, pub negative_caching: Option<bool>, pub negative_caching_policy: Vec<CachePolicyNegativeCachingPolicy>, pub request_coalescing: Option<bool>, pub serve_while_stale: Option<Duration>, /* private fields */ }
Available on crate features region-url-maps or url-maps only.
Message containing CachePolicy configuration for URL Map’s Route Action.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
cache_bypass_request_header_names: Vec<String>

Bypass the cache when the specified request headers are matched by name, e.g. Pragma or Authorization headers. Values are case-insensitive. Up to 5 header names can be specified. The cache is bypassed for all cacheMode values.

cache_key_policy: Option<CachePolicyCacheKeyPolicy>

The cache key configuration. If not specified, the default behavior depends on the backend type: for Backend Services, the complete request URI is used; for Backend Buckets, the request URI is used without the protocol or host, and only query parameters known to Cloud Storage are included.

cache_mode: Option<CacheMode>

Specifies the cache setting for all responses from this route. If not specified, Cloud CDN uses CACHE_ALL_STATIC mode.

client_ttl: Option<Duration>

Specifies a separate client (e.g. browser client) maximum TTL for cached content. This is used to clamp the max-age (or Expires) value sent to the client. With FORCE_CACHE_ALL, the lesser of clientTtl and defaultTtl is used for the response max-age directive, along with a “public” directive. For cacheable content in CACHE_ALL_STATIC mode, clientTtl clamps the max-age from the origin (if specified), or else sets the response max-age directive to the lesser of the clientTtl and defaultTtl, and also ensures a “public” cache-control directive is present. The maximum allowed value is 31,622,400s (1 year). If not specified, Cloud CDN uses 3600s (1 hour) for CACHE_ALL_STATIC mode. Cannot exceed maxTtl. Cannot be specified when cacheMode is USE_ORIGIN_HEADERS.

default_ttl: Option<Duration>

Specifies the default TTL for cached content for responses that do not have an existing valid TTL (max-age or s-maxage). Setting a TTL of “0” means “always revalidate”. The value of defaultTtl cannot be set to a value greater than that of maxTtl. When the cacheMode is set to FORCE_CACHE_ALL, the defaultTtl will overwrite the TTL set in all responses. The maximum allowed value is 31,622,400s (1 year). Infrequently accessed objects may be evicted from the cache before the defined TTL. If not specified, Cloud CDN uses 3600s (1 hour) for CACHE_ALL_STATIC and FORCE_CACHE_ALL modes. Cannot be specified when cacheMode is USE_ORIGIN_HEADERS.

max_ttl: Option<Duration>

Specifies the maximum allowed TTL for cached content. Cache directives that attempt to set a max-age or s-maxage higher than this, or an Expires header more than maxTtl seconds in the future will be capped at the value of maxTtl, as if it were the value of an s-maxage Cache-Control directive. Headers sent to the client will not be modified. Setting a TTL of “0” means “always revalidate”. The maximum allowed value is 31,622,400s (1 year). Infrequently accessed objects may be evicted from the cache before the defined TTL. If not specified, Cloud CDN uses 86400s (1 day) for CACHE_ALL_STATIC mode. Can be specified only for CACHE_ALL_STATIC cache mode.

negative_caching: Option<bool>

Negative caching allows per-status code TTLs to be set, in order to apply fine-grained caching for common errors or redirects. This can reduce the load on your origin and improve end-user experience by reducing response latency. When the cacheMode is set to CACHE_ALL_STATIC or USE_ORIGIN_HEADERS, negative caching applies to responses with the specified response code that lack any Cache-Control, Expires, or Pragma: no-cache directives. When the cacheMode is set to FORCE_CACHE_ALL, negative caching applies to all responses with the specified response code, and overrides any caching headers. By default, Cloud CDN applies the following TTLs to these HTTP status codes:

  • 300 (Multiple Choice), 301, 308 (Permanent Redirects): 10m
  • 404 (Not Found), 410 (Gone), 451 (Unavailable For Legal Reasons): 120s
  • 405 (Method Not Found), 501 (Not Implemented): 60s

These defaults can be overridden in negativeCachingPolicy. If not specified, Cloud CDN applies negative caching by default.

negative_caching_policy: Vec<CachePolicyNegativeCachingPolicy>

Sets a cache TTL for the specified HTTP status code. negativeCaching must be enabled to configure negativeCachingPolicy. Omitting the policy and leaving negativeCaching enabled will use Cloud CDN’s default cache TTLs. Note that when specifying an explicit negativeCachingPolicy, you should take care to specify a cache TTL for all response codes that you wish to cache. Cloud CDN will not apply any default negative caching when a policy exists.

request_coalescing: Option<bool>

If true then Cloud CDN will combine multiple concurrent cache fill requests into a small number of requests to the origin. If not specified, Cloud CDN applies request coalescing by default.

serve_while_stale: Option<Duration>

Serve existing content from the cache (if available) when revalidating content with the origin, or when an error is encountered when refreshing the cache. This setting defines the default “max-stale” duration for any cached responses that do not specify a max-stale directive. Stale responses that exceed the TTL configured here will not be served. The default limit (max-stale) is 86400s (1 day), which will allow stale content to be served up to this limit beyond the max-age (or s-maxage) of a cached response. The maximum allowed value is 604800 (1 week). Set this to zero (0) to disable serve-while-stale.

Implementations

Source

impl CachePolicy

pub fn new() -> Self

Creates a new default instance.

pub fn set_cache_bypass_request_header_names<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of cache_bypass_request_header_names.

Example
let x = CachePolicy::new().set_cache_bypass_request_header_names(["a", "b", "c"]);
pub fn set_cache_key_policy<T>(self, v: T) -> Self

Sets the value of cache_key_policy.

Example
use google_cloud_compute_v1::model::CachePolicyCacheKeyPolicy;
let x = CachePolicy::new().set_cache_key_policy(CachePolicyCacheKeyPolicy::default()/* use setters */);
pub fn set_or_clear_cache_key_policy<T>(self, v: Option<T>) -> Self

Sets or clears the value of cache_key_policy.

Example
use google_cloud_compute_v1::model::CachePolicyCacheKeyPolicy;
let x = CachePolicy::new().set_or_clear_cache_key_policy(Some(CachePolicyCacheKeyPolicy::default()/* use setters */));
let x = CachePolicy::new().set_or_clear_cache_key_policy(None::<CachePolicyCacheKeyPolicy>);
pub fn set_cache_mode<T>(self, v: T) -> Self
where T: Into<CacheMode>,

Sets the value of cache_mode.

Example
use google_cloud_compute_v1::model::cache_policy::CacheMode;
let x0 = CachePolicy::new().set_cache_mode(CacheMode::ForceCacheAll);
let x1 = CachePolicy::new().set_cache_mode(CacheMode::UseOriginHeaders);
pub fn set_or_clear_cache_mode<T>(self, v: Option<T>) -> Self
where T: Into<CacheMode>,

Sets or clears the value of cache_mode.

Example
use google_cloud_compute_v1::model::cache_policy::CacheMode;
let x0 = CachePolicy::new().set_or_clear_cache_mode(Some(CacheMode::ForceCacheAll));
let x1 = CachePolicy::new().set_or_clear_cache_mode(Some(CacheMode::UseOriginHeaders));
let x_none = CachePolicy::new().set_or_clear_cache_mode(None::<CacheMode>);
pub fn set_client_ttl<T>(self, v: T) -> Self
where T: Into<Duration>,

Sets the value of client_ttl.

Example
use google_cloud_compute_v1::model::Duration;
let x = CachePolicy::new().set_client_ttl(Duration::default()/* use setters */);
pub fn set_or_clear_client_ttl<T>(self, v: Option<T>) -> Self
where T: Into<Duration>,

Sets or clears the value of client_ttl.

Example
use google_cloud_compute_v1::model::Duration;
let x = CachePolicy::new().set_or_clear_client_ttl(Some(Duration::default()/* use setters */));
let x = CachePolicy::new().set_or_clear_client_ttl(None::<Duration>);
pub fn set_default_ttl<T>(self, v: T) -> Self
where T: Into<Duration>,

Sets the value of default_ttl.

Example
use google_cloud_compute_v1::model::Duration;
let x = CachePolicy::new().set_default_ttl(Duration::default()/* use setters */);
pub fn set_or_clear_default_ttl<T>(self, v: Option<T>) -> Self
where T: Into<Duration>,

Sets or clears the value of default_ttl.

Example
use google_cloud_compute_v1::model::Duration;
let x = CachePolicy::new().set_or_clear_default_ttl(Some(Duration::default()/* use setters */));
let x = CachePolicy::new().set_or_clear_default_ttl(None::<Duration>);
pub fn set_max_ttl<T>(self, v: T) -> Self
where T: Into<Duration>,

Sets the value of max_ttl.

Example
use google_cloud_compute_v1::model::Duration;
let x = CachePolicy::new().set_max_ttl(Duration::default()/* use setters */);
pub fn set_or_clear_max_ttl<T>(self, v: Option<T>) -> Self
where T: Into<Duration>,

Sets or clears the value of max_ttl.

Example
use google_cloud_compute_v1::model::Duration;
let x = CachePolicy::new().set_or_clear_max_ttl(Some(Duration::default()/* use setters */));
let x = CachePolicy::new().set_or_clear_max_ttl(None::<Duration>);
pub fn set_negative_caching<T>(self, v: T) -> Self
where T: Into<bool>,

Sets the value of negative_caching.

Example
let x = CachePolicy::new().set_negative_caching(true);
pub fn set_or_clear_negative_caching<T>(self, v: Option<T>) -> Self
where T: Into<bool>,

Sets or clears the value of negative_caching.

Example
let x = CachePolicy::new().set_or_clear_negative_caching(Some(false));
let x = CachePolicy::new().set_or_clear_negative_caching(None::<bool>);
pub fn set_negative_caching_policy<T, V>(self, v: T) -> Self

Sets the value of negative_caching_policy.

Example
use google_cloud_compute_v1::model::CachePolicyNegativeCachingPolicy;
let x = CachePolicy::new()
    .set_negative_caching_policy([
        CachePolicyNegativeCachingPolicy::default()/* use setters */,
        CachePolicyNegativeCachingPolicy::default()/* use (different) setters */,
    ]);
pub fn set_request_coalescing<T>(self, v: T) -> Self
where T: Into<bool>,

Sets the value of request_coalescing.

Example
let x = CachePolicy::new().set_request_coalescing(true);
pub fn set_or_clear_request_coalescing<T>(self, v: Option<T>) -> Self
where T: Into<bool>,

Sets or clears the value of request_coalescing.

Example
let x = CachePolicy::new().set_or_clear_request_coalescing(Some(false));
let x = CachePolicy::new().set_or_clear_request_coalescing(None::<bool>);
pub fn set_serve_while_stale<T>(self, v: T) -> Self
where T: Into<Duration>,

Sets the value of serve_while_stale.

Example
use google_cloud_compute_v1::model::Duration;
let x = CachePolicy::new().set_serve_while_stale(Duration::default()/* use setters */);
pub fn set_or_clear_serve_while_stale<T>(self, v: Option<T>) -> Self
where T: Into<Duration>,

Sets or clears the value of serve_while_stale.

Example
use google_cloud_compute_v1::model::Duration;
let x = CachePolicy::new().set_or_clear_serve_while_stale(Some(Duration::default()/* use setters */));
let x = CachePolicy::new().set_or_clear_serve_while_stale(None::<Duration>);