#[non_exhaustive]pub struct CompositeHealthCheck {
pub creation_timestamp: Option<String>,
pub description: Option<String>,
pub fingerprint: Option<Bytes>,
pub health_destination: Option<String>,
pub health_sources: Vec<String>,
pub id: Option<u64>,
pub kind: Option<String>,
pub name: Option<String>,
pub region: Option<String>,
pub self_link: Option<String>,
pub self_link_with_id: Option<String>,
/* private fields */
}region-composite-health-checks only.Expand description
Represents a composite health check.
A composite health check resource specifies the health source resources and the health destination resource to which the aggregated health result from the health source resources is delivered.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.creation_timestamp: Option<String>Output only. [Output Only] Creation timestamp inRFC3339 text format.
description: Option<String>An optional description of this resource. Provide this property when you create the resource.
fingerprint: Option<Bytes>Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a CompositeHealthCheck. An up-to-date fingerprint must be provided in order to patch the CompositeHealthCheck; Otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the CompositeHealthCheck.
health_destination: Option<String>URL to the destination resource. Must be set. Must be aForwardingRule. The ForwardingRule must have load balancing scheme INTERNAL orINTERNAL_MANAGED and must be regional and in the same region as the CompositeHealthCheck (cross-region deployment forINTERNAL_MANAGED is not supported). Can be mutated.
health_sources: Vec<String>URLs to the HealthSource resources whose results are AND’ed. I.e. he aggregated result is is HEALTHY only if all sources are HEALTHY. Must have at least 1. Must not have more than 10. Must be regional and in the same region as theCompositeHealthCheck. Can be mutated.
id: Option<u64>Output only. [Output Only] A unique identifier for this resource type. The server generates this identifier.
kind: Option<String>Output only. [Output Only] Type of the resource. Alwayscompute#compositeHealthCheck for composite health checks.
name: Option<String>Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
region: Option<String>Output only. [Output Only] URL of the region where the composite health check resides. This field applies only to the regional resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
self_link: Option<String>Output only. [Output Only] Server-defined URL for the resource.
self_link_with_id: Option<String>Output only. [Output Only] Server-defined URL with id for the resource.
Implementations
Sourceimpl CompositeHealthCheck
impl CompositeHealthCheck
pub fn new() -> Self
Sourcepub fn set_creation_timestamp<T>(self, v: T) -> Self
pub fn set_creation_timestamp<T>(self, v: T) -> Self
Sets the value of creation_timestamp.
Example
let x = CompositeHealthCheck::new().set_creation_timestamp("example");Sourcepub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
Sets or clears the value of creation_timestamp.
Example
let x = CompositeHealthCheck::new().set_or_clear_creation_timestamp(Some("example"));
let x = CompositeHealthCheck::new().set_or_clear_creation_timestamp(None::<String>);Sourcepub fn set_description<T>(self, v: T) -> Self
pub fn set_description<T>(self, v: T) -> Self
Sets the value of description.
Example
let x = CompositeHealthCheck::new().set_description("example");Sourcepub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
Sets or clears the value of description.
Example
let x = CompositeHealthCheck::new().set_or_clear_description(Some("example"));
let x = CompositeHealthCheck::new().set_or_clear_description(None::<String>);Sourcepub fn set_fingerprint<T>(self, v: T) -> Self
pub fn set_fingerprint<T>(self, v: T) -> Self
Sets the value of fingerprint.
Example
let x = CompositeHealthCheck::new().set_fingerprint(bytes::Bytes::from_static(b"example"));Sourcepub fn set_or_clear_fingerprint<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_fingerprint<T>(self, v: Option<T>) -> Self
Sets or clears the value of fingerprint.
Example
let x = CompositeHealthCheck::new().set_or_clear_fingerprint(Some(bytes::Bytes::from_static(b"example")));
let x = CompositeHealthCheck::new().set_or_clear_fingerprint(None::<bytes::Bytes>);Sourcepub fn set_health_destination<T>(self, v: T) -> Self
pub fn set_health_destination<T>(self, v: T) -> Self
Sets the value of health_destination.
Example
let x = CompositeHealthCheck::new().set_health_destination("example");Sourcepub fn set_or_clear_health_destination<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_health_destination<T>(self, v: Option<T>) -> Self
Sets or clears the value of health_destination.
Example
let x = CompositeHealthCheck::new().set_or_clear_health_destination(Some("example"));
let x = CompositeHealthCheck::new().set_or_clear_health_destination(None::<String>);Sourcepub fn set_health_sources<T, V>(self, v: T) -> Self
pub fn set_health_sources<T, V>(self, v: T) -> Self
Sets the value of health_sources.
Example
let x = CompositeHealthCheck::new().set_health_sources(["a", "b", "c"]);Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
Sourcepub fn set_region<T>(self, v: T) -> Self
pub fn set_region<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_region<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_region<T>(self, v: Option<T>) -> Self
Sourcepub fn set_self_link<T>(self, v: T) -> Self
pub fn set_self_link<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
Sourcepub fn set_self_link_with_id<T>(self, v: T) -> Self
pub fn set_self_link_with_id<T>(self, v: T) -> Self
Sets the value of self_link_with_id.
Example
let x = CompositeHealthCheck::new().set_self_link_with_id("example");Sourcepub fn set_or_clear_self_link_with_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link_with_id<T>(self, v: Option<T>) -> Self
Sets or clears the value of self_link_with_id.
Example
let x = CompositeHealthCheck::new().set_or_clear_self_link_with_id(Some("example"));
let x = CompositeHealthCheck::new().set_or_clear_self_link_with_id(None::<String>);Trait Implementations
Sourceimpl Clone for CompositeHealthCheck
impl Clone for CompositeHealthCheck
Sourcefn clone(&self) -> CompositeHealthCheck
fn clone(&self) -> CompositeHealthCheck
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more