#[non_exhaustive]pub struct CompositeHealthCheckList {
pub id: Option<String>,
pub items: Vec<CompositeHealthCheck>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
pub self_link: Option<String>,
pub warning: Option<Warning>,
/* private fields */
}region-composite-health-checks only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>[Output Only] Unique identifier for the resource; defined by the server.
items: Vec<CompositeHealthCheck>A list of CompositeHealthCheck resources.
kind: Option<String>Output only. [Output Only] Type of the resource. Alwayscompute#compositeHealthCheck for composite health checks.
next_page_token: Option<String>[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
self_link: Option<String>[Output Only] Server-defined URL for this resource.
warning: Option<Warning>[Output Only] Informational warning message.
Implementations
Sourceimpl CompositeHealthCheckList
impl CompositeHealthCheckList
Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_next_page_token<T>(self, v: T) -> Self
pub fn set_next_page_token<T>(self, v: T) -> Self
Sets the value of next_page_token.
Example
let x = CompositeHealthCheckList::new().set_next_page_token("example");Sourcepub fn set_or_clear_next_page_token<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_next_page_token<T>(self, v: Option<T>) -> Self
Sets or clears the value of next_page_token.
Example
let x = CompositeHealthCheckList::new().set_or_clear_next_page_token(Some("example"));
let x = CompositeHealthCheckList::new().set_or_clear_next_page_token(None::<String>);Sourcepub fn set_self_link<T>(self, v: T) -> Self
pub fn set_self_link<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
Sourcepub fn set_warning<T>(self, v: T) -> Self
pub fn set_warning<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self
Sets or clears the value of warning.
Example
use google_cloud_compute_v1::model::composite_health_check_list::Warning;
let x = CompositeHealthCheckList::new().set_or_clear_warning(Some(Warning::default()/* use setters */));
let x = CompositeHealthCheckList::new().set_or_clear_warning(None::<Warning>);Trait Implementations
Sourceimpl Clone for CompositeHealthCheckList
impl Clone for CompositeHealthCheckList
Sourcefn clone(&self) -> CompositeHealthCheckList
fn clone(&self) -> CompositeHealthCheckList
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CompositeHealthCheckList
impl Debug for CompositeHealthCheckList
Sourceimpl Default for CompositeHealthCheckList
impl Default for CompositeHealthCheckList
Sourcefn default() -> CompositeHealthCheckList
fn default() -> CompositeHealthCheckList
Sourceimpl Message for CompositeHealthCheckList
impl Message for CompositeHealthCheckList
Sourceimpl PartialEq for CompositeHealthCheckList
impl PartialEq for CompositeHealthCheckList
impl StructuralPartialEq for CompositeHealthCheckList