#[non_exhaustive]pub struct DiskUpdateKmsKeyRequest {
pub kms_key_name: Option<String>,
/* private fields */
}Available on crate feature
disks only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.kms_key_name: Option<String>Optional. The new KMS key to replace the current one on the disk. If empty, the disk will be re-encrypted using the primary version of the disk’s current KMS key.
The KMS key can be provided in the following formats:
- projects/project_id/locations/location/keyRings/key_ring/cryptoKeys/keyWhere project is the project ID or project number.
Implementations
Sourceimpl DiskUpdateKmsKeyRequest
impl DiskUpdateKmsKeyRequest
Sourcepub fn set_kms_key_name<T>(self, v: T) -> Self
pub fn set_kms_key_name<T>(self, v: T) -> Self
Sets the value of kms_key_name.
Example
ⓘ
let x = DiskUpdateKmsKeyRequest::new().set_kms_key_name("example");Sourcepub fn set_or_clear_kms_key_name<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kms_key_name<T>(self, v: Option<T>) -> Self
Sets or clears the value of kms_key_name.
Example
ⓘ
let x = DiskUpdateKmsKeyRequest::new().set_or_clear_kms_key_name(Some("example"));
let x = DiskUpdateKmsKeyRequest::new().set_or_clear_kms_key_name(None::<String>);Trait Implementations
Sourceimpl Clone for DiskUpdateKmsKeyRequest
impl Clone for DiskUpdateKmsKeyRequest
Sourcefn clone(&self) -> DiskUpdateKmsKeyRequest
fn clone(&self) -> DiskUpdateKmsKeyRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DiskUpdateKmsKeyRequest
impl Debug for DiskUpdateKmsKeyRequest
Sourceimpl Default for DiskUpdateKmsKeyRequest
impl Default for DiskUpdateKmsKeyRequest
Sourcefn default() -> DiskUpdateKmsKeyRequest
fn default() -> DiskUpdateKmsKeyRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for DiskUpdateKmsKeyRequest
impl Message for DiskUpdateKmsKeyRequest
Sourceimpl PartialEq for DiskUpdateKmsKeyRequest
impl PartialEq for DiskUpdateKmsKeyRequest
Sourcefn eq(&self, other: &DiskUpdateKmsKeyRequest) -> bool
fn eq(&self, other: &DiskUpdateKmsKeyRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DiskUpdateKmsKeyRequest