DistributionPolicy

Struct DistributionPolicy 

#[non_exhaustive]
pub struct DistributionPolicy { pub target_shape: Option<TargetShape>, pub zones: Vec<DistributionPolicyZoneConfiguration>, /* private fields */ }
Available on crate features instance-group-managers or region-instance-group-managers only.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
target_shape: Option<TargetShape>

The distribution shape to which the group converges either proactively or on resize events (depending on the value set inupdatePolicy.instanceRedistributionType).

zones: Vec<DistributionPolicyZoneConfiguration>

Zones where the regional managed instance group will create and manage its instances. By default, a regional MIG doesn’t automatically select an AI zone to create instances, even if an AI zone is available in the specified region. To create instances in an AI zone in the selected region, you must explicitly specify it in the distribution policy together with the other preferred zones.

Implementations

Source

impl DistributionPolicy

pub fn new() -> Self

pub fn set_target_shape<T>(self, v: T) -> Self
where T: Into<TargetShape>,

Sets the value of target_shape.

Example
use google_cloud_compute_v1::model::distribution_policy::TargetShape;
let x0 = DistributionPolicy::new().set_target_shape(TargetShape::AnySingleZone);
let x1 = DistributionPolicy::new().set_target_shape(TargetShape::Balanced);
let x2 = DistributionPolicy::new().set_target_shape(TargetShape::Even);
pub fn set_or_clear_target_shape<T>(self, v: Option<T>) -> Self
where T: Into<TargetShape>,

Sets or clears the value of target_shape.

Example
use google_cloud_compute_v1::model::distribution_policy::TargetShape;
let x0 = DistributionPolicy::new().set_or_clear_target_shape(Some(TargetShape::AnySingleZone));
let x1 = DistributionPolicy::new().set_or_clear_target_shape(Some(TargetShape::Balanced));
let x2 = DistributionPolicy::new().set_or_clear_target_shape(Some(TargetShape::Even));
let x_none = DistributionPolicy::new().set_or_clear_target_shape(None::<TargetShape>);
pub fn set_zones<T, V>(self, v: T) -> Self

Sets the value of zones.

Example
use google_cloud_compute_v1::model::DistributionPolicyZoneConfiguration;
let x = DistributionPolicy::new()
    .set_zones([
        DistributionPolicyZoneConfiguration::default()/* use setters */,
        DistributionPolicyZoneConfiguration::default()/* use (different) setters */,
    ]);