#[non_exhaustive]pub struct Expr {
pub description: Option<String>,
pub expression: Option<String>,
pub location: Option<String>,
pub title: Option<String>,
/* private fields */
}backend-buckets or backend-services or disks or firewall-policies or images or instance-templates or instances or instant-snapshot-groups or instant-snapshots or interconnect-attachment-groups or interconnect-groups or license-codes or licenses or machine-images or network-attachments or network-firewall-policies or node-groups or node-templates or organization-security-policies or region-backend-buckets or region-backend-services or region-disks or region-instant-snapshot-groups or region-instant-snapshots or region-network-firewall-policies or region-security-policies or region-snapshots or reservation-blocks or reservation-sub-blocks or reservations or resource-policies or routers or security-policies or service-attachments or snapshots or storage-pools or subnetworks only.Expand description
Represents a textual expression in the Common Expression Language (CEL) syntax. CEL is a C-like expression language. The syntax and semantics of CEL are documented at https://github.com/google/cel-spec.
Example (Comparison):
title: "Summary size limit"
description: "Determines if a summary is less than 100 chars"
expression: "document.summary.size() < 100"Example (Equality):
title: "Requestor is owner"
description: "Determines if requestor is the document owner"
expression: "document.owner == request.auth.claims.email"Example (Logic):
title: "Public documents"
description: "Determine whether the document should be publicly visible"
expression: "document.type != 'private' && document.type != 'internal'"Example (Data Manipulation):
title: "Notification string"
description: "Create a notification string with a timestamp."
expression: "'New message received at ' + string(document.create_time)"The exact variables and functions that may be referenced within an expression are determined by the service that evaluates it. See the service documentation for additional information.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.description: Option<String>Optional. Description of the expression. This is a longer text which describes the expression, e.g. when hovered over it in a UI.
expression: Option<String>Textual representation of an expression in Common Expression Language syntax.
location: Option<String>Optional. String indicating the location of the expression for error reporting, e.g. a file name and a position in the file.
title: Option<String>Optional. Title for the expression, i.e. a short string describing its purpose. This can be used e.g. in UIs which allow to enter the expression.
Implementations
Sourceimpl Expr
impl Expr
Sourcepub fn set_description<T>(self, v: T) -> Self
pub fn set_description<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
Sets or clears the value of description.
Example
let x = Expr::new().set_or_clear_description(Some("example"));
let x = Expr::new().set_or_clear_description(None::<String>);Sourcepub fn set_expression<T>(self, v: T) -> Self
pub fn set_expression<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_expression<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_expression<T>(self, v: Option<T>) -> Self
Sets or clears the value of expression.
Example
let x = Expr::new().set_or_clear_expression(Some("example"));
let x = Expr::new().set_or_clear_expression(None::<String>);Sourcepub fn set_location<T>(self, v: T) -> Self
pub fn set_location<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_location<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_location<T>(self, v: Option<T>) -> Self