#[non_exhaustive]pub struct FutureReservationStatusLastKnownGoodState {
pub description: Option<String>,
pub existing_matching_usage_info: Option<FutureReservationStatusExistingMatchingUsageInfo>,
pub future_reservation_specs: Option<FutureReservationStatusLastKnownGoodStateFutureReservationSpecs>,
pub lock_time: Option<String>,
pub name_prefix: Option<String>,
pub procurement_status: Option<ProcurementStatus>,
/* private fields */
}future-reservations only.Expand description
The state that the future reservation will be reverted to should the amendment be declined.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.description: Option<String>Output only. [Output Only] The description of the FutureReservation before an amendment was requested.
existing_matching_usage_info: Option<FutureReservationStatusExistingMatchingUsageInfo>Output only. [Output Only] Represents the matching usage for the future reservation before an amendment was requested.
future_reservation_specs: Option<FutureReservationStatusLastKnownGoodStateFutureReservationSpecs>lock_time: Option<String>Output only. [Output Only] The lock time of the FutureReservation before an amendment was requested.
name_prefix: Option<String>Output only. [Output Only] The name prefix of the Future Reservation before an amendment was requested.
procurement_status: Option<ProcurementStatus>Output only. [Output Only] The status of the last known good state for the Future Reservation.
Implementations
Sourceimpl FutureReservationStatusLastKnownGoodState
impl FutureReservationStatusLastKnownGoodState
Sourcepub fn set_description<T>(self, v: T) -> Self
pub fn set_description<T>(self, v: T) -> Self
Sets the value of description.
Example
let x = FutureReservationStatusLastKnownGoodState::new().set_description("example");Sourcepub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
Sets or clears the value of description.
Example
let x = FutureReservationStatusLastKnownGoodState::new().set_or_clear_description(Some("example"));
let x = FutureReservationStatusLastKnownGoodState::new().set_or_clear_description(None::<String>);Sourcepub fn set_existing_matching_usage_info<T>(self, v: T) -> Self
pub fn set_existing_matching_usage_info<T>(self, v: T) -> Self
Sets the value of existing_matching_usage_info.
Example
use google_cloud_compute_v1::model::FutureReservationStatusExistingMatchingUsageInfo;
let x = FutureReservationStatusLastKnownGoodState::new().set_existing_matching_usage_info(FutureReservationStatusExistingMatchingUsageInfo::default()/* use setters */);Sourcepub fn set_or_clear_existing_matching_usage_info<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_existing_matching_usage_info<T>(self, v: Option<T>) -> Self
Sets or clears the value of existing_matching_usage_info.
Example
use google_cloud_compute_v1::model::FutureReservationStatusExistingMatchingUsageInfo;
let x = FutureReservationStatusLastKnownGoodState::new().set_or_clear_existing_matching_usage_info(Some(FutureReservationStatusExistingMatchingUsageInfo::default()/* use setters */));
let x = FutureReservationStatusLastKnownGoodState::new().set_or_clear_existing_matching_usage_info(None::<FutureReservationStatusExistingMatchingUsageInfo>);Sourcepub fn set_future_reservation_specs<T>(self, v: T) -> Self
pub fn set_future_reservation_specs<T>(self, v: T) -> Self
Sets the value of future_reservation_specs.
Example
use google_cloud_compute_v1::model::FutureReservationStatusLastKnownGoodStateFutureReservationSpecs;
let x = FutureReservationStatusLastKnownGoodState::new().set_future_reservation_specs(FutureReservationStatusLastKnownGoodStateFutureReservationSpecs::default()/* use setters */);Sourcepub fn set_or_clear_future_reservation_specs<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_future_reservation_specs<T>(self, v: Option<T>) -> Self
Sets or clears the value of future_reservation_specs.
Example
use google_cloud_compute_v1::model::FutureReservationStatusLastKnownGoodStateFutureReservationSpecs;
let x = FutureReservationStatusLastKnownGoodState::new().set_or_clear_future_reservation_specs(Some(FutureReservationStatusLastKnownGoodStateFutureReservationSpecs::default()/* use setters */));
let x = FutureReservationStatusLastKnownGoodState::new().set_or_clear_future_reservation_specs(None::<FutureReservationStatusLastKnownGoodStateFutureReservationSpecs>);Sourcepub fn set_lock_time<T>(self, v: T) -> Self
pub fn set_lock_time<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_lock_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_lock_time<T>(self, v: Option<T>) -> Self
Sourcepub fn set_name_prefix<T>(self, v: T) -> Self
pub fn set_name_prefix<T>(self, v: T) -> Self
Sets the value of name_prefix.
Example
let x = FutureReservationStatusLastKnownGoodState::new().set_name_prefix("example");Sourcepub fn set_or_clear_name_prefix<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_name_prefix<T>(self, v: Option<T>) -> Self
Sets or clears the value of name_prefix.
Example
let x = FutureReservationStatusLastKnownGoodState::new().set_or_clear_name_prefix(Some("example"));
let x = FutureReservationStatusLastKnownGoodState::new().set_or_clear_name_prefix(None::<String>);Sourcepub fn set_procurement_status<T>(self, v: T) -> Selfwhere
T: Into<ProcurementStatus>,
pub fn set_procurement_status<T>(self, v: T) -> Selfwhere
T: Into<ProcurementStatus>,
Sets the value of procurement_status.
Example
use google_cloud_compute_v1::model::future_reservation_status_last_known_good_state::ProcurementStatus;
let x0 = FutureReservationStatusLastKnownGoodState::new().set_procurement_status(ProcurementStatus::Cancelled);
let x1 = FutureReservationStatusLastKnownGoodState::new().set_procurement_status(ProcurementStatus::Committed);
let x2 = FutureReservationStatusLastKnownGoodState::new().set_procurement_status(ProcurementStatus::Declined);Sourcepub fn set_or_clear_procurement_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<ProcurementStatus>,
pub fn set_or_clear_procurement_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<ProcurementStatus>,
Sets or clears the value of procurement_status.
Example
use google_cloud_compute_v1::model::future_reservation_status_last_known_good_state::ProcurementStatus;
let x0 = FutureReservationStatusLastKnownGoodState::new().set_or_clear_procurement_status(Some(ProcurementStatus::Cancelled));
let x1 = FutureReservationStatusLastKnownGoodState::new().set_or_clear_procurement_status(Some(ProcurementStatus::Committed));
let x2 = FutureReservationStatusLastKnownGoodState::new().set_or_clear_procurement_status(Some(ProcurementStatus::Declined));
let x_none = FutureReservationStatusLastKnownGoodState::new().set_or_clear_procurement_status(None::<ProcurementStatus>);Trait Implementations
Sourceimpl Clone for FutureReservationStatusLastKnownGoodState
impl Clone for FutureReservationStatusLastKnownGoodState
Sourcefn clone(&self) -> FutureReservationStatusLastKnownGoodState
fn clone(&self) -> FutureReservationStatusLastKnownGoodState
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for FutureReservationStatusLastKnownGoodState
impl Default for FutureReservationStatusLastKnownGoodState
Sourcefn default() -> FutureReservationStatusLastKnownGoodState
fn default() -> FutureReservationStatusLastKnownGoodState
impl StructuralPartialEq for FutureReservationStatusLastKnownGoodState