#[non_exhaustive]pub struct GetVersionOperationMetadataSbomInfo {
pub current_component_versions: HashMap<String, String>,
pub target_component_versions: HashMap<String, String>,
/* private fields */
}Available on crate features
addresses or autoscalers or backend-buckets or backend-services or cross-site-networks or disks or external-vpn-gateways or firewall-policies or firewalls or forwarding-rules or future-reservations or global-addresses or global-forwarding-rules or global-network-endpoint-groups or global-operations or global-organization-operations or global-public-delegated-prefixes or health-checks or http-health-checks or https-health-checks or images or instance-group-manager-resize-requests or instance-group-managers or instance-groups or instance-settings or instance-templates or instances or instant-snapshots or interconnect-attachment-groups or interconnect-attachments or interconnect-groups or interconnects or licenses or machine-images or network-attachments or network-edge-security-services or network-endpoint-groups or network-firewall-policies or networks or node-groups or node-templates or organization-security-policies or packet-mirrorings or preview-features or projects or public-advertised-prefixes or public-delegated-prefixes or region-autoscalers or region-backend-services or region-commitments or region-composite-health-checks or region-disks or region-health-aggregation-policies or region-health-check-services or region-health-checks or region-health-sources or region-instance-group-managers or region-instance-groups or region-instance-templates or region-instances or region-instant-snapshots or region-network-endpoint-groups or region-network-firewall-policies or region-notification-endpoints or region-operations or region-security-policies or region-ssl-certificates or region-ssl-policies or region-target-http-proxies or region-target-https-proxies or region-target-tcp-proxies or region-url-maps or reservation-blocks or reservation-slots or reservation-sub-blocks or reservations or resource-policies or routers or routes or security-policies or service-attachments or snapshot-settings or snapshots or ssl-certificates or ssl-policies or storage-pools or subnetworks or target-grpc-proxies or target-http-proxies or target-https-proxies or target-instances or target-pools or target-ssl-proxies or target-tcp-proxies or target-vpn-gateways or url-maps or vpn-gateways or vpn-tunnels or wire-groups or zone-operations only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.current_component_versions: HashMap<String, String>SBOM versions currently applied to the resource. The key is the component name and the value is the version.
target_component_versions: HashMap<String, String>SBOM versions scheduled for the next maintenance. The key is the component name and the value is the version.
Implementations
Sourceimpl GetVersionOperationMetadataSbomInfo
impl GetVersionOperationMetadataSbomInfo
pub fn new() -> Self
Sourcepub fn set_current_component_versions<T, K, V>(self, v: T) -> Self
pub fn set_current_component_versions<T, K, V>(self, v: T) -> Self
Sets the value of current_component_versions.
Example
ⓘ
let x = GetVersionOperationMetadataSbomInfo::new().set_current_component_versions([
("key0", "abc"),
("key1", "xyz"),
]);Sourcepub fn set_target_component_versions<T, K, V>(self, v: T) -> Self
pub fn set_target_component_versions<T, K, V>(self, v: T) -> Self
Sets the value of target_component_versions.
Example
ⓘ
let x = GetVersionOperationMetadataSbomInfo::new().set_target_component_versions([
("key0", "abc"),
("key1", "xyz"),
]);Trait Implementations
Sourceimpl Clone for GetVersionOperationMetadataSbomInfo
impl Clone for GetVersionOperationMetadataSbomInfo
Sourcefn clone(&self) -> GetVersionOperationMetadataSbomInfo
fn clone(&self) -> GetVersionOperationMetadataSbomInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for GetVersionOperationMetadataSbomInfo
impl Default for GetVersionOperationMetadataSbomInfo
Sourcefn default() -> GetVersionOperationMetadataSbomInfo
fn default() -> GetVersionOperationMetadataSbomInfo
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for GetVersionOperationMetadataSbomInfo
impl PartialEq for GetVersionOperationMetadataSbomInfo
Sourcefn eq(&self, other: &GetVersionOperationMetadataSbomInfo) -> bool
fn eq(&self, other: &GetVersionOperationMetadataSbomInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for GetVersionOperationMetadataSbomInfo