GlobalVmExtensionPolicy

Struct GlobalVmExtensionPolicy 

#[non_exhaustive]
pub struct GlobalVmExtensionPolicy {
Show 13 fields pub creation_timestamp: Option<String>, pub description: Option<String>, pub extension_policies: HashMap<String, GlobalVmExtensionPolicyExtensionPolicy>, pub id: Option<u64>, pub instance_selectors: Vec<GlobalVmExtensionPolicyInstanceSelector>, pub kind: Option<String>, pub name: Option<String>, pub priority: Option<i32>, pub rollout_operation: Option<GlobalVmExtensionPolicyRolloutOperation>, pub scoped_resource_status: Option<ScopedResourceStatus>, pub self_link: Option<String>, pub self_link_with_id: Option<String>, pub update_timestamp: Option<String>, /* private fields */
}
Available on crate feature global-vm-extension-policies only.
Message describing GlobalVmExtensionPolicy object.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
creation_timestamp: Option<String>

Output only. [Output Only] Creation timestamp inRFC3339 text format.

description: Option<String>

An optional description of this resource. Provide this property when you create the resource.

extension_policies: HashMap<String, GlobalVmExtensionPolicyExtensionPolicy>

Required. Map from extension (eg: “cloudops”) to its policy configuration. The key is the name of the extension.

id: Option<u64>

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.

instance_selectors: Vec<GlobalVmExtensionPolicyInstanceSelector>

Optional. Selector to target VMs for a policy. There is a logical “AND” between instance_selectors.

kind: Option<String>

Output only. [Output Only] Type of the resource. Alwayscompute#globalVmExtensionPolicy for globalVmExtensionPolicies.

name: Option<String>

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.

priority: Option<i32>

Optional. Used to resolve conflicts when multiple policies are active for the same extension. Defaults to 0.

Larger the number, higher the priority. When the priority is the same, the policy with the newer create time has higher priority.

rollout_operation: Option<GlobalVmExtensionPolicyRolloutOperation>

Required. The rollout strategy and status.

scoped_resource_status: Option<ScopedResourceStatus>

Output only. [Output Only] The scoped resource status. It’s only for tracking the purging status of the policy.

self_link: Option<String>

Output only. [Output Only] Server-defined fully-qualified URL for this resource.

self_link_with_id: Option<String>

Output only. [Output Only] Server-defined URL for this resource’s resource id.

update_timestamp: Option<String>

Output only. [Output Only] Update timestamp inRFC3339 text format.

Implementations

Source

impl GlobalVmExtensionPolicy

pub fn new() -> Self

Creates a new default instance.

pub fn set_creation_timestamp<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of creation_timestamp.

Example
let x = GlobalVmExtensionPolicy::new().set_creation_timestamp("example");
pub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of creation_timestamp.

Example
let x = GlobalVmExtensionPolicy::new().set_or_clear_creation_timestamp(Some("example"));
let x = GlobalVmExtensionPolicy::new().set_or_clear_creation_timestamp(None::<String>);
pub fn set_description<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of description.

Example
let x = GlobalVmExtensionPolicy::new().set_description("example");
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of description.

Example
let x = GlobalVmExtensionPolicy::new().set_or_clear_description(Some("example"));
let x = GlobalVmExtensionPolicy::new().set_or_clear_description(None::<String>);
pub fn set_extension_policies<T, K, V>(self, v: T) -> Self

Sets the value of extension_policies.

Example
use google_cloud_compute_v1::model::GlobalVmExtensionPolicyExtensionPolicy;
let x = GlobalVmExtensionPolicy::new().set_extension_policies([
    ("key0", GlobalVmExtensionPolicyExtensionPolicy::default()/* use setters */),
    ("key1", GlobalVmExtensionPolicyExtensionPolicy::default()/* use (different) setters */),
]);
pub fn set_id<T>(self, v: T) -> Self
where T: Into<u64>,

Sets the value of id.

Example
let x = GlobalVmExtensionPolicy::new().set_id(42_u32);
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
where T: Into<u64>,

Sets or clears the value of id.

Example
let x = GlobalVmExtensionPolicy::new().set_or_clear_id(Some(42_u32));
let x = GlobalVmExtensionPolicy::new().set_or_clear_id(None::<u32>);
pub fn set_instance_selectors<T, V>(self, v: T) -> Self

Sets the value of instance_selectors.

Example
use google_cloud_compute_v1::model::GlobalVmExtensionPolicyInstanceSelector;
let x = GlobalVmExtensionPolicy::new()
    .set_instance_selectors([
        GlobalVmExtensionPolicyInstanceSelector::default()/* use setters */,
        GlobalVmExtensionPolicyInstanceSelector::default()/* use (different) setters */,
    ]);
pub fn set_kind<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of kind.

Example
let x = GlobalVmExtensionPolicy::new().set_kind("example");
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of kind.

Example
let x = GlobalVmExtensionPolicy::new().set_or_clear_kind(Some("example"));
let x = GlobalVmExtensionPolicy::new().set_or_clear_kind(None::<String>);
pub fn set_name<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of name.

Example
let x = GlobalVmExtensionPolicy::new().set_name("example");
pub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of name.

Example
let x = GlobalVmExtensionPolicy::new().set_or_clear_name(Some("example"));
let x = GlobalVmExtensionPolicy::new().set_or_clear_name(None::<String>);
pub fn set_priority<T>(self, v: T) -> Self
where T: Into<i32>,

Sets the value of priority.

Example
let x = GlobalVmExtensionPolicy::new().set_priority(42);
pub fn set_or_clear_priority<T>(self, v: Option<T>) -> Self
where T: Into<i32>,

Sets or clears the value of priority.

Example
let x = GlobalVmExtensionPolicy::new().set_or_clear_priority(Some(42));
let x = GlobalVmExtensionPolicy::new().set_or_clear_priority(None::<i32>);
pub fn set_rollout_operation<T>(self, v: T) -> Self

Sets the value of rollout_operation.

Example
use google_cloud_compute_v1::model::GlobalVmExtensionPolicyRolloutOperation;
let x = GlobalVmExtensionPolicy::new().set_rollout_operation(GlobalVmExtensionPolicyRolloutOperation::default()/* use setters */);
pub fn set_or_clear_rollout_operation<T>(self, v: Option<T>) -> Self

Sets or clears the value of rollout_operation.

Example
use google_cloud_compute_v1::model::GlobalVmExtensionPolicyRolloutOperation;
let x = GlobalVmExtensionPolicy::new().set_or_clear_rollout_operation(Some(GlobalVmExtensionPolicyRolloutOperation::default()/* use setters */));
let x = GlobalVmExtensionPolicy::new().set_or_clear_rollout_operation(None::<GlobalVmExtensionPolicyRolloutOperation>);
pub fn set_scoped_resource_status<T>(self, v: T) -> Self

Sets the value of scoped_resource_status.

Example
use google_cloud_compute_v1::model::global_vm_extension_policy::ScopedResourceStatus;
let x0 = GlobalVmExtensionPolicy::new().set_scoped_resource_status(ScopedResourceStatus::Unspecified);
pub fn set_or_clear_scoped_resource_status<T>(self, v: Option<T>) -> Self

Sets or clears the value of scoped_resource_status.

Example
use google_cloud_compute_v1::model::global_vm_extension_policy::ScopedResourceStatus;
let x0 = GlobalVmExtensionPolicy::new().set_or_clear_scoped_resource_status(Some(ScopedResourceStatus::Unspecified));
let x_none = GlobalVmExtensionPolicy::new().set_or_clear_scoped_resource_status(None::<ScopedResourceStatus>);

Sets the value of self_link.

Example
let x = GlobalVmExtensionPolicy::new().set_self_link("example");

Sets or clears the value of self_link.

Example
let x = GlobalVmExtensionPolicy::new().set_or_clear_self_link(Some("example"));
let x = GlobalVmExtensionPolicy::new().set_or_clear_self_link(None::<String>);

Sets the value of self_link_with_id.

Example
let x = GlobalVmExtensionPolicy::new().set_self_link_with_id("example");

Sets or clears the value of self_link_with_id.

Example
let x = GlobalVmExtensionPolicy::new().set_or_clear_self_link_with_id(Some("example"));
let x = GlobalVmExtensionPolicy::new().set_or_clear_self_link_with_id(None::<String>);
pub fn set_update_timestamp<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of update_timestamp.

Example
let x = GlobalVmExtensionPolicy::new().set_update_timestamp("example");
pub fn set_or_clear_update_timestamp<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of update_timestamp.

Example
let x = GlobalVmExtensionPolicy::new().set_or_clear_update_timestamp(Some("example"));
let x = GlobalVmExtensionPolicy::new().set_or_clear_update_timestamp(None::<String>);