#[non_exhaustive]pub struct GroupMaintenanceInfo {
pub instance_maintenance_ongoing_count: Option<i32>,
pub instance_maintenance_pending_count: Option<i32>,
pub maintenance_ongoing_count: Option<i32>,
pub maintenance_pending_count: Option<i32>,
pub scheduling_type: Option<SchedulingType>,
pub subblock_infra_maintenance_ongoing_count: Option<i32>,
pub subblock_infra_maintenance_pending_count: Option<i32>,
pub upcoming_group_maintenance: Option<UpcomingMaintenance>,
/* private fields */
}region-commitments or reservation-blocks or reservation-sub-blocks or reservations only.Expand description
Maintenance Info for ReservationBlocks.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.instance_maintenance_ongoing_count: Option<i32>Describes number of instances that have ongoing maintenance.
instance_maintenance_pending_count: Option<i32>Describes number of instances that have pending maintenance.
maintenance_ongoing_count: Option<i32>Progress for ongoing maintenance for this group of VMs/hosts. Describes number of hosts in the block that have ongoing maintenance.
maintenance_pending_count: Option<i32>Progress for ongoing maintenance for this group of VMs/hosts. Describes number of hosts in the block that have pending maintenance.
scheduling_type: Option<SchedulingType>The type of maintenance for the reservation.
subblock_infra_maintenance_ongoing_count: Option<i32>Describes number of subblock Infrastructure that has ongoing maintenance. Here, Subblock Infrastructure Maintenance pertains to upstream hardware contained in the Subblock that is necessary for a VM Family(e.g. NVLink Domains). Not all VM Families will support this field.
subblock_infra_maintenance_pending_count: Option<i32>Describes number of subblock Infrastructure that has pending maintenance. Here, Subblock Infrastructure Maintenance pertains to upstream hardware contained in the Subblock that is necessary for a VM Family (e.g. NVLink Domains). Not all VM Families will support this field.
upcoming_group_maintenance: Option<UpcomingMaintenance>Maintenance information on this group of VMs.
Implementations
Sourceimpl GroupMaintenanceInfo
impl GroupMaintenanceInfo
Sourcepub fn set_instance_maintenance_ongoing_count<T>(self, v: T) -> Self
pub fn set_instance_maintenance_ongoing_count<T>(self, v: T) -> Self
Sets the value of instance_maintenance_ongoing_count.
Example
let x = GroupMaintenanceInfo::new().set_instance_maintenance_ongoing_count(42);Sourcepub fn set_or_clear_instance_maintenance_ongoing_count<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_instance_maintenance_ongoing_count<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of instance_maintenance_ongoing_count.
Example
let x = GroupMaintenanceInfo::new().set_or_clear_instance_maintenance_ongoing_count(Some(42));
let x = GroupMaintenanceInfo::new().set_or_clear_instance_maintenance_ongoing_count(None::<i32>);Sourcepub fn set_instance_maintenance_pending_count<T>(self, v: T) -> Self
pub fn set_instance_maintenance_pending_count<T>(self, v: T) -> Self
Sets the value of instance_maintenance_pending_count.
Example
let x = GroupMaintenanceInfo::new().set_instance_maintenance_pending_count(42);Sourcepub fn set_or_clear_instance_maintenance_pending_count<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_instance_maintenance_pending_count<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of instance_maintenance_pending_count.
Example
let x = GroupMaintenanceInfo::new().set_or_clear_instance_maintenance_pending_count(Some(42));
let x = GroupMaintenanceInfo::new().set_or_clear_instance_maintenance_pending_count(None::<i32>);Sourcepub fn set_maintenance_ongoing_count<T>(self, v: T) -> Self
pub fn set_maintenance_ongoing_count<T>(self, v: T) -> Self
Sets the value of maintenance_ongoing_count.
Example
let x = GroupMaintenanceInfo::new().set_maintenance_ongoing_count(42);Sourcepub fn set_or_clear_maintenance_ongoing_count<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_maintenance_ongoing_count<T>(self, v: Option<T>) -> Self
Sets or clears the value of maintenance_ongoing_count.
Example
let x = GroupMaintenanceInfo::new().set_or_clear_maintenance_ongoing_count(Some(42));
let x = GroupMaintenanceInfo::new().set_or_clear_maintenance_ongoing_count(None::<i32>);Sourcepub fn set_maintenance_pending_count<T>(self, v: T) -> Self
pub fn set_maintenance_pending_count<T>(self, v: T) -> Self
Sets the value of maintenance_pending_count.
Example
let x = GroupMaintenanceInfo::new().set_maintenance_pending_count(42);Sourcepub fn set_or_clear_maintenance_pending_count<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_maintenance_pending_count<T>(self, v: Option<T>) -> Self
Sets or clears the value of maintenance_pending_count.
Example
let x = GroupMaintenanceInfo::new().set_or_clear_maintenance_pending_count(Some(42));
let x = GroupMaintenanceInfo::new().set_or_clear_maintenance_pending_count(None::<i32>);Sourcepub fn set_scheduling_type<T>(self, v: T) -> Selfwhere
T: Into<SchedulingType>,
pub fn set_scheduling_type<T>(self, v: T) -> Selfwhere
T: Into<SchedulingType>,
Sets the value of scheduling_type.
Example
use google_cloud_compute_v1::model::group_maintenance_info::SchedulingType;
let x0 = GroupMaintenanceInfo::new().set_scheduling_type(SchedulingType::GroupMaintenanceTypeUnspecified);
let x1 = GroupMaintenanceInfo::new().set_scheduling_type(SchedulingType::Independent);Sourcepub fn set_or_clear_scheduling_type<T>(self, v: Option<T>) -> Selfwhere
T: Into<SchedulingType>,
pub fn set_or_clear_scheduling_type<T>(self, v: Option<T>) -> Selfwhere
T: Into<SchedulingType>,
Sets or clears the value of scheduling_type.
Example
use google_cloud_compute_v1::model::group_maintenance_info::SchedulingType;
let x0 = GroupMaintenanceInfo::new().set_or_clear_scheduling_type(Some(SchedulingType::GroupMaintenanceTypeUnspecified));
let x1 = GroupMaintenanceInfo::new().set_or_clear_scheduling_type(Some(SchedulingType::Independent));
let x_none = GroupMaintenanceInfo::new().set_or_clear_scheduling_type(None::<SchedulingType>);Sourcepub fn set_subblock_infra_maintenance_ongoing_count<T>(self, v: T) -> Self
pub fn set_subblock_infra_maintenance_ongoing_count<T>(self, v: T) -> Self
Sets the value of subblock_infra_maintenance_ongoing_count.
Example
let x = GroupMaintenanceInfo::new().set_subblock_infra_maintenance_ongoing_count(42);Sourcepub fn set_or_clear_subblock_infra_maintenance_ongoing_count<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_subblock_infra_maintenance_ongoing_count<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of subblock_infra_maintenance_ongoing_count.
Example
let x = GroupMaintenanceInfo::new().set_or_clear_subblock_infra_maintenance_ongoing_count(Some(42));
let x = GroupMaintenanceInfo::new().set_or_clear_subblock_infra_maintenance_ongoing_count(None::<i32>);Sourcepub fn set_subblock_infra_maintenance_pending_count<T>(self, v: T) -> Self
pub fn set_subblock_infra_maintenance_pending_count<T>(self, v: T) -> Self
Sets the value of subblock_infra_maintenance_pending_count.
Example
let x = GroupMaintenanceInfo::new().set_subblock_infra_maintenance_pending_count(42);Sourcepub fn set_or_clear_subblock_infra_maintenance_pending_count<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_subblock_infra_maintenance_pending_count<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of subblock_infra_maintenance_pending_count.
Example
let x = GroupMaintenanceInfo::new().set_or_clear_subblock_infra_maintenance_pending_count(Some(42));
let x = GroupMaintenanceInfo::new().set_or_clear_subblock_infra_maintenance_pending_count(None::<i32>);Sourcepub fn set_upcoming_group_maintenance<T>(self, v: T) -> Selfwhere
T: Into<UpcomingMaintenance>,
pub fn set_upcoming_group_maintenance<T>(self, v: T) -> Selfwhere
T: Into<UpcomingMaintenance>,
Sets the value of upcoming_group_maintenance.
Example
use google_cloud_compute_v1::model::UpcomingMaintenance;
let x = GroupMaintenanceInfo::new().set_upcoming_group_maintenance(UpcomingMaintenance::default()/* use setters */);Sourcepub fn set_or_clear_upcoming_group_maintenance<T>(self, v: Option<T>) -> Selfwhere
T: Into<UpcomingMaintenance>,
pub fn set_or_clear_upcoming_group_maintenance<T>(self, v: Option<T>) -> Selfwhere
T: Into<UpcomingMaintenance>,
Sets or clears the value of upcoming_group_maintenance.
Example
use google_cloud_compute_v1::model::UpcomingMaintenance;
let x = GroupMaintenanceInfo::new().set_or_clear_upcoming_group_maintenance(Some(UpcomingMaintenance::default()/* use setters */));
let x = GroupMaintenanceInfo::new().set_or_clear_upcoming_group_maintenance(None::<UpcomingMaintenance>);Trait Implementations
Sourceimpl Clone for GroupMaintenanceInfo
impl Clone for GroupMaintenanceInfo
Sourcefn clone(&self) -> GroupMaintenanceInfo
fn clone(&self) -> GroupMaintenanceInfo
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for GroupMaintenanceInfo
impl Debug for GroupMaintenanceInfo
Sourceimpl Default for GroupMaintenanceInfo
impl Default for GroupMaintenanceInfo
Sourcefn default() -> GroupMaintenanceInfo
fn default() -> GroupMaintenanceInfo
Sourceimpl Message for GroupMaintenanceInfo
impl Message for GroupMaintenanceInfo
Sourceimpl PartialEq for GroupMaintenanceInfo
impl PartialEq for GroupMaintenanceInfo
impl StructuralPartialEq for GroupMaintenanceInfo