#[non_exhaustive]pub struct HealthCheckServicesScopedList {
pub resources: Vec<HealthCheckService>,
pub warning: Option<Warning>,
/* private fields */
}Available on crate feature
region-health-check-services only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resources: Vec<HealthCheckService>A list of HealthCheckServices contained in this scope.
warning: Option<Warning>Informational warning which replaces the list of backend services when the list is empty.
Implementations
Sourceimpl HealthCheckServicesScopedList
impl HealthCheckServicesScopedList
Sourcepub fn set_resources<T, V>(self, v: T) -> Self
pub fn set_resources<T, V>(self, v: T) -> Self
Sourcepub fn set_warning<T>(self, v: T) -> Self
pub fn set_warning<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self
Sets or clears the value of warning.
Example
ⓘ
use google_cloud_compute_v1::model::health_check_services_scoped_list::Warning;
let x = HealthCheckServicesScopedList::new().set_or_clear_warning(Some(Warning::default()/* use setters */));
let x = HealthCheckServicesScopedList::new().set_or_clear_warning(None::<Warning>);Trait Implementations
Sourceimpl Clone for HealthCheckServicesScopedList
impl Clone for HealthCheckServicesScopedList
Sourcefn clone(&self) -> HealthCheckServicesScopedList
fn clone(&self) -> HealthCheckServicesScopedList
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for HealthCheckServicesScopedList
impl Default for HealthCheckServicesScopedList
Sourcefn default() -> HealthCheckServicesScopedList
fn default() -> HealthCheckServicesScopedList
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for HealthCheckServicesScopedList
impl PartialEq for HealthCheckServicesScopedList
Sourcefn eq(&self, other: &HealthCheckServicesScopedList) -> bool
fn eq(&self, other: &HealthCheckServicesScopedList) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for HealthCheckServicesScopedList