HealthSource

Struct HealthSource 

#[non_exhaustive]
pub struct HealthSource { pub creation_timestamp: Option<String>, pub description: Option<String>, pub fingerprint: Option<Bytes>, pub health_aggregation_policy: Option<String>, pub id: Option<u64>, pub kind: Option<String>, pub name: Option<String>, pub region: Option<String>, pub self_link: Option<String>, pub self_link_with_id: Option<String>, pub source_type: Option<SourceType>, pub sources: Vec<String>, /* private fields */ }
Available on crate feature region-health-sources only.
Represents a health source.

A health source resource specifies the source resources and the health aggregation policy applied to the source resources to determine the aggregated health status.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
creation_timestamp: Option<String>

Output only. [Output Only] Creation timestamp inRFC3339 text format.

description: Option<String>

An optional description of this resource. Provide this property when you create the resource.

fingerprint: Option<Bytes>

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a HealthSource. An up-to-date fingerprint must be provided in order to patch the HealthSource; Otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the HealthSource.

health_aggregation_policy: Option<String>

URL to the HealthAggregationPolicy resource. Must be set. Must be regional and in the same region as the HealthSource. Can be mutated.

id: Option<u64>

Output only. [Output Only] A unique identifier for this resource type. The server generates this identifier.

kind: Option<String>

Output only. [Output Only] Type of the resource. Alwayscompute#healthSource for health sources.

name: Option<String>

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.

region: Option<String>

Output only. [Output Only] URL of the region where the health source resides. This field applies only to the regional resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.

self_link: Option<String>

Output only. [Output Only] Server-defined URL for the resource.

self_link_with_id: Option<String>

Output only. [Output Only] Server-defined URL with id for the resource.

source_type: Option<SourceType>

Specifies the type of the HealthSource. The only allowed value is BACKEND_SERVICE. Must be specified when theHealthSource is created, and cannot be mutated.

sources: Vec<String>

URLs to the source resources. Must be size 1. Must be aBackendService if the sourceType is BACKEND_SERVICE. TheBackendService must have load balancing schemeINTERNAL or INTERNAL_MANAGED and must be regional and in the same region as the HealthSource (cross-region deployment for INTERNAL_MANAGED is not supported). TheBackendService may use only IGs, MIGs, or NEGs of typeGCE_VM_IP or GCE_VM_IP_PORT. TheBackendService may not use haPolicy. Can be mutated.

Implementations

Source

impl HealthSource

pub fn new() -> Self

pub fn set_creation_timestamp<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of creation_timestamp.

Example
let x = HealthSource::new().set_creation_timestamp("example");
pub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of creation_timestamp.

Example
let x = HealthSource::new().set_or_clear_creation_timestamp(Some("example"));
let x = HealthSource::new().set_or_clear_creation_timestamp(None::<String>);
pub fn set_description<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of description.

Example
let x = HealthSource::new().set_description("example");
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of description.

Example
let x = HealthSource::new().set_or_clear_description(Some("example"));
let x = HealthSource::new().set_or_clear_description(None::<String>);
pub fn set_fingerprint<T>(self, v: T) -> Self
where T: Into<Bytes>,

Sets the value of fingerprint.

Example
let x = HealthSource::new().set_fingerprint(bytes::Bytes::from_static(b"example"));
pub fn set_or_clear_fingerprint<T>(self, v: Option<T>) -> Self
where T: Into<Bytes>,

Sets or clears the value of fingerprint.

Example
let x = HealthSource::new().set_or_clear_fingerprint(Some(bytes::Bytes::from_static(b"example")));
let x = HealthSource::new().set_or_clear_fingerprint(None::<bytes::Bytes>);
pub fn set_health_aggregation_policy<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of health_aggregation_policy.

Example
let x = HealthSource::new().set_health_aggregation_policy("example");
pub fn set_or_clear_health_aggregation_policy<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of health_aggregation_policy.

Example
let x = HealthSource::new().set_or_clear_health_aggregation_policy(Some("example"));
let x = HealthSource::new().set_or_clear_health_aggregation_policy(None::<String>);
pub fn set_id<T>(self, v: T) -> Self
where T: Into<u64>,

Sets the value of id.

Example
let x = HealthSource::new().set_id(42_u32);
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
where T: Into<u64>,

Sets or clears the value of id.

Example
let x = HealthSource::new().set_or_clear_id(Some(42_u32));
let x = HealthSource::new().set_or_clear_id(None::<u32>);
pub fn set_kind<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of kind.

Example
let x = HealthSource::new().set_kind("example");
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of kind.

Example
let x = HealthSource::new().set_or_clear_kind(Some("example"));
let x = HealthSource::new().set_or_clear_kind(None::<String>);
pub fn set_name<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of name.

Example
let x = HealthSource::new().set_name("example");
pub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of name.

Example
let x = HealthSource::new().set_or_clear_name(Some("example"));
let x = HealthSource::new().set_or_clear_name(None::<String>);
pub fn set_region<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of region.

Example
let x = HealthSource::new().set_region("example");
pub fn set_or_clear_region<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of region.

Example
let x = HealthSource::new().set_or_clear_region(Some("example"));
let x = HealthSource::new().set_or_clear_region(None::<String>);

Sets the value of self_link.

Example
let x = HealthSource::new().set_self_link("example");

Sets or clears the value of self_link.

Example
let x = HealthSource::new().set_or_clear_self_link(Some("example"));
let x = HealthSource::new().set_or_clear_self_link(None::<String>);

Sets the value of self_link_with_id.

Example
let x = HealthSource::new().set_self_link_with_id("example");

Sets or clears the value of self_link_with_id.

Example
let x = HealthSource::new().set_or_clear_self_link_with_id(Some("example"));
let x = HealthSource::new().set_or_clear_self_link_with_id(None::<String>);
pub fn set_source_type<T>(self, v: T) -> Self
where T: Into<SourceType>,

Sets the value of source_type.

Example
use google_cloud_compute_v1::model::health_source::SourceType;
let x0 = HealthSource::new().set_source_type(SourceType::BackendService);
pub fn set_or_clear_source_type<T>(self, v: Option<T>) -> Self
where T: Into<SourceType>,

Sets or clears the value of source_type.

Example
use google_cloud_compute_v1::model::health_source::SourceType;
let x0 = HealthSource::new().set_or_clear_source_type(Some(SourceType::BackendService));
let x_none = HealthSource::new().set_or_clear_source_type(None::<SourceType>);
pub fn set_sources<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of sources.

Example
let x = HealthSource::new().set_sources(["a", "b", "c"]);