#[non_exhaustive]pub struct HealthSourcesGetHealthResponseSourceInfo {
pub backends: Vec<HealthSourcesGetHealthResponseSourceInfoBackendInfo>,
pub forwarding_rule: Option<String>,
pub source: Option<String>,
/* private fields */
}Available on crate feature
region-health-sources only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.backends: Vec<HealthSourcesGetHealthResponseSourceInfoBackendInfo>Represents an instance group or network endpoint group behind the source backend service. Only used if the sourceType of the regionHealthSource is BACKEND_SERVICE.
forwarding_rule: Option<String>Fully qualified URL of the forwarding rule associated with the source resource if it is a L4ILB backend service.
source: Option<String>Fully qualified URL of the associated source resource. This is always a backend service URL.
Implementations
Sourceimpl HealthSourcesGetHealthResponseSourceInfo
impl HealthSourcesGetHealthResponseSourceInfo
Sourcepub fn set_backends<T, V>(self, v: T) -> Self
pub fn set_backends<T, V>(self, v: T) -> Self
Sets the value of backends.
Example
ⓘ
use google_cloud_compute_v1::model::HealthSourcesGetHealthResponseSourceInfoBackendInfo;
let x = HealthSourcesGetHealthResponseSourceInfo::new()
.set_backends([
HealthSourcesGetHealthResponseSourceInfoBackendInfo::default()/* use setters */,
HealthSourcesGetHealthResponseSourceInfoBackendInfo::default()/* use (different) setters */,
]);Sourcepub fn set_forwarding_rule<T>(self, v: T) -> Self
pub fn set_forwarding_rule<T>(self, v: T) -> Self
Sets the value of forwarding_rule.
Example
ⓘ
let x = HealthSourcesGetHealthResponseSourceInfo::new().set_forwarding_rule("example");Sourcepub fn set_or_clear_forwarding_rule<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_forwarding_rule<T>(self, v: Option<T>) -> Self
Sets or clears the value of forwarding_rule.
Example
ⓘ
let x = HealthSourcesGetHealthResponseSourceInfo::new().set_or_clear_forwarding_rule(Some("example"));
let x = HealthSourcesGetHealthResponseSourceInfo::new().set_or_clear_forwarding_rule(None::<String>);Sourcepub fn set_source<T>(self, v: T) -> Self
pub fn set_source<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_source<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_source<T>(self, v: Option<T>) -> Self