#[non_exhaustive]pub struct HealthSourcesGetHealthResponseSourceInfoBackendInfo {
pub endpoint_count: Option<i32>,
pub group: Option<String>,
pub healthy_endpoint_count: Option<i32>,
/* private fields */
}Available on crate feature
region-health-sources only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.endpoint_count: Option<i32>Total number of endpoints when determining the health of the regionHealthSource.
group: Option<String>Fully qualified URL of an instance group or network endpoint group behind the source backend service.
healthy_endpoint_count: Option<i32>Number of endpoints considered healthy when determining health of the regionHealthSource.
Implementations
Sourceimpl HealthSourcesGetHealthResponseSourceInfoBackendInfo
impl HealthSourcesGetHealthResponseSourceInfoBackendInfo
Sourcepub fn set_endpoint_count<T>(self, v: T) -> Self
pub fn set_endpoint_count<T>(self, v: T) -> Self
Sets the value of endpoint_count.
Example
ⓘ
let x = HealthSourcesGetHealthResponseSourceInfoBackendInfo::new().set_endpoint_count(42);Sourcepub fn set_or_clear_endpoint_count<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_endpoint_count<T>(self, v: Option<T>) -> Self
Sets or clears the value of endpoint_count.
Example
ⓘ
let x = HealthSourcesGetHealthResponseSourceInfoBackendInfo::new().set_or_clear_endpoint_count(Some(42));
let x = HealthSourcesGetHealthResponseSourceInfoBackendInfo::new().set_or_clear_endpoint_count(None::<i32>);Sourcepub fn set_or_clear_group<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_group<T>(self, v: Option<T>) -> Self
Sourcepub fn set_healthy_endpoint_count<T>(self, v: T) -> Self
pub fn set_healthy_endpoint_count<T>(self, v: T) -> Self
Sets the value of healthy_endpoint_count.
Example
ⓘ
let x = HealthSourcesGetHealthResponseSourceInfoBackendInfo::new().set_healthy_endpoint_count(42);Sourcepub fn set_or_clear_healthy_endpoint_count<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_healthy_endpoint_count<T>(self, v: Option<T>) -> Self
Sets or clears the value of healthy_endpoint_count.
Example
ⓘ
let x = HealthSourcesGetHealthResponseSourceInfoBackendInfo::new().set_or_clear_healthy_endpoint_count(Some(42));
let x = HealthSourcesGetHealthResponseSourceInfoBackendInfo::new().set_or_clear_healthy_endpoint_count(None::<i32>);Trait Implementations
Sourceimpl Clone for HealthSourcesGetHealthResponseSourceInfoBackendInfo
impl Clone for HealthSourcesGetHealthResponseSourceInfoBackendInfo
Sourcefn clone(&self) -> HealthSourcesGetHealthResponseSourceInfoBackendInfo
fn clone(&self) -> HealthSourcesGetHealthResponseSourceInfoBackendInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for HealthSourcesGetHealthResponseSourceInfoBackendInfo
impl Default for HealthSourcesGetHealthResponseSourceInfoBackendInfo
Sourcefn default() -> HealthSourcesGetHealthResponseSourceInfoBackendInfo
fn default() -> HealthSourcesGetHealthResponseSourceInfoBackendInfo
Returns the “default value” for a type. Read more
impl StructuralPartialEq for HealthSourcesGetHealthResponseSourceInfoBackendInfo