#[non_exhaustive]pub struct HealthStatusForNetworkEndpoint {
pub backend_service: Option<BackendServiceReference>,
pub forwarding_rule: Option<ForwardingRuleReference>,
pub health_check: Option<HealthCheckReference>,
pub health_check_service: Option<HealthCheckServiceReference>,
pub health_state: Option<HealthState>,
pub ipv_6_health_state: Option<Ipv6HealthState>,
/* private fields */
}global-network-endpoint-groups or network-endpoint-groups or region-network-endpoint-groups only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.backend_service: Option<BackendServiceReference>URL of the backend service associated with the health state of the network endpoint.
forwarding_rule: Option<ForwardingRuleReference>URL of the forwarding rule associated with the health state of the network endpoint.
health_check: Option<HealthCheckReference>URL of the health check associated with the health state of the network endpoint.
health_check_service: Option<HealthCheckServiceReference>URL of the health check service associated with the health state of the network endpoint.
health_state: Option<HealthState>Health state of the network endpoint determined based on the health checks configured.
ipv_6_health_state: Option<Ipv6HealthState>Health state of the ipv6 network endpoint determined based on the health checks configured.
Implementations
Sourceimpl HealthStatusForNetworkEndpoint
impl HealthStatusForNetworkEndpoint
Sourcepub fn set_backend_service<T>(self, v: T) -> Selfwhere
T: Into<BackendServiceReference>,
pub fn set_backend_service<T>(self, v: T) -> Selfwhere
T: Into<BackendServiceReference>,
Sets the value of backend_service.
Example
use google_cloud_compute_v1::model::BackendServiceReference;
let x = HealthStatusForNetworkEndpoint::new().set_backend_service(BackendServiceReference::default()/* use setters */);Sourcepub fn set_or_clear_backend_service<T>(self, v: Option<T>) -> Selfwhere
T: Into<BackendServiceReference>,
pub fn set_or_clear_backend_service<T>(self, v: Option<T>) -> Selfwhere
T: Into<BackendServiceReference>,
Sets or clears the value of backend_service.
Example
use google_cloud_compute_v1::model::BackendServiceReference;
let x = HealthStatusForNetworkEndpoint::new().set_or_clear_backend_service(Some(BackendServiceReference::default()/* use setters */));
let x = HealthStatusForNetworkEndpoint::new().set_or_clear_backend_service(None::<BackendServiceReference>);Sourcepub fn set_forwarding_rule<T>(self, v: T) -> Selfwhere
T: Into<ForwardingRuleReference>,
pub fn set_forwarding_rule<T>(self, v: T) -> Selfwhere
T: Into<ForwardingRuleReference>,
Sets the value of forwarding_rule.
Example
use google_cloud_compute_v1::model::ForwardingRuleReference;
let x = HealthStatusForNetworkEndpoint::new().set_forwarding_rule(ForwardingRuleReference::default()/* use setters */);Sourcepub fn set_or_clear_forwarding_rule<T>(self, v: Option<T>) -> Selfwhere
T: Into<ForwardingRuleReference>,
pub fn set_or_clear_forwarding_rule<T>(self, v: Option<T>) -> Selfwhere
T: Into<ForwardingRuleReference>,
Sets or clears the value of forwarding_rule.
Example
use google_cloud_compute_v1::model::ForwardingRuleReference;
let x = HealthStatusForNetworkEndpoint::new().set_or_clear_forwarding_rule(Some(ForwardingRuleReference::default()/* use setters */));
let x = HealthStatusForNetworkEndpoint::new().set_or_clear_forwarding_rule(None::<ForwardingRuleReference>);Sourcepub fn set_health_check<T>(self, v: T) -> Selfwhere
T: Into<HealthCheckReference>,
pub fn set_health_check<T>(self, v: T) -> Selfwhere
T: Into<HealthCheckReference>,
Sets the value of health_check.
Example
use google_cloud_compute_v1::model::HealthCheckReference;
let x = HealthStatusForNetworkEndpoint::new().set_health_check(HealthCheckReference::default()/* use setters */);Sourcepub fn set_or_clear_health_check<T>(self, v: Option<T>) -> Selfwhere
T: Into<HealthCheckReference>,
pub fn set_or_clear_health_check<T>(self, v: Option<T>) -> Selfwhere
T: Into<HealthCheckReference>,
Sets or clears the value of health_check.
Example
use google_cloud_compute_v1::model::HealthCheckReference;
let x = HealthStatusForNetworkEndpoint::new().set_or_clear_health_check(Some(HealthCheckReference::default()/* use setters */));
let x = HealthStatusForNetworkEndpoint::new().set_or_clear_health_check(None::<HealthCheckReference>);Sourcepub fn set_health_check_service<T>(self, v: T) -> Selfwhere
T: Into<HealthCheckServiceReference>,
pub fn set_health_check_service<T>(self, v: T) -> Selfwhere
T: Into<HealthCheckServiceReference>,
Sets the value of health_check_service.
Example
use google_cloud_compute_v1::model::HealthCheckServiceReference;
let x = HealthStatusForNetworkEndpoint::new().set_health_check_service(HealthCheckServiceReference::default()/* use setters */);Sourcepub fn set_or_clear_health_check_service<T>(self, v: Option<T>) -> Selfwhere
T: Into<HealthCheckServiceReference>,
pub fn set_or_clear_health_check_service<T>(self, v: Option<T>) -> Selfwhere
T: Into<HealthCheckServiceReference>,
Sets or clears the value of health_check_service.
Example
use google_cloud_compute_v1::model::HealthCheckServiceReference;
let x = HealthStatusForNetworkEndpoint::new().set_or_clear_health_check_service(Some(HealthCheckServiceReference::default()/* use setters */));
let x = HealthStatusForNetworkEndpoint::new().set_or_clear_health_check_service(None::<HealthCheckServiceReference>);Sourcepub fn set_health_state<T>(self, v: T) -> Selfwhere
T: Into<HealthState>,
pub fn set_health_state<T>(self, v: T) -> Selfwhere
T: Into<HealthState>,
Sets the value of health_state.
Example
use google_cloud_compute_v1::model::health_status_for_network_endpoint::HealthState;
let x0 = HealthStatusForNetworkEndpoint::new().set_health_state(HealthState::Healthy);
let x1 = HealthStatusForNetworkEndpoint::new().set_health_state(HealthState::Unhealthy);
let x2 = HealthStatusForNetworkEndpoint::new().set_health_state(HealthState::Unknown);Sourcepub fn set_or_clear_health_state<T>(self, v: Option<T>) -> Selfwhere
T: Into<HealthState>,
pub fn set_or_clear_health_state<T>(self, v: Option<T>) -> Selfwhere
T: Into<HealthState>,
Sets or clears the value of health_state.
Example
use google_cloud_compute_v1::model::health_status_for_network_endpoint::HealthState;
let x0 = HealthStatusForNetworkEndpoint::new().set_or_clear_health_state(Some(HealthState::Healthy));
let x1 = HealthStatusForNetworkEndpoint::new().set_or_clear_health_state(Some(HealthState::Unhealthy));
let x2 = HealthStatusForNetworkEndpoint::new().set_or_clear_health_state(Some(HealthState::Unknown));
let x_none = HealthStatusForNetworkEndpoint::new().set_or_clear_health_state(None::<HealthState>);Sourcepub fn set_ipv_6_health_state<T>(self, v: T) -> Selfwhere
T: Into<Ipv6HealthState>,
pub fn set_ipv_6_health_state<T>(self, v: T) -> Selfwhere
T: Into<Ipv6HealthState>,
Sets the value of ipv_6_health_state.
Example
use google_cloud_compute_v1::model::health_status_for_network_endpoint::Ipv6HealthState;
let x0 = HealthStatusForNetworkEndpoint::new().set_ipv_6_health_state(Ipv6HealthState::Healthy);
let x1 = HealthStatusForNetworkEndpoint::new().set_ipv_6_health_state(Ipv6HealthState::Unhealthy);
let x2 = HealthStatusForNetworkEndpoint::new().set_ipv_6_health_state(Ipv6HealthState::Unknown);Sourcepub fn set_or_clear_ipv_6_health_state<T>(self, v: Option<T>) -> Selfwhere
T: Into<Ipv6HealthState>,
pub fn set_or_clear_ipv_6_health_state<T>(self, v: Option<T>) -> Selfwhere
T: Into<Ipv6HealthState>,
Sets or clears the value of ipv_6_health_state.
Example
use google_cloud_compute_v1::model::health_status_for_network_endpoint::Ipv6HealthState;
let x0 = HealthStatusForNetworkEndpoint::new().set_or_clear_ipv_6_health_state(Some(Ipv6HealthState::Healthy));
let x1 = HealthStatusForNetworkEndpoint::new().set_or_clear_ipv_6_health_state(Some(Ipv6HealthState::Unhealthy));
let x2 = HealthStatusForNetworkEndpoint::new().set_or_clear_ipv_6_health_state(Some(Ipv6HealthState::Unknown));
let x_none = HealthStatusForNetworkEndpoint::new().set_or_clear_ipv_6_health_state(None::<Ipv6HealthState>);Trait Implementations
Sourceimpl Clone for HealthStatusForNetworkEndpoint
impl Clone for HealthStatusForNetworkEndpoint
Sourcefn clone(&self) -> HealthStatusForNetworkEndpoint
fn clone(&self) -> HealthStatusForNetworkEndpoint
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for HealthStatusForNetworkEndpoint
impl Default for HealthStatusForNetworkEndpoint
Sourcefn default() -> HealthStatusForNetworkEndpoint
fn default() -> HealthStatusForNetworkEndpoint
impl StructuralPartialEq for HealthStatusForNetworkEndpoint