#[non_exhaustive]pub struct HostsListResponse {
pub etag: Option<String>,
pub id: Option<String>,
pub items: Vec<Host>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
pub self_link: Option<String>,
pub unreachables: Vec<String>,
pub warning: Option<Warning>,
/* private fields */
}Available on crate feature
hosts only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.etag: Option<String>id: Option<String>The unique identifier for the resource; defined by the server.
items: Vec<Host>A list of host resources.
kind: Option<String>The type of resource. Always compute#host for a list of hosts.
next_page_token: Option<String>This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
self_link: Option<String>The server-defined URL for this resource.
unreachables: Vec<String>Unreachable resources. end_interface: MixerListResponseWithEtagBuilder
warning: Option<Warning>An informational warning message.
Implementations
Sourceimpl HostsListResponse
impl HostsListResponse
Sourcepub fn set_or_clear_etag<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_etag<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_next_page_token<T>(self, v: T) -> Self
pub fn set_next_page_token<T>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = HostsListResponse::new().set_next_page_token("example");Sourcepub fn set_or_clear_next_page_token<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_next_page_token<T>(self, v: Option<T>) -> Self
Sets or clears the value of next_page_token.
Example
ⓘ
let x = HostsListResponse::new().set_or_clear_next_page_token(Some("example"));
let x = HostsListResponse::new().set_or_clear_next_page_token(None::<String>);Sourcepub fn set_self_link<T>(self, v: T) -> Self
pub fn set_self_link<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
Sourcepub fn set_unreachables<T, V>(self, v: T) -> Self
pub fn set_unreachables<T, V>(self, v: T) -> Self
Sets the value of unreachables.
Example
ⓘ
let x = HostsListResponse::new().set_unreachables(["a", "b", "c"]);Sourcepub fn set_warning<T>(self, v: T) -> Self
pub fn set_warning<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self