#[non_exhaustive]pub struct InstanceGroupAggregatedList {
pub id: Option<String>,
pub items: HashMap<String, InstanceGroupsScopedList>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
pub self_link: Option<String>,
pub unreachables: Vec<String>,
pub warning: Option<Warning>,
/* private fields */
}instance-groups only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>Output only. [Output Only] Unique identifier for the resource; defined by the server.
items: HashMap<String, InstanceGroupsScopedList>A list of InstanceGroupsScopedList resources.
kind: Option<String>Output only. [Output Only] The resource type, which is alwayscompute#instanceGroupAggregatedList for aggregated lists of instance groups.
next_page_token: Option<String>Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
self_link: Option<String>Output only. [Output Only] Server-defined URL for this resource.
unreachables: Vec<String>Output only. [Output Only] Unreachable resources.
warning: Option<Warning>Output only. [Output Only] Informational warning message.
Implementations
Sourceimpl InstanceGroupAggregatedList
impl InstanceGroupAggregatedList
Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_next_page_token<T>(self, v: T) -> Self
pub fn set_next_page_token<T>(self, v: T) -> Self
Sets the value of next_page_token.
Example
let x = InstanceGroupAggregatedList::new().set_next_page_token("example");Sourcepub fn set_or_clear_next_page_token<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_next_page_token<T>(self, v: Option<T>) -> Self
Sets or clears the value of next_page_token.
Example
let x = InstanceGroupAggregatedList::new().set_or_clear_next_page_token(Some("example"));
let x = InstanceGroupAggregatedList::new().set_or_clear_next_page_token(None::<String>);Sourcepub fn set_self_link<T>(self, v: T) -> Self
pub fn set_self_link<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
Sourcepub fn set_unreachables<T, V>(self, v: T) -> Self
pub fn set_unreachables<T, V>(self, v: T) -> Self
Sets the value of unreachables.
Example
let x = InstanceGroupAggregatedList::new().set_unreachables(["a", "b", "c"]);Sourcepub fn set_warning<T>(self, v: T) -> Self
pub fn set_warning<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self
Sets or clears the value of warning.
Example
use google_cloud_compute_v1::model::instance_group_aggregated_list::Warning;
let x = InstanceGroupAggregatedList::new().set_or_clear_warning(Some(Warning::default()/* use setters */));
let x = InstanceGroupAggregatedList::new().set_or_clear_warning(None::<Warning>);Trait Implementations
Sourceimpl Clone for InstanceGroupAggregatedList
impl Clone for InstanceGroupAggregatedList
Sourcefn clone(&self) -> InstanceGroupAggregatedList
fn clone(&self) -> InstanceGroupAggregatedList
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for InstanceGroupAggregatedList
impl Debug for InstanceGroupAggregatedList
Sourceimpl Default for InstanceGroupAggregatedList
impl Default for InstanceGroupAggregatedList
Sourcefn default() -> InstanceGroupAggregatedList
fn default() -> InstanceGroupAggregatedList
impl StructuralPartialEq for InstanceGroupAggregatedList