#[non_exhaustive]pub struct InstanceGroupManagerActionsSummary {Show 13 fields
pub abandoning: Option<i32>,
pub creating: Option<i32>,
pub creating_without_retries: Option<i32>,
pub deleting: Option<i32>,
pub none: Option<i32>,
pub recreating: Option<i32>,
pub refreshing: Option<i32>,
pub restarting: Option<i32>,
pub resuming: Option<i32>,
pub starting: Option<i32>,
pub stopping: Option<i32>,
pub suspending: Option<i32>,
pub verifying: Option<i32>,
/* private fields */
}instance-group-managers or region-instance-group-managers only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.abandoning: Option<i32>Output only. The total number of instances in the managed instance group that are scheduled to be abandoned. Abandoning an instance removes it from the managed instance group without deleting it.
creating: Option<i32>Output only. The number of instances in the managed instance group that are scheduled to be created or are currently being created. If the group fails to create any of these instances, it tries again until it creates the instance successfully.
If you have disabled creation retries, this field will not be populated; instead, the creatingWithoutRetries field will be populated.
creating_without_retries: Option<i32>Output only. The number of instances that the managed instance group will attempt to create. The group attempts to create each instance only once. If the group fails to create any of these instances, it decreases the group’s targetSize value accordingly.
deleting: Option<i32>Output only. The number of instances in the managed instance group that are scheduled to be deleted or are currently being deleted.
none: Option<i32>Output only. The number of instances in the managed instance group that are running and have no scheduled actions.
recreating: Option<i32>Output only. The number of instances in the managed instance group that are scheduled to be recreated or are currently being being recreated. Recreating an instance deletes the existing root persistent disk and creates a new disk from the image that is defined in the instance template.
refreshing: Option<i32>Output only. The number of instances in the managed instance group that are being reconfigured with properties that do not require a restart or a recreate action. For example, setting or removing target pools for the instance.
restarting: Option<i32>Output only. The number of instances in the managed instance group that are scheduled to be restarted or are currently being restarted.
resuming: Option<i32>Output only. The number of instances in the managed instance group that are scheduled to be resumed or are currently being resumed.
starting: Option<i32>Output only. The number of instances in the managed instance group that are scheduled to be started or are currently being started.
stopping: Option<i32>Output only. The number of instances in the managed instance group that are scheduled to be stopped or are currently being stopped.
suspending: Option<i32>Output only. The number of instances in the managed instance group that are scheduled to be suspended or are currently being suspended.
verifying: Option<i32>Output only. The number of instances in the managed instance group that are being verified. See the managedInstances[].currentAction property in the listManagedInstances method documentation.
Implementations
Sourceimpl InstanceGroupManagerActionsSummary
impl InstanceGroupManagerActionsSummary
Sourcepub fn set_abandoning<T>(self, v: T) -> Self
pub fn set_abandoning<T>(self, v: T) -> Self
Sets the value of abandoning.
Example
let x = InstanceGroupManagerActionsSummary::new().set_abandoning(42);Sourcepub fn set_or_clear_abandoning<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_abandoning<T>(self, v: Option<T>) -> Self
Sets or clears the value of abandoning.
Example
let x = InstanceGroupManagerActionsSummary::new().set_or_clear_abandoning(Some(42));
let x = InstanceGroupManagerActionsSummary::new().set_or_clear_abandoning(None::<i32>);Sourcepub fn set_creating<T>(self, v: T) -> Self
pub fn set_creating<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_creating<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_creating<T>(self, v: Option<T>) -> Self
Sourcepub fn set_creating_without_retries<T>(self, v: T) -> Self
pub fn set_creating_without_retries<T>(self, v: T) -> Self
Sets the value of creating_without_retries.
Example
let x = InstanceGroupManagerActionsSummary::new().set_creating_without_retries(42);Sourcepub fn set_or_clear_creating_without_retries<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_creating_without_retries<T>(self, v: Option<T>) -> Self
Sets or clears the value of creating_without_retries.
Example
let x = InstanceGroupManagerActionsSummary::new().set_or_clear_creating_without_retries(Some(42));
let x = InstanceGroupManagerActionsSummary::new().set_or_clear_creating_without_retries(None::<i32>);Sourcepub fn set_deleting<T>(self, v: T) -> Self
pub fn set_deleting<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_deleting<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_deleting<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_none<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_none<T>(self, v: Option<T>) -> Self
Sourcepub fn set_recreating<T>(self, v: T) -> Self
pub fn set_recreating<T>(self, v: T) -> Self
Sets the value of recreating.
Example
let x = InstanceGroupManagerActionsSummary::new().set_recreating(42);Sourcepub fn set_or_clear_recreating<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_recreating<T>(self, v: Option<T>) -> Self
Sets or clears the value of recreating.
Example
let x = InstanceGroupManagerActionsSummary::new().set_or_clear_recreating(Some(42));
let x = InstanceGroupManagerActionsSummary::new().set_or_clear_recreating(None::<i32>);Sourcepub fn set_refreshing<T>(self, v: T) -> Self
pub fn set_refreshing<T>(self, v: T) -> Self
Sets the value of refreshing.
Example
let x = InstanceGroupManagerActionsSummary::new().set_refreshing(42);Sourcepub fn set_or_clear_refreshing<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_refreshing<T>(self, v: Option<T>) -> Self
Sets or clears the value of refreshing.
Example
let x = InstanceGroupManagerActionsSummary::new().set_or_clear_refreshing(Some(42));
let x = InstanceGroupManagerActionsSummary::new().set_or_clear_refreshing(None::<i32>);Sourcepub fn set_restarting<T>(self, v: T) -> Self
pub fn set_restarting<T>(self, v: T) -> Self
Sets the value of restarting.
Example
let x = InstanceGroupManagerActionsSummary::new().set_restarting(42);Sourcepub fn set_or_clear_restarting<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_restarting<T>(self, v: Option<T>) -> Self
Sets or clears the value of restarting.
Example
let x = InstanceGroupManagerActionsSummary::new().set_or_clear_restarting(Some(42));
let x = InstanceGroupManagerActionsSummary::new().set_or_clear_restarting(None::<i32>);Sourcepub fn set_resuming<T>(self, v: T) -> Self
pub fn set_resuming<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_resuming<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_resuming<T>(self, v: Option<T>) -> Self
Sourcepub fn set_starting<T>(self, v: T) -> Self
pub fn set_starting<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_starting<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_starting<T>(self, v: Option<T>) -> Self
Sourcepub fn set_stopping<T>(self, v: T) -> Self
pub fn set_stopping<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_stopping<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_stopping<T>(self, v: Option<T>) -> Self
Sourcepub fn set_suspending<T>(self, v: T) -> Self
pub fn set_suspending<T>(self, v: T) -> Self
Sets the value of suspending.
Example
let x = InstanceGroupManagerActionsSummary::new().set_suspending(42);Sourcepub fn set_or_clear_suspending<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_suspending<T>(self, v: Option<T>) -> Self
Sets or clears the value of suspending.
Example
let x = InstanceGroupManagerActionsSummary::new().set_or_clear_suspending(Some(42));
let x = InstanceGroupManagerActionsSummary::new().set_or_clear_suspending(None::<i32>);Sourcepub fn set_verifying<T>(self, v: T) -> Self
pub fn set_verifying<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_verifying<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_verifying<T>(self, v: Option<T>) -> Self