#[non_exhaustive]pub struct InstanceGroupManagerAggregatedList {
pub id: Option<String>,
pub items: HashMap<String, InstanceGroupManagersScopedList>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
pub self_link: Option<String>,
pub unreachables: Vec<String>,
pub warning: Option<Warning>,
/* private fields */
}instance-group-managers only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>Output only. Unique identifier for the resource; defined by the server.
items: HashMap<String, InstanceGroupManagersScopedList>A list of InstanceGroupManagersScopedList resources.
kind: Option<String>Output only. The resource type, which is alwayscompute#instanceGroupManagerAggregatedList for an aggregated list of managed instance groups.
next_page_token: Option<String>Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
self_link: Option<String>Output only. Server-defined URL for this resource.
unreachables: Vec<String>Output only. Unreachable resources.
warning: Option<Warning>Output only. Informational warning message.
Implementations
Sourceimpl InstanceGroupManagerAggregatedList
impl InstanceGroupManagerAggregatedList
Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
Sourcepub fn set_items<T, K, V>(self, v: T) -> Self
pub fn set_items<T, K, V>(self, v: T) -> Self
Sets the value of items.
Example
use google_cloud_compute_v1::model::InstanceGroupManagersScopedList;
let x = InstanceGroupManagerAggregatedList::new().set_items([
("key0", InstanceGroupManagersScopedList::default()/* use setters */),
("key1", InstanceGroupManagersScopedList::default()/* use (different) setters */),
]);Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_next_page_token<T>(self, v: T) -> Self
pub fn set_next_page_token<T>(self, v: T) -> Self
Sets the value of next_page_token.
Example
let x = InstanceGroupManagerAggregatedList::new().set_next_page_token("example");Sourcepub fn set_or_clear_next_page_token<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_next_page_token<T>(self, v: Option<T>) -> Self
Sets or clears the value of next_page_token.
Example
let x = InstanceGroupManagerAggregatedList::new().set_or_clear_next_page_token(Some("example"));
let x = InstanceGroupManagerAggregatedList::new().set_or_clear_next_page_token(None::<String>);Sourcepub fn set_self_link<T>(self, v: T) -> Self
pub fn set_self_link<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
Sourcepub fn set_unreachables<T, V>(self, v: T) -> Self
pub fn set_unreachables<T, V>(self, v: T) -> Self
Sets the value of unreachables.
Example
let x = InstanceGroupManagerAggregatedList::new().set_unreachables(["a", "b", "c"]);Sourcepub fn set_warning<T>(self, v: T) -> Self
pub fn set_warning<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self
Sets or clears the value of warning.
Example
use google_cloud_compute_v1::model::instance_group_manager_aggregated_list::Warning;
let x = InstanceGroupManagerAggregatedList::new().set_or_clear_warning(Some(Warning::default()/* use setters */));
let x = InstanceGroupManagerAggregatedList::new().set_or_clear_warning(None::<Warning>);Trait Implementations
Sourceimpl Clone for InstanceGroupManagerAggregatedList
impl Clone for InstanceGroupManagerAggregatedList
Sourcefn clone(&self) -> InstanceGroupManagerAggregatedList
fn clone(&self) -> InstanceGroupManagerAggregatedList
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for InstanceGroupManagerAggregatedList
impl Default for InstanceGroupManagerAggregatedList
Sourcefn default() -> InstanceGroupManagerAggregatedList
fn default() -> InstanceGroupManagerAggregatedList
impl StructuralPartialEq for InstanceGroupManagerAggregatedList