#[non_exhaustive]pub struct InstanceGroupManagerList {
pub id: Option<String>,
pub items: Vec<InstanceGroupManager>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
pub self_link: Option<String>,
pub warning: Option<Warning>,
/* private fields */
}instance-group-managers only.Expand description
[Output Only] A list of managed instance groups.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>Output only. Unique identifier for the resource; defined by the server.
items: Vec<InstanceGroupManager>A list of InstanceGroupManager resources.
kind: Option<String>Output only. The resource type, which is always compute#instanceGroupManagerList for a list of managed instance groups.
next_page_token: Option<String>Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
self_link: Option<String>Output only. Server-defined URL for this resource.
warning: Option<Warning>Output only. Informational warning message.
Implementations
Sourceimpl InstanceGroupManagerList
impl InstanceGroupManagerList
Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_next_page_token<T>(self, v: T) -> Self
pub fn set_next_page_token<T>(self, v: T) -> Self
Sets the value of next_page_token.
Example
let x = InstanceGroupManagerList::new().set_next_page_token("example");Sourcepub fn set_or_clear_next_page_token<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_next_page_token<T>(self, v: Option<T>) -> Self
Sets or clears the value of next_page_token.
Example
let x = InstanceGroupManagerList::new().set_or_clear_next_page_token(Some("example"));
let x = InstanceGroupManagerList::new().set_or_clear_next_page_token(None::<String>);Sourcepub fn set_self_link<T>(self, v: T) -> Self
pub fn set_self_link<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
Sourcepub fn set_warning<T>(self, v: T) -> Self
pub fn set_warning<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self
Sets or clears the value of warning.
Example
use google_cloud_compute_v1::model::instance_group_manager_list::Warning;
let x = InstanceGroupManagerList::new().set_or_clear_warning(Some(Warning::default()/* use setters */));
let x = InstanceGroupManagerList::new().set_or_clear_warning(None::<Warning>);Trait Implementations
Sourceimpl Clone for InstanceGroupManagerList
impl Clone for InstanceGroupManagerList
Sourcefn clone(&self) -> InstanceGroupManagerList
fn clone(&self) -> InstanceGroupManagerList
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for InstanceGroupManagerList
impl Debug for InstanceGroupManagerList
Sourceimpl Default for InstanceGroupManagerList
impl Default for InstanceGroupManagerList
Sourcefn default() -> InstanceGroupManagerList
fn default() -> InstanceGroupManagerList
Sourceimpl Message for InstanceGroupManagerList
impl Message for InstanceGroupManagerList
Sourceimpl PartialEq for InstanceGroupManagerList
impl PartialEq for InstanceGroupManagerList
impl StructuralPartialEq for InstanceGroupManagerList