#[non_exhaustive]pub struct InstanceGroupManagerResizeRequestStatus {
pub error: Option<Error>,
pub last_attempt: Option<InstanceGroupManagerResizeRequestStatusLastAttempt>,
/* private fields */
}instance-group-manager-resize-requests or region-instance-group-manager-resize-requests only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.error: Option<Error>Output only. Fatal errors encountered during the queueing or provisioning phases of the ResizeRequest that caused the transition to the FAILED state. Contrary to the last_attempt errors, this field is final and errors are never removed from here, as the ResizeRequest is not going to retry.
last_attempt: Option<InstanceGroupManagerResizeRequestStatusLastAttempt>Output only. Information about the last attempt to fulfill the request. The value is temporary since the ResizeRequest can retry, as long as it’s still active and the last attempt value can either be cleared or replaced with a different error. Since ResizeRequest retries infrequently, the value may be stale and no longer show an active problem. The value is cleared when ResizeRequest transitions to the final state (becomes inactive). If the final state is FAILED the error describing it will be stored in the “error” field only.
Implementations
Sourceimpl InstanceGroupManagerResizeRequestStatus
impl InstanceGroupManagerResizeRequestStatus
Sourcepub fn set_or_clear_error<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_error<T>(self, v: Option<T>) -> Self
Sets or clears the value of error.
Example
use google_cloud_compute_v1::model::instance_group_manager_resize_request_status::Error;
let x = InstanceGroupManagerResizeRequestStatus::new().set_or_clear_error(Some(Error::default()/* use setters */));
let x = InstanceGroupManagerResizeRequestStatus::new().set_or_clear_error(None::<Error>);Sourcepub fn set_last_attempt<T>(self, v: T) -> Self
pub fn set_last_attempt<T>(self, v: T) -> Self
Sets the value of last_attempt.
Example
use google_cloud_compute_v1::model::InstanceGroupManagerResizeRequestStatusLastAttempt;
let x = InstanceGroupManagerResizeRequestStatus::new().set_last_attempt(InstanceGroupManagerResizeRequestStatusLastAttempt::default()/* use setters */);Sourcepub fn set_or_clear_last_attempt<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_last_attempt<T>(self, v: Option<T>) -> Self
Sets or clears the value of last_attempt.
Example
use google_cloud_compute_v1::model::InstanceGroupManagerResizeRequestStatusLastAttempt;
let x = InstanceGroupManagerResizeRequestStatus::new().set_or_clear_last_attempt(Some(InstanceGroupManagerResizeRequestStatusLastAttempt::default()/* use setters */));
let x = InstanceGroupManagerResizeRequestStatus::new().set_or_clear_last_attempt(None::<InstanceGroupManagerResizeRequestStatusLastAttempt>);Trait Implementations
Sourceimpl Clone for InstanceGroupManagerResizeRequestStatus
impl Clone for InstanceGroupManagerResizeRequestStatus
Sourcefn clone(&self) -> InstanceGroupManagerResizeRequestStatus
fn clone(&self) -> InstanceGroupManagerResizeRequestStatus
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for InstanceGroupManagerResizeRequestStatus
impl Default for InstanceGroupManagerResizeRequestStatus
Sourcefn default() -> InstanceGroupManagerResizeRequestStatus
fn default() -> InstanceGroupManagerResizeRequestStatus
impl StructuralPartialEq for InstanceGroupManagerResizeRequestStatus