#[non_exhaustive]pub struct InstanceGroupManagerResizeRequestsListResponse {
pub id: Option<String>,
pub items: Vec<InstanceGroupManagerResizeRequest>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
pub self_link: Option<String>,
pub warning: Option<Warning>,
/* private fields */
}instance-group-manager-resize-requests only.Expand description
[Output Only] A list of resize requests.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>Output only. Unique identifier for the resource; defined by the server.
items: Vec<InstanceGroupManagerResizeRequest>A list of resize request resources.
kind: Option<String>Output only. Type of the resource. Alwayscompute#instanceGroupManagerResizeRequestList for a list of resize requests.
next_page_token: Option<String>Output only. This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use thenextPageToken as a value for the query parameterpageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
self_link: Option<String>Output only. Server-defined URL for this resource.
warning: Option<Warning>Output only. Informational warning message.
Implementations
Sourceimpl InstanceGroupManagerResizeRequestsListResponse
impl InstanceGroupManagerResizeRequestsListResponse
Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
Sourcepub fn set_items<T, V>(self, v: T) -> Self
pub fn set_items<T, V>(self, v: T) -> Self
Sets the value of items.
Example
use google_cloud_compute_v1::model::InstanceGroupManagerResizeRequest;
let x = InstanceGroupManagerResizeRequestsListResponse::new()
.set_items([
InstanceGroupManagerResizeRequest::default()/* use setters */,
InstanceGroupManagerResizeRequest::default()/* use (different) setters */,
]);Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_next_page_token<T>(self, v: T) -> Self
pub fn set_next_page_token<T>(self, v: T) -> Self
Sets the value of next_page_token.
Example
let x = InstanceGroupManagerResizeRequestsListResponse::new().set_next_page_token("example");Sourcepub fn set_or_clear_next_page_token<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_next_page_token<T>(self, v: Option<T>) -> Self
Sets or clears the value of next_page_token.
Example
let x = InstanceGroupManagerResizeRequestsListResponse::new().set_or_clear_next_page_token(Some("example"));
let x = InstanceGroupManagerResizeRequestsListResponse::new().set_or_clear_next_page_token(None::<String>);Sourcepub fn set_self_link<T>(self, v: T) -> Self
pub fn set_self_link<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
Sourcepub fn set_warning<T>(self, v: T) -> Self
pub fn set_warning<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self
Sets or clears the value of warning.
Example
use google_cloud_compute_v1::model::instance_group_manager_resize_requests_list_response::Warning;
let x = InstanceGroupManagerResizeRequestsListResponse::new().set_or_clear_warning(Some(Warning::default()/* use setters */));
let x = InstanceGroupManagerResizeRequestsListResponse::new().set_or_clear_warning(None::<Warning>);Trait Implementations
Sourceimpl Clone for InstanceGroupManagerResizeRequestsListResponse
impl Clone for InstanceGroupManagerResizeRequestsListResponse
Sourcefn clone(&self) -> InstanceGroupManagerResizeRequestsListResponse
fn clone(&self) -> InstanceGroupManagerResizeRequestsListResponse
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for InstanceGroupManagerResizeRequestsListResponse
impl Default for InstanceGroupManagerResizeRequestsListResponse
Sourcefn default() -> InstanceGroupManagerResizeRequestsListResponse
fn default() -> InstanceGroupManagerResizeRequestsListResponse
impl StructuralPartialEq for InstanceGroupManagerResizeRequestsListResponse