#[non_exhaustive]pub struct InstanceGroupManagerStatusAcceleratorTopology {
pub accelerator_topology: Option<String>,
pub state: Option<State>,
pub state_details: Option<InstanceGroupManagerStatusAcceleratorTopologyAcceleratorTopologyStateDetails>,
/* private fields */
}Available on crate features
instance-group-managers or region-instance-group-managers only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.accelerator_topology: Option<String>Output only. [Output Only] Topology in the format of: “16x16”, “4x4x4”, etc. The value is the same as configured in the WorkloadPolicy.
state: Option<State>Output only. [Output Only] The state of the accelerator topology.
state_details: Option<InstanceGroupManagerStatusAcceleratorTopologyAcceleratorTopologyStateDetails>Output only. [Output Only] The result of the latest accelerator topology state check.
Implementations
Sourceimpl InstanceGroupManagerStatusAcceleratorTopology
impl InstanceGroupManagerStatusAcceleratorTopology
pub fn new() -> Self
Sourcepub fn set_accelerator_topology<T>(self, v: T) -> Self
pub fn set_accelerator_topology<T>(self, v: T) -> Self
Sets the value of accelerator_topology.
Example
ⓘ
let x = InstanceGroupManagerStatusAcceleratorTopology::new().set_accelerator_topology("example");Sourcepub fn set_or_clear_accelerator_topology<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_accelerator_topology<T>(self, v: Option<T>) -> Self
Sets or clears the value of accelerator_topology.
Example
ⓘ
let x = InstanceGroupManagerStatusAcceleratorTopology::new().set_or_clear_accelerator_topology(Some("example"));
let x = InstanceGroupManagerStatusAcceleratorTopology::new().set_or_clear_accelerator_topology(None::<String>);Sourcepub fn set_state<T>(self, v: T) -> Self
pub fn set_state<T>(self, v: T) -> Self
Sets the value of state.
Example
ⓘ
use google_cloud_compute_v1::model::instance_group_manager_status_accelerator_topology::State;
let x0 = InstanceGroupManagerStatusAcceleratorTopology::new().set_state(State::Active);
let x1 = InstanceGroupManagerStatusAcceleratorTopology::new().set_state(State::Deactivating);
let x2 = InstanceGroupManagerStatusAcceleratorTopology::new().set_state(State::Failed);Sourcepub fn set_or_clear_state<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_state<T>(self, v: Option<T>) -> Self
Sets or clears the value of state.
Example
ⓘ
use google_cloud_compute_v1::model::instance_group_manager_status_accelerator_topology::State;
let x0 = InstanceGroupManagerStatusAcceleratorTopology::new().set_or_clear_state(Some(State::Active));
let x1 = InstanceGroupManagerStatusAcceleratorTopology::new().set_or_clear_state(Some(State::Deactivating));
let x2 = InstanceGroupManagerStatusAcceleratorTopology::new().set_or_clear_state(Some(State::Failed));
let x_none = InstanceGroupManagerStatusAcceleratorTopology::new().set_or_clear_state(None::<State>);Sourcepub fn set_state_details<T>(self, v: T) -> Self
pub fn set_state_details<T>(self, v: T) -> Self
Sets the value of state_details.
Example
ⓘ
use google_cloud_compute_v1::model::InstanceGroupManagerStatusAcceleratorTopologyAcceleratorTopologyStateDetails;
let x = InstanceGroupManagerStatusAcceleratorTopology::new().set_state_details(InstanceGroupManagerStatusAcceleratorTopologyAcceleratorTopologyStateDetails::default()/* use setters */);Sourcepub fn set_or_clear_state_details<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_state_details<T>(self, v: Option<T>) -> Self
Sets or clears the value of state_details.
Example
ⓘ
use google_cloud_compute_v1::model::InstanceGroupManagerStatusAcceleratorTopologyAcceleratorTopologyStateDetails;
let x = InstanceGroupManagerStatusAcceleratorTopology::new().set_or_clear_state_details(Some(InstanceGroupManagerStatusAcceleratorTopologyAcceleratorTopologyStateDetails::default()/* use setters */));
let x = InstanceGroupManagerStatusAcceleratorTopology::new().set_or_clear_state_details(None::<InstanceGroupManagerStatusAcceleratorTopologyAcceleratorTopologyStateDetails>);Trait Implementations
Sourceimpl Clone for InstanceGroupManagerStatusAcceleratorTopology
impl Clone for InstanceGroupManagerStatusAcceleratorTopology
Sourcefn clone(&self) -> InstanceGroupManagerStatusAcceleratorTopology
fn clone(&self) -> InstanceGroupManagerStatusAcceleratorTopology
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for InstanceGroupManagerStatusAcceleratorTopology
impl Default for InstanceGroupManagerStatusAcceleratorTopology
Sourcefn default() -> InstanceGroupManagerStatusAcceleratorTopology
fn default() -> InstanceGroupManagerStatusAcceleratorTopology
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for InstanceGroupManagerStatusAcceleratorTopology
impl PartialEq for InstanceGroupManagerStatusAcceleratorTopology
Sourcefn eq(&self, other: &InstanceGroupManagerStatusAcceleratorTopology) -> bool
fn eq(&self, other: &InstanceGroupManagerStatusAcceleratorTopology) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for InstanceGroupManagerStatusAcceleratorTopology