#[non_exhaustive]pub struct InstanceGroupManagerStatusInstanceStatusSummary {Show 13 fields
pub deprovisioning: Option<i32>,
pub non_existent: Option<i32>,
pub pending: Option<i32>,
pub pending_stop: Option<i32>,
pub provisioning: Option<i32>,
pub repairing: Option<i32>,
pub running: Option<i32>,
pub staging: Option<i32>,
pub stopped: Option<i32>,
pub stopping: Option<i32>,
pub suspended: Option<i32>,
pub suspending: Option<i32>,
pub terminated: Option<i32>,
/* private fields */
}instance-group-managers or region-instance-group-managers only.Expand description
The list of instance statuses and the number of instances in this managed instance group that have the status. For more information about how to interpret each status check the instance lifecycle documentation. Currently only shown for TPU MIGs.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.deprovisioning: Option<i32>Output only. [Output Only] The number of instances in the managed instance group that have DEPROVISIONING status.
non_existent: Option<i32>Output only. [Output Only] The number of instances that have not been created yet or have been deleted. Includes only instances that would be shown in the listManagedInstances method and not all instances that have been deleted in the lifetime of the MIG. Does not include FlexStart instances that are waiting for the resources availability, they are considered as ‘pending’.
pending: Option<i32>Output only. [Output Only] The number of instances in the managed instance group that have PENDING status, that is FlexStart instances that are waiting for resources. Instances that do not exist because of the other reasons are counted as ‘non_existent’.
pending_stop: Option<i32>Output only. [Output Only] The number of instances in the managed instance group that have PENDING_STOP status.
provisioning: Option<i32>Output only. [Output Only] The number of instances in the managed instance group that have PROVISIONING status.
repairing: Option<i32>Output only. [Output Only] The number of instances in the managed instance group that have REPAIRING status.
running: Option<i32>Output only. [Output Only] The number of instances in the managed instance group that have RUNNING status.
staging: Option<i32>Output only. [Output Only] The number of instances in the managed instance group that have STAGING status.
stopped: Option<i32>Output only. [Output Only] The number of instances in the managed instance group that have STOPPED status.
stopping: Option<i32>Output only. [Output Only] The number of instances in the managed instance group that have STOPPING status.
suspended: Option<i32>Output only. [Output Only] The number of instances in the managed instance group that have SUSPENDED status.
suspending: Option<i32>Output only. [Output Only] The number of instances in the managed instance group that have SUSPENDING status.
terminated: Option<i32>Output only. [Output Only] The number of instances in the managed instance group that have TERMINATED status.
Implementations
Sourceimpl InstanceGroupManagerStatusInstanceStatusSummary
impl InstanceGroupManagerStatusInstanceStatusSummary
pub fn new() -> Self
Sourcepub fn set_deprovisioning<T>(self, v: T) -> Self
pub fn set_deprovisioning<T>(self, v: T) -> Self
Sets the value of deprovisioning.
Example
let x = InstanceGroupManagerStatusInstanceStatusSummary::new().set_deprovisioning(42);Sourcepub fn set_or_clear_deprovisioning<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_deprovisioning<T>(self, v: Option<T>) -> Self
Sets or clears the value of deprovisioning.
Example
let x = InstanceGroupManagerStatusInstanceStatusSummary::new().set_or_clear_deprovisioning(Some(42));
let x = InstanceGroupManagerStatusInstanceStatusSummary::new().set_or_clear_deprovisioning(None::<i32>);Sourcepub fn set_non_existent<T>(self, v: T) -> Self
pub fn set_non_existent<T>(self, v: T) -> Self
Sets the value of non_existent.
Example
let x = InstanceGroupManagerStatusInstanceStatusSummary::new().set_non_existent(42);Sourcepub fn set_or_clear_non_existent<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_non_existent<T>(self, v: Option<T>) -> Self
Sets or clears the value of non_existent.
Example
let x = InstanceGroupManagerStatusInstanceStatusSummary::new().set_or_clear_non_existent(Some(42));
let x = InstanceGroupManagerStatusInstanceStatusSummary::new().set_or_clear_non_existent(None::<i32>);Sourcepub fn set_pending<T>(self, v: T) -> Self
pub fn set_pending<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_pending<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_pending<T>(self, v: Option<T>) -> Self
Sourcepub fn set_pending_stop<T>(self, v: T) -> Self
pub fn set_pending_stop<T>(self, v: T) -> Self
Sets the value of pending_stop.
Example
let x = InstanceGroupManagerStatusInstanceStatusSummary::new().set_pending_stop(42);Sourcepub fn set_or_clear_pending_stop<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_pending_stop<T>(self, v: Option<T>) -> Self
Sets or clears the value of pending_stop.
Example
let x = InstanceGroupManagerStatusInstanceStatusSummary::new().set_or_clear_pending_stop(Some(42));
let x = InstanceGroupManagerStatusInstanceStatusSummary::new().set_or_clear_pending_stop(None::<i32>);Sourcepub fn set_provisioning<T>(self, v: T) -> Self
pub fn set_provisioning<T>(self, v: T) -> Self
Sets the value of provisioning.
Example
let x = InstanceGroupManagerStatusInstanceStatusSummary::new().set_provisioning(42);Sourcepub fn set_or_clear_provisioning<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_provisioning<T>(self, v: Option<T>) -> Self
Sets or clears the value of provisioning.
Example
let x = InstanceGroupManagerStatusInstanceStatusSummary::new().set_or_clear_provisioning(Some(42));
let x = InstanceGroupManagerStatusInstanceStatusSummary::new().set_or_clear_provisioning(None::<i32>);Sourcepub fn set_repairing<T>(self, v: T) -> Self
pub fn set_repairing<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_repairing<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_repairing<T>(self, v: Option<T>) -> Self
Sourcepub fn set_running<T>(self, v: T) -> Self
pub fn set_running<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_running<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_running<T>(self, v: Option<T>) -> Self
Sourcepub fn set_staging<T>(self, v: T) -> Self
pub fn set_staging<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_staging<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_staging<T>(self, v: Option<T>) -> Self
Sourcepub fn set_stopped<T>(self, v: T) -> Self
pub fn set_stopped<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_stopped<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_stopped<T>(self, v: Option<T>) -> Self
Sourcepub fn set_stopping<T>(self, v: T) -> Self
pub fn set_stopping<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_stopping<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_stopping<T>(self, v: Option<T>) -> Self
Sourcepub fn set_suspended<T>(self, v: T) -> Self
pub fn set_suspended<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_suspended<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_suspended<T>(self, v: Option<T>) -> Self
Sourcepub fn set_suspending<T>(self, v: T) -> Self
pub fn set_suspending<T>(self, v: T) -> Self
Sets the value of suspending.
Example
let x = InstanceGroupManagerStatusInstanceStatusSummary::new().set_suspending(42);Sourcepub fn set_or_clear_suspending<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_suspending<T>(self, v: Option<T>) -> Self
Sets or clears the value of suspending.
Example
let x = InstanceGroupManagerStatusInstanceStatusSummary::new().set_or_clear_suspending(Some(42));
let x = InstanceGroupManagerStatusInstanceStatusSummary::new().set_or_clear_suspending(None::<i32>);Sourcepub fn set_terminated<T>(self, v: T) -> Self
pub fn set_terminated<T>(self, v: T) -> Self
Sets the value of terminated.
Example
let x = InstanceGroupManagerStatusInstanceStatusSummary::new().set_terminated(42);Sourcepub fn set_or_clear_terminated<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_terminated<T>(self, v: Option<T>) -> Self
Sets or clears the value of terminated.
Example
let x = InstanceGroupManagerStatusInstanceStatusSummary::new().set_or_clear_terminated(Some(42));
let x = InstanceGroupManagerStatusInstanceStatusSummary::new().set_or_clear_terminated(None::<i32>);Trait Implementations
Sourceimpl Clone for InstanceGroupManagerStatusInstanceStatusSummary
impl Clone for InstanceGroupManagerStatusInstanceStatusSummary
Sourcefn clone(&self) -> InstanceGroupManagerStatusInstanceStatusSummary
fn clone(&self) -> InstanceGroupManagerStatusInstanceStatusSummary
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for InstanceGroupManagerStatusInstanceStatusSummary
impl Default for InstanceGroupManagerStatusInstanceStatusSummary
Sourcefn default() -> InstanceGroupManagerStatusInstanceStatusSummary
fn default() -> InstanceGroupManagerStatusInstanceStatusSummary
Sourceimpl PartialEq for InstanceGroupManagerStatusInstanceStatusSummary
impl PartialEq for InstanceGroupManagerStatusInstanceStatusSummary
Sourcefn eq(&self, other: &InstanceGroupManagerStatusInstanceStatusSummary) -> bool
fn eq(&self, other: &InstanceGroupManagerStatusInstanceStatusSummary) -> bool
self and other values to be equal, and is used by ==.