#[non_exhaustive]pub struct InstanceGroupManagersApplyUpdatesRequest {
pub all_instances: Option<bool>,
pub instances: Vec<String>,
pub minimal_action: Option<MinimalAction>,
pub most_disruptive_allowed_action: Option<MostDisruptiveAllowedAction>,
/* private fields */
}instance-group-managers only.Expand description
InstanceGroupManagers.applyUpdatesToInstances
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.all_instances: Option<bool>Flag to update all instances instead of specified list of “instances”. If the flag is set to true then the instances may not be specified in the request.
instances: Vec<String>The list of URLs of one or more instances for which you want to apply updates. Each URL can be a full URL or a partial URL, such aszones/[ZONE]/instances/[INSTANCE_NAME].
minimal_action: Option<MinimalAction>The minimal action that you want to perform on each instance during the update:
- REPLACE: At minimum, delete the instance and create it
again.- RESTART: Stop the instance and start it again.
- REFRESH: Do not stop the instance and limit disruption as much as possible.
- NONE: Do not disrupt the instance at all.
By default, the minimum action is NONE. If your update requires a more disruptive action than you set with this flag, the necessary action is performed to execute the update.
most_disruptive_allowed_action: Option<MostDisruptiveAllowedAction>The most disruptive action that you want to perform on each instance during the update:
- REPLACE: Delete the instance and create it again.
- RESTART: Stop the instance and start it again.
- REFRESH: Do not stop the instance and limit disruption
as much as possible.- NONE: Do not disrupt the instance at all.
By default, the most disruptive allowed action is REPLACE. If your update requires a more disruptive action than you set with this flag, the update request will fail.
Implementations
Sourceimpl InstanceGroupManagersApplyUpdatesRequest
impl InstanceGroupManagersApplyUpdatesRequest
Sourcepub fn set_all_instances<T>(self, v: T) -> Self
pub fn set_all_instances<T>(self, v: T) -> Self
Sets the value of all_instances.
Example
let x = InstanceGroupManagersApplyUpdatesRequest::new().set_all_instances(true);Sourcepub fn set_or_clear_all_instances<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_all_instances<T>(self, v: Option<T>) -> Self
Sets or clears the value of all_instances.
Example
let x = InstanceGroupManagersApplyUpdatesRequest::new().set_or_clear_all_instances(Some(false));
let x = InstanceGroupManagersApplyUpdatesRequest::new().set_or_clear_all_instances(None::<bool>);Sourcepub fn set_instances<T, V>(self, v: T) -> Self
pub fn set_instances<T, V>(self, v: T) -> Self
Sourcepub fn set_minimal_action<T>(self, v: T) -> Selfwhere
T: Into<MinimalAction>,
pub fn set_minimal_action<T>(self, v: T) -> Selfwhere
T: Into<MinimalAction>,
Sets the value of minimal_action.
Example
use google_cloud_compute_v1::model::instance_group_managers_apply_updates_request::MinimalAction;
let x0 = InstanceGroupManagersApplyUpdatesRequest::new().set_minimal_action(MinimalAction::Refresh);
let x1 = InstanceGroupManagersApplyUpdatesRequest::new().set_minimal_action(MinimalAction::Replace);
let x2 = InstanceGroupManagersApplyUpdatesRequest::new().set_minimal_action(MinimalAction::Restart);Sourcepub fn set_or_clear_minimal_action<T>(self, v: Option<T>) -> Selfwhere
T: Into<MinimalAction>,
pub fn set_or_clear_minimal_action<T>(self, v: Option<T>) -> Selfwhere
T: Into<MinimalAction>,
Sets or clears the value of minimal_action.
Example
use google_cloud_compute_v1::model::instance_group_managers_apply_updates_request::MinimalAction;
let x0 = InstanceGroupManagersApplyUpdatesRequest::new().set_or_clear_minimal_action(Some(MinimalAction::Refresh));
let x1 = InstanceGroupManagersApplyUpdatesRequest::new().set_or_clear_minimal_action(Some(MinimalAction::Replace));
let x2 = InstanceGroupManagersApplyUpdatesRequest::new().set_or_clear_minimal_action(Some(MinimalAction::Restart));
let x_none = InstanceGroupManagersApplyUpdatesRequest::new().set_or_clear_minimal_action(None::<MinimalAction>);Sourcepub fn set_most_disruptive_allowed_action<T>(self, v: T) -> Selfwhere
T: Into<MostDisruptiveAllowedAction>,
pub fn set_most_disruptive_allowed_action<T>(self, v: T) -> Selfwhere
T: Into<MostDisruptiveAllowedAction>,
Sets the value of most_disruptive_allowed_action.
Example
use google_cloud_compute_v1::model::instance_group_managers_apply_updates_request::MostDisruptiveAllowedAction;
let x0 = InstanceGroupManagersApplyUpdatesRequest::new().set_most_disruptive_allowed_action(MostDisruptiveAllowedAction::Refresh);
let x1 = InstanceGroupManagersApplyUpdatesRequest::new().set_most_disruptive_allowed_action(MostDisruptiveAllowedAction::Replace);
let x2 = InstanceGroupManagersApplyUpdatesRequest::new().set_most_disruptive_allowed_action(MostDisruptiveAllowedAction::Restart);Sourcepub fn set_or_clear_most_disruptive_allowed_action<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<MostDisruptiveAllowedAction>,
pub fn set_or_clear_most_disruptive_allowed_action<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<MostDisruptiveAllowedAction>,
Sets or clears the value of most_disruptive_allowed_action.
Example
use google_cloud_compute_v1::model::instance_group_managers_apply_updates_request::MostDisruptiveAllowedAction;
let x0 = InstanceGroupManagersApplyUpdatesRequest::new().set_or_clear_most_disruptive_allowed_action(Some(MostDisruptiveAllowedAction::Refresh));
let x1 = InstanceGroupManagersApplyUpdatesRequest::new().set_or_clear_most_disruptive_allowed_action(Some(MostDisruptiveAllowedAction::Replace));
let x2 = InstanceGroupManagersApplyUpdatesRequest::new().set_or_clear_most_disruptive_allowed_action(Some(MostDisruptiveAllowedAction::Restart));
let x_none = InstanceGroupManagersApplyUpdatesRequest::new().set_or_clear_most_disruptive_allowed_action(None::<MostDisruptiveAllowedAction>);Trait Implementations
Sourceimpl Clone for InstanceGroupManagersApplyUpdatesRequest
impl Clone for InstanceGroupManagersApplyUpdatesRequest
Sourcefn clone(&self) -> InstanceGroupManagersApplyUpdatesRequest
fn clone(&self) -> InstanceGroupManagersApplyUpdatesRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for InstanceGroupManagersApplyUpdatesRequest
impl Default for InstanceGroupManagersApplyUpdatesRequest
Sourcefn default() -> InstanceGroupManagersApplyUpdatesRequest
fn default() -> InstanceGroupManagersApplyUpdatesRequest
impl StructuralPartialEq for InstanceGroupManagersApplyUpdatesRequest