InstanceManagedByIgmError

Struct InstanceManagedByIgmError 

#[non_exhaustive]
pub struct InstanceManagedByIgmError { pub error: Option<InstanceManagedByIgmErrorManagedInstanceError>, pub instance_action_details: Option<InstanceManagedByIgmErrorInstanceActionDetails>, pub timestamp: Option<String>, /* private fields */ }
Available on crate features instance-group-managers or region-instance-group-managers only.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
error: Option<InstanceManagedByIgmErrorManagedInstanceError>

Output only. Contents of the error.

instance_action_details: Option<InstanceManagedByIgmErrorInstanceActionDetails>

Output only. Details of the instance action that triggered this error. May be null, if the error was not caused by an action on an instance. This field is optional.

timestamp: Option<String>

Output only. The time that this error occurred. This value is in RFC3339 text format.

Implementations

Source

impl InstanceManagedByIgmError

pub fn new() -> Self

Creates a new default instance.

pub fn set_error<T>(self, v: T) -> Self

Sets the value of error.

Example
use google_cloud_compute_v1::model::InstanceManagedByIgmErrorManagedInstanceError;
let x = InstanceManagedByIgmError::new().set_error(InstanceManagedByIgmErrorManagedInstanceError::default()/* use setters */);
pub fn set_or_clear_error<T>(self, v: Option<T>) -> Self

Sets or clears the value of error.

Example
use google_cloud_compute_v1::model::InstanceManagedByIgmErrorManagedInstanceError;
let x = InstanceManagedByIgmError::new().set_or_clear_error(Some(InstanceManagedByIgmErrorManagedInstanceError::default()/* use setters */));
let x = InstanceManagedByIgmError::new().set_or_clear_error(None::<InstanceManagedByIgmErrorManagedInstanceError>);
pub fn set_instance_action_details<T>(self, v: T) -> Self

Sets the value of instance_action_details.

Example
use google_cloud_compute_v1::model::InstanceManagedByIgmErrorInstanceActionDetails;
let x = InstanceManagedByIgmError::new().set_instance_action_details(InstanceManagedByIgmErrorInstanceActionDetails::default()/* use setters */);
pub fn set_or_clear_instance_action_details<T>(self, v: Option<T>) -> Self

Sets or clears the value of instance_action_details.

Example
use google_cloud_compute_v1::model::InstanceManagedByIgmErrorInstanceActionDetails;
let x = InstanceManagedByIgmError::new().set_or_clear_instance_action_details(Some(InstanceManagedByIgmErrorInstanceActionDetails::default()/* use setters */));
let x = InstanceManagedByIgmError::new().set_or_clear_instance_action_details(None::<InstanceManagedByIgmErrorInstanceActionDetails>);
pub fn set_timestamp<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of timestamp.

Example
let x = InstanceManagedByIgmError::new().set_timestamp("example");
pub fn set_or_clear_timestamp<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of timestamp.

Example
let x = InstanceManagedByIgmError::new().set_or_clear_timestamp(Some("example"));
let x = InstanceManagedByIgmError::new().set_or_clear_timestamp(None::<String>);