#[non_exhaustive]pub struct InstantSnapshotGroupParameters {
pub source_instant_snapshot_group: Option<String>,
/* private fields */
}Available on crate features
disks or region-disks only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source_instant_snapshot_group: Option<String>The source instant snapshot group used to create disks. You can provide this as a partial or full URL to the resource. For example, the following are valid values:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone/instantSnapshotGroups/instantSnapshotGroup
- projects/project/zones/zone/instantSnapshotGroups/instantSnapshotGroup
- zones/zone/instantSnapshotGroups/instantSnapshotGroupImplementations
Sourceimpl InstantSnapshotGroupParameters
impl InstantSnapshotGroupParameters
Sourcepub fn set_source_instant_snapshot_group<T>(self, v: T) -> Self
pub fn set_source_instant_snapshot_group<T>(self, v: T) -> Self
Sets the value of source_instant_snapshot_group.
Example
ⓘ
let x = InstantSnapshotGroupParameters::new().set_source_instant_snapshot_group("example");Sourcepub fn set_or_clear_source_instant_snapshot_group<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_source_instant_snapshot_group<T>(self, v: Option<T>) -> Self
Sets or clears the value of source_instant_snapshot_group.
Example
ⓘ
let x = InstantSnapshotGroupParameters::new().set_or_clear_source_instant_snapshot_group(Some("example"));
let x = InstantSnapshotGroupParameters::new().set_or_clear_source_instant_snapshot_group(None::<String>);Trait Implementations
Sourceimpl Clone for InstantSnapshotGroupParameters
impl Clone for InstantSnapshotGroupParameters
Sourcefn clone(&self) -> InstantSnapshotGroupParameters
fn clone(&self) -> InstantSnapshotGroupParameters
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for InstantSnapshotGroupParameters
impl Default for InstantSnapshotGroupParameters
Sourcefn default() -> InstantSnapshotGroupParameters
fn default() -> InstantSnapshotGroupParameters
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for InstantSnapshotGroupParameters
impl PartialEq for InstantSnapshotGroupParameters
Sourcefn eq(&self, other: &InstantSnapshotGroupParameters) -> bool
fn eq(&self, other: &InstantSnapshotGroupParameters) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for InstantSnapshotGroupParameters