#[non_exhaustive]pub struct InstantSnapshotParams {
pub resource_manager_tags: HashMap<String, String>,
/* private fields */
}Available on crate features
instant-snapshots or region-instant-snapshots only.Expand description
Additional instant snapshot params.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.Input only. Resource manager tags to be bound to the instant snapshot. Tag keys and
values have the same definition as resource
manager tags. Keys and values can be either in numeric format,
such as tagKeys/{tag_key_id} and tagValues/{tag_value_id} or in
namespaced format such as {org_id|project_id}/{tag_key_short_name} and
{tag_value_short_name}. The field is ignored (both PUT &
PATCH) when empty.
Implementations
Sourceimpl InstantSnapshotParams
impl InstantSnapshotParams
pub fn new() -> Self
Sets the value of resource_manager_tags.
Example
ⓘ
let x = InstantSnapshotParams::new().set_resource_manager_tags([
("key0", "abc"),
("key1", "xyz"),
]);Trait Implementations
Sourceimpl Clone for InstantSnapshotParams
impl Clone for InstantSnapshotParams
Sourcefn clone(&self) -> InstantSnapshotParams
fn clone(&self) -> InstantSnapshotParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InstantSnapshotParams
impl Debug for InstantSnapshotParams
Sourceimpl Default for InstantSnapshotParams
impl Default for InstantSnapshotParams
Sourcefn default() -> InstantSnapshotParams
fn default() -> InstantSnapshotParams
Returns the “default value” for a type. Read more
Sourceimpl Message for InstantSnapshotParams
impl Message for InstantSnapshotParams
Sourceimpl PartialEq for InstantSnapshotParams
impl PartialEq for InstantSnapshotParams
impl StructuralPartialEq for InstantSnapshotParams