#[non_exhaustive]pub struct InterconnectAttachmentConfigurationConstraints {
pub bgp_md_5: Option<BgpMd5>,
pub bgp_peer_asn_ranges: Vec<InterconnectAttachmentConfigurationConstraintsBgpPeerASNRange>,
/* private fields */
}interconnect-attachments or interconnect-remote-locations only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bgp_md_5: Option<BgpMd5>Output only. [Output Only] Whether the attachment’s BGP session requires/allows/disallows BGP MD5 authentication. This can take one of the following values: MD5_OPTIONAL, MD5_REQUIRED, MD5_UNSUPPORTED.
For example, a Cross-Cloud Interconnect connection to a remote cloud provider that requires BGP MD5 authentication has the interconnectRemoteLocation attachment_configuration_constraints.bgp_md5 field set to MD5_REQUIRED, and that property is propagated to the attachment. Similarly, if BGP MD5 is MD5_UNSUPPORTED, an error is returned if MD5 is requested.
bgp_peer_asn_ranges: Vec<InterconnectAttachmentConfigurationConstraintsBgpPeerASNRange>Output only. [Output Only] List of ASN ranges that the remote location is known to support. Formatted as an array of inclusive ranges {min: min-value, max: max-value}. For example, [{min: 123, max: 123}, {min: 64512, max: 65534}] allows the peer ASN to be 123 or anything in the range 64512-65534.
This field is only advisory. Although the API accepts other ranges, these are the ranges that we recommend.
Implementations
Sourceimpl InterconnectAttachmentConfigurationConstraints
impl InterconnectAttachmentConfigurationConstraints
Sourcepub fn set_bgp_md_5<T>(self, v: T) -> Self
pub fn set_bgp_md_5<T>(self, v: T) -> Self
Sets the value of bgp_md_5.
Example
use google_cloud_compute_v1::model::interconnect_attachment_configuration_constraints::BgpMd5;
let x0 = InterconnectAttachmentConfigurationConstraints::new().set_bgp_md_5(BgpMd5::Md5Required);
let x1 = InterconnectAttachmentConfigurationConstraints::new().set_bgp_md_5(BgpMd5::Md5Unsupported);Sourcepub fn set_or_clear_bgp_md_5<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_bgp_md_5<T>(self, v: Option<T>) -> Self
Sets or clears the value of bgp_md_5.
Example
use google_cloud_compute_v1::model::interconnect_attachment_configuration_constraints::BgpMd5;
let x0 = InterconnectAttachmentConfigurationConstraints::new().set_or_clear_bgp_md_5(Some(BgpMd5::Md5Required));
let x1 = InterconnectAttachmentConfigurationConstraints::new().set_or_clear_bgp_md_5(Some(BgpMd5::Md5Unsupported));
let x_none = InterconnectAttachmentConfigurationConstraints::new().set_or_clear_bgp_md_5(None::<BgpMd5>);Sourcepub fn set_bgp_peer_asn_ranges<T, V>(self, v: T) -> Selfwhere
T: IntoIterator<Item = V>,
V: Into<InterconnectAttachmentConfigurationConstraintsBgpPeerASNRange>,
pub fn set_bgp_peer_asn_ranges<T, V>(self, v: T) -> Selfwhere
T: IntoIterator<Item = V>,
V: Into<InterconnectAttachmentConfigurationConstraintsBgpPeerASNRange>,
Sets the value of bgp_peer_asn_ranges.
Example
use google_cloud_compute_v1::model::InterconnectAttachmentConfigurationConstraintsBgpPeerASNRange;
let x = InterconnectAttachmentConfigurationConstraints::new()
.set_bgp_peer_asn_ranges([
InterconnectAttachmentConfigurationConstraintsBgpPeerASNRange::default()/* use setters */,
InterconnectAttachmentConfigurationConstraintsBgpPeerASNRange::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for InterconnectAttachmentConfigurationConstraints
impl Clone for InterconnectAttachmentConfigurationConstraints
Sourcefn clone(&self) -> InterconnectAttachmentConfigurationConstraints
fn clone(&self) -> InterconnectAttachmentConfigurationConstraints
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for InterconnectAttachmentConfigurationConstraints
impl Default for InterconnectAttachmentConfigurationConstraints
Sourcefn default() -> InterconnectAttachmentConfigurationConstraints
fn default() -> InterconnectAttachmentConfigurationConstraints
impl StructuralPartialEq for InterconnectAttachmentConfigurationConstraints