#[non_exhaustive]pub struct InterconnectAttachmentGroup {
pub attachments: HashMap<String, InterconnectAttachmentGroupAttachment>,
pub configured: Option<InterconnectAttachmentGroupConfigured>,
pub creation_timestamp: Option<String>,
pub description: Option<String>,
pub etag: Option<String>,
pub id: Option<u64>,
pub intent: Option<InterconnectAttachmentGroupIntent>,
pub interconnect_group: Option<String>,
pub kind: Option<String>,
pub logical_structure: Option<InterconnectAttachmentGroupLogicalStructure>,
pub name: Option<String>,
pub self_link: Option<String>,
/* private fields */
}interconnect-attachment-groups only.Expand description
An interconnect attachment group resource allows customers to create, analyze, and expand highly available deployments.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.attachments: HashMap<String, InterconnectAttachmentGroupAttachment>Attachments in the AttachmentGroup. Keys are arbitrary user-specified strings. Users are encouraged, but not required, to use their preferred format for resource links as keys. Note that there are add-members and remove-members methods in gcloud. The size of this map is limited by an “Attachments per group” quota.
configured: Option<InterconnectAttachmentGroupConfigured>creation_timestamp: Option<String>Output only. [Output Only] Creation timestamp inRFC3339 text format.
description: Option<String>An optional description of this resource. Provide this property when you create the resource.
etag: Option<String>Opaque system-generated token that uniquely identifies the configuration. If provided when patching a configuration in update mode, the provided token must match the current token or the update is rejected. This provides a reliable means of doing read-modify-write (optimistic locking) as described byAIP 154.
id: Option<u64>Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier.
intent: Option<InterconnectAttachmentGroupIntent>interconnect_group: Option<String>The URL of an InterconnectGroup that groups these Attachments’ Interconnects. Customers do not need to set this unless directed by Google Support.
kind: Option<String>Output only. [Output Only] Type of the resource. Always compute#interconnectAttachmentGroup.
logical_structure: Option<InterconnectAttachmentGroupLogicalStructure>name: Option<String>Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
self_link: Option<String>Output only. [Output Only] Server-defined URL for the resource.
Implementations
Sourceimpl InterconnectAttachmentGroup
impl InterconnectAttachmentGroup
Sourcepub fn set_attachments<T, K, V>(self, v: T) -> Selfwhere
T: IntoIterator<Item = (K, V)>,
K: Into<String>,
V: Into<InterconnectAttachmentGroupAttachment>,
pub fn set_attachments<T, K, V>(self, v: T) -> Selfwhere
T: IntoIterator<Item = (K, V)>,
K: Into<String>,
V: Into<InterconnectAttachmentGroupAttachment>,
Sets the value of attachments.
Example
use google_cloud_compute_v1::model::InterconnectAttachmentGroupAttachment;
let x = InterconnectAttachmentGroup::new().set_attachments([
("key0", InterconnectAttachmentGroupAttachment::default()/* use setters */),
("key1", InterconnectAttachmentGroupAttachment::default()/* use (different) setters */),
]);Sourcepub fn set_configured<T>(self, v: T) -> Selfwhere
T: Into<InterconnectAttachmentGroupConfigured>,
pub fn set_configured<T>(self, v: T) -> Selfwhere
T: Into<InterconnectAttachmentGroupConfigured>,
Sets the value of configured.
Example
use google_cloud_compute_v1::model::InterconnectAttachmentGroupConfigured;
let x = InterconnectAttachmentGroup::new().set_configured(InterconnectAttachmentGroupConfigured::default()/* use setters */);Sourcepub fn set_or_clear_configured<T>(self, v: Option<T>) -> Selfwhere
T: Into<InterconnectAttachmentGroupConfigured>,
pub fn set_or_clear_configured<T>(self, v: Option<T>) -> Selfwhere
T: Into<InterconnectAttachmentGroupConfigured>,
Sets or clears the value of configured.
Example
use google_cloud_compute_v1::model::InterconnectAttachmentGroupConfigured;
let x = InterconnectAttachmentGroup::new().set_or_clear_configured(Some(InterconnectAttachmentGroupConfigured::default()/* use setters */));
let x = InterconnectAttachmentGroup::new().set_or_clear_configured(None::<InterconnectAttachmentGroupConfigured>);Sourcepub fn set_creation_timestamp<T>(self, v: T) -> Self
pub fn set_creation_timestamp<T>(self, v: T) -> Self
Sets the value of creation_timestamp.
Example
let x = InterconnectAttachmentGroup::new().set_creation_timestamp("example");Sourcepub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
Sets or clears the value of creation_timestamp.
Example
let x = InterconnectAttachmentGroup::new().set_or_clear_creation_timestamp(Some("example"));
let x = InterconnectAttachmentGroup::new().set_or_clear_creation_timestamp(None::<String>);Sourcepub fn set_description<T>(self, v: T) -> Self
pub fn set_description<T>(self, v: T) -> Self
Sets the value of description.
Example
let x = InterconnectAttachmentGroup::new().set_description("example");Sourcepub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
Sets or clears the value of description.
Example
let x = InterconnectAttachmentGroup::new().set_or_clear_description(Some("example"));
let x = InterconnectAttachmentGroup::new().set_or_clear_description(None::<String>);Sourcepub fn set_or_clear_etag<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_etag<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
Sourcepub fn set_intent<T>(self, v: T) -> Selfwhere
T: Into<InterconnectAttachmentGroupIntent>,
pub fn set_intent<T>(self, v: T) -> Selfwhere
T: Into<InterconnectAttachmentGroupIntent>,
Sourcepub fn set_or_clear_intent<T>(self, v: Option<T>) -> Selfwhere
T: Into<InterconnectAttachmentGroupIntent>,
pub fn set_or_clear_intent<T>(self, v: Option<T>) -> Selfwhere
T: Into<InterconnectAttachmentGroupIntent>,
Sets or clears the value of intent.
Example
use google_cloud_compute_v1::model::InterconnectAttachmentGroupIntent;
let x = InterconnectAttachmentGroup::new().set_or_clear_intent(Some(InterconnectAttachmentGroupIntent::default()/* use setters */));
let x = InterconnectAttachmentGroup::new().set_or_clear_intent(None::<InterconnectAttachmentGroupIntent>);Sourcepub fn set_interconnect_group<T>(self, v: T) -> Self
pub fn set_interconnect_group<T>(self, v: T) -> Self
Sets the value of interconnect_group.
Example
let x = InterconnectAttachmentGroup::new().set_interconnect_group("example");Sourcepub fn set_or_clear_interconnect_group<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_interconnect_group<T>(self, v: Option<T>) -> Self
Sets or clears the value of interconnect_group.
Example
let x = InterconnectAttachmentGroup::new().set_or_clear_interconnect_group(Some("example"));
let x = InterconnectAttachmentGroup::new().set_or_clear_interconnect_group(None::<String>);Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_logical_structure<T>(self, v: T) -> Selfwhere
T: Into<InterconnectAttachmentGroupLogicalStructure>,
pub fn set_logical_structure<T>(self, v: T) -> Selfwhere
T: Into<InterconnectAttachmentGroupLogicalStructure>,
Sets the value of logical_structure.
Example
use google_cloud_compute_v1::model::InterconnectAttachmentGroupLogicalStructure;
let x = InterconnectAttachmentGroup::new().set_logical_structure(InterconnectAttachmentGroupLogicalStructure::default()/* use setters */);Sourcepub fn set_or_clear_logical_structure<T>(self, v: Option<T>) -> Selfwhere
T: Into<InterconnectAttachmentGroupLogicalStructure>,
pub fn set_or_clear_logical_structure<T>(self, v: Option<T>) -> Selfwhere
T: Into<InterconnectAttachmentGroupLogicalStructure>,
Sets or clears the value of logical_structure.
Example
use google_cloud_compute_v1::model::InterconnectAttachmentGroupLogicalStructure;
let x = InterconnectAttachmentGroup::new().set_or_clear_logical_structure(Some(InterconnectAttachmentGroupLogicalStructure::default()/* use setters */));
let x = InterconnectAttachmentGroup::new().set_or_clear_logical_structure(None::<InterconnectAttachmentGroupLogicalStructure>);Sourcepub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
Sourcepub fn set_self_link<T>(self, v: T) -> Self
pub fn set_self_link<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self