#[non_exhaustive]pub struct InterconnectAttachmentGroupConfiguredAvailabilitySLA {
pub effective_sla: Option<EffectiveSla>,
pub intended_sla_blockers: Vec<InterconnectAttachmentGroupConfiguredAvailabilitySLAIntendedSlaBlockers>,
/* private fields */
}Available on crate feature
interconnect-attachment-groups only.Expand description
[Output Only] Which SLA this group is configured to support, and why this group does or does not meet that SLA’s requirements.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.effective_sla: Option<EffectiveSla>intended_sla_blockers: Vec<InterconnectAttachmentGroupConfiguredAvailabilitySLAIntendedSlaBlockers>Implementations
Sourceimpl InterconnectAttachmentGroupConfiguredAvailabilitySLA
impl InterconnectAttachmentGroupConfiguredAvailabilitySLA
Sourcepub fn set_effective_sla<T>(self, v: T) -> Selfwhere
T: Into<EffectiveSla>,
pub fn set_effective_sla<T>(self, v: T) -> Selfwhere
T: Into<EffectiveSla>,
Sets the value of effective_sla.
Example
ⓘ
use google_cloud_compute_v1::model::interconnect_attachment_group_configured_availability_sla::EffectiveSla;
let x0 = InterconnectAttachmentGroupConfiguredAvailabilitySLA::new().set_effective_sla(EffectiveSla::NoSla);
let x1 = InterconnectAttachmentGroupConfiguredAvailabilitySLA::new().set_effective_sla(EffectiveSla::ProductionCritical);
let x2 = InterconnectAttachmentGroupConfiguredAvailabilitySLA::new().set_effective_sla(EffectiveSla::ProductionNonCritical);Sourcepub fn set_or_clear_effective_sla<T>(self, v: Option<T>) -> Selfwhere
T: Into<EffectiveSla>,
pub fn set_or_clear_effective_sla<T>(self, v: Option<T>) -> Selfwhere
T: Into<EffectiveSla>,
Sets or clears the value of effective_sla.
Example
ⓘ
use google_cloud_compute_v1::model::interconnect_attachment_group_configured_availability_sla::EffectiveSla;
let x0 = InterconnectAttachmentGroupConfiguredAvailabilitySLA::new().set_or_clear_effective_sla(Some(EffectiveSla::NoSla));
let x1 = InterconnectAttachmentGroupConfiguredAvailabilitySLA::new().set_or_clear_effective_sla(Some(EffectiveSla::ProductionCritical));
let x2 = InterconnectAttachmentGroupConfiguredAvailabilitySLA::new().set_or_clear_effective_sla(Some(EffectiveSla::ProductionNonCritical));
let x_none = InterconnectAttachmentGroupConfiguredAvailabilitySLA::new().set_or_clear_effective_sla(None::<EffectiveSla>);Sourcepub fn set_intended_sla_blockers<T, V>(self, v: T) -> Selfwhere
T: IntoIterator<Item = V>,
V: Into<InterconnectAttachmentGroupConfiguredAvailabilitySLAIntendedSlaBlockers>,
pub fn set_intended_sla_blockers<T, V>(self, v: T) -> Selfwhere
T: IntoIterator<Item = V>,
V: Into<InterconnectAttachmentGroupConfiguredAvailabilitySLAIntendedSlaBlockers>,
Sets the value of intended_sla_blockers.
Example
ⓘ
use google_cloud_compute_v1::model::InterconnectAttachmentGroupConfiguredAvailabilitySLAIntendedSlaBlockers;
let x = InterconnectAttachmentGroupConfiguredAvailabilitySLA::new()
.set_intended_sla_blockers([
InterconnectAttachmentGroupConfiguredAvailabilitySLAIntendedSlaBlockers::default()/* use setters */,
InterconnectAttachmentGroupConfiguredAvailabilitySLAIntendedSlaBlockers::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for InterconnectAttachmentGroupConfiguredAvailabilitySLA
impl Clone for InterconnectAttachmentGroupConfiguredAvailabilitySLA
Sourcefn clone(&self) -> InterconnectAttachmentGroupConfiguredAvailabilitySLA
fn clone(&self) -> InterconnectAttachmentGroupConfiguredAvailabilitySLA
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for InterconnectAttachmentGroupConfiguredAvailabilitySLA
impl Default for InterconnectAttachmentGroupConfiguredAvailabilitySLA
Sourcefn default() -> InterconnectAttachmentGroupConfiguredAvailabilitySLA
fn default() -> InterconnectAttachmentGroupConfiguredAvailabilitySLA
Returns the “default value” for a type. Read more
impl StructuralPartialEq for InterconnectAttachmentGroupConfiguredAvailabilitySLA