#[non_exhaustive]pub struct InterconnectAttachmentGroupLogicalStructure {
pub regions: Vec<InterconnectAttachmentGroupLogicalStructureRegion>,
/* private fields */
}Available on crate feature
interconnect-attachment-groups only.Expand description
[Output Only] An analysis of the logical layout of Attachments in this group. Every Attachment in the group is shown once in this structure.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.regions: Vec<InterconnectAttachmentGroupLogicalStructureRegion>Implementations
Sourceimpl InterconnectAttachmentGroupLogicalStructure
impl InterconnectAttachmentGroupLogicalStructure
Sourcepub fn set_regions<T, V>(self, v: T) -> Self
pub fn set_regions<T, V>(self, v: T) -> Self
Sets the value of regions.
Example
ⓘ
use google_cloud_compute_v1::model::InterconnectAttachmentGroupLogicalStructureRegion;
let x = InterconnectAttachmentGroupLogicalStructure::new()
.set_regions([
InterconnectAttachmentGroupLogicalStructureRegion::default()/* use setters */,
InterconnectAttachmentGroupLogicalStructureRegion::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for InterconnectAttachmentGroupLogicalStructure
impl Clone for InterconnectAttachmentGroupLogicalStructure
Sourcefn clone(&self) -> InterconnectAttachmentGroupLogicalStructure
fn clone(&self) -> InterconnectAttachmentGroupLogicalStructure
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for InterconnectAttachmentGroupLogicalStructure
impl Default for InterconnectAttachmentGroupLogicalStructure
Sourcefn default() -> InterconnectAttachmentGroupLogicalStructure
fn default() -> InterconnectAttachmentGroupLogicalStructure
Returns the “default value” for a type. Read more
impl StructuralPartialEq for InterconnectAttachmentGroupLogicalStructure