#[non_exhaustive]pub struct InterconnectAttachmentGroupsOperationalStatusAttachmentStatus {
pub admin_enabled: Option<bool>,
pub attachment: Option<String>,
pub is_active: Option<IsActive>,
pub status: Option<Status>,
/* private fields */
}interconnect-attachment-groups only.Expand description
The status of one Attachment in the group. List order is arbitrary.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.admin_enabled: Option<bool>Output only. Whether this Attachment is enabled. This becomes false when the customer drains their Attachment.
attachment: Option<String>Output only. The URL of the Attachment being described.
is_active: Option<IsActive>Output only. Whether this Attachment is participating in the redundant configuration. This will be ACTIVE if and only if the status below is CONNECTION_UP. Any INACTIVE Attachments are excluded from the analysis that generates operational.availabilitySLA.
status: Option<Status>Output only. Whether this Attachment is active, and if so, whether BGP is up.
Implementations
Sourceimpl InterconnectAttachmentGroupsOperationalStatusAttachmentStatus
impl InterconnectAttachmentGroupsOperationalStatusAttachmentStatus
Sourcepub fn set_admin_enabled<T>(self, v: T) -> Self
pub fn set_admin_enabled<T>(self, v: T) -> Self
Sets the value of admin_enabled.
Example
let x = InterconnectAttachmentGroupsOperationalStatusAttachmentStatus::new().set_admin_enabled(true);Sourcepub fn set_or_clear_admin_enabled<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_admin_enabled<T>(self, v: Option<T>) -> Self
Sets or clears the value of admin_enabled.
Example
let x = InterconnectAttachmentGroupsOperationalStatusAttachmentStatus::new().set_or_clear_admin_enabled(Some(false));
let x = InterconnectAttachmentGroupsOperationalStatusAttachmentStatus::new().set_or_clear_admin_enabled(None::<bool>);Sourcepub fn set_attachment<T>(self, v: T) -> Self
pub fn set_attachment<T>(self, v: T) -> Self
Sets the value of attachment.
Example
let x = InterconnectAttachmentGroupsOperationalStatusAttachmentStatus::new().set_attachment("example");Sourcepub fn set_or_clear_attachment<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_attachment<T>(self, v: Option<T>) -> Self
Sets or clears the value of attachment.
Example
let x = InterconnectAttachmentGroupsOperationalStatusAttachmentStatus::new().set_or_clear_attachment(Some("example"));
let x = InterconnectAttachmentGroupsOperationalStatusAttachmentStatus::new().set_or_clear_attachment(None::<String>);Sourcepub fn set_is_active<T>(self, v: T) -> Self
pub fn set_is_active<T>(self, v: T) -> Self
Sets the value of is_active.
Example
use google_cloud_compute_v1::model::interconnect_attachment_groups_operational_status_attachment_status::IsActive;
let x0 = InterconnectAttachmentGroupsOperationalStatusAttachmentStatus::new().set_is_active(IsActive::Inactive);
let x1 = InterconnectAttachmentGroupsOperationalStatusAttachmentStatus::new().set_is_active(IsActive::Unspecified);Sourcepub fn set_or_clear_is_active<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_is_active<T>(self, v: Option<T>) -> Self
Sets or clears the value of is_active.
Example
use google_cloud_compute_v1::model::interconnect_attachment_groups_operational_status_attachment_status::IsActive;
let x0 = InterconnectAttachmentGroupsOperationalStatusAttachmentStatus::new().set_or_clear_is_active(Some(IsActive::Inactive));
let x1 = InterconnectAttachmentGroupsOperationalStatusAttachmentStatus::new().set_or_clear_is_active(Some(IsActive::Unspecified));
let x_none = InterconnectAttachmentGroupsOperationalStatusAttachmentStatus::new().set_or_clear_is_active(None::<IsActive>);Sourcepub fn set_status<T>(self, v: T) -> Self
pub fn set_status<T>(self, v: T) -> Self
Sets the value of status.
Example
use google_cloud_compute_v1::model::interconnect_attachment_groups_operational_status_attachment_status::Status;
let x0 = InterconnectAttachmentGroupsOperationalStatusAttachmentStatus::new().set_status(Status::ConnectionDisabled);
let x1 = InterconnectAttachmentGroupsOperationalStatusAttachmentStatus::new().set_status(Status::ConnectionDown);
let x2 = InterconnectAttachmentGroupsOperationalStatusAttachmentStatus::new().set_status(Status::ConnectionUp);Sourcepub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
Sets or clears the value of status.
Example
use google_cloud_compute_v1::model::interconnect_attachment_groups_operational_status_attachment_status::Status;
let x0 = InterconnectAttachmentGroupsOperationalStatusAttachmentStatus::new().set_or_clear_status(Some(Status::ConnectionDisabled));
let x1 = InterconnectAttachmentGroupsOperationalStatusAttachmentStatus::new().set_or_clear_status(Some(Status::ConnectionDown));
let x2 = InterconnectAttachmentGroupsOperationalStatusAttachmentStatus::new().set_or_clear_status(Some(Status::ConnectionUp));
let x_none = InterconnectAttachmentGroupsOperationalStatusAttachmentStatus::new().set_or_clear_status(None::<Status>);Trait Implementations
Sourceimpl Clone for InterconnectAttachmentGroupsOperationalStatusAttachmentStatus
impl Clone for InterconnectAttachmentGroupsOperationalStatusAttachmentStatus
Sourcefn clone(&self) -> InterconnectAttachmentGroupsOperationalStatusAttachmentStatus
fn clone(&self) -> InterconnectAttachmentGroupsOperationalStatusAttachmentStatus
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for InterconnectAttachmentGroupsOperationalStatusAttachmentStatus
impl Default for InterconnectAttachmentGroupsOperationalStatusAttachmentStatus
Sourcefn default() -> InterconnectAttachmentGroupsOperationalStatusAttachmentStatus
fn default() -> InterconnectAttachmentGroupsOperationalStatusAttachmentStatus
impl StructuralPartialEq for InterconnectAttachmentGroupsOperationalStatusAttachmentStatus