#[non_exhaustive]pub struct InterconnectAttachmentList {
pub id: Option<String>,
pub items: Vec<InterconnectAttachment>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
pub self_link: Option<String>,
pub warning: Option<Warning>,
/* private fields */
}interconnect-attachments only.Expand description
Response to the list request, and contains a list of interconnect attachments.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>[Output Only] Unique identifier for the resource; defined by the server.
items: Vec<InterconnectAttachment>A list of InterconnectAttachment resources.
kind: Option<String>Output only. [Output Only] Type of resource. Alwayscompute#interconnectAttachmentList for lists of interconnect attachments.
next_page_token: Option<String>[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
self_link: Option<String>Output only. [Output Only] Server-defined URL for this resource.
warning: Option<Warning>[Output Only] Informational warning message.
Implementations
Sourceimpl InterconnectAttachmentList
impl InterconnectAttachmentList
Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_next_page_token<T>(self, v: T) -> Self
pub fn set_next_page_token<T>(self, v: T) -> Self
Sets the value of next_page_token.
Example
let x = InterconnectAttachmentList::new().set_next_page_token("example");Sourcepub fn set_or_clear_next_page_token<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_next_page_token<T>(self, v: Option<T>) -> Self
Sets or clears the value of next_page_token.
Example
let x = InterconnectAttachmentList::new().set_or_clear_next_page_token(Some("example"));
let x = InterconnectAttachmentList::new().set_or_clear_next_page_token(None::<String>);Sourcepub fn set_self_link<T>(self, v: T) -> Self
pub fn set_self_link<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
Sourcepub fn set_warning<T>(self, v: T) -> Self
pub fn set_warning<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self
Sets or clears the value of warning.
Example
use google_cloud_compute_v1::model::interconnect_attachment_list::Warning;
let x = InterconnectAttachmentList::new().set_or_clear_warning(Some(Warning::default()/* use setters */));
let x = InterconnectAttachmentList::new().set_or_clear_warning(None::<Warning>);Trait Implementations
Sourceimpl Clone for InterconnectAttachmentList
impl Clone for InterconnectAttachmentList
Sourcefn clone(&self) -> InterconnectAttachmentList
fn clone(&self) -> InterconnectAttachmentList
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for InterconnectAttachmentList
impl Debug for InterconnectAttachmentList
Sourceimpl Default for InterconnectAttachmentList
impl Default for InterconnectAttachmentList
Sourcefn default() -> InterconnectAttachmentList
fn default() -> InterconnectAttachmentList
Sourceimpl Message for InterconnectAttachmentList
impl Message for InterconnectAttachmentList
impl StructuralPartialEq for InterconnectAttachmentList