#[non_exhaustive]pub struct InterconnectAttachmentParams {
pub resource_manager_tags: HashMap<String, String>,
/* private fields */
}Available on crate feature
interconnect-attachments only.Expand description
Additional interconnect attachment parameters.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.Tag keys/values directly bound to this resource. Tag keys and values have the same definition as resource manager tags. The field is allowed for INSERT only. The keys/values to set on the resource should be specified in either ID { : } or Namespaced format { : }. For example the following are valid inputs:
- {“tagKeys/333” : “tagValues/444”, “tagKeys/123” : “tagValues/456”}
- {“123/environment” : “production”, “345/abc” : “xyz”} Note:
- Invalid combinations of ID & namespaced format is not supported. For instance: {“123/environment” : “tagValues/444”} is invalid.
- Inconsistent format is not supported. For instance: {“tagKeys/333” : “tagValues/444”, “123/env” : “prod”} is invalid.
Implementations
Sourceimpl InterconnectAttachmentParams
impl InterconnectAttachmentParams
Sets the value of resource_manager_tags.
Example
ⓘ
let x = InterconnectAttachmentParams::new().set_resource_manager_tags([
("key0", "abc"),
("key1", "xyz"),
]);Trait Implementations
Sourceimpl Clone for InterconnectAttachmentParams
impl Clone for InterconnectAttachmentParams
Sourcefn clone(&self) -> InterconnectAttachmentParams
fn clone(&self) -> InterconnectAttachmentParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InterconnectAttachmentParams
impl Debug for InterconnectAttachmentParams
Sourceimpl Default for InterconnectAttachmentParams
impl Default for InterconnectAttachmentParams
Sourcefn default() -> InterconnectAttachmentParams
fn default() -> InterconnectAttachmentParams
Returns the “default value” for a type. Read more
impl StructuralPartialEq for InterconnectAttachmentParams