#[non_exhaustive]pub struct InterconnectDiagnostics {
pub arp_caches: Vec<InterconnectDiagnosticsARPEntry>,
pub bundle_aggregation_type: Option<BundleAggregationType>,
pub bundle_operational_status: Option<BundleOperationalStatus>,
pub links: Vec<InterconnectDiagnosticsLinkStatus>,
pub mac_address: Option<String>,
/* private fields */
}interconnect-groups or interconnects only.Expand description
Diagnostics information about the Interconnect connection, which contains detailed and current technical information about Google’s side of the connection.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.arp_caches: Vec<InterconnectDiagnosticsARPEntry>A list of InterconnectDiagnostics.ARPEntry objects, describing individual neighbors currently seen by the Google router in the ARP cache for the Interconnect. This will be empty when the Interconnect is not bundled.
bundle_aggregation_type: Option<BundleAggregationType>The aggregation type of the bundle interface.
bundle_operational_status: Option<BundleOperationalStatus>The operational status of the bundle interface.
links: Vec<InterconnectDiagnosticsLinkStatus>A list of InterconnectDiagnostics.LinkStatus objects, describing the status for each link on the Interconnect.
mac_address: Option<String>The MAC address of the Interconnect’s bundle interface.
Implementations
Sourceimpl InterconnectDiagnostics
impl InterconnectDiagnostics
Sourcepub fn set_arp_caches<T, V>(self, v: T) -> Self
pub fn set_arp_caches<T, V>(self, v: T) -> Self
Sets the value of arp_caches.
Example
use google_cloud_compute_v1::model::InterconnectDiagnosticsARPEntry;
let x = InterconnectDiagnostics::new()
.set_arp_caches([
InterconnectDiagnosticsARPEntry::default()/* use setters */,
InterconnectDiagnosticsARPEntry::default()/* use (different) setters */,
]);Sourcepub fn set_bundle_aggregation_type<T>(self, v: T) -> Selfwhere
T: Into<BundleAggregationType>,
pub fn set_bundle_aggregation_type<T>(self, v: T) -> Selfwhere
T: Into<BundleAggregationType>,
Sets the value of bundle_aggregation_type.
Example
use google_cloud_compute_v1::model::interconnect_diagnostics::BundleAggregationType;
let x0 = InterconnectDiagnostics::new().set_bundle_aggregation_type(BundleAggregationType::Static);Sourcepub fn set_or_clear_bundle_aggregation_type<T>(self, v: Option<T>) -> Selfwhere
T: Into<BundleAggregationType>,
pub fn set_or_clear_bundle_aggregation_type<T>(self, v: Option<T>) -> Selfwhere
T: Into<BundleAggregationType>,
Sets or clears the value of bundle_aggregation_type.
Example
use google_cloud_compute_v1::model::interconnect_diagnostics::BundleAggregationType;
let x0 = InterconnectDiagnostics::new().set_or_clear_bundle_aggregation_type(Some(BundleAggregationType::Static));
let x_none = InterconnectDiagnostics::new().set_or_clear_bundle_aggregation_type(None::<BundleAggregationType>);Sourcepub fn set_bundle_operational_status<T>(self, v: T) -> Selfwhere
T: Into<BundleOperationalStatus>,
pub fn set_bundle_operational_status<T>(self, v: T) -> Selfwhere
T: Into<BundleOperationalStatus>,
Sets the value of bundle_operational_status.
Example
use google_cloud_compute_v1::model::interconnect_diagnostics::BundleOperationalStatus;
let x0 = InterconnectDiagnostics::new().set_bundle_operational_status(BundleOperationalStatus::Up);Sourcepub fn set_or_clear_bundle_operational_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<BundleOperationalStatus>,
pub fn set_or_clear_bundle_operational_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<BundleOperationalStatus>,
Sets or clears the value of bundle_operational_status.
Example
use google_cloud_compute_v1::model::interconnect_diagnostics::BundleOperationalStatus;
let x0 = InterconnectDiagnostics::new().set_or_clear_bundle_operational_status(Some(BundleOperationalStatus::Up));
let x_none = InterconnectDiagnostics::new().set_or_clear_bundle_operational_status(None::<BundleOperationalStatus>);Sourcepub fn set_mac_address<T>(self, v: T) -> Self
pub fn set_mac_address<T>(self, v: T) -> Self
Sets the value of mac_address.
Example
let x = InterconnectDiagnostics::new().set_mac_address("example");Sourcepub fn set_or_clear_mac_address<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_mac_address<T>(self, v: Option<T>) -> Self
Sets or clears the value of mac_address.
Example
let x = InterconnectDiagnostics::new().set_or_clear_mac_address(Some("example"));
let x = InterconnectDiagnostics::new().set_or_clear_mac_address(None::<String>);Trait Implementations
Sourceimpl Clone for InterconnectDiagnostics
impl Clone for InterconnectDiagnostics
Sourcefn clone(&self) -> InterconnectDiagnostics
fn clone(&self) -> InterconnectDiagnostics
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for InterconnectDiagnostics
impl Debug for InterconnectDiagnostics
Sourceimpl Default for InterconnectDiagnostics
impl Default for InterconnectDiagnostics
Sourcefn default() -> InterconnectDiagnostics
fn default() -> InterconnectDiagnostics
Sourceimpl Message for InterconnectDiagnostics
impl Message for InterconnectDiagnostics
Sourceimpl PartialEq for InterconnectDiagnostics
impl PartialEq for InterconnectDiagnostics
Sourcefn eq(&self, other: &InterconnectDiagnostics) -> bool
fn eq(&self, other: &InterconnectDiagnostics) -> bool
self and other values to be equal, and is used by ==.