#[non_exhaustive]pub struct InterconnectDiagnosticsLinkStatus {
pub arp_caches: Vec<InterconnectDiagnosticsARPEntry>,
pub circuit_id: Option<String>,
pub google_demarc: Option<String>,
pub lacp_status: Option<InterconnectDiagnosticsLinkLACPStatus>,
pub macsec: Option<InterconnectDiagnosticsMacsecStatus>,
pub operational_status: Option<OperationalStatus>,
pub receiving_optical_power: Option<InterconnectDiagnosticsLinkOpticalPower>,
pub transmitting_optical_power: Option<InterconnectDiagnosticsLinkOpticalPower>,
/* private fields */
}interconnect-groups or interconnects only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.arp_caches: Vec<InterconnectDiagnosticsARPEntry>A list of InterconnectDiagnostics.ARPEntry objects, describing the ARP neighbor entries seen on this link. This will be empty if the link is bundled
circuit_id: Option<String>The unique ID for this link assigned during turn up by Google.
google_demarc: Option<String>The Demarc address assigned by Google and provided in the LoA.
lacp_status: Option<InterconnectDiagnosticsLinkLACPStatus>macsec: Option<InterconnectDiagnosticsMacsecStatus>Describes the status of MACsec encryption on this link.
operational_status: Option<OperationalStatus>The operational status of the link.
receiving_optical_power: Option<InterconnectDiagnosticsLinkOpticalPower>An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the received light level.
transmitting_optical_power: Option<InterconnectDiagnosticsLinkOpticalPower>An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the transmitted light level.
Implementations
Sourceimpl InterconnectDiagnosticsLinkStatus
impl InterconnectDiagnosticsLinkStatus
Sourcepub fn set_arp_caches<T, V>(self, v: T) -> Self
pub fn set_arp_caches<T, V>(self, v: T) -> Self
Sets the value of arp_caches.
Example
use google_cloud_compute_v1::model::InterconnectDiagnosticsARPEntry;
let x = InterconnectDiagnosticsLinkStatus::new()
.set_arp_caches([
InterconnectDiagnosticsARPEntry::default()/* use setters */,
InterconnectDiagnosticsARPEntry::default()/* use (different) setters */,
]);Sourcepub fn set_circuit_id<T>(self, v: T) -> Self
pub fn set_circuit_id<T>(self, v: T) -> Self
Sets the value of circuit_id.
Example
let x = InterconnectDiagnosticsLinkStatus::new().set_circuit_id("example");Sourcepub fn set_or_clear_circuit_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_circuit_id<T>(self, v: Option<T>) -> Self
Sets or clears the value of circuit_id.
Example
let x = InterconnectDiagnosticsLinkStatus::new().set_or_clear_circuit_id(Some("example"));
let x = InterconnectDiagnosticsLinkStatus::new().set_or_clear_circuit_id(None::<String>);Sourcepub fn set_google_demarc<T>(self, v: T) -> Self
pub fn set_google_demarc<T>(self, v: T) -> Self
Sets the value of google_demarc.
Example
let x = InterconnectDiagnosticsLinkStatus::new().set_google_demarc("example");Sourcepub fn set_or_clear_google_demarc<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_google_demarc<T>(self, v: Option<T>) -> Self
Sets or clears the value of google_demarc.
Example
let x = InterconnectDiagnosticsLinkStatus::new().set_or_clear_google_demarc(Some("example"));
let x = InterconnectDiagnosticsLinkStatus::new().set_or_clear_google_demarc(None::<String>);Sourcepub fn set_lacp_status<T>(self, v: T) -> Selfwhere
T: Into<InterconnectDiagnosticsLinkLACPStatus>,
pub fn set_lacp_status<T>(self, v: T) -> Selfwhere
T: Into<InterconnectDiagnosticsLinkLACPStatus>,
Sets the value of lacp_status.
Example
use google_cloud_compute_v1::model::InterconnectDiagnosticsLinkLACPStatus;
let x = InterconnectDiagnosticsLinkStatus::new().set_lacp_status(InterconnectDiagnosticsLinkLACPStatus::default()/* use setters */);Sourcepub fn set_or_clear_lacp_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<InterconnectDiagnosticsLinkLACPStatus>,
pub fn set_or_clear_lacp_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<InterconnectDiagnosticsLinkLACPStatus>,
Sets or clears the value of lacp_status.
Example
use google_cloud_compute_v1::model::InterconnectDiagnosticsLinkLACPStatus;
let x = InterconnectDiagnosticsLinkStatus::new().set_or_clear_lacp_status(Some(InterconnectDiagnosticsLinkLACPStatus::default()/* use setters */));
let x = InterconnectDiagnosticsLinkStatus::new().set_or_clear_lacp_status(None::<InterconnectDiagnosticsLinkLACPStatus>);Sourcepub fn set_macsec<T>(self, v: T) -> Selfwhere
T: Into<InterconnectDiagnosticsMacsecStatus>,
pub fn set_macsec<T>(self, v: T) -> Selfwhere
T: Into<InterconnectDiagnosticsMacsecStatus>,
Sourcepub fn set_or_clear_macsec<T>(self, v: Option<T>) -> Selfwhere
T: Into<InterconnectDiagnosticsMacsecStatus>,
pub fn set_or_clear_macsec<T>(self, v: Option<T>) -> Selfwhere
T: Into<InterconnectDiagnosticsMacsecStatus>,
Sets or clears the value of macsec.
Example
use google_cloud_compute_v1::model::InterconnectDiagnosticsMacsecStatus;
let x = InterconnectDiagnosticsLinkStatus::new().set_or_clear_macsec(Some(InterconnectDiagnosticsMacsecStatus::default()/* use setters */));
let x = InterconnectDiagnosticsLinkStatus::new().set_or_clear_macsec(None::<InterconnectDiagnosticsMacsecStatus>);Sourcepub fn set_operational_status<T>(self, v: T) -> Selfwhere
T: Into<OperationalStatus>,
pub fn set_operational_status<T>(self, v: T) -> Selfwhere
T: Into<OperationalStatus>,
Sets the value of operational_status.
Example
use google_cloud_compute_v1::model::interconnect_diagnostics_link_status::OperationalStatus;
let x0 = InterconnectDiagnosticsLinkStatus::new().set_operational_status(OperationalStatus::LinkOperationalStatusUp);Sourcepub fn set_or_clear_operational_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<OperationalStatus>,
pub fn set_or_clear_operational_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<OperationalStatus>,
Sets or clears the value of operational_status.
Example
use google_cloud_compute_v1::model::interconnect_diagnostics_link_status::OperationalStatus;
let x0 = InterconnectDiagnosticsLinkStatus::new().set_or_clear_operational_status(Some(OperationalStatus::LinkOperationalStatusUp));
let x_none = InterconnectDiagnosticsLinkStatus::new().set_or_clear_operational_status(None::<OperationalStatus>);Sourcepub fn set_receiving_optical_power<T>(self, v: T) -> Selfwhere
T: Into<InterconnectDiagnosticsLinkOpticalPower>,
pub fn set_receiving_optical_power<T>(self, v: T) -> Selfwhere
T: Into<InterconnectDiagnosticsLinkOpticalPower>,
Sets the value of receiving_optical_power.
Example
use google_cloud_compute_v1::model::InterconnectDiagnosticsLinkOpticalPower;
let x = InterconnectDiagnosticsLinkStatus::new().set_receiving_optical_power(InterconnectDiagnosticsLinkOpticalPower::default()/* use setters */);Sourcepub fn set_or_clear_receiving_optical_power<T>(self, v: Option<T>) -> Selfwhere
T: Into<InterconnectDiagnosticsLinkOpticalPower>,
pub fn set_or_clear_receiving_optical_power<T>(self, v: Option<T>) -> Selfwhere
T: Into<InterconnectDiagnosticsLinkOpticalPower>,
Sets or clears the value of receiving_optical_power.
Example
use google_cloud_compute_v1::model::InterconnectDiagnosticsLinkOpticalPower;
let x = InterconnectDiagnosticsLinkStatus::new().set_or_clear_receiving_optical_power(Some(InterconnectDiagnosticsLinkOpticalPower::default()/* use setters */));
let x = InterconnectDiagnosticsLinkStatus::new().set_or_clear_receiving_optical_power(None::<InterconnectDiagnosticsLinkOpticalPower>);Sourcepub fn set_transmitting_optical_power<T>(self, v: T) -> Selfwhere
T: Into<InterconnectDiagnosticsLinkOpticalPower>,
pub fn set_transmitting_optical_power<T>(self, v: T) -> Selfwhere
T: Into<InterconnectDiagnosticsLinkOpticalPower>,
Sets the value of transmitting_optical_power.
Example
use google_cloud_compute_v1::model::InterconnectDiagnosticsLinkOpticalPower;
let x = InterconnectDiagnosticsLinkStatus::new().set_transmitting_optical_power(InterconnectDiagnosticsLinkOpticalPower::default()/* use setters */);Sourcepub fn set_or_clear_transmitting_optical_power<T>(self, v: Option<T>) -> Selfwhere
T: Into<InterconnectDiagnosticsLinkOpticalPower>,
pub fn set_or_clear_transmitting_optical_power<T>(self, v: Option<T>) -> Selfwhere
T: Into<InterconnectDiagnosticsLinkOpticalPower>,
Sets or clears the value of transmitting_optical_power.
Example
use google_cloud_compute_v1::model::InterconnectDiagnosticsLinkOpticalPower;
let x = InterconnectDiagnosticsLinkStatus::new().set_or_clear_transmitting_optical_power(Some(InterconnectDiagnosticsLinkOpticalPower::default()/* use setters */));
let x = InterconnectDiagnosticsLinkStatus::new().set_or_clear_transmitting_optical_power(None::<InterconnectDiagnosticsLinkOpticalPower>);Trait Implementations
Sourceimpl Clone for InterconnectDiagnosticsLinkStatus
impl Clone for InterconnectDiagnosticsLinkStatus
Sourcefn clone(&self) -> InterconnectDiagnosticsLinkStatus
fn clone(&self) -> InterconnectDiagnosticsLinkStatus
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for InterconnectDiagnosticsLinkStatus
impl Default for InterconnectDiagnosticsLinkStatus
Sourcefn default() -> InterconnectDiagnosticsLinkStatus
fn default() -> InterconnectDiagnosticsLinkStatus
impl StructuralPartialEq for InterconnectDiagnosticsLinkStatus