#[non_exhaustive]pub struct InterconnectGroup {
pub configured: Option<InterconnectGroupConfigured>,
pub creation_timestamp: Option<String>,
pub description: Option<String>,
pub etag: Option<String>,
pub id: Option<u64>,
pub intent: Option<InterconnectGroupIntent>,
pub interconnects: HashMap<String, InterconnectGroupInterconnect>,
pub kind: Option<String>,
pub name: Option<String>,
pub physical_structure: Option<InterconnectGroupPhysicalStructure>,
pub self_link: Option<String>,
/* private fields */
}interconnect-groups only.Expand description
An interconnect group resource allows customers to create, analyze, and expand their redundant connections.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.configured: Option<InterconnectGroupConfigured>creation_timestamp: Option<String>Output only. [Output Only] Creation timestamp inRFC3339 text format.
description: Option<String>An optional description of this resource. Provide this property when you create the resource.
etag: Option<String>Opaque system-generated token that uniquely identifies the configuration. If provided when patching a configuration in update mode, the provided token must match the current token or the update is rejected. This provides a reliable means of doing read-modify-write (optimistic locking) as described by AIP 154.
id: Option<u64>Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier.
intent: Option<InterconnectGroupIntent>interconnects: HashMap<String, InterconnectGroupInterconnect>Interconnects in the InterconnectGroup. Keys are arbitrary user-specified strings. Users are encouraged, but not required, to use their preferred format for resource links as keys. Note that there are add-members and remove-members methods in gcloud. The size of this map is limited by an “Interconnects per group” quota.
kind: Option<String>Output only. [Output Only] Type of the resource. Always compute#InterconnectGroup
name: Option<String>Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
physical_structure: Option<InterconnectGroupPhysicalStructure>self_link: Option<String>Output only. [Output Only] Server-defined URL for the resource.
Implementations
Sourceimpl InterconnectGroup
impl InterconnectGroup
Sourcepub fn set_configured<T>(self, v: T) -> Selfwhere
T: Into<InterconnectGroupConfigured>,
pub fn set_configured<T>(self, v: T) -> Selfwhere
T: Into<InterconnectGroupConfigured>,
Sets the value of configured.
Example
use google_cloud_compute_v1::model::InterconnectGroupConfigured;
let x = InterconnectGroup::new().set_configured(InterconnectGroupConfigured::default()/* use setters */);Sourcepub fn set_or_clear_configured<T>(self, v: Option<T>) -> Selfwhere
T: Into<InterconnectGroupConfigured>,
pub fn set_or_clear_configured<T>(self, v: Option<T>) -> Selfwhere
T: Into<InterconnectGroupConfigured>,
Sets or clears the value of configured.
Example
use google_cloud_compute_v1::model::InterconnectGroupConfigured;
let x = InterconnectGroup::new().set_or_clear_configured(Some(InterconnectGroupConfigured::default()/* use setters */));
let x = InterconnectGroup::new().set_or_clear_configured(None::<InterconnectGroupConfigured>);Sourcepub fn set_creation_timestamp<T>(self, v: T) -> Self
pub fn set_creation_timestamp<T>(self, v: T) -> Self
Sets the value of creation_timestamp.
Example
let x = InterconnectGroup::new().set_creation_timestamp("example");Sourcepub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
Sets or clears the value of creation_timestamp.
Example
let x = InterconnectGroup::new().set_or_clear_creation_timestamp(Some("example"));
let x = InterconnectGroup::new().set_or_clear_creation_timestamp(None::<String>);Sourcepub fn set_description<T>(self, v: T) -> Self
pub fn set_description<T>(self, v: T) -> Self
Sets the value of description.
Example
let x = InterconnectGroup::new().set_description("example");Sourcepub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
Sets or clears the value of description.
Example
let x = InterconnectGroup::new().set_or_clear_description(Some("example"));
let x = InterconnectGroup::new().set_or_clear_description(None::<String>);Sourcepub fn set_or_clear_etag<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_etag<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
Sourcepub fn set_intent<T>(self, v: T) -> Selfwhere
T: Into<InterconnectGroupIntent>,
pub fn set_intent<T>(self, v: T) -> Selfwhere
T: Into<InterconnectGroupIntent>,
Sourcepub fn set_or_clear_intent<T>(self, v: Option<T>) -> Selfwhere
T: Into<InterconnectGroupIntent>,
pub fn set_or_clear_intent<T>(self, v: Option<T>) -> Selfwhere
T: Into<InterconnectGroupIntent>,
Sets or clears the value of intent.
Example
use google_cloud_compute_v1::model::InterconnectGroupIntent;
let x = InterconnectGroup::new().set_or_clear_intent(Some(InterconnectGroupIntent::default()/* use setters */));
let x = InterconnectGroup::new().set_or_clear_intent(None::<InterconnectGroupIntent>);Sourcepub fn set_interconnects<T, K, V>(self, v: T) -> Self
pub fn set_interconnects<T, K, V>(self, v: T) -> Self
Sets the value of interconnects.
Example
use google_cloud_compute_v1::model::InterconnectGroupInterconnect;
let x = InterconnectGroup::new().set_interconnects([
("key0", InterconnectGroupInterconnect::default()/* use setters */),
("key1", InterconnectGroupInterconnect::default()/* use (different) setters */),
]);Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
Sourcepub fn set_physical_structure<T>(self, v: T) -> Selfwhere
T: Into<InterconnectGroupPhysicalStructure>,
pub fn set_physical_structure<T>(self, v: T) -> Selfwhere
T: Into<InterconnectGroupPhysicalStructure>,
Sets the value of physical_structure.
Example
use google_cloud_compute_v1::model::InterconnectGroupPhysicalStructure;
let x = InterconnectGroup::new().set_physical_structure(InterconnectGroupPhysicalStructure::default()/* use setters */);Sourcepub fn set_or_clear_physical_structure<T>(self, v: Option<T>) -> Selfwhere
T: Into<InterconnectGroupPhysicalStructure>,
pub fn set_or_clear_physical_structure<T>(self, v: Option<T>) -> Selfwhere
T: Into<InterconnectGroupPhysicalStructure>,
Sets or clears the value of physical_structure.
Example
use google_cloud_compute_v1::model::InterconnectGroupPhysicalStructure;
let x = InterconnectGroup::new().set_or_clear_physical_structure(Some(InterconnectGroupPhysicalStructure::default()/* use setters */));
let x = InterconnectGroup::new().set_or_clear_physical_structure(None::<InterconnectGroupPhysicalStructure>);Sourcepub fn set_self_link<T>(self, v: T) -> Self
pub fn set_self_link<T>(self, v: T) -> Self