#[non_exhaustive]pub struct InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers {
pub blocker_type: Option<BlockerType>,
pub documentation_link: Option<String>,
pub explanation: Option<String>,
pub facilities: Vec<String>,
pub interconnects: Vec<String>,
pub metros: Vec<String>,
pub zones: Vec<String>,
/* private fields */
}interconnect-groups only.Expand description
[Output Only] Reasons why configuration.topologyCapability.sla differs from intent.topologyCapability. This list is empty if and only if those are the same.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.blocker_type: Option<BlockerType>documentation_link: Option<String>Output only. [Output Only] The url of Google Cloud public documentation explaining this requirement. This is set for every type of requirement.
explanation: Option<String>Output only. [Output Only] A human-readable explanation of this requirement and why it’s not met. This is set for every type of requirement.
facilities: Vec<String>Output only. [Output Only] Facilities used to explain this blocker in more detail. Like physicalStructure.metros.facilities.facility, this is a numeric string like “5467”.
interconnects: Vec<String>Output only. [Output Only] Interconnects used to explain this blocker in more detail.
metros: Vec<String>Output only. [Output Only] Metros used to explain this blocker in more detail. These are three-letter lowercase strings like “iad”. A blocker like INCOMPATIBLE_METROS will specify the problematic metros in this field.
zones: Vec<String>Output only. [Output Only] Zones used to explain this blocker in more detail. Zone names are “zone1” and/or “zone2”.
Implementations
Sourceimpl InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers
impl InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers
Sourcepub fn set_blocker_type<T>(self, v: T) -> Selfwhere
T: Into<BlockerType>,
pub fn set_blocker_type<T>(self, v: T) -> Selfwhere
T: Into<BlockerType>,
Sets the value of blocker_type.
Example
use google_cloud_compute_v1::model::interconnect_group_configured_topology_capability_intended_capability_blockers::BlockerType;
let x0 = InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers::new().set_blocker_type(BlockerType::NotAvailable);
let x1 = InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers::new().set_blocker_type(BlockerType::NoInterconnects);
let x2 = InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers::new().set_blocker_type(BlockerType::NoInterconnectsInMetroAndZone);Sourcepub fn set_or_clear_blocker_type<T>(self, v: Option<T>) -> Selfwhere
T: Into<BlockerType>,
pub fn set_or_clear_blocker_type<T>(self, v: Option<T>) -> Selfwhere
T: Into<BlockerType>,
Sets or clears the value of blocker_type.
Example
use google_cloud_compute_v1::model::interconnect_group_configured_topology_capability_intended_capability_blockers::BlockerType;
let x0 = InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers::new().set_or_clear_blocker_type(Some(BlockerType::NotAvailable));
let x1 = InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers::new().set_or_clear_blocker_type(Some(BlockerType::NoInterconnects));
let x2 = InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers::new().set_or_clear_blocker_type(Some(BlockerType::NoInterconnectsInMetroAndZone));
let x_none = InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers::new().set_or_clear_blocker_type(None::<BlockerType>);Sourcepub fn set_documentation_link<T>(self, v: T) -> Self
pub fn set_documentation_link<T>(self, v: T) -> Self
Sets the value of documentation_link.
Example
let x = InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers::new().set_documentation_link("example");Sourcepub fn set_or_clear_documentation_link<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_documentation_link<T>(self, v: Option<T>) -> Self
Sets or clears the value of documentation_link.
Example
let x = InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers::new().set_or_clear_documentation_link(Some("example"));
let x = InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers::new().set_or_clear_documentation_link(None::<String>);Sourcepub fn set_explanation<T>(self, v: T) -> Self
pub fn set_explanation<T>(self, v: T) -> Self
Sets the value of explanation.
Example
let x = InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers::new().set_explanation("example");Sourcepub fn set_or_clear_explanation<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_explanation<T>(self, v: Option<T>) -> Self
Sets or clears the value of explanation.
Example
let x = InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers::new().set_or_clear_explanation(Some("example"));
let x = InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers::new().set_or_clear_explanation(None::<String>);Sourcepub fn set_facilities<T, V>(self, v: T) -> Self
pub fn set_facilities<T, V>(self, v: T) -> Self
Sets the value of facilities.
Example
let x = InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers::new().set_facilities(["a", "b", "c"]);Sourcepub fn set_interconnects<T, V>(self, v: T) -> Self
pub fn set_interconnects<T, V>(self, v: T) -> Self
Sets the value of interconnects.
Example
let x = InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers::new().set_interconnects(["a", "b", "c"]);Sourcepub fn set_metros<T, V>(self, v: T) -> Self
pub fn set_metros<T, V>(self, v: T) -> Self