#[non_exhaustive]pub struct InterconnectMacsec {
pub fail_open: Option<bool>,
pub pre_shared_keys: Vec<InterconnectMacsecPreSharedKey>,
/* private fields */
}interconnects only.Expand description
Configuration information for enabling Media Access Control security (MACsec) on this Cloud Interconnect connection between Google and your on-premises router.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.fail_open: Option<bool>If set to true, the Interconnect connection is configured with ashould-secure MACsec security policy, that allows the Google router to fallback to cleartext traffic if the MKA session cannot be established. By default, the Interconnect connection is configured with amust-secure security policy that drops all traffic if the MKA session cannot be established with your router.
Required. A keychain placeholder describing a set of named key objects along with their start times. A MACsec CKN/CAK is generated for each key in the key chain. Google router automatically picks the key with the most recent startTime when establishing or re-establishing a MACsec secure link.
Implementations
Sourceimpl InterconnectMacsec
impl InterconnectMacsec
Sourcepub fn set_fail_open<T>(self, v: T) -> Self
pub fn set_fail_open<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_fail_open<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_fail_open<T>(self, v: Option<T>) -> Self
Sets the value of pre_shared_keys.
Example
use google_cloud_compute_v1::model::InterconnectMacsecPreSharedKey;
let x = InterconnectMacsec::new()
.set_pre_shared_keys([
InterconnectMacsecPreSharedKey::default()/* use setters */,
InterconnectMacsecPreSharedKey::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for InterconnectMacsec
impl Clone for InterconnectMacsec
Sourcefn clone(&self) -> InterconnectMacsec
fn clone(&self) -> InterconnectMacsec
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for InterconnectMacsec
impl Debug for InterconnectMacsec
Sourceimpl Default for InterconnectMacsec
impl Default for InterconnectMacsec
Sourcefn default() -> InterconnectMacsec
fn default() -> InterconnectMacsec
Sourceimpl Message for InterconnectMacsec
impl Message for InterconnectMacsec
Sourceimpl PartialEq for InterconnectMacsec
impl PartialEq for InterconnectMacsec
impl StructuralPartialEq for InterconnectMacsec