#[non_exhaustive]pub struct InterconnectOutageNotification {
pub affected_circuits: Vec<String>,
pub description: Option<String>,
pub end_time: Option<i64>,
pub issue_type: Option<IssueType>,
pub name: Option<String>,
pub source: Option<Source>,
pub start_time: Option<i64>,
pub state: Option<State>,
/* private fields */
}interconnects only.Expand description
Description of a planned outage on this Interconnect.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.affected_circuits: Vec<String>If issue_type is IT_PARTIAL_OUTAGE, a list of the Google-side circuit IDs that will be affected.
description: Option<String>A description about the purpose of the outage.
end_time: Option<i64>Scheduled end time for the outage (milliseconds since Unix epoch).
issue_type: Option<IssueType>Form this outage is expected to take, which can take one of the following values:
- OUTAGE: The Interconnect may be completely out of service for some or all of the specified window.
- PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole should remain up, but with reduced bandwidth.
Note that the versions of this enum prefixed with “IT_” have been deprecated in favor of the unprefixed values.
name: Option<String>Unique identifier for this outage notification.
source: Option<Source>The party that generated this notification, which can take the following value:
- GOOGLE: this notification as generated by Google.
Note that the value of NSRC_GOOGLE has been deprecated in favor of GOOGLE.
start_time: Option<i64>Scheduled start time for the outage (milliseconds since Unix epoch).
state: Option<State>State of this notification, which can take one of the following values:
- ACTIVE: This outage notification is active. The event could be in the past, present, or future. See start_time and end_time for scheduling.
- CANCELLED: The outage associated with this notification was cancelled before the outage was due to start.
- COMPLETED: The outage associated with this notification is complete.
Note that the versions of this enum prefixed with “NS_” have been deprecated in favor of the unprefixed values.
Implementations
Sourceimpl InterconnectOutageNotification
impl InterconnectOutageNotification
Sourcepub fn set_affected_circuits<T, V>(self, v: T) -> Self
pub fn set_affected_circuits<T, V>(self, v: T) -> Self
Sets the value of affected_circuits.
Example
let x = InterconnectOutageNotification::new().set_affected_circuits(["a", "b", "c"]);Sourcepub fn set_description<T>(self, v: T) -> Self
pub fn set_description<T>(self, v: T) -> Self
Sets the value of description.
Example
let x = InterconnectOutageNotification::new().set_description("example");Sourcepub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
Sets or clears the value of description.
Example
let x = InterconnectOutageNotification::new().set_or_clear_description(Some("example"));
let x = InterconnectOutageNotification::new().set_or_clear_description(None::<String>);Sourcepub fn set_end_time<T>(self, v: T) -> Self
pub fn set_end_time<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
Sourcepub fn set_issue_type<T>(self, v: T) -> Self
pub fn set_issue_type<T>(self, v: T) -> Self
Sets the value of issue_type.
Example
use google_cloud_compute_v1::model::interconnect_outage_notification::IssueType;
let x0 = InterconnectOutageNotification::new().set_issue_type(IssueType::ItPartialOutage);
let x1 = InterconnectOutageNotification::new().set_issue_type(IssueType::Outage);
let x2 = InterconnectOutageNotification::new().set_issue_type(IssueType::PartialOutage);Sourcepub fn set_or_clear_issue_type<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_issue_type<T>(self, v: Option<T>) -> Self
Sets or clears the value of issue_type.
Example
use google_cloud_compute_v1::model::interconnect_outage_notification::IssueType;
let x0 = InterconnectOutageNotification::new().set_or_clear_issue_type(Some(IssueType::ItPartialOutage));
let x1 = InterconnectOutageNotification::new().set_or_clear_issue_type(Some(IssueType::Outage));
let x2 = InterconnectOutageNotification::new().set_or_clear_issue_type(Some(IssueType::PartialOutage));
let x_none = InterconnectOutageNotification::new().set_or_clear_issue_type(None::<IssueType>);Sourcepub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
Sourcepub fn set_source<T>(self, v: T) -> Self
pub fn set_source<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_source<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_source<T>(self, v: Option<T>) -> Self
Sets or clears the value of source.
Example
use google_cloud_compute_v1::model::interconnect_outage_notification::Source;
let x0 = InterconnectOutageNotification::new().set_or_clear_source(Some(Source::NsrcGoogle));
let x_none = InterconnectOutageNotification::new().set_or_clear_source(None::<Source>);Sourcepub fn set_start_time<T>(self, v: T) -> Self
pub fn set_start_time<T>(self, v: T) -> Self
Sets the value of start_time.
Example
let x = InterconnectOutageNotification::new().set_start_time(42);Sourcepub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of start_time.
Example
let x = InterconnectOutageNotification::new().set_or_clear_start_time(Some(42));
let x = InterconnectOutageNotification::new().set_or_clear_start_time(None::<i32>);Sourcepub fn set_state<T>(self, v: T) -> Self
pub fn set_state<T>(self, v: T) -> Self
Sets the value of state.
Example
use google_cloud_compute_v1::model::interconnect_outage_notification::State;
let x0 = InterconnectOutageNotification::new().set_state(State::Cancelled);
let x1 = InterconnectOutageNotification::new().set_state(State::Completed);
let x2 = InterconnectOutageNotification::new().set_state(State::NsActive);Sourcepub fn set_or_clear_state<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_state<T>(self, v: Option<T>) -> Self
Sets or clears the value of state.
Example
use google_cloud_compute_v1::model::interconnect_outage_notification::State;
let x0 = InterconnectOutageNotification::new().set_or_clear_state(Some(State::Cancelled));
let x1 = InterconnectOutageNotification::new().set_or_clear_state(Some(State::Completed));
let x2 = InterconnectOutageNotification::new().set_or_clear_state(Some(State::NsActive));
let x_none = InterconnectOutageNotification::new().set_or_clear_state(None::<State>);Trait Implementations
Sourceimpl Clone for InterconnectOutageNotification
impl Clone for InterconnectOutageNotification
Sourcefn clone(&self) -> InterconnectOutageNotification
fn clone(&self) -> InterconnectOutageNotification
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for InterconnectOutageNotification
impl Default for InterconnectOutageNotification
Sourcefn default() -> InterconnectOutageNotification
fn default() -> InterconnectOutageNotification
impl StructuralPartialEq for InterconnectOutageNotification