#[non_exhaustive]pub struct InterconnectRemoteLocation {Show 21 fields
pub address: Option<String>,
pub attachment_configuration_constraints: Option<InterconnectAttachmentConfigurationConstraints>,
pub city: Option<String>,
pub constraints: Option<InterconnectRemoteLocationConstraints>,
pub continent: Option<Continent>,
pub creation_timestamp: Option<String>,
pub description: Option<String>,
pub facility_provider: Option<String>,
pub facility_provider_facility_id: Option<String>,
pub id: Option<u64>,
pub kind: Option<String>,
pub lacp: Option<Lacp>,
pub max_lag_size_100_gbps: Option<i32>,
pub max_lag_size_10_gbps: Option<i32>,
pub max_lag_size_400_gbps: Option<i32>,
pub name: Option<String>,
pub peeringdb_facility_id: Option<String>,
pub permitted_connections: Vec<InterconnectRemoteLocationPermittedConnections>,
pub remote_service: Option<String>,
pub self_link: Option<String>,
pub status: Option<Status>,
/* private fields */
}interconnect-remote-locations only.Expand description
Represents a Cross-Cloud Interconnect Remote Location resource.
You can use this resource to find remote location details about an Interconnect attachment (VLAN).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.address: Option<String>Output only. [Output Only] The postal address of the Point of Presence, each line in the address is separated by a newline character.
attachment_configuration_constraints: Option<InterconnectAttachmentConfigurationConstraints>Output only. [Output Only] Subset of fields from InterconnectAttachment’s |configurationConstraints| field that apply to all attachments for this remote location.
city: Option<String>Output only. [Output Only] Metropolitan area designator that indicates which city an interconnect is located. For example: “Chicago, IL”, “Amsterdam, Netherlands”.
constraints: Option<InterconnectRemoteLocationConstraints>Output only. [Output Only] Constraints on the parameters for creating Cross-Cloud Interconnect and associated InterconnectAttachments.
continent: Option<Continent>Output only. [Output Only] Continent for this location, which can take one of the following values:
- AFRICA
- ASIA_PAC
- EUROPE
- NORTH_AMERICA
- SOUTH_AMERICA
creation_timestamp: Option<String>Output only. [Output Only] Creation timestamp inRFC3339 text format.
description: Option<String>Output only. [Output Only] An optional description of the resource.
facility_provider: Option<String>Output only. [Output Only] The name of the provider for this facility (e.g., EQUINIX).
facility_provider_facility_id: Option<String>Output only. [Output Only] A provider-assigned Identifier for this facility (e.g., Ashburn-DC1).
id: Option<u64>Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.
kind: Option<String>Output only. [Output Only] Type of the resource. Alwayscompute#interconnectRemoteLocation for interconnect remote locations.
lacp: Option<Lacp>Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED
max_lag_size_100_gbps: Option<i32>Output only. [Output Only] The maximum number of 100 Gbps ports supported in a link aggregation group (LAG). When linkType is 100 Gbps, requestedLinkCount cannot exceed max_lag_size_100_gbps.
max_lag_size_10_gbps: Option<i32>Output only. [Output Only] The maximum number of 10 Gbps ports supported in a link aggregation group (LAG). When linkType is 10 Gbps, requestedLinkCount cannot exceed max_lag_size_10_gbps.
max_lag_size_400_gbps: Option<i32>Output only. [Output Only] The maximum number of 400 Gbps ports supported in a link aggregation group (LAG). When linkType is 400 Gbps, requestedLinkCount cannot exceed max_lag_size_400_gbps.
name: Option<String>Output only. [Output Only] Name of the resource.
peeringdb_facility_id: Option<String>Output only. [Output Only] The peeringdb identifier for this facility (corresponding with a netfac type in peeringdb).
permitted_connections: Vec<InterconnectRemoteLocationPermittedConnections>Output only. [Output Only] Permitted connections.
remote_service: Option<String>Output only. [Output Only] Indicates the service provider present at the remote location. Example values: “Amazon Web Services”, “Microsoft Azure”.
self_link: Option<String>Output only. [Output Only] Server-defined URL for the resource.
status: Option<Status>Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take one of the following values:
- CLOSED: The InterconnectRemoteLocation is closed and is unavailable for provisioning new Cross-Cloud Interconnects.
- AVAILABLE: The InterconnectRemoteLocation is available for provisioning new Cross-Cloud Interconnects.
Implementations
Sourceimpl InterconnectRemoteLocation
impl InterconnectRemoteLocation
Sourcepub fn set_address<T>(self, v: T) -> Self
pub fn set_address<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_address<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_address<T>(self, v: Option<T>) -> Self
Sourcepub fn set_attachment_configuration_constraints<T>(self, v: T) -> Self
pub fn set_attachment_configuration_constraints<T>(self, v: T) -> Self
Sets the value of attachment_configuration_constraints.
Example
use google_cloud_compute_v1::model::InterconnectAttachmentConfigurationConstraints;
let x = InterconnectRemoteLocation::new().set_attachment_configuration_constraints(InterconnectAttachmentConfigurationConstraints::default()/* use setters */);Sourcepub fn set_or_clear_attachment_configuration_constraints<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_attachment_configuration_constraints<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of attachment_configuration_constraints.
Example
use google_cloud_compute_v1::model::InterconnectAttachmentConfigurationConstraints;
let x = InterconnectRemoteLocation::new().set_or_clear_attachment_configuration_constraints(Some(InterconnectAttachmentConfigurationConstraints::default()/* use setters */));
let x = InterconnectRemoteLocation::new().set_or_clear_attachment_configuration_constraints(None::<InterconnectAttachmentConfigurationConstraints>);Sourcepub fn set_or_clear_city<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_city<T>(self, v: Option<T>) -> Self
Sourcepub fn set_constraints<T>(self, v: T) -> Selfwhere
T: Into<InterconnectRemoteLocationConstraints>,
pub fn set_constraints<T>(self, v: T) -> Selfwhere
T: Into<InterconnectRemoteLocationConstraints>,
Sets the value of constraints.
Example
use google_cloud_compute_v1::model::InterconnectRemoteLocationConstraints;
let x = InterconnectRemoteLocation::new().set_constraints(InterconnectRemoteLocationConstraints::default()/* use setters */);Sourcepub fn set_or_clear_constraints<T>(self, v: Option<T>) -> Selfwhere
T: Into<InterconnectRemoteLocationConstraints>,
pub fn set_or_clear_constraints<T>(self, v: Option<T>) -> Selfwhere
T: Into<InterconnectRemoteLocationConstraints>,
Sets or clears the value of constraints.
Example
use google_cloud_compute_v1::model::InterconnectRemoteLocationConstraints;
let x = InterconnectRemoteLocation::new().set_or_clear_constraints(Some(InterconnectRemoteLocationConstraints::default()/* use setters */));
let x = InterconnectRemoteLocation::new().set_or_clear_constraints(None::<InterconnectRemoteLocationConstraints>);Sourcepub fn set_continent<T>(self, v: T) -> Self
pub fn set_continent<T>(self, v: T) -> Self
Sets the value of continent.
Example
use google_cloud_compute_v1::model::interconnect_remote_location::Continent;
let x0 = InterconnectRemoteLocation::new().set_continent(Continent::AsiaPac);
let x1 = InterconnectRemoteLocation::new().set_continent(Continent::Europe);
let x2 = InterconnectRemoteLocation::new().set_continent(Continent::NorthAmerica);Sourcepub fn set_or_clear_continent<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_continent<T>(self, v: Option<T>) -> Self
Sets or clears the value of continent.
Example
use google_cloud_compute_v1::model::interconnect_remote_location::Continent;
let x0 = InterconnectRemoteLocation::new().set_or_clear_continent(Some(Continent::AsiaPac));
let x1 = InterconnectRemoteLocation::new().set_or_clear_continent(Some(Continent::Europe));
let x2 = InterconnectRemoteLocation::new().set_or_clear_continent(Some(Continent::NorthAmerica));
let x_none = InterconnectRemoteLocation::new().set_or_clear_continent(None::<Continent>);Sourcepub fn set_creation_timestamp<T>(self, v: T) -> Self
pub fn set_creation_timestamp<T>(self, v: T) -> Self
Sets the value of creation_timestamp.
Example
let x = InterconnectRemoteLocation::new().set_creation_timestamp("example");Sourcepub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
Sets or clears the value of creation_timestamp.
Example
let x = InterconnectRemoteLocation::new().set_or_clear_creation_timestamp(Some("example"));
let x = InterconnectRemoteLocation::new().set_or_clear_creation_timestamp(None::<String>);Sourcepub fn set_description<T>(self, v: T) -> Self
pub fn set_description<T>(self, v: T) -> Self
Sets the value of description.
Example
let x = InterconnectRemoteLocation::new().set_description("example");Sourcepub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
Sets or clears the value of description.
Example
let x = InterconnectRemoteLocation::new().set_or_clear_description(Some("example"));
let x = InterconnectRemoteLocation::new().set_or_clear_description(None::<String>);Sourcepub fn set_facility_provider<T>(self, v: T) -> Self
pub fn set_facility_provider<T>(self, v: T) -> Self
Sets the value of facility_provider.
Example
let x = InterconnectRemoteLocation::new().set_facility_provider("example");Sourcepub fn set_or_clear_facility_provider<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_facility_provider<T>(self, v: Option<T>) -> Self
Sets or clears the value of facility_provider.
Example
let x = InterconnectRemoteLocation::new().set_or_clear_facility_provider(Some("example"));
let x = InterconnectRemoteLocation::new().set_or_clear_facility_provider(None::<String>);Sourcepub fn set_facility_provider_facility_id<T>(self, v: T) -> Self
pub fn set_facility_provider_facility_id<T>(self, v: T) -> Self
Sets the value of facility_provider_facility_id.
Example
let x = InterconnectRemoteLocation::new().set_facility_provider_facility_id("example");Sourcepub fn set_or_clear_facility_provider_facility_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_facility_provider_facility_id<T>(self, v: Option<T>) -> Self
Sets or clears the value of facility_provider_facility_id.
Example
let x = InterconnectRemoteLocation::new().set_or_clear_facility_provider_facility_id(Some("example"));
let x = InterconnectRemoteLocation::new().set_or_clear_facility_provider_facility_id(None::<String>);Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_lacp<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_lacp<T>(self, v: Option<T>) -> Self
Sourcepub fn set_max_lag_size_100_gbps<T>(self, v: T) -> Self
pub fn set_max_lag_size_100_gbps<T>(self, v: T) -> Self
Sets the value of max_lag_size_100_gbps.
Example
let x = InterconnectRemoteLocation::new().set_max_lag_size_100_gbps(42);Sourcepub fn set_or_clear_max_lag_size_100_gbps<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_max_lag_size_100_gbps<T>(self, v: Option<T>) -> Self
Sets or clears the value of max_lag_size_100_gbps.
Example
let x = InterconnectRemoteLocation::new().set_or_clear_max_lag_size_100_gbps(Some(42));
let x = InterconnectRemoteLocation::new().set_or_clear_max_lag_size_100_gbps(None::<i32>);Sourcepub fn set_max_lag_size_10_gbps<T>(self, v: T) -> Self
pub fn set_max_lag_size_10_gbps<T>(self, v: T) -> Self
Sets the value of max_lag_size_10_gbps.
Example
let x = InterconnectRemoteLocation::new().set_max_lag_size_10_gbps(42);Sourcepub fn set_or_clear_max_lag_size_10_gbps<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_max_lag_size_10_gbps<T>(self, v: Option<T>) -> Self
Sets or clears the value of max_lag_size_10_gbps.
Example
let x = InterconnectRemoteLocation::new().set_or_clear_max_lag_size_10_gbps(Some(42));
let x = InterconnectRemoteLocation::new().set_or_clear_max_lag_size_10_gbps(None::<i32>);Sourcepub fn set_max_lag_size_400_gbps<T>(self, v: T) -> Self
pub fn set_max_lag_size_400_gbps<T>(self, v: T) -> Self
Sets the value of max_lag_size_400_gbps.
Example
let x = InterconnectRemoteLocation::new().set_max_lag_size_400_gbps(42);Sourcepub fn set_or_clear_max_lag_size_400_gbps<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_max_lag_size_400_gbps<T>(self, v: Option<T>) -> Self
Sets or clears the value of max_lag_size_400_gbps.
Example
let x = InterconnectRemoteLocation::new().set_or_clear_max_lag_size_400_gbps(Some(42));
let x = InterconnectRemoteLocation::new().set_or_clear_max_lag_size_400_gbps(None::<i32>);Sourcepub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
Sourcepub fn set_peeringdb_facility_id<T>(self, v: T) -> Self
pub fn set_peeringdb_facility_id<T>(self, v: T) -> Self
Sets the value of peeringdb_facility_id.
Example
let x = InterconnectRemoteLocation::new().set_peeringdb_facility_id("example");Sourcepub fn set_or_clear_peeringdb_facility_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_peeringdb_facility_id<T>(self, v: Option<T>) -> Self
Sets or clears the value of peeringdb_facility_id.
Example
let x = InterconnectRemoteLocation::new().set_or_clear_peeringdb_facility_id(Some("example"));
let x = InterconnectRemoteLocation::new().set_or_clear_peeringdb_facility_id(None::<String>);Sourcepub fn set_permitted_connections<T, V>(self, v: T) -> Self
pub fn set_permitted_connections<T, V>(self, v: T) -> Self
Sets the value of permitted_connections.
Example
use google_cloud_compute_v1::model::InterconnectRemoteLocationPermittedConnections;
let x = InterconnectRemoteLocation::new()
.set_permitted_connections([
InterconnectRemoteLocationPermittedConnections::default()/* use setters */,
InterconnectRemoteLocationPermittedConnections::default()/* use (different) setters */,
]);Sourcepub fn set_remote_service<T>(self, v: T) -> Self
pub fn set_remote_service<T>(self, v: T) -> Self
Sets the value of remote_service.
Example
let x = InterconnectRemoteLocation::new().set_remote_service("example");Sourcepub fn set_or_clear_remote_service<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_remote_service<T>(self, v: Option<T>) -> Self
Sets or clears the value of remote_service.
Example
let x = InterconnectRemoteLocation::new().set_or_clear_remote_service(Some("example"));
let x = InterconnectRemoteLocation::new().set_or_clear_remote_service(None::<String>);Sourcepub fn set_self_link<T>(self, v: T) -> Self
pub fn set_self_link<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
Sourcepub fn set_status<T>(self, v: T) -> Self
pub fn set_status<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_status<T>(self, v: Option<T>) -> Self