#[non_exhaustive]pub struct InterconnectRemoteLocationList {
pub id: Option<String>,
pub items: Vec<InterconnectRemoteLocation>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
pub self_link: Option<String>,
pub warning: Option<Warning>,
/* private fields */
}interconnect-remote-locations only.Expand description
Response to the list request, and contains a list of interconnect remote locations.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>[Output Only] Unique identifier for the resource; defined by the server.
items: Vec<InterconnectRemoteLocation>A list of InterconnectRemoteLocation resources.
kind: Option<String>Output only. [Output Only] Type of resource. Alwayscompute#interconnectRemoteLocationList for lists of interconnect remote locations.
next_page_token: Option<String>[Output Only] This token lets you get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
self_link: Option<String>Output only. [Output Only] Server-defined URL for this resource.
warning: Option<Warning>[Output Only] Informational warning message.
Implementations
Sourceimpl InterconnectRemoteLocationList
impl InterconnectRemoteLocationList
Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_next_page_token<T>(self, v: T) -> Self
pub fn set_next_page_token<T>(self, v: T) -> Self
Sets the value of next_page_token.
Example
let x = InterconnectRemoteLocationList::new().set_next_page_token("example");Sourcepub fn set_or_clear_next_page_token<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_next_page_token<T>(self, v: Option<T>) -> Self
Sets or clears the value of next_page_token.
Example
let x = InterconnectRemoteLocationList::new().set_or_clear_next_page_token(Some("example"));
let x = InterconnectRemoteLocationList::new().set_or_clear_next_page_token(None::<String>);Sourcepub fn set_self_link<T>(self, v: T) -> Self
pub fn set_self_link<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
Sourcepub fn set_warning<T>(self, v: T) -> Self
pub fn set_warning<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self
Sets or clears the value of warning.
Example
use google_cloud_compute_v1::model::interconnect_remote_location_list::Warning;
let x = InterconnectRemoteLocationList::new().set_or_clear_warning(Some(Warning::default()/* use setters */));
let x = InterconnectRemoteLocationList::new().set_or_clear_warning(None::<Warning>);Trait Implementations
Sourceimpl Clone for InterconnectRemoteLocationList
impl Clone for InterconnectRemoteLocationList
Sourcefn clone(&self) -> InterconnectRemoteLocationList
fn clone(&self) -> InterconnectRemoteLocationList
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for InterconnectRemoteLocationList
impl Default for InterconnectRemoteLocationList
Sourcefn default() -> InterconnectRemoteLocationList
fn default() -> InterconnectRemoteLocationList
impl StructuralPartialEq for InterconnectRemoteLocationList