LicenseCode

Struct LicenseCode 

#[non_exhaustive]
pub struct LicenseCode {
Show 19 fields pub allowed_replacement_licenses: Vec<String>, pub appendable_to_disk: Option<bool>, pub creation_timestamp: Option<String>, pub description: Option<String>, pub id: Option<u64>, pub incompatible_licenses: Vec<String>, pub kind: Option<String>, pub license_alias: Vec<LicenseCodeLicenseAlias>, pub minimum_retention: Option<Duration>, pub multi_tenant_only: Option<bool>, pub name: Option<String>, pub os_license: Option<bool>, pub removable_from_disk: Option<bool>, pub required_coattached_licenses: Vec<String>, pub self_link: Option<String>, pub sole_tenant_only: Option<bool>, pub state: Option<State>, pub transferable: Option<bool>, pub update_timestamp: Option<String>, /* private fields */
}
Available on crate feature license-codes only.
Represents a License Code resource.

A License Code is a unique identifier used to represent alicense resource. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
allowed_replacement_licenses: Vec<String>

Specifies licenseCodes of licenses that can replace this license. Note: such replacements are allowed even if removable_from_disk is false.

appendable_to_disk: Option<bool>

If true, this license can be appended to an existing disk’s set of licenses.

creation_timestamp: Option<String>

Output only. [Output Only] Creation timestamp inRFC3339 text format.

description: Option<String>

Output only. [Output Only] Description of this License Code.

id: Option<u64>

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.

incompatible_licenses: Vec<String>

Specifies licenseCodes of licenses that are incompatible with this license. If a license is incompatible with this license, it cannot be attached to the same disk or image.

kind: Option<String>

Output only. [Output Only] Type of resource. Always compute#licenseCode for licenses.

license_alias: Vec<LicenseCodeLicenseAlias>

[Output Only] URL and description aliases of Licenses with the same License Code.

minimum_retention: Option<Duration>

If set, this license will be unable to be removed or replaced once attached to a disk until the minimum_retention period has passed.

multi_tenant_only: Option<bool>

If true, this license can only be used on VMs on multi tenant nodes.

name: Option<String>

Output only. [Output Only] Name of the resource. The name is 1-20 characters long and must be a valid 64 bit integer.

os_license: Option<bool>

If true, indicates this is an OS license. Only one OS license can be attached to a disk or image at a time.

removable_from_disk: Option<bool>

If true, this license can be removed from a disk’s set of licenses, with no replacement license needed.

required_coattached_licenses: Vec<String>

Specifies the set of permissible coattached licenseCodes of licenses that satisfy the coattachment requirement of this license. At least one license from the set must be attached to the same disk or image as this license.

self_link: Option<String>

Output only. [Output Only] Server-defined URL for the resource.

sole_tenant_only: Option<bool>

If true, this license can only be used on VMs on sole tenant nodes.

state: Option<State>

Output only. [Output Only] Current state of this License Code.

transferable: Option<bool>

Output only. [Output Only] If true, the license will remain attached when creating images or snapshots from disks. Otherwise, the license is not transferred.

update_timestamp: Option<String>

Output only. [Output Only] Last update timestamp inRFC3339 text format.

Implementations

Source

impl LicenseCode

pub fn new() -> Self

Creates a new default instance.

pub fn set_allowed_replacement_licenses<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of allowed_replacement_licenses.

Example
let x = LicenseCode::new().set_allowed_replacement_licenses(["a", "b", "c"]);
pub fn set_appendable_to_disk<T>(self, v: T) -> Self
where T: Into<bool>,

Sets the value of appendable_to_disk.

Example
let x = LicenseCode::new().set_appendable_to_disk(true);
pub fn set_or_clear_appendable_to_disk<T>(self, v: Option<T>) -> Self
where T: Into<bool>,

Sets or clears the value of appendable_to_disk.

Example
let x = LicenseCode::new().set_or_clear_appendable_to_disk(Some(false));
let x = LicenseCode::new().set_or_clear_appendable_to_disk(None::<bool>);
pub fn set_creation_timestamp<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of creation_timestamp.

Example
let x = LicenseCode::new().set_creation_timestamp("example");
pub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of creation_timestamp.

Example
let x = LicenseCode::new().set_or_clear_creation_timestamp(Some("example"));
let x = LicenseCode::new().set_or_clear_creation_timestamp(None::<String>);
pub fn set_description<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of description.

Example
let x = LicenseCode::new().set_description("example");
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of description.

Example
let x = LicenseCode::new().set_or_clear_description(Some("example"));
let x = LicenseCode::new().set_or_clear_description(None::<String>);
pub fn set_id<T>(self, v: T) -> Self
where T: Into<u64>,

Sets the value of id.

Example
let x = LicenseCode::new().set_id(42_u32);
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
where T: Into<u64>,

Sets or clears the value of id.

Example
let x = LicenseCode::new().set_or_clear_id(Some(42_u32));
let x = LicenseCode::new().set_or_clear_id(None::<u32>);
pub fn set_incompatible_licenses<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of incompatible_licenses.

Example
let x = LicenseCode::new().set_incompatible_licenses(["a", "b", "c"]);
pub fn set_kind<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of kind.

Example
let x = LicenseCode::new().set_kind("example");
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of kind.

Example
let x = LicenseCode::new().set_or_clear_kind(Some("example"));
let x = LicenseCode::new().set_or_clear_kind(None::<String>);
pub fn set_license_alias<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<LicenseCodeLicenseAlias>,

Sets the value of license_alias.

Example
use google_cloud_compute_v1::model::LicenseCodeLicenseAlias;
let x = LicenseCode::new()
    .set_license_alias([
        LicenseCodeLicenseAlias::default()/* use setters */,
        LicenseCodeLicenseAlias::default()/* use (different) setters */,
    ]);
pub fn set_minimum_retention<T>(self, v: T) -> Self
where T: Into<Duration>,

Sets the value of minimum_retention.

Example
use google_cloud_compute_v1::model::Duration;
let x = LicenseCode::new().set_minimum_retention(Duration::default()/* use setters */);
pub fn set_or_clear_minimum_retention<T>(self, v: Option<T>) -> Self
where T: Into<Duration>,

Sets or clears the value of minimum_retention.

Example
use google_cloud_compute_v1::model::Duration;
let x = LicenseCode::new().set_or_clear_minimum_retention(Some(Duration::default()/* use setters */));
let x = LicenseCode::new().set_or_clear_minimum_retention(None::<Duration>);
pub fn set_multi_tenant_only<T>(self, v: T) -> Self
where T: Into<bool>,

Sets the value of multi_tenant_only.

Example
let x = LicenseCode::new().set_multi_tenant_only(true);
pub fn set_or_clear_multi_tenant_only<T>(self, v: Option<T>) -> Self
where T: Into<bool>,

Sets or clears the value of multi_tenant_only.

Example
let x = LicenseCode::new().set_or_clear_multi_tenant_only(Some(false));
let x = LicenseCode::new().set_or_clear_multi_tenant_only(None::<bool>);
pub fn set_name<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of name.

Example
let x = LicenseCode::new().set_name("example");
pub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of name.

Example
let x = LicenseCode::new().set_or_clear_name(Some("example"));
let x = LicenseCode::new().set_or_clear_name(None::<String>);
pub fn set_os_license<T>(self, v: T) -> Self
where T: Into<bool>,

Sets the value of os_license.

Example
let x = LicenseCode::new().set_os_license(true);
pub fn set_or_clear_os_license<T>(self, v: Option<T>) -> Self
where T: Into<bool>,

Sets or clears the value of os_license.

Example
let x = LicenseCode::new().set_or_clear_os_license(Some(false));
let x = LicenseCode::new().set_or_clear_os_license(None::<bool>);
pub fn set_removable_from_disk<T>(self, v: T) -> Self
where T: Into<bool>,

Sets the value of removable_from_disk.

Example
let x = LicenseCode::new().set_removable_from_disk(true);
pub fn set_or_clear_removable_from_disk<T>(self, v: Option<T>) -> Self
where T: Into<bool>,

Sets or clears the value of removable_from_disk.

Example
let x = LicenseCode::new().set_or_clear_removable_from_disk(Some(false));
let x = LicenseCode::new().set_or_clear_removable_from_disk(None::<bool>);
pub fn set_required_coattached_licenses<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of required_coattached_licenses.

Example
let x = LicenseCode::new().set_required_coattached_licenses(["a", "b", "c"]);

Sets the value of self_link.

Example
let x = LicenseCode::new().set_self_link("example");

Sets or clears the value of self_link.

Example
let x = LicenseCode::new().set_or_clear_self_link(Some("example"));
let x = LicenseCode::new().set_or_clear_self_link(None::<String>);
pub fn set_sole_tenant_only<T>(self, v: T) -> Self
where T: Into<bool>,

Sets the value of sole_tenant_only.

Example
let x = LicenseCode::new().set_sole_tenant_only(true);
pub fn set_or_clear_sole_tenant_only<T>(self, v: Option<T>) -> Self
where T: Into<bool>,

Sets or clears the value of sole_tenant_only.

Example
let x = LicenseCode::new().set_or_clear_sole_tenant_only(Some(false));
let x = LicenseCode::new().set_or_clear_sole_tenant_only(None::<bool>);
pub fn set_state<T>(self, v: T) -> Self
where T: Into<State>,

Sets the value of state.

Example
use google_cloud_compute_v1::model::license_code::State;
let x0 = LicenseCode::new().set_state(State::Enabled);
let x1 = LicenseCode::new().set_state(State::Restricted);
let x2 = LicenseCode::new().set_state(State::Unspecified);
pub fn set_or_clear_state<T>(self, v: Option<T>) -> Self
where T: Into<State>,

Sets or clears the value of state.

Example
use google_cloud_compute_v1::model::license_code::State;
let x0 = LicenseCode::new().set_or_clear_state(Some(State::Enabled));
let x1 = LicenseCode::new().set_or_clear_state(Some(State::Restricted));
let x2 = LicenseCode::new().set_or_clear_state(Some(State::Unspecified));
let x_none = LicenseCode::new().set_or_clear_state(None::<State>);
pub fn set_transferable<T>(self, v: T) -> Self
where T: Into<bool>,

Sets the value of transferable.

Example
let x = LicenseCode::new().set_transferable(true);
pub fn set_or_clear_transferable<T>(self, v: Option<T>) -> Self
where T: Into<bool>,

Sets or clears the value of transferable.

Example
let x = LicenseCode::new().set_or_clear_transferable(Some(false));
let x = LicenseCode::new().set_or_clear_transferable(None::<bool>);
pub fn set_update_timestamp<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of update_timestamp.

Example
let x = LicenseCode::new().set_update_timestamp("example");
pub fn set_or_clear_update_timestamp<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of update_timestamp.

Example
let x = LicenseCode::new().set_or_clear_update_timestamp(Some("example"));
let x = LicenseCode::new().set_or_clear_update_timestamp(None::<String>);