#[non_exhaustive]pub struct MachineImageParams {
pub resource_manager_tags: HashMap<String, String>,
/* private fields */
}Available on crate feature
machine-images only.Expand description
Machine Image parameters
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.Input only. Resource manager tags to be bound to the machine image. Tag keys and values
have the same definition as resource
manager tags. Keys and values can be either in numeric format,
such as tagKeys/{tag_key_id} and tagValues/{tag_value_id} or in
namespaced format such as {org_id|project_id}/{tag_key_short_name} and
{tag_value_short_name}. The field is ignored (both PUT &
PATCH) when empty.
Implementations
Sourceimpl MachineImageParams
impl MachineImageParams
pub fn new() -> Self
Sets the value of resource_manager_tags.
Example
ⓘ
let x = MachineImageParams::new().set_resource_manager_tags([
("key0", "abc"),
("key1", "xyz"),
]);Trait Implementations
Sourceimpl Clone for MachineImageParams
impl Clone for MachineImageParams
Sourcefn clone(&self) -> MachineImageParams
fn clone(&self) -> MachineImageParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MachineImageParams
impl Debug for MachineImageParams
Sourceimpl Default for MachineImageParams
impl Default for MachineImageParams
Sourcefn default() -> MachineImageParams
fn default() -> MachineImageParams
Returns the “default value” for a type. Read more
Sourceimpl Message for MachineImageParams
impl Message for MachineImageParams
Sourceimpl PartialEq for MachineImageParams
impl PartialEq for MachineImageParams
impl StructuralPartialEq for MachineImageParams