#[non_exhaustive]pub struct ManagedInstanceScheduling {
pub graceful_shutdown_timestamp: Option<Timestamp>,
pub termination_timestamp: Option<Timestamp>,
/* private fields */
}Available on crate features
instance-group-managers or region-instance-group-managers only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.graceful_shutdown_timestamp: Option<Timestamp>Output only. The timestamp at which the underlying instance will be triggered for graceful shutdown if it is configured. This is in RFC3339 text format.
termination_timestamp: Option<Timestamp>Output only. The timestamp at which the managed instance will be terminated. This is in RFC3339 text format.
Implementations
Sourceimpl ManagedInstanceScheduling
impl ManagedInstanceScheduling
Sourcepub fn set_graceful_shutdown_timestamp<T>(self, v: T) -> Self
pub fn set_graceful_shutdown_timestamp<T>(self, v: T) -> Self
Sets the value of graceful_shutdown_timestamp.
Example
ⓘ
use wkt::Timestamp;
let x = ManagedInstanceScheduling::new().set_graceful_shutdown_timestamp(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_graceful_shutdown_timestamp<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_graceful_shutdown_timestamp<T>(self, v: Option<T>) -> Self
Sets or clears the value of graceful_shutdown_timestamp.
Example
ⓘ
use wkt::Timestamp;
let x = ManagedInstanceScheduling::new().set_or_clear_graceful_shutdown_timestamp(Some(Timestamp::default()/* use setters */));
let x = ManagedInstanceScheduling::new().set_or_clear_graceful_shutdown_timestamp(None::<Timestamp>);Sourcepub fn set_termination_timestamp<T>(self, v: T) -> Self
pub fn set_termination_timestamp<T>(self, v: T) -> Self
Sets the value of termination_timestamp.
Example
ⓘ
use wkt::Timestamp;
let x = ManagedInstanceScheduling::new().set_termination_timestamp(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_termination_timestamp<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_termination_timestamp<T>(self, v: Option<T>) -> Self
Sets or clears the value of termination_timestamp.
Example
ⓘ
use wkt::Timestamp;
let x = ManagedInstanceScheduling::new().set_or_clear_termination_timestamp(Some(Timestamp::default()/* use setters */));
let x = ManagedInstanceScheduling::new().set_or_clear_termination_timestamp(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for ManagedInstanceScheduling
impl Clone for ManagedInstanceScheduling
Sourcefn clone(&self) -> ManagedInstanceScheduling
fn clone(&self) -> ManagedInstanceScheduling
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ManagedInstanceScheduling
impl Debug for ManagedInstanceScheduling
Sourceimpl Default for ManagedInstanceScheduling
impl Default for ManagedInstanceScheduling
Sourcefn default() -> ManagedInstanceScheduling
fn default() -> ManagedInstanceScheduling
Returns the “default value” for a type. Read more
Sourceimpl Message for ManagedInstanceScheduling
impl Message for ManagedInstanceScheduling
impl StructuralPartialEq for ManagedInstanceScheduling