NamedSet

Struct NamedSet 

#[non_exhaustive]
pub struct NamedSet { pub description: Option<String>, pub elements: Vec<Expr>, pub fingerprint: Option<Bytes>, pub name: Option<String>, pub type: Option<Type>, /* private fields */ }
Available on crate feature routers only.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
description: Option<String>

An optional description of named set.

elements: Vec<Expr>

CEL expressions that are comparable to constructs of this set’s type (see Policy Language).

fingerprint: Option<Bytes>

A fingerprint for the Named Set being applied to this Router, which is essentially a hash of the Named Set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update the Named Set. You must always provide an up-to-date fingerprint hash in order to update or change labels.

To see the latest fingerprint, make a getNamedSet() request to retrieve a Named Set.

name: Option<String>

This set’s name, which must be a resource ID segment and unique within all named sets owned by the Router. Name should conform to RFC1035.

type: Option<Type>

This named set’s type

Implementations

Source

impl NamedSet

pub fn new() -> Self

Creates a new default instance.

pub fn set_description<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of description.

Example
let x = NamedSet::new().set_description("example");
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of description.

Example
let x = NamedSet::new().set_or_clear_description(Some("example"));
let x = NamedSet::new().set_or_clear_description(None::<String>);
pub fn set_elements<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<Expr>,

Sets the value of elements.

Example
use google_cloud_compute_v1::model::Expr;
let x = NamedSet::new()
    .set_elements([
        Expr::default()/* use setters */,
        Expr::default()/* use (different) setters */,
    ]);
pub fn set_fingerprint<T>(self, v: T) -> Self
where T: Into<Bytes>,

Sets the value of fingerprint.

Example
let x = NamedSet::new().set_fingerprint(bytes::Bytes::from_static(b"example"));
pub fn set_or_clear_fingerprint<T>(self, v: Option<T>) -> Self
where T: Into<Bytes>,

Sets or clears the value of fingerprint.

Example
let x = NamedSet::new().set_or_clear_fingerprint(Some(bytes::Bytes::from_static(b"example")));
let x = NamedSet::new().set_or_clear_fingerprint(None::<bytes::Bytes>);
pub fn set_name<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of name.

Example
let x = NamedSet::new().set_name("example");
pub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of name.

Example
let x = NamedSet::new().set_or_clear_name(Some("example"));
let x = NamedSet::new().set_or_clear_name(None::<String>);
pub fn set_type<T>(self, v: T) -> Self
where T: Into<Type>,

Sets the value of r#type.

Example
use google_cloud_compute_v1::model::named_set::Type;
let x0 = NamedSet::new().set_type(Type::NamedSetTypePrefix);
pub fn set_or_clear_type<T>(self, v: Option<T>) -> Self
where T: Into<Type>,

Sets or clears the value of r#type.

Example
use google_cloud_compute_v1::model::named_set::Type;
let x0 = NamedSet::new().set_or_clear_type(Some(Type::NamedSetTypePrefix));
let x_none = NamedSet::new().set_or_clear_type(None::<Type>);