#[non_exhaustive]pub struct NetworkAttachmentConnectedEndpoint {
pub ip_address: Option<String>,
pub ipv_6_address: Option<String>,
pub project_id_or_num: Option<String>,
pub secondary_ip_cidr_ranges: Vec<String>,
pub service_class_id: Option<String>,
pub status: Option<Status>,
pub subnetwork: Option<String>,
pub subnetwork_cidr_range: Option<String>,
/* private fields */
}network-attachments only.Expand description
[Output Only] A connection connected to this network attachment.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ip_address: Option<String>The IPv4 address assigned to the producer instance network interface. This value will be a range in case of Serverless.
ipv_6_address: Option<String>The IPv6 address assigned to the producer instance network interface. This is only assigned when the stack types of both the instance network interface and the consumer subnet are IPv4_IPv6.
project_id_or_num: Option<String>The project id or number of the interface to which the IP was assigned.
secondary_ip_cidr_ranges: Vec<String>Alias IP ranges from the same subnetwork.
service_class_id: Option<String>The service class id of the producer service to which the IP was assigned.
status: Option<Status>The status of a connected endpoint to this network attachment.
subnetwork: Option<String>The subnetwork used to assign the IP to the producer instance network interface.
subnetwork_cidr_range: Option<String>Output only. [Output Only] The CIDR range of the subnet from which the IPv4 internal IP was allocated from.
Implementations
Sourceimpl NetworkAttachmentConnectedEndpoint
impl NetworkAttachmentConnectedEndpoint
Sourcepub fn set_ip_address<T>(self, v: T) -> Self
pub fn set_ip_address<T>(self, v: T) -> Self
Sets the value of ip_address.
Example
let x = NetworkAttachmentConnectedEndpoint::new().set_ip_address("example");Sourcepub fn set_or_clear_ip_address<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_ip_address<T>(self, v: Option<T>) -> Self
Sets or clears the value of ip_address.
Example
let x = NetworkAttachmentConnectedEndpoint::new().set_or_clear_ip_address(Some("example"));
let x = NetworkAttachmentConnectedEndpoint::new().set_or_clear_ip_address(None::<String>);Sourcepub fn set_ipv_6_address<T>(self, v: T) -> Self
pub fn set_ipv_6_address<T>(self, v: T) -> Self
Sets the value of ipv_6_address.
Example
let x = NetworkAttachmentConnectedEndpoint::new().set_ipv_6_address("example");Sourcepub fn set_or_clear_ipv_6_address<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_ipv_6_address<T>(self, v: Option<T>) -> Self
Sets or clears the value of ipv_6_address.
Example
let x = NetworkAttachmentConnectedEndpoint::new().set_or_clear_ipv_6_address(Some("example"));
let x = NetworkAttachmentConnectedEndpoint::new().set_or_clear_ipv_6_address(None::<String>);Sourcepub fn set_project_id_or_num<T>(self, v: T) -> Self
pub fn set_project_id_or_num<T>(self, v: T) -> Self
Sets the value of project_id_or_num.
Example
let x = NetworkAttachmentConnectedEndpoint::new().set_project_id_or_num("example");Sourcepub fn set_or_clear_project_id_or_num<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_project_id_or_num<T>(self, v: Option<T>) -> Self
Sets or clears the value of project_id_or_num.
Example
let x = NetworkAttachmentConnectedEndpoint::new().set_or_clear_project_id_or_num(Some("example"));
let x = NetworkAttachmentConnectedEndpoint::new().set_or_clear_project_id_or_num(None::<String>);Sourcepub fn set_secondary_ip_cidr_ranges<T, V>(self, v: T) -> Self
pub fn set_secondary_ip_cidr_ranges<T, V>(self, v: T) -> Self
Sets the value of secondary_ip_cidr_ranges.
Example
let x = NetworkAttachmentConnectedEndpoint::new().set_secondary_ip_cidr_ranges(["a", "b", "c"]);Sourcepub fn set_service_class_id<T>(self, v: T) -> Self
pub fn set_service_class_id<T>(self, v: T) -> Self
Sets the value of service_class_id.
Example
let x = NetworkAttachmentConnectedEndpoint::new().set_service_class_id("example");Sourcepub fn set_or_clear_service_class_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_service_class_id<T>(self, v: Option<T>) -> Self
Sets or clears the value of service_class_id.
Example
let x = NetworkAttachmentConnectedEndpoint::new().set_or_clear_service_class_id(Some("example"));
let x = NetworkAttachmentConnectedEndpoint::new().set_or_clear_service_class_id(None::<String>);Sourcepub fn set_status<T>(self, v: T) -> Self
pub fn set_status<T>(self, v: T) -> Self
Sets the value of status.
Example
use google_cloud_compute_v1::model::network_attachment_connected_endpoint::Status;
let x0 = NetworkAttachmentConnectedEndpoint::new().set_status(Status::Closed);
let x1 = NetworkAttachmentConnectedEndpoint::new().set_status(Status::NeedsAttention);
let x2 = NetworkAttachmentConnectedEndpoint::new().set_status(Status::Pending);Sourcepub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
Sets or clears the value of status.
Example
use google_cloud_compute_v1::model::network_attachment_connected_endpoint::Status;
let x0 = NetworkAttachmentConnectedEndpoint::new().set_or_clear_status(Some(Status::Closed));
let x1 = NetworkAttachmentConnectedEndpoint::new().set_or_clear_status(Some(Status::NeedsAttention));
let x2 = NetworkAttachmentConnectedEndpoint::new().set_or_clear_status(Some(Status::Pending));
let x_none = NetworkAttachmentConnectedEndpoint::new().set_or_clear_status(None::<Status>);Sourcepub fn set_subnetwork<T>(self, v: T) -> Self
pub fn set_subnetwork<T>(self, v: T) -> Self
Sets the value of subnetwork.
Example
let x = NetworkAttachmentConnectedEndpoint::new().set_subnetwork("example");Sourcepub fn set_or_clear_subnetwork<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_subnetwork<T>(self, v: Option<T>) -> Self
Sets or clears the value of subnetwork.
Example
let x = NetworkAttachmentConnectedEndpoint::new().set_or_clear_subnetwork(Some("example"));
let x = NetworkAttachmentConnectedEndpoint::new().set_or_clear_subnetwork(None::<String>);Sourcepub fn set_subnetwork_cidr_range<T>(self, v: T) -> Self
pub fn set_subnetwork_cidr_range<T>(self, v: T) -> Self
Sets the value of subnetwork_cidr_range.
Example
let x = NetworkAttachmentConnectedEndpoint::new().set_subnetwork_cidr_range("example");Sourcepub fn set_or_clear_subnetwork_cidr_range<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_subnetwork_cidr_range<T>(self, v: Option<T>) -> Self
Sets or clears the value of subnetwork_cidr_range.
Example
let x = NetworkAttachmentConnectedEndpoint::new().set_or_clear_subnetwork_cidr_range(Some("example"));
let x = NetworkAttachmentConnectedEndpoint::new().set_or_clear_subnetwork_cidr_range(None::<String>);Trait Implementations
Sourceimpl Clone for NetworkAttachmentConnectedEndpoint
impl Clone for NetworkAttachmentConnectedEndpoint
Sourcefn clone(&self) -> NetworkAttachmentConnectedEndpoint
fn clone(&self) -> NetworkAttachmentConnectedEndpoint
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for NetworkAttachmentConnectedEndpoint
impl Default for NetworkAttachmentConnectedEndpoint
Sourcefn default() -> NetworkAttachmentConnectedEndpoint
fn default() -> NetworkAttachmentConnectedEndpoint
impl StructuralPartialEq for NetworkAttachmentConnectedEndpoint