#[non_exhaustive]pub struct NetworkEdgeSecurityService {
pub creation_timestamp: Option<String>,
pub description: Option<String>,
pub fingerprint: Option<Bytes>,
pub id: Option<u64>,
pub kind: Option<String>,
pub name: Option<String>,
pub region: Option<String>,
pub security_policy: Option<String>,
pub self_link: Option<String>,
pub self_link_with_id: Option<String>,
/* private fields */
}network-edge-security-services only.Expand description
Represents a Google Cloud Armor network edge security service resource.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.creation_timestamp: Option<String>Output only. [Output Only] Creation timestamp inRFC3339 text format.
description: Option<String>An optional description of this resource. Provide this property when you create the resource.
fingerprint: Option<Bytes>Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a NetworkEdgeSecurityService. An up-to-date fingerprint must be provided in order to update the NetworkEdgeSecurityService, otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to retrieve a NetworkEdgeSecurityService.
id: Option<u64>Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.
kind: Option<String>Output only. [Output only] Type of the resource. Alwayscompute#networkEdgeSecurityService for NetworkEdgeSecurityServices
name: Option<String>Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
region: Option<String>Output only. [Output Only] URL of the region where the resource resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
security_policy: Option<String>The resource URL for the network edge security service associated with this network edge security service.
self_link: Option<String>Output only. [Output Only] Server-defined URL for the resource.
self_link_with_id: Option<String>Output only. [Output Only] Server-defined URL for this resource with the resource id.
Implementations
Sourceimpl NetworkEdgeSecurityService
impl NetworkEdgeSecurityService
Sourcepub fn set_creation_timestamp<T>(self, v: T) -> Self
pub fn set_creation_timestamp<T>(self, v: T) -> Self
Sets the value of creation_timestamp.
Example
let x = NetworkEdgeSecurityService::new().set_creation_timestamp("example");Sourcepub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
Sets or clears the value of creation_timestamp.
Example
let x = NetworkEdgeSecurityService::new().set_or_clear_creation_timestamp(Some("example"));
let x = NetworkEdgeSecurityService::new().set_or_clear_creation_timestamp(None::<String>);Sourcepub fn set_description<T>(self, v: T) -> Self
pub fn set_description<T>(self, v: T) -> Self
Sets the value of description.
Example
let x = NetworkEdgeSecurityService::new().set_description("example");Sourcepub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
Sets or clears the value of description.
Example
let x = NetworkEdgeSecurityService::new().set_or_clear_description(Some("example"));
let x = NetworkEdgeSecurityService::new().set_or_clear_description(None::<String>);Sourcepub fn set_fingerprint<T>(self, v: T) -> Self
pub fn set_fingerprint<T>(self, v: T) -> Self
Sets the value of fingerprint.
Example
let x = NetworkEdgeSecurityService::new().set_fingerprint(bytes::Bytes::from_static(b"example"));Sourcepub fn set_or_clear_fingerprint<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_fingerprint<T>(self, v: Option<T>) -> Self
Sets or clears the value of fingerprint.
Example
let x = NetworkEdgeSecurityService::new().set_or_clear_fingerprint(Some(bytes::Bytes::from_static(b"example")));
let x = NetworkEdgeSecurityService::new().set_or_clear_fingerprint(None::<bytes::Bytes>);Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
Sourcepub fn set_region<T>(self, v: T) -> Self
pub fn set_region<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_region<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_region<T>(self, v: Option<T>) -> Self
Sourcepub fn set_security_policy<T>(self, v: T) -> Self
pub fn set_security_policy<T>(self, v: T) -> Self
Sets the value of security_policy.
Example
let x = NetworkEdgeSecurityService::new().set_security_policy("example");Sourcepub fn set_or_clear_security_policy<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_security_policy<T>(self, v: Option<T>) -> Self
Sets or clears the value of security_policy.
Example
let x = NetworkEdgeSecurityService::new().set_or_clear_security_policy(Some("example"));
let x = NetworkEdgeSecurityService::new().set_or_clear_security_policy(None::<String>);Sourcepub fn set_self_link<T>(self, v: T) -> Self
pub fn set_self_link<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
Sourcepub fn set_self_link_with_id<T>(self, v: T) -> Self
pub fn set_self_link_with_id<T>(self, v: T) -> Self
Sets the value of self_link_with_id.
Example
let x = NetworkEdgeSecurityService::new().set_self_link_with_id("example");Sourcepub fn set_or_clear_self_link_with_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link_with_id<T>(self, v: Option<T>) -> Self
Sets or clears the value of self_link_with_id.
Example
let x = NetworkEdgeSecurityService::new().set_or_clear_self_link_with_id(Some("example"));
let x = NetworkEdgeSecurityService::new().set_or_clear_self_link_with_id(None::<String>);Trait Implementations
Sourceimpl Clone for NetworkEdgeSecurityService
impl Clone for NetworkEdgeSecurityService
Sourcefn clone(&self) -> NetworkEdgeSecurityService
fn clone(&self) -> NetworkEdgeSecurityService
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for NetworkEdgeSecurityService
impl Debug for NetworkEdgeSecurityService
Sourceimpl Default for NetworkEdgeSecurityService
impl Default for NetworkEdgeSecurityService
Sourcefn default() -> NetworkEdgeSecurityService
fn default() -> NetworkEdgeSecurityService
Sourceimpl Message for NetworkEdgeSecurityService
impl Message for NetworkEdgeSecurityService
impl StructuralPartialEq for NetworkEdgeSecurityService