#[non_exhaustive]pub struct NetworkEndpointGroupCloudFunction {
pub function: Option<String>,
pub url_mask: Option<String>,
/* private fields */
}global-network-endpoint-groups or network-endpoint-groups or region-network-endpoint-groups only.Expand description
Configuration for a Cloud Function network endpoint group (NEG). The function must be provided explicitly or in the URL mask.
Note: Cloud Function must be in the same project and located in the same region as the Serverless NEG.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.function: Option<String>A user-defined name of the Cloud Function.
The function name is case-sensitive and must be 1-63 characters long.
Example value: func1.
url_mask: Option<String>An URL mask is one of the main components of the Cloud Function.
A template to parse function field from a request URL. URL mask allows for routing to multiple Cloud Functions without having to create multiple Network Endpoint Groups and backend services.
For example, request URLs mydomain.com/function1 andmydomain.com/function2 can be backed by the same Serverless NEG with URL mask /<function>. The URL mask will parse them to { function = “function1” } and{ function = “function2” } respectively.
Implementations
Sourceimpl NetworkEndpointGroupCloudFunction
impl NetworkEndpointGroupCloudFunction
Sourcepub fn set_function<T>(self, v: T) -> Self
pub fn set_function<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_function<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_function<T>(self, v: Option<T>) -> Self
Sourcepub fn set_url_mask<T>(self, v: T) -> Self
pub fn set_url_mask<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_url_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_url_mask<T>(self, v: Option<T>) -> Self