#[non_exhaustive]pub struct NetworkEndpointGroupCloudRun {
pub service: Option<String>,
pub tag: Option<String>,
pub url_mask: Option<String>,
/* private fields */
}global-network-endpoint-groups or network-endpoint-groups or region-network-endpoint-groups only.Expand description
Configuration for a Cloud Run network endpoint group (NEG). The service must be provided explicitly or in the URL mask. The tag is optional, may be provided explicitly or in the URL mask.
Note: Cloud Run service must be in the same project and located in the same region as the Serverless NEG.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.service: Option<String>Cloud Run service is the main resource of Cloud Run.
The service must be 1-63 characters long, and comply withRFC1035.
Example value: “run-service”.
tag: Option<String>Optional Cloud Run tag represents the “named-revision” to provide additional fine-grained traffic routing information.
The tag must be 1-63 characters long, and comply withRFC1035.
Example value: “revision-0010”.
url_mask: Option<String>An URL mask is one of the main components of the Cloud Function.
A template to parse <service> and<tag> fields from a request URL. URL mask allows for routing to multiple Run services without having to create multiple network endpoint groups and backend services.
For example, request URLs foo1.domain.com/bar1 andfoo1.domain.com/bar2 can be backed by the same Serverless Network Endpoint Group (NEG) with URL mask<tag>.domain.com/<service>. The URL mask will parse them to { service=“bar1”, tag=“foo1” } and { service=“bar2”, tag=“foo2” } respectively.
Implementations
Sourceimpl NetworkEndpointGroupCloudRun
impl NetworkEndpointGroupCloudRun
Sourcepub fn set_service<T>(self, v: T) -> Self
pub fn set_service<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_service<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_service<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_tag<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_tag<T>(self, v: Option<T>) -> Self
Sourcepub fn set_url_mask<T>(self, v: T) -> Self
pub fn set_url_mask<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_url_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_url_mask<T>(self, v: Option<T>) -> Self