#[non_exhaustive]pub struct NetworkEndpointGroupPscData {
pub consumer_psc_address: Option<String>,
pub producer_port: Option<i32>,
pub psc_connection_id: Option<u64>,
pub psc_connection_status: Option<PscConnectionStatus>,
/* private fields */
}global-network-endpoint-groups or network-endpoint-groups or region-network-endpoint-groups only.Expand description
All data that is specifically relevant to only network endpoint groups of type PRIVATE_SERVICE_CONNECT.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.consumer_psc_address: Option<String>Output only. [Output Only] Address allocated from given subnetwork for PSC. This IP address acts as a VIP for a PSC NEG, allowing it to act as an endpoint in L7 PSC-XLB.
producer_port: Option<i32>The psc producer port is used to connect PSC NEG with specific port on the PSC Producer side; should only be used for the PRIVATE_SERVICE_CONNECT NEG type
psc_connection_id: Option<u64>Output only. [Output Only] The PSC connection id of the PSC Network Endpoint Group Consumer.
psc_connection_status: Option<PscConnectionStatus>Output only. [Output Only] The connection status of the PSC Forwarding Rule.
Implementations
Sourceimpl NetworkEndpointGroupPscData
impl NetworkEndpointGroupPscData
Sourcepub fn set_consumer_psc_address<T>(self, v: T) -> Self
pub fn set_consumer_psc_address<T>(self, v: T) -> Self
Sets the value of consumer_psc_address.
Example
let x = NetworkEndpointGroupPscData::new().set_consumer_psc_address("example");Sourcepub fn set_or_clear_consumer_psc_address<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_consumer_psc_address<T>(self, v: Option<T>) -> Self
Sets or clears the value of consumer_psc_address.
Example
let x = NetworkEndpointGroupPscData::new().set_or_clear_consumer_psc_address(Some("example"));
let x = NetworkEndpointGroupPscData::new().set_or_clear_consumer_psc_address(None::<String>);Sourcepub fn set_producer_port<T>(self, v: T) -> Self
pub fn set_producer_port<T>(self, v: T) -> Self
Sets the value of producer_port.
Example
let x = NetworkEndpointGroupPscData::new().set_producer_port(42);Sourcepub fn set_or_clear_producer_port<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_producer_port<T>(self, v: Option<T>) -> Self
Sets or clears the value of producer_port.
Example
let x = NetworkEndpointGroupPscData::new().set_or_clear_producer_port(Some(42));
let x = NetworkEndpointGroupPscData::new().set_or_clear_producer_port(None::<i32>);Sourcepub fn set_psc_connection_id<T>(self, v: T) -> Self
pub fn set_psc_connection_id<T>(self, v: T) -> Self
Sets the value of psc_connection_id.
Example
let x = NetworkEndpointGroupPscData::new().set_psc_connection_id(42_u32);Sourcepub fn set_or_clear_psc_connection_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_psc_connection_id<T>(self, v: Option<T>) -> Self
Sets or clears the value of psc_connection_id.
Example
let x = NetworkEndpointGroupPscData::new().set_or_clear_psc_connection_id(Some(42_u32));
let x = NetworkEndpointGroupPscData::new().set_or_clear_psc_connection_id(None::<u32>);Sourcepub fn set_psc_connection_status<T>(self, v: T) -> Selfwhere
T: Into<PscConnectionStatus>,
pub fn set_psc_connection_status<T>(self, v: T) -> Selfwhere
T: Into<PscConnectionStatus>,
Sets the value of psc_connection_status.
Example
use google_cloud_compute_v1::model::network_endpoint_group_psc_data::PscConnectionStatus;
let x0 = NetworkEndpointGroupPscData::new().set_psc_connection_status(PscConnectionStatus::Closed);
let x1 = NetworkEndpointGroupPscData::new().set_psc_connection_status(PscConnectionStatus::NeedsAttention);
let x2 = NetworkEndpointGroupPscData::new().set_psc_connection_status(PscConnectionStatus::Pending);Sourcepub fn set_or_clear_psc_connection_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<PscConnectionStatus>,
pub fn set_or_clear_psc_connection_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<PscConnectionStatus>,
Sets or clears the value of psc_connection_status.
Example
use google_cloud_compute_v1::model::network_endpoint_group_psc_data::PscConnectionStatus;
let x0 = NetworkEndpointGroupPscData::new().set_or_clear_psc_connection_status(Some(PscConnectionStatus::Closed));
let x1 = NetworkEndpointGroupPscData::new().set_or_clear_psc_connection_status(Some(PscConnectionStatus::NeedsAttention));
let x2 = NetworkEndpointGroupPscData::new().set_or_clear_psc_connection_status(Some(PscConnectionStatus::Pending));
let x_none = NetworkEndpointGroupPscData::new().set_or_clear_psc_connection_status(None::<PscConnectionStatus>);Trait Implementations
Sourceimpl Clone for NetworkEndpointGroupPscData
impl Clone for NetworkEndpointGroupPscData
Sourcefn clone(&self) -> NetworkEndpointGroupPscData
fn clone(&self) -> NetworkEndpointGroupPscData
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for NetworkEndpointGroupPscData
impl Debug for NetworkEndpointGroupPscData
Sourceimpl Default for NetworkEndpointGroupPscData
impl Default for NetworkEndpointGroupPscData
Sourcefn default() -> NetworkEndpointGroupPscData
fn default() -> NetworkEndpointGroupPscData
impl StructuralPartialEq for NetworkEndpointGroupPscData