#[non_exhaustive]pub struct NetworkEndpointGroupsListNetworkEndpoints {
pub id: Option<String>,
pub items: Vec<NetworkEndpointWithHealthStatus>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
pub warning: Option<Warning>,
/* private fields */
}global-network-endpoint-groups or network-endpoint-groups or region-network-endpoint-groups only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>[Output Only] Unique identifier for the resource; defined by the server.
items: Vec<NetworkEndpointWithHealthStatus>A list of NetworkEndpointWithHealthStatus resources.
kind: Option<String>Output only. [Output Only] The resource type, which is alwayscompute#networkEndpointGroupsListNetworkEndpoints for the list of network endpoints in the specified network endpoint group.
next_page_token: Option<String>[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
warning: Option<Warning>[Output Only] Informational warning message.
Implementations
Sourceimpl NetworkEndpointGroupsListNetworkEndpoints
impl NetworkEndpointGroupsListNetworkEndpoints
Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
Sourcepub fn set_items<T, V>(self, v: T) -> Self
pub fn set_items<T, V>(self, v: T) -> Self
Sets the value of items.
Example
use google_cloud_compute_v1::model::NetworkEndpointWithHealthStatus;
let x = NetworkEndpointGroupsListNetworkEndpoints::new()
.set_items([
NetworkEndpointWithHealthStatus::default()/* use setters */,
NetworkEndpointWithHealthStatus::default()/* use (different) setters */,
]);Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_next_page_token<T>(self, v: T) -> Self
pub fn set_next_page_token<T>(self, v: T) -> Self
Sets the value of next_page_token.
Example
let x = NetworkEndpointGroupsListNetworkEndpoints::new().set_next_page_token("example");Sourcepub fn set_or_clear_next_page_token<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_next_page_token<T>(self, v: Option<T>) -> Self
Sets or clears the value of next_page_token.
Example
let x = NetworkEndpointGroupsListNetworkEndpoints::new().set_or_clear_next_page_token(Some("example"));
let x = NetworkEndpointGroupsListNetworkEndpoints::new().set_or_clear_next_page_token(None::<String>);Sourcepub fn set_warning<T>(self, v: T) -> Self
pub fn set_warning<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self
Sets or clears the value of warning.
Example
use google_cloud_compute_v1::model::network_endpoint_groups_list_network_endpoints::Warning;
let x = NetworkEndpointGroupsListNetworkEndpoints::new().set_or_clear_warning(Some(Warning::default()/* use setters */));
let x = NetworkEndpointGroupsListNetworkEndpoints::new().set_or_clear_warning(None::<Warning>);Trait Implementations
Sourceimpl Clone for NetworkEndpointGroupsListNetworkEndpoints
impl Clone for NetworkEndpointGroupsListNetworkEndpoints
Sourcefn clone(&self) -> NetworkEndpointGroupsListNetworkEndpoints
fn clone(&self) -> NetworkEndpointGroupsListNetworkEndpoints
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for NetworkEndpointGroupsListNetworkEndpoints
impl Default for NetworkEndpointGroupsListNetworkEndpoints
Sourcefn default() -> NetworkEndpointGroupsListNetworkEndpoints
fn default() -> NetworkEndpointGroupsListNetworkEndpoints
impl StructuralPartialEq for NetworkEndpointGroupsListNetworkEndpoints