#[non_exhaustive]pub struct NetworkPeeringConnectionStatus {
pub consensus_state: Option<NetworkPeeringConnectionStatusConsensusState>,
pub traffic_configuration: Option<NetworkPeeringConnectionStatusTrafficConfiguration>,
pub update_strategy: Option<UpdateStrategy>,
/* private fields */
}networks only.Expand description
[Output Only] Describes the state of a peering connection, not just the local peering. This field provides information about the effective settings for the connection as a whole, including pending delete/update requests for CONSENSUS peerings.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.consensus_state: Option<NetworkPeeringConnectionStatusConsensusState>The consensus state contains information about the status of update and delete for a consensus peering connection.
traffic_configuration: Option<NetworkPeeringConnectionStatusTrafficConfiguration>The active connectivity settings for the peering connection based on the settings of the network peerings.
update_strategy: Option<UpdateStrategy>The update strategy determines the update/delete semantics for this peering connection.
Implementations
Sourceimpl NetworkPeeringConnectionStatus
impl NetworkPeeringConnectionStatus
Sourcepub fn set_consensus_state<T>(self, v: T) -> Selfwhere
T: Into<NetworkPeeringConnectionStatusConsensusState>,
pub fn set_consensus_state<T>(self, v: T) -> Selfwhere
T: Into<NetworkPeeringConnectionStatusConsensusState>,
Sets the value of consensus_state.
Example
use google_cloud_compute_v1::model::NetworkPeeringConnectionStatusConsensusState;
let x = NetworkPeeringConnectionStatus::new().set_consensus_state(NetworkPeeringConnectionStatusConsensusState::default()/* use setters */);Sourcepub fn set_or_clear_consensus_state<T>(self, v: Option<T>) -> Selfwhere
T: Into<NetworkPeeringConnectionStatusConsensusState>,
pub fn set_or_clear_consensus_state<T>(self, v: Option<T>) -> Selfwhere
T: Into<NetworkPeeringConnectionStatusConsensusState>,
Sets or clears the value of consensus_state.
Example
use google_cloud_compute_v1::model::NetworkPeeringConnectionStatusConsensusState;
let x = NetworkPeeringConnectionStatus::new().set_or_clear_consensus_state(Some(NetworkPeeringConnectionStatusConsensusState::default()/* use setters */));
let x = NetworkPeeringConnectionStatus::new().set_or_clear_consensus_state(None::<NetworkPeeringConnectionStatusConsensusState>);Sourcepub fn set_traffic_configuration<T>(self, v: T) -> Self
pub fn set_traffic_configuration<T>(self, v: T) -> Self
Sets the value of traffic_configuration.
Example
use google_cloud_compute_v1::model::NetworkPeeringConnectionStatusTrafficConfiguration;
let x = NetworkPeeringConnectionStatus::new().set_traffic_configuration(NetworkPeeringConnectionStatusTrafficConfiguration::default()/* use setters */);Sourcepub fn set_or_clear_traffic_configuration<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_traffic_configuration<T>(self, v: Option<T>) -> Self
Sets or clears the value of traffic_configuration.
Example
use google_cloud_compute_v1::model::NetworkPeeringConnectionStatusTrafficConfiguration;
let x = NetworkPeeringConnectionStatus::new().set_or_clear_traffic_configuration(Some(NetworkPeeringConnectionStatusTrafficConfiguration::default()/* use setters */));
let x = NetworkPeeringConnectionStatus::new().set_or_clear_traffic_configuration(None::<NetworkPeeringConnectionStatusTrafficConfiguration>);Sourcepub fn set_update_strategy<T>(self, v: T) -> Selfwhere
T: Into<UpdateStrategy>,
pub fn set_update_strategy<T>(self, v: T) -> Selfwhere
T: Into<UpdateStrategy>,
Sets the value of update_strategy.
Example
use google_cloud_compute_v1::model::network_peering_connection_status::UpdateStrategy;
let x0 = NetworkPeeringConnectionStatus::new().set_update_strategy(UpdateStrategy::Independent);
let x1 = NetworkPeeringConnectionStatus::new().set_update_strategy(UpdateStrategy::Unspecified);Sourcepub fn set_or_clear_update_strategy<T>(self, v: Option<T>) -> Selfwhere
T: Into<UpdateStrategy>,
pub fn set_or_clear_update_strategy<T>(self, v: Option<T>) -> Selfwhere
T: Into<UpdateStrategy>,
Sets or clears the value of update_strategy.
Example
use google_cloud_compute_v1::model::network_peering_connection_status::UpdateStrategy;
let x0 = NetworkPeeringConnectionStatus::new().set_or_clear_update_strategy(Some(UpdateStrategy::Independent));
let x1 = NetworkPeeringConnectionStatus::new().set_or_clear_update_strategy(Some(UpdateStrategy::Unspecified));
let x_none = NetworkPeeringConnectionStatus::new().set_or_clear_update_strategy(None::<UpdateStrategy>);Trait Implementations
Sourceimpl Clone for NetworkPeeringConnectionStatus
impl Clone for NetworkPeeringConnectionStatus
Sourcefn clone(&self) -> NetworkPeeringConnectionStatus
fn clone(&self) -> NetworkPeeringConnectionStatus
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for NetworkPeeringConnectionStatus
impl Default for NetworkPeeringConnectionStatus
Sourcefn default() -> NetworkPeeringConnectionStatus
fn default() -> NetworkPeeringConnectionStatus
impl StructuralPartialEq for NetworkPeeringConnectionStatus