#[non_exhaustive]pub struct NetworkPeeringConnectionStatusTrafficConfiguration {
pub export_custom_routes_to_peer: Option<bool>,
pub export_subnet_routes_with_public_ip_to_peer: Option<bool>,
pub import_custom_routes_from_peer: Option<bool>,
pub import_subnet_routes_with_public_ip_from_peer: Option<bool>,
pub stack_type: Option<StackType>,
/* private fields */
}networks only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.export_custom_routes_to_peer: Option<bool>Whether custom routes are being exported to the peer network.
export_subnet_routes_with_public_ip_to_peer: Option<bool>Whether subnet routes with public IP ranges are being exported to the peer network.
import_custom_routes_from_peer: Option<bool>Whether custom routes are being imported from the peer network.
import_subnet_routes_with_public_ip_from_peer: Option<bool>Whether subnet routes with public IP ranges are being imported from the peer network.
stack_type: Option<StackType>Which IP version(s) of traffic and routes are being imported or exported between peer networks.
Implementations
Sourceimpl NetworkPeeringConnectionStatusTrafficConfiguration
impl NetworkPeeringConnectionStatusTrafficConfiguration
Sourcepub fn set_export_custom_routes_to_peer<T>(self, v: T) -> Self
pub fn set_export_custom_routes_to_peer<T>(self, v: T) -> Self
Sets the value of export_custom_routes_to_peer.
Example
let x = NetworkPeeringConnectionStatusTrafficConfiguration::new().set_export_custom_routes_to_peer(true);Sourcepub fn set_or_clear_export_custom_routes_to_peer<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_export_custom_routes_to_peer<T>(self, v: Option<T>) -> Self
Sets or clears the value of export_custom_routes_to_peer.
Example
let x = NetworkPeeringConnectionStatusTrafficConfiguration::new().set_or_clear_export_custom_routes_to_peer(Some(false));
let x = NetworkPeeringConnectionStatusTrafficConfiguration::new().set_or_clear_export_custom_routes_to_peer(None::<bool>);Sourcepub fn set_export_subnet_routes_with_public_ip_to_peer<T>(self, v: T) -> Self
pub fn set_export_subnet_routes_with_public_ip_to_peer<T>(self, v: T) -> Self
Sets the value of export_subnet_routes_with_public_ip_to_peer.
Example
let x = NetworkPeeringConnectionStatusTrafficConfiguration::new().set_export_subnet_routes_with_public_ip_to_peer(true);Sourcepub fn set_or_clear_export_subnet_routes_with_public_ip_to_peer<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_export_subnet_routes_with_public_ip_to_peer<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of export_subnet_routes_with_public_ip_to_peer.
Example
let x = NetworkPeeringConnectionStatusTrafficConfiguration::new().set_or_clear_export_subnet_routes_with_public_ip_to_peer(Some(false));
let x = NetworkPeeringConnectionStatusTrafficConfiguration::new().set_or_clear_export_subnet_routes_with_public_ip_to_peer(None::<bool>);Sourcepub fn set_import_custom_routes_from_peer<T>(self, v: T) -> Self
pub fn set_import_custom_routes_from_peer<T>(self, v: T) -> Self
Sets the value of import_custom_routes_from_peer.
Example
let x = NetworkPeeringConnectionStatusTrafficConfiguration::new().set_import_custom_routes_from_peer(true);Sourcepub fn set_or_clear_import_custom_routes_from_peer<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_import_custom_routes_from_peer<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of import_custom_routes_from_peer.
Example
let x = NetworkPeeringConnectionStatusTrafficConfiguration::new().set_or_clear_import_custom_routes_from_peer(Some(false));
let x = NetworkPeeringConnectionStatusTrafficConfiguration::new().set_or_clear_import_custom_routes_from_peer(None::<bool>);Sourcepub fn set_import_subnet_routes_with_public_ip_from_peer<T>(self, v: T) -> Self
pub fn set_import_subnet_routes_with_public_ip_from_peer<T>(self, v: T) -> Self
Sets the value of import_subnet_routes_with_public_ip_from_peer.
Example
let x = NetworkPeeringConnectionStatusTrafficConfiguration::new().set_import_subnet_routes_with_public_ip_from_peer(true);Sourcepub fn set_or_clear_import_subnet_routes_with_public_ip_from_peer<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_import_subnet_routes_with_public_ip_from_peer<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of import_subnet_routes_with_public_ip_from_peer.
Example
let x = NetworkPeeringConnectionStatusTrafficConfiguration::new().set_or_clear_import_subnet_routes_with_public_ip_from_peer(Some(false));
let x = NetworkPeeringConnectionStatusTrafficConfiguration::new().set_or_clear_import_subnet_routes_with_public_ip_from_peer(None::<bool>);Sourcepub fn set_stack_type<T>(self, v: T) -> Self
pub fn set_stack_type<T>(self, v: T) -> Self
Sets the value of stack_type.
Example
use google_cloud_compute_v1::model::network_peering_connection_status_traffic_configuration::StackType;
let x0 = NetworkPeeringConnectionStatusTrafficConfiguration::new().set_stack_type(StackType::Ipv4Only);Sourcepub fn set_or_clear_stack_type<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_stack_type<T>(self, v: Option<T>) -> Self
Sets or clears the value of stack_type.
Example
use google_cloud_compute_v1::model::network_peering_connection_status_traffic_configuration::StackType;
let x0 = NetworkPeeringConnectionStatusTrafficConfiguration::new().set_or_clear_stack_type(Some(StackType::Ipv4Only));
let x_none = NetworkPeeringConnectionStatusTrafficConfiguration::new().set_or_clear_stack_type(None::<StackType>);Trait Implementations
Sourceimpl Clone for NetworkPeeringConnectionStatusTrafficConfiguration
impl Clone for NetworkPeeringConnectionStatusTrafficConfiguration
Sourcefn clone(&self) -> NetworkPeeringConnectionStatusTrafficConfiguration
fn clone(&self) -> NetworkPeeringConnectionStatusTrafficConfiguration
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for NetworkPeeringConnectionStatusTrafficConfiguration
impl Default for NetworkPeeringConnectionStatusTrafficConfiguration
Sourcefn default() -> NetworkPeeringConnectionStatusTrafficConfiguration
fn default() -> NetworkPeeringConnectionStatusTrafficConfiguration
impl StructuralPartialEq for NetworkPeeringConnectionStatusTrafficConfiguration