#[non_exhaustive]pub struct NetworkProfileNetworkFeatures {Show 38 fields
pub address_purposes: Vec<AddressPurposes>,
pub allow_address_creation: Option<AllowAddressCreation>,
pub allow_alias_ip_ranges: Option<AllowAliasIpRanges>,
pub allow_auto_mode_subnet: Option<AllowAutoModeSubnet>,
pub allow_class_d_firewalls: Option<AllowClassDfirewalls>,
pub allow_cloud_nat: Option<AllowCloudNat>,
pub allow_cloud_router: Option<AllowCloudRouter>,
pub allow_default_nic_attachment: Option<AllowDefaultNicAttachment>,
pub allow_external_ip_access: Option<AllowExternalIpAccess>,
pub allow_firewall_policy: Option<AllowFirewallPolicy>,
pub allow_interconnect: Option<AllowInterconnect>,
pub allow_ip_forwarding: Option<AllowIpForwarding>,
pub allow_load_balancing: Option<AllowLoadBalancing>,
pub allow_multi_nic_in_same_network: Option<AllowMultiNicInSameNetwork>,
pub allow_multi_nic_in_same_subnetwork: Option<AllowMultiNicInSameSubnetwork>,
pub allow_multicast: Option<AllowMulticast>,
pub allow_ncc: Option<AllowNcc>,
pub allow_network_migration: Option<AllowNetworkMigration>,
pub allow_packet_mirroring: Option<AllowPacketMirroring>,
pub allow_private_google_access: Option<AllowPrivateGoogleAccess>,
pub allow_psc: Option<AllowPsc>,
pub allow_same_network_unicast: Option<AllowSameNetworkUnicast>,
pub allow_static_routes: Option<AllowStaticRoutes>,
pub allow_sub_interfaces: Option<AllowSubInterfaces>,
pub allow_subnetwork_creation: Option<AllowSubnetworkCreation>,
pub allow_vpc_firewall_rules: Option<AllowVpcFirewallRules>,
pub allow_vpc_peering: Option<AllowVpcPeering>,
pub allow_vpn: Option<AllowVpn>,
pub firewall_policy_types: Vec<FirewallPolicyTypes>,
pub interface_types: Vec<InterfaceTypes>,
pub multicast: Option<Multicast>,
pub predefined_network_internal_ipv_6_range: Option<String>,
pub predefined_subnetwork_ranges: Vec<NetworkProfileNetworkFeaturesPredefinedSubnetworkRange>,
pub subnet_purposes: Vec<SubnetPurposes>,
pub subnet_stack_types: Vec<SubnetStackTypes>,
pub subnetwork_purposes: Vec<SubnetworkPurposes>,
pub subnetwork_stack_types: Vec<SubnetworkStackTypes>,
pub unicast: Option<Unicast>,
/* private fields */
}network-profiles only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.address_purposes: Vec<AddressPurposes>Specifies what address purposes are supported. If empty, all address purposes are supported.
allow_address_creation: Option<AllowAddressCreation>Specifies whether address creation is allowed.
allow_alias_ip_ranges: Option<AllowAliasIpRanges>Specifies whether alias IP ranges (and secondary address ranges) are allowed.
allow_auto_mode_subnet: Option<AllowAutoModeSubnet>Specifies whether auto mode subnet creation is allowed.
allow_class_d_firewalls: Option<AllowClassDfirewalls>Specifies whether firewalls for Class D address ranges are supported.
allow_cloud_nat: Option<AllowCloudNat>Specifies whether cloud NAT creation is allowed.
allow_cloud_router: Option<AllowCloudRouter>Specifies whether cloud router creation is allowed.
allow_default_nic_attachment: Option<AllowDefaultNicAttachment>Specifies whether default NIC attachment is allowed.
allow_external_ip_access: Option<AllowExternalIpAccess>Specifies whether VMs are allowed to have external IP access on network interfaces connected to this VPC.
allow_firewall_policy: Option<AllowFirewallPolicy>Specifies whether firewall policy can be attached to the network.
allow_interconnect: Option<AllowInterconnect>Specifies whether Cloud Interconnect creation is allowed.
allow_ip_forwarding: Option<AllowIpForwarding>Specifies whether IP forwarding is allowed.
allow_load_balancing: Option<AllowLoadBalancing>Specifies whether cloud load balancing is allowed.
allow_multi_nic_in_same_network: Option<AllowMultiNicInSameNetwork>Specifies whether multi-nic in the same network is allowed.
allow_multi_nic_in_same_subnetwork: Option<AllowMultiNicInSameSubnetwork>Specifies whether multi-nic in the same subnetwork is allowed.
allow_multicast: Option<AllowMulticast>Specifies whether multicast is allowed.
allow_ncc: Option<AllowNcc>Specifies whether NCC is allowed.
allow_network_migration: Option<AllowNetworkMigration>Specifies whether VM network migration is allowed.
allow_packet_mirroring: Option<AllowPacketMirroring>Specifies whether Packet Mirroring 1.0 is supported.
allow_private_google_access: Option<AllowPrivateGoogleAccess>Specifies whether private Google access is allowed.
allow_psc: Option<AllowPsc>Specifies whether PSC creation is allowed.
allow_same_network_unicast: Option<AllowSameNetworkUnicast>Specifies whether unicast within the same network is allowed.
allow_static_routes: Option<AllowStaticRoutes>Specifies whether static route creation is allowed.
allow_sub_interfaces: Option<AllowSubInterfaces>Specifies whether sub interfaces are allowed.
allow_subnetwork_creation: Option<AllowSubnetworkCreation>Specifies whether subnetwork creation is allowed.
allow_vpc_firewall_rules: Option<AllowVpcFirewallRules>Specifies whether VPC firewall rules can be created under the network.
allow_vpc_peering: Option<AllowVpcPeering>Specifies whether VPC peering is allowed.
allow_vpn: Option<AllowVpn>Specifies whether VPN creation is allowed.
firewall_policy_types: Vec<FirewallPolicyTypes>interface_types: Vec<InterfaceTypes>If set, limits the interface types that the network supports. If empty, all interface types are supported.
multicast: Option<Multicast>Specifies which type of multicast is supported.
predefined_network_internal_ipv_6_range: Option<String>Specifies a predefined internal IPv6 range for the network.
predefined_subnetwork_ranges: Vec<NetworkProfileNetworkFeaturesPredefinedSubnetworkRange>Predefined subnetwork ranges for the network.
subnet_purposes: Vec<SubnetPurposes>Specifies which subnetwork purposes are supported.
subnet_stack_types: Vec<SubnetStackTypes>Specifies which subnetwork stack types are supported.
subnetwork_purposes: Vec<SubnetworkPurposes>Output only. Specifies which subnetwork purposes are supported.
subnetwork_stack_types: Vec<SubnetworkStackTypes>Output only. Specifies which subnetwork stack types are supported.
unicast: Option<Unicast>Specifies which type of unicast is supported.
Implementations
Sourceimpl NetworkProfileNetworkFeatures
impl NetworkProfileNetworkFeatures
Sourcepub fn set_address_purposes<T, V>(self, v: T) -> Self
pub fn set_address_purposes<T, V>(self, v: T) -> Self
Sets the value of address_purposes.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AddressPurposes;
let x = NetworkProfileNetworkFeatures::new().set_address_purposes([
AddressPurposes::GceEndpoint,
AddressPurposes::IpsecInterconnect,
AddressPurposes::NatAuto,
]);Sourcepub fn set_allow_address_creation<T>(self, v: T) -> Selfwhere
T: Into<AllowAddressCreation>,
pub fn set_allow_address_creation<T>(self, v: T) -> Selfwhere
T: Into<AllowAddressCreation>,
Sets the value of allow_address_creation.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowAddressCreation;
let x0 = NetworkProfileNetworkFeatures::new().set_allow_address_creation(AllowAddressCreation::AddressCreationBlocked);Sourcepub fn set_or_clear_allow_address_creation<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowAddressCreation>,
pub fn set_or_clear_allow_address_creation<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowAddressCreation>,
Sets or clears the value of allow_address_creation.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowAddressCreation;
let x0 = NetworkProfileNetworkFeatures::new().set_or_clear_allow_address_creation(Some(AllowAddressCreation::AddressCreationBlocked));
let x_none = NetworkProfileNetworkFeatures::new().set_or_clear_allow_address_creation(None::<AllowAddressCreation>);Sourcepub fn set_allow_alias_ip_ranges<T>(self, v: T) -> Selfwhere
T: Into<AllowAliasIpRanges>,
pub fn set_allow_alias_ip_ranges<T>(self, v: T) -> Selfwhere
T: Into<AllowAliasIpRanges>,
Sets the value of allow_alias_ip_ranges.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowAliasIpRanges;
let x0 = NetworkProfileNetworkFeatures::new().set_allow_alias_ip_ranges(AllowAliasIpRanges::AliasIpRangesBlocked);Sourcepub fn set_or_clear_allow_alias_ip_ranges<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowAliasIpRanges>,
pub fn set_or_clear_allow_alias_ip_ranges<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowAliasIpRanges>,
Sets or clears the value of allow_alias_ip_ranges.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowAliasIpRanges;
let x0 = NetworkProfileNetworkFeatures::new().set_or_clear_allow_alias_ip_ranges(Some(AllowAliasIpRanges::AliasIpRangesBlocked));
let x_none = NetworkProfileNetworkFeatures::new().set_or_clear_allow_alias_ip_ranges(None::<AllowAliasIpRanges>);Sourcepub fn set_allow_auto_mode_subnet<T>(self, v: T) -> Selfwhere
T: Into<AllowAutoModeSubnet>,
pub fn set_allow_auto_mode_subnet<T>(self, v: T) -> Selfwhere
T: Into<AllowAutoModeSubnet>,
Sets the value of allow_auto_mode_subnet.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowAutoModeSubnet;
let x0 = NetworkProfileNetworkFeatures::new().set_allow_auto_mode_subnet(AllowAutoModeSubnet::AutoModeSubnetBlocked);Sourcepub fn set_or_clear_allow_auto_mode_subnet<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowAutoModeSubnet>,
pub fn set_or_clear_allow_auto_mode_subnet<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowAutoModeSubnet>,
Sets or clears the value of allow_auto_mode_subnet.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowAutoModeSubnet;
let x0 = NetworkProfileNetworkFeatures::new().set_or_clear_allow_auto_mode_subnet(Some(AllowAutoModeSubnet::AutoModeSubnetBlocked));
let x_none = NetworkProfileNetworkFeatures::new().set_or_clear_allow_auto_mode_subnet(None::<AllowAutoModeSubnet>);Sourcepub fn set_allow_class_d_firewalls<T>(self, v: T) -> Selfwhere
T: Into<AllowClassDfirewalls>,
pub fn set_allow_class_d_firewalls<T>(self, v: T) -> Selfwhere
T: Into<AllowClassDfirewalls>,
Sets the value of allow_class_d_firewalls.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowClassDfirewalls;
let x0 = NetworkProfileNetworkFeatures::new().set_allow_class_d_firewalls(AllowClassDfirewalls::ClassDFirewallsBlocked);Sourcepub fn set_or_clear_allow_class_d_firewalls<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowClassDfirewalls>,
pub fn set_or_clear_allow_class_d_firewalls<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowClassDfirewalls>,
Sets or clears the value of allow_class_d_firewalls.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowClassDfirewalls;
let x0 = NetworkProfileNetworkFeatures::new().set_or_clear_allow_class_d_firewalls(Some(AllowClassDfirewalls::ClassDFirewallsBlocked));
let x_none = NetworkProfileNetworkFeatures::new().set_or_clear_allow_class_d_firewalls(None::<AllowClassDfirewalls>);Sourcepub fn set_allow_cloud_nat<T>(self, v: T) -> Selfwhere
T: Into<AllowCloudNat>,
pub fn set_allow_cloud_nat<T>(self, v: T) -> Selfwhere
T: Into<AllowCloudNat>,
Sets the value of allow_cloud_nat.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowCloudNat;
let x0 = NetworkProfileNetworkFeatures::new().set_allow_cloud_nat(AllowCloudNat::CloudNatBlocked);Sourcepub fn set_or_clear_allow_cloud_nat<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowCloudNat>,
pub fn set_or_clear_allow_cloud_nat<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowCloudNat>,
Sets or clears the value of allow_cloud_nat.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowCloudNat;
let x0 = NetworkProfileNetworkFeatures::new().set_or_clear_allow_cloud_nat(Some(AllowCloudNat::CloudNatBlocked));
let x_none = NetworkProfileNetworkFeatures::new().set_or_clear_allow_cloud_nat(None::<AllowCloudNat>);Sourcepub fn set_allow_cloud_router<T>(self, v: T) -> Selfwhere
T: Into<AllowCloudRouter>,
pub fn set_allow_cloud_router<T>(self, v: T) -> Selfwhere
T: Into<AllowCloudRouter>,
Sets the value of allow_cloud_router.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowCloudRouter;
let x0 = NetworkProfileNetworkFeatures::new().set_allow_cloud_router(AllowCloudRouter::CloudRouterBlocked);Sourcepub fn set_or_clear_allow_cloud_router<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowCloudRouter>,
pub fn set_or_clear_allow_cloud_router<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowCloudRouter>,
Sets or clears the value of allow_cloud_router.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowCloudRouter;
let x0 = NetworkProfileNetworkFeatures::new().set_or_clear_allow_cloud_router(Some(AllowCloudRouter::CloudRouterBlocked));
let x_none = NetworkProfileNetworkFeatures::new().set_or_clear_allow_cloud_router(None::<AllowCloudRouter>);Sourcepub fn set_allow_default_nic_attachment<T>(self, v: T) -> Selfwhere
T: Into<AllowDefaultNicAttachment>,
pub fn set_allow_default_nic_attachment<T>(self, v: T) -> Selfwhere
T: Into<AllowDefaultNicAttachment>,
Sets the value of allow_default_nic_attachment.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowDefaultNicAttachment;
let x0 = NetworkProfileNetworkFeatures::new().set_allow_default_nic_attachment(AllowDefaultNicAttachment::DefaultNicAttachmentBlocked);Sourcepub fn set_or_clear_allow_default_nic_attachment<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowDefaultNicAttachment>,
pub fn set_or_clear_allow_default_nic_attachment<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowDefaultNicAttachment>,
Sets or clears the value of allow_default_nic_attachment.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowDefaultNicAttachment;
let x0 = NetworkProfileNetworkFeatures::new().set_or_clear_allow_default_nic_attachment(Some(AllowDefaultNicAttachment::DefaultNicAttachmentBlocked));
let x_none = NetworkProfileNetworkFeatures::new().set_or_clear_allow_default_nic_attachment(None::<AllowDefaultNicAttachment>);Sourcepub fn set_allow_external_ip_access<T>(self, v: T) -> Selfwhere
T: Into<AllowExternalIpAccess>,
pub fn set_allow_external_ip_access<T>(self, v: T) -> Selfwhere
T: Into<AllowExternalIpAccess>,
Sets the value of allow_external_ip_access.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowExternalIpAccess;
let x0 = NetworkProfileNetworkFeatures::new().set_allow_external_ip_access(AllowExternalIpAccess::ExternalIpAccessBlocked);Sourcepub fn set_or_clear_allow_external_ip_access<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowExternalIpAccess>,
pub fn set_or_clear_allow_external_ip_access<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowExternalIpAccess>,
Sets or clears the value of allow_external_ip_access.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowExternalIpAccess;
let x0 = NetworkProfileNetworkFeatures::new().set_or_clear_allow_external_ip_access(Some(AllowExternalIpAccess::ExternalIpAccessBlocked));
let x_none = NetworkProfileNetworkFeatures::new().set_or_clear_allow_external_ip_access(None::<AllowExternalIpAccess>);Sourcepub fn set_allow_firewall_policy<T>(self, v: T) -> Selfwhere
T: Into<AllowFirewallPolicy>,
pub fn set_allow_firewall_policy<T>(self, v: T) -> Selfwhere
T: Into<AllowFirewallPolicy>,
Sets the value of allow_firewall_policy.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowFirewallPolicy;
let x0 = NetworkProfileNetworkFeatures::new().set_allow_firewall_policy(AllowFirewallPolicy::FirewallPolicyBlocked);Sourcepub fn set_or_clear_allow_firewall_policy<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowFirewallPolicy>,
pub fn set_or_clear_allow_firewall_policy<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowFirewallPolicy>,
Sets or clears the value of allow_firewall_policy.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowFirewallPolicy;
let x0 = NetworkProfileNetworkFeatures::new().set_or_clear_allow_firewall_policy(Some(AllowFirewallPolicy::FirewallPolicyBlocked));
let x_none = NetworkProfileNetworkFeatures::new().set_or_clear_allow_firewall_policy(None::<AllowFirewallPolicy>);Sourcepub fn set_allow_interconnect<T>(self, v: T) -> Selfwhere
T: Into<AllowInterconnect>,
pub fn set_allow_interconnect<T>(self, v: T) -> Selfwhere
T: Into<AllowInterconnect>,
Sets the value of allow_interconnect.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowInterconnect;
let x0 = NetworkProfileNetworkFeatures::new().set_allow_interconnect(AllowInterconnect::InterconnectBlocked);Sourcepub fn set_or_clear_allow_interconnect<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowInterconnect>,
pub fn set_or_clear_allow_interconnect<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowInterconnect>,
Sets or clears the value of allow_interconnect.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowInterconnect;
let x0 = NetworkProfileNetworkFeatures::new().set_or_clear_allow_interconnect(Some(AllowInterconnect::InterconnectBlocked));
let x_none = NetworkProfileNetworkFeatures::new().set_or_clear_allow_interconnect(None::<AllowInterconnect>);Sourcepub fn set_allow_ip_forwarding<T>(self, v: T) -> Selfwhere
T: Into<AllowIpForwarding>,
pub fn set_allow_ip_forwarding<T>(self, v: T) -> Selfwhere
T: Into<AllowIpForwarding>,
Sets the value of allow_ip_forwarding.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowIpForwarding;
let x0 = NetworkProfileNetworkFeatures::new().set_allow_ip_forwarding(AllowIpForwarding::IpForwardingBlocked);Sourcepub fn set_or_clear_allow_ip_forwarding<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowIpForwarding>,
pub fn set_or_clear_allow_ip_forwarding<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowIpForwarding>,
Sets or clears the value of allow_ip_forwarding.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowIpForwarding;
let x0 = NetworkProfileNetworkFeatures::new().set_or_clear_allow_ip_forwarding(Some(AllowIpForwarding::IpForwardingBlocked));
let x_none = NetworkProfileNetworkFeatures::new().set_or_clear_allow_ip_forwarding(None::<AllowIpForwarding>);Sourcepub fn set_allow_load_balancing<T>(self, v: T) -> Selfwhere
T: Into<AllowLoadBalancing>,
pub fn set_allow_load_balancing<T>(self, v: T) -> Selfwhere
T: Into<AllowLoadBalancing>,
Sets the value of allow_load_balancing.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowLoadBalancing;
let x0 = NetworkProfileNetworkFeatures::new().set_allow_load_balancing(AllowLoadBalancing::LoadBalancingBlocked);Sourcepub fn set_or_clear_allow_load_balancing<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowLoadBalancing>,
pub fn set_or_clear_allow_load_balancing<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowLoadBalancing>,
Sets or clears the value of allow_load_balancing.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowLoadBalancing;
let x0 = NetworkProfileNetworkFeatures::new().set_or_clear_allow_load_balancing(Some(AllowLoadBalancing::LoadBalancingBlocked));
let x_none = NetworkProfileNetworkFeatures::new().set_or_clear_allow_load_balancing(None::<AllowLoadBalancing>);Sourcepub fn set_allow_multi_nic_in_same_network<T>(self, v: T) -> Selfwhere
T: Into<AllowMultiNicInSameNetwork>,
pub fn set_allow_multi_nic_in_same_network<T>(self, v: T) -> Selfwhere
T: Into<AllowMultiNicInSameNetwork>,
Sets the value of allow_multi_nic_in_same_network.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowMultiNicInSameNetwork;
let x0 = NetworkProfileNetworkFeatures::new().set_allow_multi_nic_in_same_network(AllowMultiNicInSameNetwork::MultiNicInSameNetworkBlocked);Sourcepub fn set_or_clear_allow_multi_nic_in_same_network<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<AllowMultiNicInSameNetwork>,
pub fn set_or_clear_allow_multi_nic_in_same_network<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<AllowMultiNicInSameNetwork>,
Sets or clears the value of allow_multi_nic_in_same_network.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowMultiNicInSameNetwork;
let x0 = NetworkProfileNetworkFeatures::new().set_or_clear_allow_multi_nic_in_same_network(Some(AllowMultiNicInSameNetwork::MultiNicInSameNetworkBlocked));
let x_none = NetworkProfileNetworkFeatures::new().set_or_clear_allow_multi_nic_in_same_network(None::<AllowMultiNicInSameNetwork>);Sourcepub fn set_allow_multi_nic_in_same_subnetwork<T>(self, v: T) -> Selfwhere
T: Into<AllowMultiNicInSameSubnetwork>,
pub fn set_allow_multi_nic_in_same_subnetwork<T>(self, v: T) -> Selfwhere
T: Into<AllowMultiNicInSameSubnetwork>,
Sets the value of allow_multi_nic_in_same_subnetwork.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowMultiNicInSameSubnetwork;
let x0 = NetworkProfileNetworkFeatures::new().set_allow_multi_nic_in_same_subnetwork(AllowMultiNicInSameSubnetwork::MultiNicInSameSubnetworkBlocked);Sourcepub fn set_or_clear_allow_multi_nic_in_same_subnetwork<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<AllowMultiNicInSameSubnetwork>,
pub fn set_or_clear_allow_multi_nic_in_same_subnetwork<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<AllowMultiNicInSameSubnetwork>,
Sets or clears the value of allow_multi_nic_in_same_subnetwork.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowMultiNicInSameSubnetwork;
let x0 = NetworkProfileNetworkFeatures::new().set_or_clear_allow_multi_nic_in_same_subnetwork(Some(AllowMultiNicInSameSubnetwork::MultiNicInSameSubnetworkBlocked));
let x_none = NetworkProfileNetworkFeatures::new().set_or_clear_allow_multi_nic_in_same_subnetwork(None::<AllowMultiNicInSameSubnetwork>);Sourcepub fn set_allow_multicast<T>(self, v: T) -> Selfwhere
T: Into<AllowMulticast>,
pub fn set_allow_multicast<T>(self, v: T) -> Selfwhere
T: Into<AllowMulticast>,
Sets the value of allow_multicast.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowMulticast;
let x0 = NetworkProfileNetworkFeatures::new().set_allow_multicast(AllowMulticast::MulticastBlocked);Sourcepub fn set_or_clear_allow_multicast<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowMulticast>,
pub fn set_or_clear_allow_multicast<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowMulticast>,
Sets or clears the value of allow_multicast.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowMulticast;
let x0 = NetworkProfileNetworkFeatures::new().set_or_clear_allow_multicast(Some(AllowMulticast::MulticastBlocked));
let x_none = NetworkProfileNetworkFeatures::new().set_or_clear_allow_multicast(None::<AllowMulticast>);Sourcepub fn set_allow_ncc<T>(self, v: T) -> Self
pub fn set_allow_ncc<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_allow_ncc<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_allow_ncc<T>(self, v: Option<T>) -> Self
Sets or clears the value of allow_ncc.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowNcc;
let x0 = NetworkProfileNetworkFeatures::new().set_or_clear_allow_ncc(Some(AllowNcc::NccBlocked));
let x_none = NetworkProfileNetworkFeatures::new().set_or_clear_allow_ncc(None::<AllowNcc>);Sourcepub fn set_allow_network_migration<T>(self, v: T) -> Selfwhere
T: Into<AllowNetworkMigration>,
pub fn set_allow_network_migration<T>(self, v: T) -> Selfwhere
T: Into<AllowNetworkMigration>,
Sets the value of allow_network_migration.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowNetworkMigration;
let x0 = NetworkProfileNetworkFeatures::new().set_allow_network_migration(AllowNetworkMigration::NetworkMigrationBlocked);Sourcepub fn set_or_clear_allow_network_migration<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowNetworkMigration>,
pub fn set_or_clear_allow_network_migration<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowNetworkMigration>,
Sets or clears the value of allow_network_migration.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowNetworkMigration;
let x0 = NetworkProfileNetworkFeatures::new().set_or_clear_allow_network_migration(Some(AllowNetworkMigration::NetworkMigrationBlocked));
let x_none = NetworkProfileNetworkFeatures::new().set_or_clear_allow_network_migration(None::<AllowNetworkMigration>);Sourcepub fn set_allow_packet_mirroring<T>(self, v: T) -> Selfwhere
T: Into<AllowPacketMirroring>,
pub fn set_allow_packet_mirroring<T>(self, v: T) -> Selfwhere
T: Into<AllowPacketMirroring>,
Sets the value of allow_packet_mirroring.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowPacketMirroring;
let x0 = NetworkProfileNetworkFeatures::new().set_allow_packet_mirroring(AllowPacketMirroring::PacketMirroringBlocked);Sourcepub fn set_or_clear_allow_packet_mirroring<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowPacketMirroring>,
pub fn set_or_clear_allow_packet_mirroring<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowPacketMirroring>,
Sets or clears the value of allow_packet_mirroring.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowPacketMirroring;
let x0 = NetworkProfileNetworkFeatures::new().set_or_clear_allow_packet_mirroring(Some(AllowPacketMirroring::PacketMirroringBlocked));
let x_none = NetworkProfileNetworkFeatures::new().set_or_clear_allow_packet_mirroring(None::<AllowPacketMirroring>);Sourcepub fn set_allow_private_google_access<T>(self, v: T) -> Selfwhere
T: Into<AllowPrivateGoogleAccess>,
pub fn set_allow_private_google_access<T>(self, v: T) -> Selfwhere
T: Into<AllowPrivateGoogleAccess>,
Sets the value of allow_private_google_access.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowPrivateGoogleAccess;
let x0 = NetworkProfileNetworkFeatures::new().set_allow_private_google_access(AllowPrivateGoogleAccess::PrivateGoogleAccessBlocked);Sourcepub fn set_or_clear_allow_private_google_access<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowPrivateGoogleAccess>,
pub fn set_or_clear_allow_private_google_access<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowPrivateGoogleAccess>,
Sets or clears the value of allow_private_google_access.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowPrivateGoogleAccess;
let x0 = NetworkProfileNetworkFeatures::new().set_or_clear_allow_private_google_access(Some(AllowPrivateGoogleAccess::PrivateGoogleAccessBlocked));
let x_none = NetworkProfileNetworkFeatures::new().set_or_clear_allow_private_google_access(None::<AllowPrivateGoogleAccess>);Sourcepub fn set_allow_psc<T>(self, v: T) -> Self
pub fn set_allow_psc<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_allow_psc<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_allow_psc<T>(self, v: Option<T>) -> Self
Sets or clears the value of allow_psc.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowPsc;
let x0 = NetworkProfileNetworkFeatures::new().set_or_clear_allow_psc(Some(AllowPsc::PscBlocked));
let x_none = NetworkProfileNetworkFeatures::new().set_or_clear_allow_psc(None::<AllowPsc>);Sourcepub fn set_allow_same_network_unicast<T>(self, v: T) -> Selfwhere
T: Into<AllowSameNetworkUnicast>,
pub fn set_allow_same_network_unicast<T>(self, v: T) -> Selfwhere
T: Into<AllowSameNetworkUnicast>,
Sets the value of allow_same_network_unicast.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowSameNetworkUnicast;
let x0 = NetworkProfileNetworkFeatures::new().set_allow_same_network_unicast(AllowSameNetworkUnicast::SameNetworkUnicastBlocked);Sourcepub fn set_or_clear_allow_same_network_unicast<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowSameNetworkUnicast>,
pub fn set_or_clear_allow_same_network_unicast<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowSameNetworkUnicast>,
Sets or clears the value of allow_same_network_unicast.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowSameNetworkUnicast;
let x0 = NetworkProfileNetworkFeatures::new().set_or_clear_allow_same_network_unicast(Some(AllowSameNetworkUnicast::SameNetworkUnicastBlocked));
let x_none = NetworkProfileNetworkFeatures::new().set_or_clear_allow_same_network_unicast(None::<AllowSameNetworkUnicast>);Sourcepub fn set_allow_static_routes<T>(self, v: T) -> Selfwhere
T: Into<AllowStaticRoutes>,
pub fn set_allow_static_routes<T>(self, v: T) -> Selfwhere
T: Into<AllowStaticRoutes>,
Sets the value of allow_static_routes.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowStaticRoutes;
let x0 = NetworkProfileNetworkFeatures::new().set_allow_static_routes(AllowStaticRoutes::StaticRoutesBlocked);Sourcepub fn set_or_clear_allow_static_routes<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowStaticRoutes>,
pub fn set_or_clear_allow_static_routes<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowStaticRoutes>,
Sets or clears the value of allow_static_routes.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowStaticRoutes;
let x0 = NetworkProfileNetworkFeatures::new().set_or_clear_allow_static_routes(Some(AllowStaticRoutes::StaticRoutesBlocked));
let x_none = NetworkProfileNetworkFeatures::new().set_or_clear_allow_static_routes(None::<AllowStaticRoutes>);Sourcepub fn set_allow_sub_interfaces<T>(self, v: T) -> Selfwhere
T: Into<AllowSubInterfaces>,
pub fn set_allow_sub_interfaces<T>(self, v: T) -> Selfwhere
T: Into<AllowSubInterfaces>,
Sets the value of allow_sub_interfaces.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowSubInterfaces;
let x0 = NetworkProfileNetworkFeatures::new().set_allow_sub_interfaces(AllowSubInterfaces::SubinterfacesBlocked);Sourcepub fn set_or_clear_allow_sub_interfaces<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowSubInterfaces>,
pub fn set_or_clear_allow_sub_interfaces<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowSubInterfaces>,
Sets or clears the value of allow_sub_interfaces.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowSubInterfaces;
let x0 = NetworkProfileNetworkFeatures::new().set_or_clear_allow_sub_interfaces(Some(AllowSubInterfaces::SubinterfacesBlocked));
let x_none = NetworkProfileNetworkFeatures::new().set_or_clear_allow_sub_interfaces(None::<AllowSubInterfaces>);Sourcepub fn set_allow_subnetwork_creation<T>(self, v: T) -> Selfwhere
T: Into<AllowSubnetworkCreation>,
pub fn set_allow_subnetwork_creation<T>(self, v: T) -> Selfwhere
T: Into<AllowSubnetworkCreation>,
Sets the value of allow_subnetwork_creation.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowSubnetworkCreation;
let x0 = NetworkProfileNetworkFeatures::new().set_allow_subnetwork_creation(AllowSubnetworkCreation::SubnetworkCreationBlocked);Sourcepub fn set_or_clear_allow_subnetwork_creation<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowSubnetworkCreation>,
pub fn set_or_clear_allow_subnetwork_creation<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowSubnetworkCreation>,
Sets or clears the value of allow_subnetwork_creation.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowSubnetworkCreation;
let x0 = NetworkProfileNetworkFeatures::new().set_or_clear_allow_subnetwork_creation(Some(AllowSubnetworkCreation::SubnetworkCreationBlocked));
let x_none = NetworkProfileNetworkFeatures::new().set_or_clear_allow_subnetwork_creation(None::<AllowSubnetworkCreation>);Sourcepub fn set_allow_vpc_firewall_rules<T>(self, v: T) -> Selfwhere
T: Into<AllowVpcFirewallRules>,
pub fn set_allow_vpc_firewall_rules<T>(self, v: T) -> Selfwhere
T: Into<AllowVpcFirewallRules>,
Sets the value of allow_vpc_firewall_rules.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowVpcFirewallRules;
let x0 = NetworkProfileNetworkFeatures::new().set_allow_vpc_firewall_rules(AllowVpcFirewallRules::VpcFirewallRulesBlocked);Sourcepub fn set_or_clear_allow_vpc_firewall_rules<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowVpcFirewallRules>,
pub fn set_or_clear_allow_vpc_firewall_rules<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowVpcFirewallRules>,
Sets or clears the value of allow_vpc_firewall_rules.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowVpcFirewallRules;
let x0 = NetworkProfileNetworkFeatures::new().set_or_clear_allow_vpc_firewall_rules(Some(AllowVpcFirewallRules::VpcFirewallRulesBlocked));
let x_none = NetworkProfileNetworkFeatures::new().set_or_clear_allow_vpc_firewall_rules(None::<AllowVpcFirewallRules>);Sourcepub fn set_allow_vpc_peering<T>(self, v: T) -> Selfwhere
T: Into<AllowVpcPeering>,
pub fn set_allow_vpc_peering<T>(self, v: T) -> Selfwhere
T: Into<AllowVpcPeering>,
Sets the value of allow_vpc_peering.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowVpcPeering;
let x0 = NetworkProfileNetworkFeatures::new().set_allow_vpc_peering(AllowVpcPeering::VpcPeeringBlocked);Sourcepub fn set_or_clear_allow_vpc_peering<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowVpcPeering>,
pub fn set_or_clear_allow_vpc_peering<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllowVpcPeering>,
Sets or clears the value of allow_vpc_peering.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowVpcPeering;
let x0 = NetworkProfileNetworkFeatures::new().set_or_clear_allow_vpc_peering(Some(AllowVpcPeering::VpcPeeringBlocked));
let x_none = NetworkProfileNetworkFeatures::new().set_or_clear_allow_vpc_peering(None::<AllowVpcPeering>);Sourcepub fn set_allow_vpn<T>(self, v: T) -> Self
pub fn set_allow_vpn<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_allow_vpn<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_allow_vpn<T>(self, v: Option<T>) -> Self
Sets or clears the value of allow_vpn.
Example
use google_cloud_compute_v1::model::network_profile_network_features::AllowVpn;
let x0 = NetworkProfileNetworkFeatures::new().set_or_clear_allow_vpn(Some(AllowVpn::VpnBlocked));
let x_none = NetworkProfileNetworkFeatures::new().set_or_clear_allow_vpn(None::<AllowVpn>);Sourcepub fn set_firewall_policy_types<T, V>(self, v: T) -> Self
pub fn set_firewall_policy_types<T, V>(self, v: T) -> Self
Sets the value of firewall_policy_types.
Example
use google_cloud_compute_v1::model::network_profile_network_features::FirewallPolicyTypes;
let x = NetworkProfileNetworkFeatures::new().set_firewall_policy_types([
FirewallPolicyTypes::UllPolicy,
FirewallPolicyTypes::VpcPolicy,
]);Sourcepub fn set_interface_types<T, V>(self, v: T) -> Self
pub fn set_interface_types<T, V>(self, v: T) -> Self
Sets the value of interface_types.
Example
use google_cloud_compute_v1::model::network_profile_network_features::InterfaceTypes;
let x = NetworkProfileNetworkFeatures::new().set_interface_types([
InterfaceTypes::Idpf,
InterfaceTypes::Irdma,
InterfaceTypes::Mrdma,
]);Sourcepub fn set_multicast<T>(self, v: T) -> Self
pub fn set_multicast<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_multicast<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_multicast<T>(self, v: Option<T>) -> Self
Sets or clears the value of multicast.
Example
use google_cloud_compute_v1::model::network_profile_network_features::Multicast;
let x0 = NetworkProfileNetworkFeatures::new().set_or_clear_multicast(Some(Multicast::Ull));
let x_none = NetworkProfileNetworkFeatures::new().set_or_clear_multicast(None::<Multicast>);Sourcepub fn set_predefined_network_internal_ipv_6_range<T>(self, v: T) -> Self
pub fn set_predefined_network_internal_ipv_6_range<T>(self, v: T) -> Self
Sets the value of predefined_network_internal_ipv_6_range.
Example
let x = NetworkProfileNetworkFeatures::new().set_predefined_network_internal_ipv_6_range("example");Sourcepub fn set_or_clear_predefined_network_internal_ipv_6_range<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_predefined_network_internal_ipv_6_range<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of predefined_network_internal_ipv_6_range.
Example
let x = NetworkProfileNetworkFeatures::new().set_or_clear_predefined_network_internal_ipv_6_range(Some("example"));
let x = NetworkProfileNetworkFeatures::new().set_or_clear_predefined_network_internal_ipv_6_range(None::<String>);Sourcepub fn set_predefined_subnetwork_ranges<T, V>(self, v: T) -> Self
pub fn set_predefined_subnetwork_ranges<T, V>(self, v: T) -> Self
Sets the value of predefined_subnetwork_ranges.
Example
use google_cloud_compute_v1::model::NetworkProfileNetworkFeaturesPredefinedSubnetworkRange;
let x = NetworkProfileNetworkFeatures::new()
.set_predefined_subnetwork_ranges([
NetworkProfileNetworkFeaturesPredefinedSubnetworkRange::default()/* use setters */,
NetworkProfileNetworkFeaturesPredefinedSubnetworkRange::default()/* use (different) setters */,
]);Sourcepub fn set_subnet_purposes<T, V>(self, v: T) -> Self
pub fn set_subnet_purposes<T, V>(self, v: T) -> Self
Sets the value of subnet_purposes.
Example
use google_cloud_compute_v1::model::network_profile_network_features::SubnetPurposes;
let x = NetworkProfileNetworkFeatures::new().set_subnet_purposes([
SubnetPurposes::SubnetPurposePrivate,
]);Sourcepub fn set_subnet_stack_types<T, V>(self, v: T) -> Self
pub fn set_subnet_stack_types<T, V>(self, v: T) -> Self
Sets the value of subnet_stack_types.
Example
use google_cloud_compute_v1::model::network_profile_network_features::SubnetStackTypes;
let x = NetworkProfileNetworkFeatures::new().set_subnet_stack_types([
SubnetStackTypes::SubnetStackTypeIpv4Only,
SubnetStackTypes::SubnetStackTypeIpv6Only,
]);Sourcepub fn set_subnetwork_purposes<T, V>(self, v: T) -> Self
pub fn set_subnetwork_purposes<T, V>(self, v: T) -> Self
Sets the value of subnetwork_purposes.
Example
use google_cloud_compute_v1::model::network_profile_network_features::SubnetworkPurposes;
let x = NetworkProfileNetworkFeatures::new().set_subnetwork_purposes([
SubnetworkPurposes::InternalHttpsLoadBalancer,
SubnetworkPurposes::PeerMigration,
SubnetworkPurposes::Private,
]);Sourcepub fn set_subnetwork_stack_types<T, V>(self, v: T) -> Self
pub fn set_subnetwork_stack_types<T, V>(self, v: T) -> Self
Sets the value of subnetwork_stack_types.
Example
use google_cloud_compute_v1::model::network_profile_network_features::SubnetworkStackTypes;
let x = NetworkProfileNetworkFeatures::new().set_subnetwork_stack_types([
SubnetworkStackTypes::Ipv4Only,
SubnetworkStackTypes::Ipv6Only,
]);Sourcepub fn set_unicast<T>(self, v: T) -> Self
pub fn set_unicast<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_unicast<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_unicast<T>(self, v: Option<T>) -> Self
Sets or clears the value of unicast.
Example
use google_cloud_compute_v1::model::network_profile_network_features::Unicast;
let x0 = NetworkProfileNetworkFeatures::new().set_or_clear_unicast(Some(Unicast::Ull));
let x_none = NetworkProfileNetworkFeatures::new().set_or_clear_unicast(None::<Unicast>);Trait Implementations
Sourceimpl Clone for NetworkProfileNetworkFeatures
impl Clone for NetworkProfileNetworkFeatures
Sourcefn clone(&self) -> NetworkProfileNetworkFeatures
fn clone(&self) -> NetworkProfileNetworkFeatures
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for NetworkProfileNetworkFeatures
impl Default for NetworkProfileNetworkFeatures
Sourcefn default() -> NetworkProfileNetworkFeatures
fn default() -> NetworkProfileNetworkFeatures
impl StructuralPartialEq for NetworkProfileNetworkFeatures