#[non_exhaustive]pub struct NetworksGetEffectiveFirewallsResponse {
pub firewall_policys: Vec<NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy>,
pub firewalls: Vec<Firewall>,
/* private fields */
}Available on crate feature
networks only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.firewall_policys: Vec<NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy>[Output Only] Effective firewalls from firewall policy. It returns Global Network Firewall Policies and Hierarchical Firewall Policies. UseregionNetworkFirewallPolicies.getEffectiveFirewalls to get Regional Network Firewall Policies as well.
firewalls: Vec<Firewall>Effective firewalls on the network.
Implementations
Sourceimpl NetworksGetEffectiveFirewallsResponse
impl NetworksGetEffectiveFirewallsResponse
Sourcepub fn set_firewall_policys<T, V>(self, v: T) -> Selfwhere
T: IntoIterator<Item = V>,
V: Into<NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy>,
pub fn set_firewall_policys<T, V>(self, v: T) -> Selfwhere
T: IntoIterator<Item = V>,
V: Into<NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy>,
Sets the value of firewall_policys.
Example
ⓘ
use google_cloud_compute_v1::model::NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy;
let x = NetworksGetEffectiveFirewallsResponse::new()
.set_firewall_policys([
NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy::default()/* use setters */,
NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy::default()/* use (different) setters */,
]);Sourcepub fn set_firewalls<T, V>(self, v: T) -> Self
pub fn set_firewalls<T, V>(self, v: T) -> Self