#[non_exhaustive]pub struct NodeType {Show 13 fields
pub cpu_platform: Option<String>,
pub creation_timestamp: Option<String>,
pub deprecated: Option<DeprecationStatus>,
pub description: Option<String>,
pub guest_cpus: Option<i32>,
pub id: Option<u64>,
pub kind: Option<String>,
pub local_ssd_gb: Option<i32>,
pub max_vms: Option<i32>,
pub memory_mb: Option<i32>,
pub name: Option<String>,
pub self_link: Option<String>,
pub zone: Option<String>,
/* private fields */
}node-types only.Expand description
Represent a sole-tenant Node Type resource.
Each node within a node group must have a node type. A node type specifies the total amount of cores and memory for that node. Currently, the only available node type is n1-node-96-624 node type that has 96 vCPUs and 624 GB of memory, available in multiple zones. For more information readNode types.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cpu_platform: Option<String>[Output Only] The CPU platform used by this node type.
creation_timestamp: Option<String>[Output Only] Creation timestamp inRFC3339 text format.
deprecated: Option<DeprecationStatus>[Output Only] The deprecation status associated with this node type.
description: Option<String>[Output Only] An optional textual description of the resource.
guest_cpus: Option<i32>[Output Only] The number of virtual CPUs that are available to the node type.
id: Option<u64>[Output Only] The unique identifier for the resource. This identifier is defined by the server.
kind: Option<String>Output only. [Output Only] The type of the resource. Alwayscompute#nodeType for node types.
local_ssd_gb: Option<i32>[Output Only] Local SSD available to the node type, defined in GB.
max_vms: Option<i32>Output only. [Output Only] Maximum number of VMs that can be created for this node type.
memory_mb: Option<i32>[Output Only] The amount of physical memory available to the node type, defined in MB.
name: Option<String>[Output Only] Name of the resource.
self_link: Option<String>Output only. [Output Only] Server-defined URL for the resource.
zone: Option<String>Output only. [Output Only] The name of the zone where the node type resides, such as us-central1-a.
Implementations
Sourceimpl NodeType
impl NodeType
Sourcepub fn set_cpu_platform<T>(self, v: T) -> Self
pub fn set_cpu_platform<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_cpu_platform<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_cpu_platform<T>(self, v: Option<T>) -> Self
Sets or clears the value of cpu_platform.
Example
let x = NodeType::new().set_or_clear_cpu_platform(Some("example"));
let x = NodeType::new().set_or_clear_cpu_platform(None::<String>);Sourcepub fn set_creation_timestamp<T>(self, v: T) -> Self
pub fn set_creation_timestamp<T>(self, v: T) -> Self
Sets the value of creation_timestamp.
Example
let x = NodeType::new().set_creation_timestamp("example");Sourcepub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
Sets or clears the value of creation_timestamp.
Example
let x = NodeType::new().set_or_clear_creation_timestamp(Some("example"));
let x = NodeType::new().set_or_clear_creation_timestamp(None::<String>);Sourcepub fn set_deprecated<T>(self, v: T) -> Selfwhere
T: Into<DeprecationStatus>,
pub fn set_deprecated<T>(self, v: T) -> Selfwhere
T: Into<DeprecationStatus>,
Sets the value of deprecated.
Example
use google_cloud_compute_v1::model::DeprecationStatus;
let x = NodeType::new().set_deprecated(DeprecationStatus::default()/* use setters */);Sourcepub fn set_or_clear_deprecated<T>(self, v: Option<T>) -> Selfwhere
T: Into<DeprecationStatus>,
pub fn set_or_clear_deprecated<T>(self, v: Option<T>) -> Selfwhere
T: Into<DeprecationStatus>,
Sets or clears the value of deprecated.
Example
use google_cloud_compute_v1::model::DeprecationStatus;
let x = NodeType::new().set_or_clear_deprecated(Some(DeprecationStatus::default()/* use setters */));
let x = NodeType::new().set_or_clear_deprecated(None::<DeprecationStatus>);Sourcepub fn set_description<T>(self, v: T) -> Self
pub fn set_description<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
Sets or clears the value of description.
Example
let x = NodeType::new().set_or_clear_description(Some("example"));
let x = NodeType::new().set_or_clear_description(None::<String>);Sourcepub fn set_guest_cpus<T>(self, v: T) -> Self
pub fn set_guest_cpus<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_guest_cpus<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_guest_cpus<T>(self, v: Option<T>) -> Self
Sets or clears the value of guest_cpus.
Example
let x = NodeType::new().set_or_clear_guest_cpus(Some(42));
let x = NodeType::new().set_or_clear_guest_cpus(None::<i32>);Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_local_ssd_gb<T>(self, v: T) -> Self
pub fn set_local_ssd_gb<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_local_ssd_gb<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_local_ssd_gb<T>(self, v: Option<T>) -> Self
Sets or clears the value of local_ssd_gb.
Example
let x = NodeType::new().set_or_clear_local_ssd_gb(Some(42));
let x = NodeType::new().set_or_clear_local_ssd_gb(None::<i32>);Sourcepub fn set_max_vms<T>(self, v: T) -> Self
pub fn set_max_vms<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_max_vms<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_max_vms<T>(self, v: Option<T>) -> Self
Sourcepub fn set_memory_mb<T>(self, v: T) -> Self
pub fn set_memory_mb<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_memory_mb<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_memory_mb<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
Sourcepub fn set_self_link<T>(self, v: T) -> Self
pub fn set_self_link<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self