#[non_exhaustive]pub struct NotificationEndpointsScopedList {
pub resources: Vec<NotificationEndpoint>,
pub warning: Option<Warning>,
/* private fields */
}Available on crate feature
region-notification-endpoints only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resources: Vec<NotificationEndpoint>A list of NotificationEndpoints contained in this scope.
warning: Option<Warning>Informational warning which replaces the list of notification endpoints when the list is empty.
Implementations
Sourceimpl NotificationEndpointsScopedList
impl NotificationEndpointsScopedList
pub fn new() -> Self
Sourcepub fn set_resources<T, V>(self, v: T) -> Self
pub fn set_resources<T, V>(self, v: T) -> Self
Sourcepub fn set_warning<T>(self, v: T) -> Self
pub fn set_warning<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self
Sets or clears the value of warning.
Example
ⓘ
use google_cloud_compute_v1::model::notification_endpoints_scoped_list::Warning;
let x = NotificationEndpointsScopedList::new().set_or_clear_warning(Some(Warning::default()/* use setters */));
let x = NotificationEndpointsScopedList::new().set_or_clear_warning(None::<Warning>);Trait Implementations
Sourceimpl Clone for NotificationEndpointsScopedList
impl Clone for NotificationEndpointsScopedList
Sourcefn clone(&self) -> NotificationEndpointsScopedList
fn clone(&self) -> NotificationEndpointsScopedList
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for NotificationEndpointsScopedList
impl Default for NotificationEndpointsScopedList
Sourcefn default() -> NotificationEndpointsScopedList
fn default() -> NotificationEndpointsScopedList
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for NotificationEndpointsScopedList
impl PartialEq for NotificationEndpointsScopedList
Sourcefn eq(&self, other: &NotificationEndpointsScopedList) -> bool
fn eq(&self, other: &NotificationEndpointsScopedList) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for NotificationEndpointsScopedList