PartnerMetadata

Struct PartnerMetadata 

#[non_exhaustive]
pub struct PartnerMetadata { pub fingerprint: Option<Bytes>, pub partner_metadata: HashMap<String, StructuredEntries>, /* private fields */ }
Available on crate feature instances only.
Model definition of partner_metadata field. To be used in dedicated Partner Metadata methods and to be inlined in the Instance and InstanceTemplate resources.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
fingerprint: Option<Bytes>

Instance-level hash to be used for optimistic locking.

partner_metadata: HashMap<String, StructuredEntries>

Partner Metadata assigned to the instance. A map from a subdomain to entries map. Subdomain name must be compliant withRFC1035 definition. The total size of all keys and values must be less than 2MB. Subdomain ‘metadata.compute.googleapis.com’ is reserverd for instance’s metadata.

Implementations

Source

impl PartnerMetadata

pub fn new() -> Self

pub fn set_fingerprint<T>(self, v: T) -> Self
where T: Into<Bytes>,

Sets the value of fingerprint.

Example
let x = PartnerMetadata::new().set_fingerprint(bytes::Bytes::from_static(b"example"));
pub fn set_or_clear_fingerprint<T>(self, v: Option<T>) -> Self
where T: Into<Bytes>,

Sets or clears the value of fingerprint.

Example
let x = PartnerMetadata::new().set_or_clear_fingerprint(Some(bytes::Bytes::from_static(b"example")));
let x = PartnerMetadata::new().set_or_clear_fingerprint(None::<bytes::Bytes>);
pub fn set_partner_metadata<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<StructuredEntries>,

Sets the value of partner_metadata.

Example
use google_cloud_compute_v1::model::StructuredEntries;
let x = PartnerMetadata::new().set_partner_metadata([
    ("key0", StructuredEntries::default()/* use setters */),
    ("key1", StructuredEntries::default()/* use (different) setters */),
]);