#[non_exhaustive]pub struct PeriodicPartialMaintenanceSchedule {
pub sub_type: Option<SubType>,
pub target_resource: Option<String>,
pub type: Option<Type>,
pub window_end_time: Option<DateTime>,
pub window_start_time: Option<DateTime>,
/* private fields */
}region-zones or zones only.Expand description
The periodic partial maintenance schedule includes 52 weeks worth of maintenance windows. LINT.IfChange(PeriodicPartialMaintenanceSchedule)
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.sub_type: Option<SubType>The maintenance type in which the zone is during the given window.
target_resource: Option<String>The target resource that the maintenance window is for. For example, “projects/my-project/zones/us-central1-a”.
type: Option<Type>window_end_time: Option<DateTime>The end civil timestamp of the window (not inclusive). This contains a time zone.
window_start_time: Option<DateTime>The start civil timestamp of the window. This contains a time zone.
Implementations
Sourceimpl PeriodicPartialMaintenanceSchedule
impl PeriodicPartialMaintenanceSchedule
Sourcepub fn set_sub_type<T>(self, v: T) -> Self
pub fn set_sub_type<T>(self, v: T) -> Self
Sets the value of sub_type.
Example
use google_cloud_compute_v1::model::periodic_partial_maintenance_schedule::SubType;
let x0 = PeriodicPartialMaintenanceSchedule::new().set_sub_type(SubType::MaintenanceTypeCustomerMaintenance);
let x1 = PeriodicPartialMaintenanceSchedule::new().set_sub_type(SubType::MaintenanceTypeDisruptiveUpgrade);
let x2 = PeriodicPartialMaintenanceSchedule::new().set_sub_type(SubType::MaintenanceTypeStable);Sourcepub fn set_or_clear_sub_type<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_sub_type<T>(self, v: Option<T>) -> Self
Sets or clears the value of sub_type.
Example
use google_cloud_compute_v1::model::periodic_partial_maintenance_schedule::SubType;
let x0 = PeriodicPartialMaintenanceSchedule::new().set_or_clear_sub_type(Some(SubType::MaintenanceTypeCustomerMaintenance));
let x1 = PeriodicPartialMaintenanceSchedule::new().set_or_clear_sub_type(Some(SubType::MaintenanceTypeDisruptiveUpgrade));
let x2 = PeriodicPartialMaintenanceSchedule::new().set_or_clear_sub_type(Some(SubType::MaintenanceTypeStable));
let x_none = PeriodicPartialMaintenanceSchedule::new().set_or_clear_sub_type(None::<SubType>);Sourcepub fn set_target_resource<T>(self, v: T) -> Self
pub fn set_target_resource<T>(self, v: T) -> Self
Sets the value of target_resource.
Example
let x = PeriodicPartialMaintenanceSchedule::new().set_target_resource("example");Sourcepub fn set_or_clear_target_resource<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_target_resource<T>(self, v: Option<T>) -> Self
Sets or clears the value of target_resource.
Example
let x = PeriodicPartialMaintenanceSchedule::new().set_or_clear_target_resource(Some("example"));
let x = PeriodicPartialMaintenanceSchedule::new().set_or_clear_target_resource(None::<String>);Sourcepub fn set_or_clear_type<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_type<T>(self, v: Option<T>) -> Self
Sets or clears the value of r#type.
Example
use google_cloud_compute_v1::model::periodic_partial_maintenance_schedule::Type;
let x0 = PeriodicPartialMaintenanceSchedule::new().set_or_clear_type(Some(Type::PrivateZoneMaintenance));
let x_none = PeriodicPartialMaintenanceSchedule::new().set_or_clear_type(None::<Type>);Sourcepub fn set_window_end_time<T>(self, v: T) -> Self
pub fn set_window_end_time<T>(self, v: T) -> Self
Sets the value of window_end_time.
Example
use google_cloud_compute_v1::model::DateTime;
let x = PeriodicPartialMaintenanceSchedule::new().set_window_end_time(DateTime::default()/* use setters */);Sourcepub fn set_or_clear_window_end_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_window_end_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of window_end_time.
Example
use google_cloud_compute_v1::model::DateTime;
let x = PeriodicPartialMaintenanceSchedule::new().set_or_clear_window_end_time(Some(DateTime::default()/* use setters */));
let x = PeriodicPartialMaintenanceSchedule::new().set_or_clear_window_end_time(None::<DateTime>);Sourcepub fn set_window_start_time<T>(self, v: T) -> Self
pub fn set_window_start_time<T>(self, v: T) -> Self
Sets the value of window_start_time.
Example
use google_cloud_compute_v1::model::DateTime;
let x = PeriodicPartialMaintenanceSchedule::new().set_window_start_time(DateTime::default()/* use setters */);Sourcepub fn set_or_clear_window_start_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_window_start_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of window_start_time.
Example
use google_cloud_compute_v1::model::DateTime;
let x = PeriodicPartialMaintenanceSchedule::new().set_or_clear_window_start_time(Some(DateTime::default()/* use setters */));
let x = PeriodicPartialMaintenanceSchedule::new().set_or_clear_window_start_time(None::<DateTime>);Trait Implementations
Sourceimpl Clone for PeriodicPartialMaintenanceSchedule
impl Clone for PeriodicPartialMaintenanceSchedule
Sourcefn clone(&self) -> PeriodicPartialMaintenanceSchedule
fn clone(&self) -> PeriodicPartialMaintenanceSchedule
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for PeriodicPartialMaintenanceSchedule
impl Default for PeriodicPartialMaintenanceSchedule
Sourcefn default() -> PeriodicPartialMaintenanceSchedule
fn default() -> PeriodicPartialMaintenanceSchedule
impl StructuralPartialEq for PeriodicPartialMaintenanceSchedule