#[non_exhaustive]pub struct PublicAdvertisedPrefix {Show 15 fields
pub byoip_api_version: Option<ByoipApiVersion>,
pub creation_timestamp: Option<String>,
pub description: Option<String>,
pub dns_verification_ip: Option<String>,
pub fingerprint: Option<Bytes>,
pub id: Option<u64>,
pub ip_cidr_range: Option<String>,
pub ipv_6_access_type: Option<Ipv6AccessType>,
pub kind: Option<String>,
pub name: Option<String>,
pub pdp_scope: Option<PdpScope>,
pub public_delegated_prefixs: Vec<PublicAdvertisedPrefixPublicDelegatedPrefix>,
pub self_link: Option<String>,
pub shared_secret: Option<String>,
pub status: Option<Status>,
/* private fields */
}public-advertised-prefixes only.Expand description
A public advertised prefix represents an aggregated IP prefix or netblock which customers bring to cloud. The IP prefix is a single unit of route advertisement and is announced globally to the internet.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.byoip_api_version: Option<ByoipApiVersion>Output only. [Output Only] The version of BYOIP API.
creation_timestamp: Option<String>Output only. [Output Only] Creation timestamp inRFC3339 text format.
description: Option<String>An optional description of this resource. Provide this property when you create the resource.
dns_verification_ip: Option<String>The address to be used for reverse DNS verification.
fingerprint: Option<Bytes>Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a new PublicAdvertisedPrefix. An up-to-date fingerprint must be provided in order to update thePublicAdvertisedPrefix, otherwise the request will fail with error 412 conditionNotMet.
To see the latest fingerprint, make a get() request to retrieve a PublicAdvertisedPrefix.
id: Option<u64>Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier.
ip_cidr_range: Option<String>The address range, in CIDR format, represented by this public advertised prefix.
ipv_6_access_type: Option<Ipv6AccessType>The internet access type for IPv6 Public Advertised Prefixes.
kind: Option<String>Output only. [Output Only] Type of the resource. Alwayscompute#publicAdvertisedPrefix for public advertised prefixes.
name: Option<String>Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
pdp_scope: Option<PdpScope>Specifies how child public delegated prefix will be scoped. It could be one of following values:
- `REGIONAL`: The public delegated prefix is regional only. The
provisioning will take a few minutes.
- `GLOBAL`: The public delegated prefix is global only. The
provisioning will take ~4 weeks.
- `GLOBAL_AND_REGIONAL` [output only]: The public delegated prefixes is
BYOIP V1 legacy prefix. This is output only value and no longer
supported in BYOIP V2.public_delegated_prefixs: Vec<PublicAdvertisedPrefixPublicDelegatedPrefix>Output only. [Output Only] The list of public delegated prefixes that exist for this public advertised prefix.
self_link: Option<String>Output only. [Output Only] Server-defined URL for the resource.
[Output Only] The shared secret to be used for reverse DNS verification.
status: Option<Status>The status of the public advertised prefix. Possible values include:
- `INITIAL`: RPKI validation is complete.
- `PTR_CONFIGURED`: User has configured the PTR.
- `VALIDATED`: Reverse DNS lookup is successful.
- `REVERSE_DNS_LOOKUP_FAILED`: Reverse DNS lookup failed.
- `PREFIX_CONFIGURATION_IN_PROGRESS`: The prefix is being
configured.
- `PREFIX_CONFIGURATION_COMPLETE`: The prefix is fully configured.
- `PREFIX_REMOVAL_IN_PROGRESS`: The prefix is being removed.Implementations
Sourceimpl PublicAdvertisedPrefix
impl PublicAdvertisedPrefix
Sourcepub fn set_byoip_api_version<T>(self, v: T) -> Selfwhere
T: Into<ByoipApiVersion>,
pub fn set_byoip_api_version<T>(self, v: T) -> Selfwhere
T: Into<ByoipApiVersion>,
Sets the value of byoip_api_version.
Example
use google_cloud_compute_v1::model::public_advertised_prefix::ByoipApiVersion;
let x0 = PublicAdvertisedPrefix::new().set_byoip_api_version(ByoipApiVersion::V2);Sourcepub fn set_or_clear_byoip_api_version<T>(self, v: Option<T>) -> Selfwhere
T: Into<ByoipApiVersion>,
pub fn set_or_clear_byoip_api_version<T>(self, v: Option<T>) -> Selfwhere
T: Into<ByoipApiVersion>,
Sets or clears the value of byoip_api_version.
Example
use google_cloud_compute_v1::model::public_advertised_prefix::ByoipApiVersion;
let x0 = PublicAdvertisedPrefix::new().set_or_clear_byoip_api_version(Some(ByoipApiVersion::V2));
let x_none = PublicAdvertisedPrefix::new().set_or_clear_byoip_api_version(None::<ByoipApiVersion>);Sourcepub fn set_creation_timestamp<T>(self, v: T) -> Self
pub fn set_creation_timestamp<T>(self, v: T) -> Self
Sets the value of creation_timestamp.
Example
let x = PublicAdvertisedPrefix::new().set_creation_timestamp("example");Sourcepub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
Sets or clears the value of creation_timestamp.
Example
let x = PublicAdvertisedPrefix::new().set_or_clear_creation_timestamp(Some("example"));
let x = PublicAdvertisedPrefix::new().set_or_clear_creation_timestamp(None::<String>);Sourcepub fn set_description<T>(self, v: T) -> Self
pub fn set_description<T>(self, v: T) -> Self
Sets the value of description.
Example
let x = PublicAdvertisedPrefix::new().set_description("example");Sourcepub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
Sets or clears the value of description.
Example
let x = PublicAdvertisedPrefix::new().set_or_clear_description(Some("example"));
let x = PublicAdvertisedPrefix::new().set_or_clear_description(None::<String>);Sourcepub fn set_dns_verification_ip<T>(self, v: T) -> Self
pub fn set_dns_verification_ip<T>(self, v: T) -> Self
Sets the value of dns_verification_ip.
Example
let x = PublicAdvertisedPrefix::new().set_dns_verification_ip("example");Sourcepub fn set_or_clear_dns_verification_ip<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_dns_verification_ip<T>(self, v: Option<T>) -> Self
Sets or clears the value of dns_verification_ip.
Example
let x = PublicAdvertisedPrefix::new().set_or_clear_dns_verification_ip(Some("example"));
let x = PublicAdvertisedPrefix::new().set_or_clear_dns_verification_ip(None::<String>);Sourcepub fn set_fingerprint<T>(self, v: T) -> Self
pub fn set_fingerprint<T>(self, v: T) -> Self
Sets the value of fingerprint.
Example
let x = PublicAdvertisedPrefix::new().set_fingerprint(bytes::Bytes::from_static(b"example"));Sourcepub fn set_or_clear_fingerprint<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_fingerprint<T>(self, v: Option<T>) -> Self
Sets or clears the value of fingerprint.
Example
let x = PublicAdvertisedPrefix::new().set_or_clear_fingerprint(Some(bytes::Bytes::from_static(b"example")));
let x = PublicAdvertisedPrefix::new().set_or_clear_fingerprint(None::<bytes::Bytes>);Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
Sourcepub fn set_ip_cidr_range<T>(self, v: T) -> Self
pub fn set_ip_cidr_range<T>(self, v: T) -> Self
Sets the value of ip_cidr_range.
Example
let x = PublicAdvertisedPrefix::new().set_ip_cidr_range("example");Sourcepub fn set_or_clear_ip_cidr_range<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_ip_cidr_range<T>(self, v: Option<T>) -> Self
Sets or clears the value of ip_cidr_range.
Example
let x = PublicAdvertisedPrefix::new().set_or_clear_ip_cidr_range(Some("example"));
let x = PublicAdvertisedPrefix::new().set_or_clear_ip_cidr_range(None::<String>);Sourcepub fn set_ipv_6_access_type<T>(self, v: T) -> Selfwhere
T: Into<Ipv6AccessType>,
pub fn set_ipv_6_access_type<T>(self, v: T) -> Selfwhere
T: Into<Ipv6AccessType>,
Sets the value of ipv_6_access_type.
Example
use google_cloud_compute_v1::model::public_advertised_prefix::Ipv6AccessType;
let x0 = PublicAdvertisedPrefix::new().set_ipv_6_access_type(Ipv6AccessType::Internal);Sourcepub fn set_or_clear_ipv_6_access_type<T>(self, v: Option<T>) -> Selfwhere
T: Into<Ipv6AccessType>,
pub fn set_or_clear_ipv_6_access_type<T>(self, v: Option<T>) -> Selfwhere
T: Into<Ipv6AccessType>,
Sets or clears the value of ipv_6_access_type.
Example
use google_cloud_compute_v1::model::public_advertised_prefix::Ipv6AccessType;
let x0 = PublicAdvertisedPrefix::new().set_or_clear_ipv_6_access_type(Some(Ipv6AccessType::Internal));
let x_none = PublicAdvertisedPrefix::new().set_or_clear_ipv_6_access_type(None::<Ipv6AccessType>);Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
Sourcepub fn set_pdp_scope<T>(self, v: T) -> Self
pub fn set_pdp_scope<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_pdp_scope<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_pdp_scope<T>(self, v: Option<T>) -> Self
Sets or clears the value of pdp_scope.
Example
use google_cloud_compute_v1::model::public_advertised_prefix::PdpScope;
let x0 = PublicAdvertisedPrefix::new().set_or_clear_pdp_scope(Some(PdpScope::GlobalAndRegional));
let x1 = PublicAdvertisedPrefix::new().set_or_clear_pdp_scope(Some(PdpScope::Regional));
let x_none = PublicAdvertisedPrefix::new().set_or_clear_pdp_scope(None::<PdpScope>);Sourcepub fn set_public_delegated_prefixs<T, V>(self, v: T) -> Self
pub fn set_public_delegated_prefixs<T, V>(self, v: T) -> Self
Sets the value of public_delegated_prefixs.
Example
use google_cloud_compute_v1::model::PublicAdvertisedPrefixPublicDelegatedPrefix;
let x = PublicAdvertisedPrefix::new()
.set_public_delegated_prefixs([
PublicAdvertisedPrefixPublicDelegatedPrefix::default()/* use setters */,
PublicAdvertisedPrefixPublicDelegatedPrefix::default()/* use (different) setters */,
]);Sourcepub fn set_self_link<T>(self, v: T) -> Self
pub fn set_self_link<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
Sets the value of shared_secret.
Example
let x = PublicAdvertisedPrefix::new().set_shared_secret("example");Sets or clears the value of shared_secret.
Example
let x = PublicAdvertisedPrefix::new().set_or_clear_shared_secret(Some("example"));
let x = PublicAdvertisedPrefix::new().set_or_clear_shared_secret(None::<String>);Sourcepub fn set_status<T>(self, v: T) -> Self
pub fn set_status<T>(self, v: T) -> Self
Sets the value of status.
Example
use google_cloud_compute_v1::model::public_advertised_prefix::Status;
let x0 = PublicAdvertisedPrefix::new().set_status(Status::Initial);
let x1 = PublicAdvertisedPrefix::new().set_status(Status::PrefixConfigurationComplete);
let x2 = PublicAdvertisedPrefix::new().set_status(Status::PrefixConfigurationInProgress);Sourcepub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
Sets or clears the value of status.
Example
use google_cloud_compute_v1::model::public_advertised_prefix::Status;
let x0 = PublicAdvertisedPrefix::new().set_or_clear_status(Some(Status::Initial));
let x1 = PublicAdvertisedPrefix::new().set_or_clear_status(Some(Status::PrefixConfigurationComplete));
let x2 = PublicAdvertisedPrefix::new().set_or_clear_status(Some(Status::PrefixConfigurationInProgress));
let x_none = PublicAdvertisedPrefix::new().set_or_clear_status(None::<Status>);Trait Implementations
Sourceimpl Clone for PublicAdvertisedPrefix
impl Clone for PublicAdvertisedPrefix
Sourcefn clone(&self) -> PublicAdvertisedPrefix
fn clone(&self) -> PublicAdvertisedPrefix
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for PublicAdvertisedPrefix
impl Debug for PublicAdvertisedPrefix
Sourceimpl Default for PublicAdvertisedPrefix
impl Default for PublicAdvertisedPrefix
Sourcefn default() -> PublicAdvertisedPrefix
fn default() -> PublicAdvertisedPrefix
Sourceimpl Message for PublicAdvertisedPrefix
impl Message for PublicAdvertisedPrefix
Sourceimpl PartialEq for PublicAdvertisedPrefix
impl PartialEq for PublicAdvertisedPrefix
impl StructuralPartialEq for PublicAdvertisedPrefix