#[non_exhaustive]pub struct Region {
pub creation_timestamp: Option<String>,
pub deprecated: Option<DeprecationStatus>,
pub description: Option<String>,
pub id: Option<u64>,
pub kind: Option<String>,
pub name: Option<String>,
pub quota_status_warning: Option<QuotaStatusWarning>,
pub quotas: Vec<Quota>,
pub self_link: Option<String>,
pub status: Option<Status>,
pub supports_pzs: Option<bool>,
pub zones: Vec<String>,
/* private fields */
}regions only.Expand description
Represents a Region resource.
A region is a geographical area where a resource is located. For more information, readRegions and Zones.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.creation_timestamp: Option<String>[Output Only] Creation timestamp inRFC3339 text format.
deprecated: Option<DeprecationStatus>[Output Only] The deprecation status associated with this region.
description: Option<String>[Output Only] Textual description of the resource.
id: Option<u64>[Output Only] The unique identifier for the resource. This identifier is defined by the server.
kind: Option<String>Output only. [Output Only] Type of the resource. Always compute#region for regions.
name: Option<String>[Output Only] Name of the resource.
quota_status_warning: Option<QuotaStatusWarning>Output only. [Output Only] Warning of fetching the quotas field for this region. This
field is populated only if fetching of the quotas field fails.
quotas: Vec<Quota>[Output Only] Quotas assigned to this region.
self_link: Option<String>[Output Only] Server-defined URL for the resource.
status: Option<Status>[Output Only] Status of the region, either UP orDOWN.
supports_pzs: Option<bool>Output only. [Output Only] Reserved for future use.
zones: Vec<String>[Output Only] A list of zones available in this region, in the form of resource URLs.
Implementations
Sourceimpl Region
impl Region
Sourcepub fn set_creation_timestamp<T>(self, v: T) -> Self
pub fn set_creation_timestamp<T>(self, v: T) -> Self
Sets the value of creation_timestamp.
Example
let x = Region::new().set_creation_timestamp("example");Sourcepub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
Sets or clears the value of creation_timestamp.
Example
let x = Region::new().set_or_clear_creation_timestamp(Some("example"));
let x = Region::new().set_or_clear_creation_timestamp(None::<String>);Sourcepub fn set_deprecated<T>(self, v: T) -> Selfwhere
T: Into<DeprecationStatus>,
pub fn set_deprecated<T>(self, v: T) -> Selfwhere
T: Into<DeprecationStatus>,
Sets the value of deprecated.
Example
use google_cloud_compute_v1::model::DeprecationStatus;
let x = Region::new().set_deprecated(DeprecationStatus::default()/* use setters */);Sourcepub fn set_or_clear_deprecated<T>(self, v: Option<T>) -> Selfwhere
T: Into<DeprecationStatus>,
pub fn set_or_clear_deprecated<T>(self, v: Option<T>) -> Selfwhere
T: Into<DeprecationStatus>,
Sets or clears the value of deprecated.
Example
use google_cloud_compute_v1::model::DeprecationStatus;
let x = Region::new().set_or_clear_deprecated(Some(DeprecationStatus::default()/* use setters */));
let x = Region::new().set_or_clear_deprecated(None::<DeprecationStatus>);Sourcepub fn set_description<T>(self, v: T) -> Self
pub fn set_description<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
Sets or clears the value of description.
Example
let x = Region::new().set_or_clear_description(Some("example"));
let x = Region::new().set_or_clear_description(None::<String>);Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
Sourcepub fn set_quota_status_warning<T>(self, v: T) -> Selfwhere
T: Into<QuotaStatusWarning>,
pub fn set_quota_status_warning<T>(self, v: T) -> Selfwhere
T: Into<QuotaStatusWarning>,
Sets the value of quota_status_warning.
Example
use google_cloud_compute_v1::model::region::QuotaStatusWarning;
let x = Region::new().set_quota_status_warning(QuotaStatusWarning::default()/* use setters */);Sourcepub fn set_or_clear_quota_status_warning<T>(self, v: Option<T>) -> Selfwhere
T: Into<QuotaStatusWarning>,
pub fn set_or_clear_quota_status_warning<T>(self, v: Option<T>) -> Selfwhere
T: Into<QuotaStatusWarning>,
Sets or clears the value of quota_status_warning.
Example
use google_cloud_compute_v1::model::region::QuotaStatusWarning;
let x = Region::new().set_or_clear_quota_status_warning(Some(QuotaStatusWarning::default()/* use setters */));
let x = Region::new().set_or_clear_quota_status_warning(None::<QuotaStatusWarning>);Sourcepub fn set_quotas<T, V>(self, v: T) -> Self
pub fn set_quotas<T, V>(self, v: T) -> Self
Sourcepub fn set_self_link<T>(self, v: T) -> Self
pub fn set_self_link<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
Sourcepub fn set_status<T>(self, v: T) -> Self
pub fn set_status<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
Sourcepub fn set_supports_pzs<T>(self, v: T) -> Self
pub fn set_supports_pzs<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_supports_pzs<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_supports_pzs<T>(self, v: Option<T>) -> Self
Sets or clears the value of supports_pzs.
Example
let x = Region::new().set_or_clear_supports_pzs(Some(false));
let x = Region::new().set_or_clear_supports_pzs(None::<bool>);Trait Implementations
impl StructuralPartialEq for Region