#[non_exhaustive]pub struct RegionDiskUpdateKmsKeyRequest {
pub kms_key_name: Option<String>,
/* private fields */
}Available on crate feature
region-disks only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.kms_key_name: Option<String>Optional. The new KMS key to replace the current one on the disk. If empty, the disk will be re-encrypted using the primary version of the disk’s current KMS key.
The KMS key can be provided in the following formats:
- projects/project_id/locations/location/keyRings/key_ring/cryptoKeys/keyWhere project is the project ID or project number.
Implementations
Sourceimpl RegionDiskUpdateKmsKeyRequest
impl RegionDiskUpdateKmsKeyRequest
Sourcepub fn set_kms_key_name<T>(self, v: T) -> Self
pub fn set_kms_key_name<T>(self, v: T) -> Self
Sets the value of kms_key_name.
Example
ⓘ
let x = RegionDiskUpdateKmsKeyRequest::new().set_kms_key_name("example");Sourcepub fn set_or_clear_kms_key_name<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kms_key_name<T>(self, v: Option<T>) -> Self
Sets or clears the value of kms_key_name.
Example
ⓘ
let x = RegionDiskUpdateKmsKeyRequest::new().set_or_clear_kms_key_name(Some("example"));
let x = RegionDiskUpdateKmsKeyRequest::new().set_or_clear_kms_key_name(None::<String>);Trait Implementations
Sourceimpl Clone for RegionDiskUpdateKmsKeyRequest
impl Clone for RegionDiskUpdateKmsKeyRequest
Sourcefn clone(&self) -> RegionDiskUpdateKmsKeyRequest
fn clone(&self) -> RegionDiskUpdateKmsKeyRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for RegionDiskUpdateKmsKeyRequest
impl Default for RegionDiskUpdateKmsKeyRequest
Sourcefn default() -> RegionDiskUpdateKmsKeyRequest
fn default() -> RegionDiskUpdateKmsKeyRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for RegionDiskUpdateKmsKeyRequest
impl PartialEq for RegionDiskUpdateKmsKeyRequest
Sourcefn eq(&self, other: &RegionDiskUpdateKmsKeyRequest) -> bool
fn eq(&self, other: &RegionDiskUpdateKmsKeyRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RegionDiskUpdateKmsKeyRequest