#[non_exhaustive]pub struct RegionInstanceGroupList {
pub id: Option<String>,
pub items: Vec<InstanceGroup>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
pub self_link: Option<String>,
pub warning: Option<Warning>,
/* private fields */
}region-instance-groups only.Expand description
Contains a list of InstanceGroup resources.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>Output only. [Output Only] Unique identifier for the resource; defined by the server.
items: Vec<InstanceGroup>A list of InstanceGroup resources.
kind: Option<String>Output only. The resource type.
next_page_token: Option<String>Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
self_link: Option<String>Output only. [Output Only] Server-defined URL for this resource.
warning: Option<Warning>Output only. [Output Only] Informational warning message.
Implementations
Sourceimpl RegionInstanceGroupList
impl RegionInstanceGroupList
Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_next_page_token<T>(self, v: T) -> Self
pub fn set_next_page_token<T>(self, v: T) -> Self
Sets the value of next_page_token.
Example
let x = RegionInstanceGroupList::new().set_next_page_token("example");Sourcepub fn set_or_clear_next_page_token<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_next_page_token<T>(self, v: Option<T>) -> Self
Sets or clears the value of next_page_token.
Example
let x = RegionInstanceGroupList::new().set_or_clear_next_page_token(Some("example"));
let x = RegionInstanceGroupList::new().set_or_clear_next_page_token(None::<String>);Sourcepub fn set_self_link<T>(self, v: T) -> Self
pub fn set_self_link<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
Sourcepub fn set_warning<T>(self, v: T) -> Self
pub fn set_warning<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self
Sets or clears the value of warning.
Example
use google_cloud_compute_v1::model::region_instance_group_list::Warning;
let x = RegionInstanceGroupList::new().set_or_clear_warning(Some(Warning::default()/* use setters */));
let x = RegionInstanceGroupList::new().set_or_clear_warning(None::<Warning>);Trait Implementations
Sourceimpl Clone for RegionInstanceGroupList
impl Clone for RegionInstanceGroupList
Sourcefn clone(&self) -> RegionInstanceGroupList
fn clone(&self) -> RegionInstanceGroupList
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for RegionInstanceGroupList
impl Debug for RegionInstanceGroupList
Sourceimpl Default for RegionInstanceGroupList
impl Default for RegionInstanceGroupList
Sourcefn default() -> RegionInstanceGroupList
fn default() -> RegionInstanceGroupList
Sourceimpl Message for RegionInstanceGroupList
impl Message for RegionInstanceGroupList
Sourceimpl PartialEq for RegionInstanceGroupList
impl PartialEq for RegionInstanceGroupList
impl StructuralPartialEq for RegionInstanceGroupList