#[non_exhaustive]pub struct RegionInstanceGroupManagerList {
pub id: Option<String>,
pub items: Vec<InstanceGroupManager>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
pub self_link: Option<String>,
pub warning: Option<Warning>,
/* private fields */
}region-instance-group-managers only.Expand description
Contains a list of managed instance groups.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>Output only. Unique identifier for the resource; defined by the server.
items: Vec<InstanceGroupManager>A list of InstanceGroupManager resources.
kind: Option<String>Output only. The resource type, which is always compute#instanceGroupManagerList for a list of managed instance groups that exist in th regional scope.
next_page_token: Option<String>Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
self_link: Option<String>Output only. Server-defined URL for this resource.
warning: Option<Warning>Output only. Informational warning message.
Implementations
Sourceimpl RegionInstanceGroupManagerList
impl RegionInstanceGroupManagerList
Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_next_page_token<T>(self, v: T) -> Self
pub fn set_next_page_token<T>(self, v: T) -> Self
Sets the value of next_page_token.
Example
let x = RegionInstanceGroupManagerList::new().set_next_page_token("example");Sourcepub fn set_or_clear_next_page_token<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_next_page_token<T>(self, v: Option<T>) -> Self
Sets or clears the value of next_page_token.
Example
let x = RegionInstanceGroupManagerList::new().set_or_clear_next_page_token(Some("example"));
let x = RegionInstanceGroupManagerList::new().set_or_clear_next_page_token(None::<String>);Sourcepub fn set_self_link<T>(self, v: T) -> Self
pub fn set_self_link<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
Sourcepub fn set_warning<T>(self, v: T) -> Self
pub fn set_warning<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self
Sets or clears the value of warning.
Example
use google_cloud_compute_v1::model::region_instance_group_manager_list::Warning;
let x = RegionInstanceGroupManagerList::new().set_or_clear_warning(Some(Warning::default()/* use setters */));
let x = RegionInstanceGroupManagerList::new().set_or_clear_warning(None::<Warning>);Trait Implementations
Sourceimpl Clone for RegionInstanceGroupManagerList
impl Clone for RegionInstanceGroupManagerList
Sourcefn clone(&self) -> RegionInstanceGroupManagerList
fn clone(&self) -> RegionInstanceGroupManagerList
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for RegionInstanceGroupManagerList
impl Default for RegionInstanceGroupManagerList
Sourcefn default() -> RegionInstanceGroupManagerList
fn default() -> RegionInstanceGroupManagerList
impl StructuralPartialEq for RegionInstanceGroupManagerList