#[non_exhaustive]pub struct ReservationBlock {Show 16 fields
pub count: Option<i32>,
pub creation_timestamp: Option<String>,
pub health_info: Option<ReservationBlockHealthInfo>,
pub id: Option<u64>,
pub in_use_count: Option<i32>,
pub in_use_host_count: Option<i32>,
pub kind: Option<String>,
pub name: Option<String>,
pub physical_topology: Option<ReservationBlockPhysicalTopology>,
pub reservation_maintenance: Option<GroupMaintenanceInfo>,
pub reservation_sub_block_count: Option<i32>,
pub reservation_sub_block_in_use_count: Option<i32>,
pub self_link: Option<String>,
pub self_link_with_id: Option<String>,
pub status: Option<Status>,
pub zone: Option<String>,
/* private fields */
}reservation-blocks only.Expand description
Represents a reservation block resource.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.count: Option<i32>Output only. [Output Only] The number of resources that are allocated in this reservation block.
creation_timestamp: Option<String>Output only. [Output Only] Creation timestamp inRFC3339 text format.
health_info: Option<ReservationBlockHealthInfo>Output only. [Output Only] Health information for the reservation block.
id: Option<u64>Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.
in_use_count: Option<i32>Output only. [Output Only] The number of instances that are currently in use on this reservation block.
in_use_host_count: Option<i32>Output only. Number of hosts currently in use. If there is one or more Instances running on the host, it is considered in use.
kind: Option<String>Output only. [Output Only] Type of the resource. Alwayscompute#reservationBlock for reservation blocks.
name: Option<String>Output only. [Output Only] The name of this reservation block generated by Google Compute Engine. The name must be 1-63 characters long, and comply with RFC1035 @pattern a-z?
physical_topology: Option<ReservationBlockPhysicalTopology>Output only. [Output Only] The physical topology of the reservation block.
reservation_maintenance: Option<GroupMaintenanceInfo>Output only. [Output Only] Maintenance information for this reservation block.
reservation_sub_block_count: Option<i32>Output only. [Output Only] The number of reservation subBlocks associated with this reservation block.
reservation_sub_block_in_use_count: Option<i32>Output only. [Output Only] The number of in-use reservation subBlocks associated with this reservation block. If at least one VM is running on a subBlock, it is considered in-use.
self_link: Option<String>Output only. [Output Only] Server-defined fully-qualified URL for this resource.
self_link_with_id: Option<String>Output only. [Output Only] Server-defined URL for this resource with the resource id.
status: Option<Status>Output only. [Output Only] Status of the reservation block.
zone: Option<String>Output only. [Output Only] Zone in which the reservation block resides.
Implementations
Sourceimpl ReservationBlock
impl ReservationBlock
Sourcepub fn set_or_clear_count<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_count<T>(self, v: Option<T>) -> Self
Sourcepub fn set_creation_timestamp<T>(self, v: T) -> Self
pub fn set_creation_timestamp<T>(self, v: T) -> Self
Sets the value of creation_timestamp.
Example
let x = ReservationBlock::new().set_creation_timestamp("example");Sourcepub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
Sets or clears the value of creation_timestamp.
Example
let x = ReservationBlock::new().set_or_clear_creation_timestamp(Some("example"));
let x = ReservationBlock::new().set_or_clear_creation_timestamp(None::<String>);Sourcepub fn set_health_info<T>(self, v: T) -> Selfwhere
T: Into<ReservationBlockHealthInfo>,
pub fn set_health_info<T>(self, v: T) -> Selfwhere
T: Into<ReservationBlockHealthInfo>,
Sets the value of health_info.
Example
use google_cloud_compute_v1::model::ReservationBlockHealthInfo;
let x = ReservationBlock::new().set_health_info(ReservationBlockHealthInfo::default()/* use setters */);Sourcepub fn set_or_clear_health_info<T>(self, v: Option<T>) -> Selfwhere
T: Into<ReservationBlockHealthInfo>,
pub fn set_or_clear_health_info<T>(self, v: Option<T>) -> Selfwhere
T: Into<ReservationBlockHealthInfo>,
Sets or clears the value of health_info.
Example
use google_cloud_compute_v1::model::ReservationBlockHealthInfo;
let x = ReservationBlock::new().set_or_clear_health_info(Some(ReservationBlockHealthInfo::default()/* use setters */));
let x = ReservationBlock::new().set_or_clear_health_info(None::<ReservationBlockHealthInfo>);Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
Sourcepub fn set_in_use_count<T>(self, v: T) -> Self
pub fn set_in_use_count<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_in_use_count<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_in_use_count<T>(self, v: Option<T>) -> Self
Sets or clears the value of in_use_count.
Example
let x = ReservationBlock::new().set_or_clear_in_use_count(Some(42));
let x = ReservationBlock::new().set_or_clear_in_use_count(None::<i32>);Sourcepub fn set_in_use_host_count<T>(self, v: T) -> Self
pub fn set_in_use_host_count<T>(self, v: T) -> Self
Sets the value of in_use_host_count.
Example
let x = ReservationBlock::new().set_in_use_host_count(42);Sourcepub fn set_or_clear_in_use_host_count<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_in_use_host_count<T>(self, v: Option<T>) -> Self
Sets or clears the value of in_use_host_count.
Example
let x = ReservationBlock::new().set_or_clear_in_use_host_count(Some(42));
let x = ReservationBlock::new().set_or_clear_in_use_host_count(None::<i32>);Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
Sourcepub fn set_physical_topology<T>(self, v: T) -> Selfwhere
T: Into<ReservationBlockPhysicalTopology>,
pub fn set_physical_topology<T>(self, v: T) -> Selfwhere
T: Into<ReservationBlockPhysicalTopology>,
Sets the value of physical_topology.
Example
use google_cloud_compute_v1::model::ReservationBlockPhysicalTopology;
let x = ReservationBlock::new().set_physical_topology(ReservationBlockPhysicalTopology::default()/* use setters */);Sourcepub fn set_or_clear_physical_topology<T>(self, v: Option<T>) -> Selfwhere
T: Into<ReservationBlockPhysicalTopology>,
pub fn set_or_clear_physical_topology<T>(self, v: Option<T>) -> Selfwhere
T: Into<ReservationBlockPhysicalTopology>,
Sets or clears the value of physical_topology.
Example
use google_cloud_compute_v1::model::ReservationBlockPhysicalTopology;
let x = ReservationBlock::new().set_or_clear_physical_topology(Some(ReservationBlockPhysicalTopology::default()/* use setters */));
let x = ReservationBlock::new().set_or_clear_physical_topology(None::<ReservationBlockPhysicalTopology>);Sourcepub fn set_reservation_maintenance<T>(self, v: T) -> Selfwhere
T: Into<GroupMaintenanceInfo>,
pub fn set_reservation_maintenance<T>(self, v: T) -> Selfwhere
T: Into<GroupMaintenanceInfo>,
Sets the value of reservation_maintenance.
Example
use google_cloud_compute_v1::model::GroupMaintenanceInfo;
let x = ReservationBlock::new().set_reservation_maintenance(GroupMaintenanceInfo::default()/* use setters */);Sourcepub fn set_or_clear_reservation_maintenance<T>(self, v: Option<T>) -> Selfwhere
T: Into<GroupMaintenanceInfo>,
pub fn set_or_clear_reservation_maintenance<T>(self, v: Option<T>) -> Selfwhere
T: Into<GroupMaintenanceInfo>,
Sets or clears the value of reservation_maintenance.
Example
use google_cloud_compute_v1::model::GroupMaintenanceInfo;
let x = ReservationBlock::new().set_or_clear_reservation_maintenance(Some(GroupMaintenanceInfo::default()/* use setters */));
let x = ReservationBlock::new().set_or_clear_reservation_maintenance(None::<GroupMaintenanceInfo>);Sourcepub fn set_reservation_sub_block_count<T>(self, v: T) -> Self
pub fn set_reservation_sub_block_count<T>(self, v: T) -> Self
Sets the value of reservation_sub_block_count.
Example
let x = ReservationBlock::new().set_reservation_sub_block_count(42);Sourcepub fn set_or_clear_reservation_sub_block_count<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_reservation_sub_block_count<T>(self, v: Option<T>) -> Self
Sets or clears the value of reservation_sub_block_count.
Example
let x = ReservationBlock::new().set_or_clear_reservation_sub_block_count(Some(42));
let x = ReservationBlock::new().set_or_clear_reservation_sub_block_count(None::<i32>);Sourcepub fn set_reservation_sub_block_in_use_count<T>(self, v: T) -> Self
pub fn set_reservation_sub_block_in_use_count<T>(self, v: T) -> Self
Sets the value of reservation_sub_block_in_use_count.
Example
let x = ReservationBlock::new().set_reservation_sub_block_in_use_count(42);Sourcepub fn set_or_clear_reservation_sub_block_in_use_count<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_reservation_sub_block_in_use_count<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of reservation_sub_block_in_use_count.
Example
let x = ReservationBlock::new().set_or_clear_reservation_sub_block_in_use_count(Some(42));
let x = ReservationBlock::new().set_or_clear_reservation_sub_block_in_use_count(None::<i32>);Sourcepub fn set_self_link<T>(self, v: T) -> Self
pub fn set_self_link<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
Sourcepub fn set_self_link_with_id<T>(self, v: T) -> Self
pub fn set_self_link_with_id<T>(self, v: T) -> Self
Sets the value of self_link_with_id.
Example
let x = ReservationBlock::new().set_self_link_with_id("example");Sourcepub fn set_or_clear_self_link_with_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link_with_id<T>(self, v: Option<T>) -> Self
Sets or clears the value of self_link_with_id.
Example
let x = ReservationBlock::new().set_or_clear_self_link_with_id(Some("example"));
let x = ReservationBlock::new().set_or_clear_self_link_with_id(None::<String>);Sourcepub fn set_status<T>(self, v: T) -> Self
pub fn set_status<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
Sets or clears the value of status.
Example
use google_cloud_compute_v1::model::reservation_block::Status;
let x0 = ReservationBlock::new().set_or_clear_status(Some(Status::Deleting));
let x1 = ReservationBlock::new().set_or_clear_status(Some(Status::Invalid));
let x2 = ReservationBlock::new().set_or_clear_status(Some(Status::Ready));
let x_none = ReservationBlock::new().set_or_clear_status(None::<Status>);Trait Implementations
Sourceimpl Clone for ReservationBlock
impl Clone for ReservationBlock
Sourcefn clone(&self) -> ReservationBlock
fn clone(&self) -> ReservationBlock
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ReservationBlock
impl Debug for ReservationBlock
Sourceimpl Default for ReservationBlock
impl Default for ReservationBlock
Sourcefn default() -> ReservationBlock
fn default() -> ReservationBlock
Sourceimpl Message for ReservationBlock
impl Message for ReservationBlock
Sourceimpl PartialEq for ReservationBlock
impl PartialEq for ReservationBlock
impl StructuralPartialEq for ReservationBlock