#[non_exhaustive]pub struct ReservationParams {
pub resource_manager_tags: HashMap<String, String>,
/* private fields */
}Available on crate features
region-commitments or reservations only.Expand description
Additional reservation params.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.Input only. Resource manager tags to be bound to the reservation. Tag keys and
values have the same definition as resource
manager tags. Keys and values can be either in numeric format,
such as tagKeys/{tag_key_id} and tagValues/{tag_value_id} or in
namespaced format such as {org_id|project_id}/{tag_key_short_name} and
{tag_value_short_name}. The field is ignored (both PUT &
PATCH) when empty.
Implementations
Sourceimpl ReservationParams
impl ReservationParams
pub fn new() -> Self
Sets the value of resource_manager_tags.
Example
ⓘ
let x = ReservationParams::new().set_resource_manager_tags([
("key0", "abc"),
("key1", "xyz"),
]);Trait Implementations
Sourceimpl Clone for ReservationParams
impl Clone for ReservationParams
Sourcefn clone(&self) -> ReservationParams
fn clone(&self) -> ReservationParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReservationParams
impl Debug for ReservationParams
Sourceimpl Default for ReservationParams
impl Default for ReservationParams
Sourcefn default() -> ReservationParams
fn default() -> ReservationParams
Returns the “default value” for a type. Read more
Sourceimpl Message for ReservationParams
impl Message for ReservationParams
Sourceimpl PartialEq for ReservationParams
impl PartialEq for ReservationParams
impl StructuralPartialEq for ReservationParams