#[non_exhaustive]pub struct ReservationSubBlock {Show 15 fields
pub accelerator_topologies_info: Option<AcceleratorTopologiesInfo>,
pub count: Option<i32>,
pub creation_timestamp: Option<String>,
pub health_info: Option<ReservationSubBlockHealthInfo>,
pub id: Option<u64>,
pub in_use_count: Option<i32>,
pub in_use_host_count: Option<i32>,
pub kind: Option<String>,
pub name: Option<String>,
pub physical_topology: Option<ReservationSubBlockPhysicalTopology>,
pub reservation_sub_block_maintenance: Option<GroupMaintenanceInfo>,
pub self_link: Option<String>,
pub self_link_with_id: Option<String>,
pub status: Option<Status>,
pub zone: Option<String>,
/* private fields */
}reservation-sub-blocks only.Expand description
Represents a reservation subBlock resource.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.accelerator_topologies_info: Option<AcceleratorTopologiesInfo>Output only. [Output Only] Slice info for the reservation subBlock.
count: Option<i32>Output only. [Output Only] The number of hosts that are allocated in this reservation subBlock.
creation_timestamp: Option<String>Output only. [Output Only] Creation timestamp inRFC3339 text format.
health_info: Option<ReservationSubBlockHealthInfo>Output only. [Output Only] Health information for the reservation subBlock.
id: Option<u64>Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.
in_use_count: Option<i32>Output only. [Output Only] The number of instances that are currently in use on this reservation subBlock.
in_use_host_count: Option<i32>Output only. Number of hosts currently in use. If there is one or more Instances running on the host, it is considered in use.
kind: Option<String>Output only. [Output Only] Type of the resource. Alwayscompute#reservationSubBlock for reservation subBlocks.
name: Option<String>Output only. [Output Only] The name of this reservation subBlock generated by Google Compute Engine. The name must be 1-63 characters long, and comply with RFC1035 @pattern a-z?
physical_topology: Option<ReservationSubBlockPhysicalTopology>Output only. [Output Only] The physical topology of the reservation subBlock.
reservation_sub_block_maintenance: Option<GroupMaintenanceInfo>Output only. Maintenance information for this reservation subBlock.
self_link: Option<String>Output only. [Output Only] Server-defined fully-qualified URL for this resource.
self_link_with_id: Option<String>Output only. [Output Only] Server-defined URL for this resource with the resource id.
status: Option<Status>Output only. [Output Only] Status of the reservation subBlock.
zone: Option<String>Output only. [Output Only] Zone in which the reservation subBlock resides.
Implementations
Sourceimpl ReservationSubBlock
impl ReservationSubBlock
Sourcepub fn set_accelerator_topologies_info<T>(self, v: T) -> Selfwhere
T: Into<AcceleratorTopologiesInfo>,
pub fn set_accelerator_topologies_info<T>(self, v: T) -> Selfwhere
T: Into<AcceleratorTopologiesInfo>,
Sets the value of accelerator_topologies_info.
Example
use google_cloud_compute_v1::model::AcceleratorTopologiesInfo;
let x = ReservationSubBlock::new().set_accelerator_topologies_info(AcceleratorTopologiesInfo::default()/* use setters */);Sourcepub fn set_or_clear_accelerator_topologies_info<T>(self, v: Option<T>) -> Selfwhere
T: Into<AcceleratorTopologiesInfo>,
pub fn set_or_clear_accelerator_topologies_info<T>(self, v: Option<T>) -> Selfwhere
T: Into<AcceleratorTopologiesInfo>,
Sets or clears the value of accelerator_topologies_info.
Example
use google_cloud_compute_v1::model::AcceleratorTopologiesInfo;
let x = ReservationSubBlock::new().set_or_clear_accelerator_topologies_info(Some(AcceleratorTopologiesInfo::default()/* use setters */));
let x = ReservationSubBlock::new().set_or_clear_accelerator_topologies_info(None::<AcceleratorTopologiesInfo>);Sourcepub fn set_or_clear_count<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_count<T>(self, v: Option<T>) -> Self
Sourcepub fn set_creation_timestamp<T>(self, v: T) -> Self
pub fn set_creation_timestamp<T>(self, v: T) -> Self
Sets the value of creation_timestamp.
Example
let x = ReservationSubBlock::new().set_creation_timestamp("example");Sourcepub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
Sets or clears the value of creation_timestamp.
Example
let x = ReservationSubBlock::new().set_or_clear_creation_timestamp(Some("example"));
let x = ReservationSubBlock::new().set_or_clear_creation_timestamp(None::<String>);Sourcepub fn set_health_info<T>(self, v: T) -> Selfwhere
T: Into<ReservationSubBlockHealthInfo>,
pub fn set_health_info<T>(self, v: T) -> Selfwhere
T: Into<ReservationSubBlockHealthInfo>,
Sets the value of health_info.
Example
use google_cloud_compute_v1::model::ReservationSubBlockHealthInfo;
let x = ReservationSubBlock::new().set_health_info(ReservationSubBlockHealthInfo::default()/* use setters */);Sourcepub fn set_or_clear_health_info<T>(self, v: Option<T>) -> Selfwhere
T: Into<ReservationSubBlockHealthInfo>,
pub fn set_or_clear_health_info<T>(self, v: Option<T>) -> Selfwhere
T: Into<ReservationSubBlockHealthInfo>,
Sets or clears the value of health_info.
Example
use google_cloud_compute_v1::model::ReservationSubBlockHealthInfo;
let x = ReservationSubBlock::new().set_or_clear_health_info(Some(ReservationSubBlockHealthInfo::default()/* use setters */));
let x = ReservationSubBlock::new().set_or_clear_health_info(None::<ReservationSubBlockHealthInfo>);Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
Sourcepub fn set_in_use_count<T>(self, v: T) -> Self
pub fn set_in_use_count<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_in_use_count<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_in_use_count<T>(self, v: Option<T>) -> Self
Sets or clears the value of in_use_count.
Example
let x = ReservationSubBlock::new().set_or_clear_in_use_count(Some(42));
let x = ReservationSubBlock::new().set_or_clear_in_use_count(None::<i32>);Sourcepub fn set_in_use_host_count<T>(self, v: T) -> Self
pub fn set_in_use_host_count<T>(self, v: T) -> Self
Sets the value of in_use_host_count.
Example
let x = ReservationSubBlock::new().set_in_use_host_count(42);Sourcepub fn set_or_clear_in_use_host_count<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_in_use_host_count<T>(self, v: Option<T>) -> Self
Sets or clears the value of in_use_host_count.
Example
let x = ReservationSubBlock::new().set_or_clear_in_use_host_count(Some(42));
let x = ReservationSubBlock::new().set_or_clear_in_use_host_count(None::<i32>);Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
Sourcepub fn set_physical_topology<T>(self, v: T) -> Selfwhere
T: Into<ReservationSubBlockPhysicalTopology>,
pub fn set_physical_topology<T>(self, v: T) -> Selfwhere
T: Into<ReservationSubBlockPhysicalTopology>,
Sets the value of physical_topology.
Example
use google_cloud_compute_v1::model::ReservationSubBlockPhysicalTopology;
let x = ReservationSubBlock::new().set_physical_topology(ReservationSubBlockPhysicalTopology::default()/* use setters */);Sourcepub fn set_or_clear_physical_topology<T>(self, v: Option<T>) -> Selfwhere
T: Into<ReservationSubBlockPhysicalTopology>,
pub fn set_or_clear_physical_topology<T>(self, v: Option<T>) -> Selfwhere
T: Into<ReservationSubBlockPhysicalTopology>,
Sets or clears the value of physical_topology.
Example
use google_cloud_compute_v1::model::ReservationSubBlockPhysicalTopology;
let x = ReservationSubBlock::new().set_or_clear_physical_topology(Some(ReservationSubBlockPhysicalTopology::default()/* use setters */));
let x = ReservationSubBlock::new().set_or_clear_physical_topology(None::<ReservationSubBlockPhysicalTopology>);Sourcepub fn set_reservation_sub_block_maintenance<T>(self, v: T) -> Selfwhere
T: Into<GroupMaintenanceInfo>,
pub fn set_reservation_sub_block_maintenance<T>(self, v: T) -> Selfwhere
T: Into<GroupMaintenanceInfo>,
Sets the value of reservation_sub_block_maintenance.
Example
use google_cloud_compute_v1::model::GroupMaintenanceInfo;
let x = ReservationSubBlock::new().set_reservation_sub_block_maintenance(GroupMaintenanceInfo::default()/* use setters */);Sourcepub fn set_or_clear_reservation_sub_block_maintenance<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<GroupMaintenanceInfo>,
pub fn set_or_clear_reservation_sub_block_maintenance<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<GroupMaintenanceInfo>,
Sets or clears the value of reservation_sub_block_maintenance.
Example
use google_cloud_compute_v1::model::GroupMaintenanceInfo;
let x = ReservationSubBlock::new().set_or_clear_reservation_sub_block_maintenance(Some(GroupMaintenanceInfo::default()/* use setters */));
let x = ReservationSubBlock::new().set_or_clear_reservation_sub_block_maintenance(None::<GroupMaintenanceInfo>);Sourcepub fn set_self_link<T>(self, v: T) -> Self
pub fn set_self_link<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
Sourcepub fn set_self_link_with_id<T>(self, v: T) -> Self
pub fn set_self_link_with_id<T>(self, v: T) -> Self
Sets the value of self_link_with_id.
Example
let x = ReservationSubBlock::new().set_self_link_with_id("example");Sourcepub fn set_or_clear_self_link_with_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link_with_id<T>(self, v: Option<T>) -> Self
Sets or clears the value of self_link_with_id.
Example
let x = ReservationSubBlock::new().set_or_clear_self_link_with_id(Some("example"));
let x = ReservationSubBlock::new().set_or_clear_self_link_with_id(None::<String>);Sourcepub fn set_status<T>(self, v: T) -> Self
pub fn set_status<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
Sets or clears the value of status.
Example
use google_cloud_compute_v1::model::reservation_sub_block::Status;
let x0 = ReservationSubBlock::new().set_or_clear_status(Some(Status::Deleting));
let x1 = ReservationSubBlock::new().set_or_clear_status(Some(Status::Invalid));
let x2 = ReservationSubBlock::new().set_or_clear_status(Some(Status::Ready));
let x_none = ReservationSubBlock::new().set_or_clear_status(None::<Status>);Trait Implementations
Sourceimpl Clone for ReservationSubBlock
impl Clone for ReservationSubBlock
Sourcefn clone(&self) -> ReservationSubBlock
fn clone(&self) -> ReservationSubBlock
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ReservationSubBlock
impl Debug for ReservationSubBlock
Sourceimpl Default for ReservationSubBlock
impl Default for ReservationSubBlock
Sourcefn default() -> ReservationSubBlock
fn default() -> ReservationSubBlock
Sourceimpl Message for ReservationSubBlock
impl Message for ReservationSubBlock
Sourceimpl PartialEq for ReservationSubBlock
impl PartialEq for ReservationSubBlock
impl StructuralPartialEq for ReservationSubBlock