#[non_exhaustive]pub struct ReservationSubBlockHealthInfo {
pub degraded_host_count: Option<i32>,
pub degraded_infra_count: Option<i32>,
pub health_status: Option<HealthStatus>,
pub healthy_host_count: Option<i32>,
pub healthy_infra_count: Option<i32>,
/* private fields */
}reservation-sub-blocks only.Expand description
Health information for the reservation subBlock.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.degraded_host_count: Option<i32>The number of degraded hosts in the reservation subBlock.
degraded_infra_count: Option<i32>The number of degraded infrastructure (e.g NV link domain) in the reservation subblock.
health_status: Option<HealthStatus>The health status of the reservation subBlock.
healthy_host_count: Option<i32>The number of healthy hosts in the reservation subBlock.
healthy_infra_count: Option<i32>The number of healthy infrastructure (e.g NV link domain) in the reservation subblock.
Implementations
Sourceimpl ReservationSubBlockHealthInfo
impl ReservationSubBlockHealthInfo
Sourcepub fn set_degraded_host_count<T>(self, v: T) -> Self
pub fn set_degraded_host_count<T>(self, v: T) -> Self
Sets the value of degraded_host_count.
Example
let x = ReservationSubBlockHealthInfo::new().set_degraded_host_count(42);Sourcepub fn set_or_clear_degraded_host_count<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_degraded_host_count<T>(self, v: Option<T>) -> Self
Sets or clears the value of degraded_host_count.
Example
let x = ReservationSubBlockHealthInfo::new().set_or_clear_degraded_host_count(Some(42));
let x = ReservationSubBlockHealthInfo::new().set_or_clear_degraded_host_count(None::<i32>);Sourcepub fn set_degraded_infra_count<T>(self, v: T) -> Self
pub fn set_degraded_infra_count<T>(self, v: T) -> Self
Sets the value of degraded_infra_count.
Example
let x = ReservationSubBlockHealthInfo::new().set_degraded_infra_count(42);Sourcepub fn set_or_clear_degraded_infra_count<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_degraded_infra_count<T>(self, v: Option<T>) -> Self
Sets or clears the value of degraded_infra_count.
Example
let x = ReservationSubBlockHealthInfo::new().set_or_clear_degraded_infra_count(Some(42));
let x = ReservationSubBlockHealthInfo::new().set_or_clear_degraded_infra_count(None::<i32>);Sourcepub fn set_health_status<T>(self, v: T) -> Selfwhere
T: Into<HealthStatus>,
pub fn set_health_status<T>(self, v: T) -> Selfwhere
T: Into<HealthStatus>,
Sets the value of health_status.
Example
use google_cloud_compute_v1::model::reservation_sub_block_health_info::HealthStatus;
let x0 = ReservationSubBlockHealthInfo::new().set_health_status(HealthStatus::Healthy);
let x1 = ReservationSubBlockHealthInfo::new().set_health_status(HealthStatus::Unspecified);Sourcepub fn set_or_clear_health_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<HealthStatus>,
pub fn set_or_clear_health_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<HealthStatus>,
Sets or clears the value of health_status.
Example
use google_cloud_compute_v1::model::reservation_sub_block_health_info::HealthStatus;
let x0 = ReservationSubBlockHealthInfo::new().set_or_clear_health_status(Some(HealthStatus::Healthy));
let x1 = ReservationSubBlockHealthInfo::new().set_or_clear_health_status(Some(HealthStatus::Unspecified));
let x_none = ReservationSubBlockHealthInfo::new().set_or_clear_health_status(None::<HealthStatus>);Sourcepub fn set_healthy_host_count<T>(self, v: T) -> Self
pub fn set_healthy_host_count<T>(self, v: T) -> Self
Sets the value of healthy_host_count.
Example
let x = ReservationSubBlockHealthInfo::new().set_healthy_host_count(42);Sourcepub fn set_or_clear_healthy_host_count<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_healthy_host_count<T>(self, v: Option<T>) -> Self
Sets or clears the value of healthy_host_count.
Example
let x = ReservationSubBlockHealthInfo::new().set_or_clear_healthy_host_count(Some(42));
let x = ReservationSubBlockHealthInfo::new().set_or_clear_healthy_host_count(None::<i32>);Sourcepub fn set_healthy_infra_count<T>(self, v: T) -> Self
pub fn set_healthy_infra_count<T>(self, v: T) -> Self
Sets the value of healthy_infra_count.
Example
let x = ReservationSubBlockHealthInfo::new().set_healthy_infra_count(42);Sourcepub fn set_or_clear_healthy_infra_count<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_healthy_infra_count<T>(self, v: Option<T>) -> Self
Sets or clears the value of healthy_infra_count.
Example
let x = ReservationSubBlockHealthInfo::new().set_or_clear_healthy_infra_count(Some(42));
let x = ReservationSubBlockHealthInfo::new().set_or_clear_healthy_infra_count(None::<i32>);Trait Implementations
Sourceimpl Clone for ReservationSubBlockHealthInfo
impl Clone for ReservationSubBlockHealthInfo
Sourcefn clone(&self) -> ReservationSubBlockHealthInfo
fn clone(&self) -> ReservationSubBlockHealthInfo
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for ReservationSubBlockHealthInfo
impl Default for ReservationSubBlockHealthInfo
Sourcefn default() -> ReservationSubBlockHealthInfo
fn default() -> ReservationSubBlockHealthInfo
impl StructuralPartialEq for ReservationSubBlockHealthInfo