#[non_exhaustive]pub struct ResourceStatus {
pub effective_instance_metadata: Option<ResourceStatusEffectiveInstanceMetadata>,
pub physical_host: Option<String>,
pub physical_host_topology: Option<ResourceStatusPhysicalHostTopology>,
pub reservation_consumption_info: Option<ResourceStatusReservationConsumptionInfo>,
pub scheduling: Option<ResourceStatusScheduling>,
pub upcoming_maintenance: Option<UpcomingMaintenance>,
/* private fields */
}instances only.Expand description
Contains output only fields. Use this sub-message for actual values set on Instance attributes as compared to the value requested by the user (intent) in their instance CRUD calls.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.effective_instance_metadata: Option<ResourceStatusEffectiveInstanceMetadata>Output only. [Output Only] Effective metadata is a field that consolidates project, zonal instance settings, and instance-level predefined metadata keys to provide the overridden value for those metadata keys at the instance level.
physical_host: Option<String>Output only. [Output Only] The precise location of your instance within the zone’s data center, including the block, sub-block, and host. The field is formatted as follows: blockId/subBlockId/hostId.
physical_host_topology: Option<ResourceStatusPhysicalHostTopology>Output only. [Output Only] A series of fields containing the global name of the Compute Engine cluster, as well as the ID of the block, sub-block, and host on which the running instance is located.
reservation_consumption_info: Option<ResourceStatusReservationConsumptionInfo>Output only. [Output Only] Reservation information that the instance is consuming from.
scheduling: Option<ResourceStatusScheduling>upcoming_maintenance: Option<UpcomingMaintenance>Implementations
Sourceimpl ResourceStatus
impl ResourceStatus
Sourcepub fn set_effective_instance_metadata<T>(self, v: T) -> Selfwhere
T: Into<ResourceStatusEffectiveInstanceMetadata>,
pub fn set_effective_instance_metadata<T>(self, v: T) -> Selfwhere
T: Into<ResourceStatusEffectiveInstanceMetadata>,
Sets the value of effective_instance_metadata.
Example
use google_cloud_compute_v1::model::ResourceStatusEffectiveInstanceMetadata;
let x = ResourceStatus::new().set_effective_instance_metadata(ResourceStatusEffectiveInstanceMetadata::default()/* use setters */);Sourcepub fn set_or_clear_effective_instance_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<ResourceStatusEffectiveInstanceMetadata>,
pub fn set_or_clear_effective_instance_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<ResourceStatusEffectiveInstanceMetadata>,
Sets or clears the value of effective_instance_metadata.
Example
use google_cloud_compute_v1::model::ResourceStatusEffectiveInstanceMetadata;
let x = ResourceStatus::new().set_or_clear_effective_instance_metadata(Some(ResourceStatusEffectiveInstanceMetadata::default()/* use setters */));
let x = ResourceStatus::new().set_or_clear_effective_instance_metadata(None::<ResourceStatusEffectiveInstanceMetadata>);Sourcepub fn set_physical_host<T>(self, v: T) -> Self
pub fn set_physical_host<T>(self, v: T) -> Self
Sets the value of physical_host.
Example
let x = ResourceStatus::new().set_physical_host("example");Sourcepub fn set_or_clear_physical_host<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_physical_host<T>(self, v: Option<T>) -> Self
Sets or clears the value of physical_host.
Example
let x = ResourceStatus::new().set_or_clear_physical_host(Some("example"));
let x = ResourceStatus::new().set_or_clear_physical_host(None::<String>);Sourcepub fn set_physical_host_topology<T>(self, v: T) -> Selfwhere
T: Into<ResourceStatusPhysicalHostTopology>,
pub fn set_physical_host_topology<T>(self, v: T) -> Selfwhere
T: Into<ResourceStatusPhysicalHostTopology>,
Sets the value of physical_host_topology.
Example
use google_cloud_compute_v1::model::ResourceStatusPhysicalHostTopology;
let x = ResourceStatus::new().set_physical_host_topology(ResourceStatusPhysicalHostTopology::default()/* use setters */);Sourcepub fn set_or_clear_physical_host_topology<T>(self, v: Option<T>) -> Selfwhere
T: Into<ResourceStatusPhysicalHostTopology>,
pub fn set_or_clear_physical_host_topology<T>(self, v: Option<T>) -> Selfwhere
T: Into<ResourceStatusPhysicalHostTopology>,
Sets or clears the value of physical_host_topology.
Example
use google_cloud_compute_v1::model::ResourceStatusPhysicalHostTopology;
let x = ResourceStatus::new().set_or_clear_physical_host_topology(Some(ResourceStatusPhysicalHostTopology::default()/* use setters */));
let x = ResourceStatus::new().set_or_clear_physical_host_topology(None::<ResourceStatusPhysicalHostTopology>);Sourcepub fn set_reservation_consumption_info<T>(self, v: T) -> Selfwhere
T: Into<ResourceStatusReservationConsumptionInfo>,
pub fn set_reservation_consumption_info<T>(self, v: T) -> Selfwhere
T: Into<ResourceStatusReservationConsumptionInfo>,
Sets the value of reservation_consumption_info.
Example
use google_cloud_compute_v1::model::ResourceStatusReservationConsumptionInfo;
let x = ResourceStatus::new().set_reservation_consumption_info(ResourceStatusReservationConsumptionInfo::default()/* use setters */);Sourcepub fn set_or_clear_reservation_consumption_info<T>(self, v: Option<T>) -> Selfwhere
T: Into<ResourceStatusReservationConsumptionInfo>,
pub fn set_or_clear_reservation_consumption_info<T>(self, v: Option<T>) -> Selfwhere
T: Into<ResourceStatusReservationConsumptionInfo>,
Sets or clears the value of reservation_consumption_info.
Example
use google_cloud_compute_v1::model::ResourceStatusReservationConsumptionInfo;
let x = ResourceStatus::new().set_or_clear_reservation_consumption_info(Some(ResourceStatusReservationConsumptionInfo::default()/* use setters */));
let x = ResourceStatus::new().set_or_clear_reservation_consumption_info(None::<ResourceStatusReservationConsumptionInfo>);Sourcepub fn set_scheduling<T>(self, v: T) -> Selfwhere
T: Into<ResourceStatusScheduling>,
pub fn set_scheduling<T>(self, v: T) -> Selfwhere
T: Into<ResourceStatusScheduling>,
Sets the value of scheduling.
Example
use google_cloud_compute_v1::model::ResourceStatusScheduling;
let x = ResourceStatus::new().set_scheduling(ResourceStatusScheduling::default()/* use setters */);Sourcepub fn set_or_clear_scheduling<T>(self, v: Option<T>) -> Selfwhere
T: Into<ResourceStatusScheduling>,
pub fn set_or_clear_scheduling<T>(self, v: Option<T>) -> Selfwhere
T: Into<ResourceStatusScheduling>,
Sets or clears the value of scheduling.
Example
use google_cloud_compute_v1::model::ResourceStatusScheduling;
let x = ResourceStatus::new().set_or_clear_scheduling(Some(ResourceStatusScheduling::default()/* use setters */));
let x = ResourceStatus::new().set_or_clear_scheduling(None::<ResourceStatusScheduling>);Sourcepub fn set_upcoming_maintenance<T>(self, v: T) -> Selfwhere
T: Into<UpcomingMaintenance>,
pub fn set_upcoming_maintenance<T>(self, v: T) -> Selfwhere
T: Into<UpcomingMaintenance>,
Sets the value of upcoming_maintenance.
Example
use google_cloud_compute_v1::model::UpcomingMaintenance;
let x = ResourceStatus::new().set_upcoming_maintenance(UpcomingMaintenance::default()/* use setters */);Sourcepub fn set_or_clear_upcoming_maintenance<T>(self, v: Option<T>) -> Selfwhere
T: Into<UpcomingMaintenance>,
pub fn set_or_clear_upcoming_maintenance<T>(self, v: Option<T>) -> Selfwhere
T: Into<UpcomingMaintenance>,
Sets or clears the value of upcoming_maintenance.
Example
use google_cloud_compute_v1::model::UpcomingMaintenance;
let x = ResourceStatus::new().set_or_clear_upcoming_maintenance(Some(UpcomingMaintenance::default()/* use setters */));
let x = ResourceStatus::new().set_or_clear_upcoming_maintenance(None::<UpcomingMaintenance>);Trait Implementations
Sourceimpl Clone for ResourceStatus
impl Clone for ResourceStatus
Sourcefn clone(&self) -> ResourceStatus
fn clone(&self) -> ResourceStatus
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ResourceStatus
impl Debug for ResourceStatus
Sourceimpl Default for ResourceStatus
impl Default for ResourceStatus
Sourcefn default() -> ResourceStatus
fn default() -> ResourceStatus
Sourceimpl Message for ResourceStatus
impl Message for ResourceStatus
Sourceimpl PartialEq for ResourceStatus
impl PartialEq for ResourceStatus
impl StructuralPartialEq for ResourceStatus