#[non_exhaustive]pub struct ResourceStatusPhysicalHostTopologyAdditionalAttributes {
pub accelerator_topology_ids: HashMap<String, String>,
/* private fields */
}Available on crate feature
instances only.Expand description
Additional location information of the running instance.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.accelerator_topology_ids: HashMap<String, String>Output only. The IDs of the accelerator topologies the instance belongs to. For example The key will be topologies like “4x4”, “2x2x2” and the value will be the location ID of the topologies.
Implementations
Sourceimpl ResourceStatusPhysicalHostTopologyAdditionalAttributes
impl ResourceStatusPhysicalHostTopologyAdditionalAttributes
Sourcepub fn set_accelerator_topology_ids<T, K, V>(self, v: T) -> Self
pub fn set_accelerator_topology_ids<T, K, V>(self, v: T) -> Self
Sets the value of accelerator_topology_ids.
Example
ⓘ
let x = ResourceStatusPhysicalHostTopologyAdditionalAttributes::new().set_accelerator_topology_ids([
("key0", "abc"),
("key1", "xyz"),
]);Trait Implementations
Sourceimpl Clone for ResourceStatusPhysicalHostTopologyAdditionalAttributes
impl Clone for ResourceStatusPhysicalHostTopologyAdditionalAttributes
Sourcefn clone(&self) -> ResourceStatusPhysicalHostTopologyAdditionalAttributes
fn clone(&self) -> ResourceStatusPhysicalHostTopologyAdditionalAttributes
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ResourceStatusPhysicalHostTopologyAdditionalAttributes
impl Default for ResourceStatusPhysicalHostTopologyAdditionalAttributes
Sourcefn default() -> ResourceStatusPhysicalHostTopologyAdditionalAttributes
fn default() -> ResourceStatusPhysicalHostTopologyAdditionalAttributes
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ResourceStatusPhysicalHostTopologyAdditionalAttributes
impl PartialEq for ResourceStatusPhysicalHostTopologyAdditionalAttributes
Sourcefn eq(
&self,
other: &ResourceStatusPhysicalHostTopologyAdditionalAttributes,
) -> bool
fn eq( &self, other: &ResourceStatusPhysicalHostTopologyAdditionalAttributes, ) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ResourceStatusPhysicalHostTopologyAdditionalAttributes