#[non_exhaustive]pub struct ResourceStatusScheduling {
pub availability_domain: Option<i32>,
pub graceful_shutdown_timestamp: Option<String>,
pub termination_timestamp: Option<String>,
/* private fields */
}Available on crate feature
instances only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.availability_domain: Option<i32>Specifies the availability domain to place the instance in. The value must be a number between 1 and the number of availability domains specified in the spread placement policy attached to the instance.
graceful_shutdown_timestamp: Option<String>Output only. Specifies the timestamp, when the instance will start graceful shutdown process, in RFC3339 text format.
termination_timestamp: Option<String>Time in future when the instance will be terminated inRFC3339 text format.
Implementations
Sourceimpl ResourceStatusScheduling
impl ResourceStatusScheduling
Sourcepub fn set_availability_domain<T>(self, v: T) -> Self
pub fn set_availability_domain<T>(self, v: T) -> Self
Sets the value of availability_domain.
Example
ⓘ
let x = ResourceStatusScheduling::new().set_availability_domain(42);Sourcepub fn set_or_clear_availability_domain<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_availability_domain<T>(self, v: Option<T>) -> Self
Sets or clears the value of availability_domain.
Example
ⓘ
let x = ResourceStatusScheduling::new().set_or_clear_availability_domain(Some(42));
let x = ResourceStatusScheduling::new().set_or_clear_availability_domain(None::<i32>);Sourcepub fn set_graceful_shutdown_timestamp<T>(self, v: T) -> Self
pub fn set_graceful_shutdown_timestamp<T>(self, v: T) -> Self
Sets the value of graceful_shutdown_timestamp.
Example
ⓘ
let x = ResourceStatusScheduling::new().set_graceful_shutdown_timestamp("example");Sourcepub fn set_or_clear_graceful_shutdown_timestamp<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_graceful_shutdown_timestamp<T>(self, v: Option<T>) -> Self
Sets or clears the value of graceful_shutdown_timestamp.
Example
ⓘ
let x = ResourceStatusScheduling::new().set_or_clear_graceful_shutdown_timestamp(Some("example"));
let x = ResourceStatusScheduling::new().set_or_clear_graceful_shutdown_timestamp(None::<String>);Sourcepub fn set_termination_timestamp<T>(self, v: T) -> Self
pub fn set_termination_timestamp<T>(self, v: T) -> Self
Sets the value of termination_timestamp.
Example
ⓘ
let x = ResourceStatusScheduling::new().set_termination_timestamp("example");Sourcepub fn set_or_clear_termination_timestamp<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_termination_timestamp<T>(self, v: Option<T>) -> Self
Sets or clears the value of termination_timestamp.
Example
ⓘ
let x = ResourceStatusScheduling::new().set_or_clear_termination_timestamp(Some("example"));
let x = ResourceStatusScheduling::new().set_or_clear_termination_timestamp(None::<String>);Trait Implementations
Sourceimpl Clone for ResourceStatusScheduling
impl Clone for ResourceStatusScheduling
Sourcefn clone(&self) -> ResourceStatusScheduling
fn clone(&self) -> ResourceStatusScheduling
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResourceStatusScheduling
impl Debug for ResourceStatusScheduling
Sourceimpl Default for ResourceStatusScheduling
impl Default for ResourceStatusScheduling
Sourcefn default() -> ResourceStatusScheduling
fn default() -> ResourceStatusScheduling
Returns the “default value” for a type. Read more
Sourceimpl Message for ResourceStatusScheduling
impl Message for ResourceStatusScheduling
Sourceimpl PartialEq for ResourceStatusScheduling
impl PartialEq for ResourceStatusScheduling
impl StructuralPartialEq for ResourceStatusScheduling