#[non_exhaustive]pub struct RiskDetails {
pub duration: Option<Duration>,
pub global_dns_insight: Option<RiskDetailsGlobalDnsInsight>,
pub last_update_timestamp: Option<Timestamp>,
pub severity: Option<Severity>,
pub type: Option<Type>,
/* private fields */
}Available on crate feature
reliability-risks only.Expand description
Detailed insights and metrics about a detected reliability risk.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.duration: Option<Duration>The duration of the risk since it was detected.
global_dns_insight: Option<RiskDetailsGlobalDnsInsight>Insight details for global DNS risk.
last_update_timestamp: Option<Timestamp>The last time the risk was updated.
severity: Option<Severity>The severity of the risk.
type: Option<Type>The type of risk.
Implementations
Sourceimpl RiskDetails
impl RiskDetails
Sourcepub fn set_duration<T>(self, v: T) -> Self
pub fn set_duration<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_duration<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_duration<T>(self, v: Option<T>) -> Self
Sourcepub fn set_global_dns_insight<T>(self, v: T) -> Selfwhere
T: Into<RiskDetailsGlobalDnsInsight>,
pub fn set_global_dns_insight<T>(self, v: T) -> Selfwhere
T: Into<RiskDetailsGlobalDnsInsight>,
Sets the value of global_dns_insight.
Example
ⓘ
use google_cloud_compute_v1::model::RiskDetailsGlobalDnsInsight;
let x = RiskDetails::new().set_global_dns_insight(RiskDetailsGlobalDnsInsight::default()/* use setters */);Sourcepub fn set_or_clear_global_dns_insight<T>(self, v: Option<T>) -> Selfwhere
T: Into<RiskDetailsGlobalDnsInsight>,
pub fn set_or_clear_global_dns_insight<T>(self, v: Option<T>) -> Selfwhere
T: Into<RiskDetailsGlobalDnsInsight>,
Sets or clears the value of global_dns_insight.
Example
ⓘ
use google_cloud_compute_v1::model::RiskDetailsGlobalDnsInsight;
let x = RiskDetails::new().set_or_clear_global_dns_insight(Some(RiskDetailsGlobalDnsInsight::default()/* use setters */));
let x = RiskDetails::new().set_or_clear_global_dns_insight(None::<RiskDetailsGlobalDnsInsight>);Sourcepub fn set_last_update_timestamp<T>(self, v: T) -> Self
pub fn set_last_update_timestamp<T>(self, v: T) -> Self
Sets the value of last_update_timestamp.
Example
ⓘ
use wkt::Timestamp;
let x = RiskDetails::new().set_last_update_timestamp(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_last_update_timestamp<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_last_update_timestamp<T>(self, v: Option<T>) -> Self
Sets or clears the value of last_update_timestamp.
Example
ⓘ
use wkt::Timestamp;
let x = RiskDetails::new().set_or_clear_last_update_timestamp(Some(Timestamp::default()/* use setters */));
let x = RiskDetails::new().set_or_clear_last_update_timestamp(None::<Timestamp>);Sourcepub fn set_severity<T>(self, v: T) -> Self
pub fn set_severity<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_severity<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_severity<T>(self, v: Option<T>) -> Self
Sets or clears the value of severity.
Example
ⓘ
use google_cloud_compute_v1::model::risk_details::Severity;
let x0 = RiskDetails::new().set_or_clear_severity(Some(Severity::High));
let x1 = RiskDetails::new().set_or_clear_severity(Some(Severity::Low));
let x2 = RiskDetails::new().set_or_clear_severity(Some(Severity::Medium));
let x_none = RiskDetails::new().set_or_clear_severity(None::<Severity>);Sourcepub fn set_or_clear_type<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_type<T>(self, v: Option<T>) -> Self