Rollout

Struct Rollout 

#[non_exhaustive]
pub struct Rollout {
Show 17 fields pub cancellation_time: Option<String>, pub completion_time: Option<String>, pub creation_timestamp: Option<String>, pub current_wave_number: Option<i64>, pub description: Option<String>, pub etag: Option<String>, pub id: Option<u64>, pub kind: Option<String>, pub name: Option<String>, pub pause_time: Option<String>, pub resume_time: Option<String>, pub rollout_entity: Option<RolloutRolloutEntity>, pub rollout_plan: Option<String>, pub self_link: Option<String>, pub self_link_with_id: Option<String>, pub state: Option<State>, pub wave_details: Vec<RolloutWaveDetails>, /* private fields */
}
Available on crate feature rollouts only.
Rollout resource.

A Rollout is a specific instance of a RolloutPlan. It represents a single execution of a strategy to roll out a specific resource. It also provides APIs to interact with the rollout.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
cancellation_time: Option<String>

Output only. The timestamp at which the Rollout was cancelled.

completion_time: Option<String>

Output only. The timestamp at which the Rollout was completed.

creation_timestamp: Option<String>

Output only. [Output Only] Creation timestamp inRFC3339 text format.

current_wave_number: Option<i64>

Output only. The number of the currently running wave. Ex. 1

description: Option<String>

An optional description of this resource. Provide this property when you create the resource.

etag: Option<String>

Output only. etag of the Rollout Ex. abc1234

id: Option<u64>

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.

kind: Option<String>

Output only. [Output Only] Type of the resource. Always compute#rollout for rollouts.

name: Option<String>

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.

pause_time: Option<String>

Output only. The timestamp at which the Rollout was paused.

resume_time: Option<String>

Output only. The timestamp at which the Rollout was resumed.

rollout_entity: Option<RolloutRolloutEntity>

Required. The resource being rolled out.

rollout_plan: Option<String>

Required. Rollout Plan used to model the Rollout. Ex. compute.googleapis.com/v1/projects/1234/rolloutPlans/rp1

self_link: Option<String>

Output only. [Output Only] Server-defined fully-qualified URL for this resource.

self_link_with_id: Option<String>

Output only. [Output Only] Server-defined URL for this resource’s resource id.

state: Option<State>

Output only. The current state of the Rollout.

wave_details: Vec<RolloutWaveDetails>

Output only. Details about each wave of the rollout.

Implementations

Source

impl Rollout

pub fn new() -> Self

Creates a new default instance.

pub fn set_cancellation_time<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of cancellation_time.

Example
let x = Rollout::new().set_cancellation_time("example");
pub fn set_or_clear_cancellation_time<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of cancellation_time.

Example
let x = Rollout::new().set_or_clear_cancellation_time(Some("example"));
let x = Rollout::new().set_or_clear_cancellation_time(None::<String>);
pub fn set_completion_time<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of completion_time.

Example
let x = Rollout::new().set_completion_time("example");
pub fn set_or_clear_completion_time<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of completion_time.

Example
let x = Rollout::new().set_or_clear_completion_time(Some("example"));
let x = Rollout::new().set_or_clear_completion_time(None::<String>);
pub fn set_creation_timestamp<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of creation_timestamp.

Example
let x = Rollout::new().set_creation_timestamp("example");
pub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of creation_timestamp.

Example
let x = Rollout::new().set_or_clear_creation_timestamp(Some("example"));
let x = Rollout::new().set_or_clear_creation_timestamp(None::<String>);
pub fn set_current_wave_number<T>(self, v: T) -> Self
where T: Into<i64>,

Sets the value of current_wave_number.

Example
let x = Rollout::new().set_current_wave_number(42);
pub fn set_or_clear_current_wave_number<T>(self, v: Option<T>) -> Self
where T: Into<i64>,

Sets or clears the value of current_wave_number.

Example
let x = Rollout::new().set_or_clear_current_wave_number(Some(42));
let x = Rollout::new().set_or_clear_current_wave_number(None::<i32>);
pub fn set_description<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of description.

Example
let x = Rollout::new().set_description("example");
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of description.

Example
let x = Rollout::new().set_or_clear_description(Some("example"));
let x = Rollout::new().set_or_clear_description(None::<String>);
pub fn set_etag<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of etag.

Example
let x = Rollout::new().set_etag("example");
pub fn set_or_clear_etag<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of etag.

Example
let x = Rollout::new().set_or_clear_etag(Some("example"));
let x = Rollout::new().set_or_clear_etag(None::<String>);
pub fn set_id<T>(self, v: T) -> Self
where T: Into<u64>,

Sets the value of id.

Example
let x = Rollout::new().set_id(42_u32);
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
where T: Into<u64>,

Sets or clears the value of id.

Example
let x = Rollout::new().set_or_clear_id(Some(42_u32));
let x = Rollout::new().set_or_clear_id(None::<u32>);
pub fn set_kind<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of kind.

Example
let x = Rollout::new().set_kind("example");
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of kind.

Example
let x = Rollout::new().set_or_clear_kind(Some("example"));
let x = Rollout::new().set_or_clear_kind(None::<String>);
pub fn set_name<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of name.

Example
let x = Rollout::new().set_name("example");
pub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of name.

Example
let x = Rollout::new().set_or_clear_name(Some("example"));
let x = Rollout::new().set_or_clear_name(None::<String>);
pub fn set_pause_time<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of pause_time.

Example
let x = Rollout::new().set_pause_time("example");
pub fn set_or_clear_pause_time<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of pause_time.

Example
let x = Rollout::new().set_or_clear_pause_time(Some("example"));
let x = Rollout::new().set_or_clear_pause_time(None::<String>);
pub fn set_resume_time<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of resume_time.

Example
let x = Rollout::new().set_resume_time("example");
pub fn set_or_clear_resume_time<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of resume_time.

Example
let x = Rollout::new().set_or_clear_resume_time(Some("example"));
let x = Rollout::new().set_or_clear_resume_time(None::<String>);
pub fn set_rollout_entity<T>(self, v: T) -> Self

Sets the value of rollout_entity.

Example
use google_cloud_compute_v1::model::RolloutRolloutEntity;
let x = Rollout::new().set_rollout_entity(RolloutRolloutEntity::default()/* use setters */);
pub fn set_or_clear_rollout_entity<T>(self, v: Option<T>) -> Self

Sets or clears the value of rollout_entity.

Example
use google_cloud_compute_v1::model::RolloutRolloutEntity;
let x = Rollout::new().set_or_clear_rollout_entity(Some(RolloutRolloutEntity::default()/* use setters */));
let x = Rollout::new().set_or_clear_rollout_entity(None::<RolloutRolloutEntity>);
pub fn set_rollout_plan<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of rollout_plan.

Example
let x = Rollout::new().set_rollout_plan("example");
pub fn set_or_clear_rollout_plan<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of rollout_plan.

Example
let x = Rollout::new().set_or_clear_rollout_plan(Some("example"));
let x = Rollout::new().set_or_clear_rollout_plan(None::<String>);

Sets the value of self_link.

Example
let x = Rollout::new().set_self_link("example");

Sets or clears the value of self_link.

Example
let x = Rollout::new().set_or_clear_self_link(Some("example"));
let x = Rollout::new().set_or_clear_self_link(None::<String>);

Sets the value of self_link_with_id.

Example
let x = Rollout::new().set_self_link_with_id("example");

Sets or clears the value of self_link_with_id.

Example
let x = Rollout::new().set_or_clear_self_link_with_id(Some("example"));
let x = Rollout::new().set_or_clear_self_link_with_id(None::<String>);
pub fn set_state<T>(self, v: T) -> Self
where T: Into<State>,

Sets the value of state.

Example
use google_cloud_compute_v1::model::rollout::State;
let x0 = Rollout::new().set_state(State::Cancelling);
let x1 = Rollout::new().set_state(State::CancelFailed);
let x2 = Rollout::new().set_state(State::Completed);
pub fn set_or_clear_state<T>(self, v: Option<T>) -> Self
where T: Into<State>,

Sets or clears the value of state.

Example
use google_cloud_compute_v1::model::rollout::State;
let x0 = Rollout::new().set_or_clear_state(Some(State::Cancelling));
let x1 = Rollout::new().set_or_clear_state(Some(State::CancelFailed));
let x2 = Rollout::new().set_or_clear_state(Some(State::Completed));
let x_none = Rollout::new().set_or_clear_state(None::<State>);
pub fn set_wave_details<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<RolloutWaveDetails>,

Sets the value of wave_details.

Example
use google_cloud_compute_v1::model::RolloutWaveDetails;
let x = Rollout::new()
    .set_wave_details([
        RolloutWaveDetails::default()/* use setters */,
        RolloutWaveDetails::default()/* use (different) setters */,
    ]);