#[non_exhaustive]pub struct RolloutPlan {
pub creation_timestamp: Option<String>,
pub description: Option<String>,
pub id: Option<u64>,
pub kind: Option<String>,
pub location_scope: Option<LocationScope>,
pub name: Option<String>,
pub self_link: Option<String>,
pub self_link_with_id: Option<String>,
pub waves: Vec<RolloutPlanWave>,
/* private fields */
}rollout-plans only.Expand description
RolloutPlan resource.
A RolloutPlan is the customer-defined strategy to divide a large-scale change into smaller increments, referred to as “waves”. Each wave targets a specific portion of the overall affected area and defines criteria that must be met before progressing to the subsequent wave.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.creation_timestamp: Option<String>Output only. [Output Only] Creation timestamp inRFC3339 text format.
description: Option<String>An optional description of this resource. Provide this property when you create the resource.
id: Option<u64>Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.
kind: Option<String>Output only. [Output Only] Type of the resource. Always compute#rolloutPlan for rolloutPlans.
location_scope: Option<LocationScope>The location scope of the rollout plan. If not specified, the location scope is considered as ZONAL.
name: Option<String>Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?
which means the first character must be a lowercase letter, and all
following characters must be a dash, lowercase letter, or digit, except
the last character, which cannot be a dash.
self_link: Option<String>Output only. [Output Only] Server-defined fully-qualified URL for this resource.
self_link_with_id: Option<String>Output only. [Output Only] Server-defined URL for this resource’s resource id.
waves: Vec<RolloutPlanWave>Required. The waves included in this rollout plan.
Implementations
Sourceimpl RolloutPlan
impl RolloutPlan
Sourcepub fn set_creation_timestamp<T>(self, v: T) -> Self
pub fn set_creation_timestamp<T>(self, v: T) -> Self
Sets the value of creation_timestamp.
Example
let x = RolloutPlan::new().set_creation_timestamp("example");Sourcepub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
Sets or clears the value of creation_timestamp.
Example
let x = RolloutPlan::new().set_or_clear_creation_timestamp(Some("example"));
let x = RolloutPlan::new().set_or_clear_creation_timestamp(None::<String>);Sourcepub fn set_description<T>(self, v: T) -> Self
pub fn set_description<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
Sets or clears the value of description.
Example
let x = RolloutPlan::new().set_or_clear_description(Some("example"));
let x = RolloutPlan::new().set_or_clear_description(None::<String>);Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_location_scope<T>(self, v: T) -> Selfwhere
T: Into<LocationScope>,
pub fn set_location_scope<T>(self, v: T) -> Selfwhere
T: Into<LocationScope>,
Sets the value of location_scope.
Example
use google_cloud_compute_v1::model::rollout_plan::LocationScope;
let x0 = RolloutPlan::new().set_location_scope(LocationScope::Regional);
let x1 = RolloutPlan::new().set_location_scope(LocationScope::Zonal);Sourcepub fn set_or_clear_location_scope<T>(self, v: Option<T>) -> Selfwhere
T: Into<LocationScope>,
pub fn set_or_clear_location_scope<T>(self, v: Option<T>) -> Selfwhere
T: Into<LocationScope>,
Sets or clears the value of location_scope.
Example
use google_cloud_compute_v1::model::rollout_plan::LocationScope;
let x0 = RolloutPlan::new().set_or_clear_location_scope(Some(LocationScope::Regional));
let x1 = RolloutPlan::new().set_or_clear_location_scope(Some(LocationScope::Zonal));
let x_none = RolloutPlan::new().set_or_clear_location_scope(None::<LocationScope>);Sourcepub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
Sourcepub fn set_self_link<T>(self, v: T) -> Self
pub fn set_self_link<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
Sourcepub fn set_self_link_with_id<T>(self, v: T) -> Self
pub fn set_self_link_with_id<T>(self, v: T) -> Self
Sets the value of self_link_with_id.
Example
let x = RolloutPlan::new().set_self_link_with_id("example");Sourcepub fn set_or_clear_self_link_with_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link_with_id<T>(self, v: Option<T>) -> Self
Sets or clears the value of self_link_with_id.
Example
let x = RolloutPlan::new().set_or_clear_self_link_with_id(Some("example"));
let x = RolloutPlan::new().set_or_clear_self_link_with_id(None::<String>);Trait Implementations
Sourceimpl Clone for RolloutPlan
impl Clone for RolloutPlan
Sourcefn clone(&self) -> RolloutPlan
fn clone(&self) -> RolloutPlan
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for RolloutPlan
impl Debug for RolloutPlan
Sourceimpl Default for RolloutPlan
impl Default for RolloutPlan
Sourcefn default() -> RolloutPlan
fn default() -> RolloutPlan
Sourceimpl Message for RolloutPlan
impl Message for RolloutPlan
Sourceimpl PartialEq for RolloutPlan
impl PartialEq for RolloutPlan
impl StructuralPartialEq for RolloutPlan