#[non_exhaustive]pub struct RolloutPlanWave {
pub display_name: Option<String>,
pub number: Option<i64>,
pub orchestration_options: Option<RolloutPlanWaveOrchestrationOptions>,
pub selectors: Vec<RolloutPlanWaveSelector>,
pub validation: Option<RolloutPlanWaveValidation>,
/* private fields */
}Available on crate feature
rollout-plans only.Expand description
A single wave in a rollout plan.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.display_name: Option<String>Optional. The display name of this wave of the rollout plan.
number: Option<i64>Output only. The wave number.
orchestration_options: Option<RolloutPlanWaveOrchestrationOptions>Optional. The orchestration options for this wave.
selectors: Vec<RolloutPlanWaveSelector>Required. The selectors for this wave. There is a logical AND between each selector defined in a wave, so a resource must satisfy the criteria of all the specified selectors to be in scope for the wave.
validation: Option<RolloutPlanWaveValidation>Required. The validation to be performed at the end of this wave.
Implementations
Sourceimpl RolloutPlanWave
impl RolloutPlanWave
Sourcepub fn set_display_name<T>(self, v: T) -> Self
pub fn set_display_name<T>(self, v: T) -> Self
Sets the value of display_name.
Example
ⓘ
let x = RolloutPlanWave::new().set_display_name("example");Sourcepub fn set_or_clear_display_name<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_display_name<T>(self, v: Option<T>) -> Self
Sets or clears the value of display_name.
Example
ⓘ
let x = RolloutPlanWave::new().set_or_clear_display_name(Some("example"));
let x = RolloutPlanWave::new().set_or_clear_display_name(None::<String>);Sourcepub fn set_number<T>(self, v: T) -> Self
pub fn set_number<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_number<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_number<T>(self, v: Option<T>) -> Self
Sourcepub fn set_orchestration_options<T>(self, v: T) -> Selfwhere
T: Into<RolloutPlanWaveOrchestrationOptions>,
pub fn set_orchestration_options<T>(self, v: T) -> Selfwhere
T: Into<RolloutPlanWaveOrchestrationOptions>,
Sets the value of orchestration_options.
Example
ⓘ
use google_cloud_compute_v1::model::RolloutPlanWaveOrchestrationOptions;
let x = RolloutPlanWave::new().set_orchestration_options(RolloutPlanWaveOrchestrationOptions::default()/* use setters */);Sourcepub fn set_or_clear_orchestration_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<RolloutPlanWaveOrchestrationOptions>,
pub fn set_or_clear_orchestration_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<RolloutPlanWaveOrchestrationOptions>,
Sets or clears the value of orchestration_options.
Example
ⓘ
use google_cloud_compute_v1::model::RolloutPlanWaveOrchestrationOptions;
let x = RolloutPlanWave::new().set_or_clear_orchestration_options(Some(RolloutPlanWaveOrchestrationOptions::default()/* use setters */));
let x = RolloutPlanWave::new().set_or_clear_orchestration_options(None::<RolloutPlanWaveOrchestrationOptions>);Sourcepub fn set_selectors<T, V>(self, v: T) -> Self
pub fn set_selectors<T, V>(self, v: T) -> Self
Sourcepub fn set_validation<T>(self, v: T) -> Selfwhere
T: Into<RolloutPlanWaveValidation>,
pub fn set_validation<T>(self, v: T) -> Selfwhere
T: Into<RolloutPlanWaveValidation>,
Sets the value of validation.
Example
ⓘ
use google_cloud_compute_v1::model::RolloutPlanWaveValidation;
let x = RolloutPlanWave::new().set_validation(RolloutPlanWaveValidation::default()/* use setters */);Sourcepub fn set_or_clear_validation<T>(self, v: Option<T>) -> Selfwhere
T: Into<RolloutPlanWaveValidation>,
pub fn set_or_clear_validation<T>(self, v: Option<T>) -> Selfwhere
T: Into<RolloutPlanWaveValidation>,
Sets or clears the value of validation.
Example
ⓘ
use google_cloud_compute_v1::model::RolloutPlanWaveValidation;
let x = RolloutPlanWave::new().set_or_clear_validation(Some(RolloutPlanWaveValidation::default()/* use setters */));
let x = RolloutPlanWave::new().set_or_clear_validation(None::<RolloutPlanWaveValidation>);Trait Implementations
Sourceimpl Clone for RolloutPlanWave
impl Clone for RolloutPlanWave
Sourcefn clone(&self) -> RolloutPlanWave
fn clone(&self) -> RolloutPlanWave
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RolloutPlanWave
impl Debug for RolloutPlanWave
Sourceimpl Default for RolloutPlanWave
impl Default for RolloutPlanWave
Sourcefn default() -> RolloutPlanWave
fn default() -> RolloutPlanWave
Returns the “default value” for a type. Read more
Sourceimpl Message for RolloutPlanWave
impl Message for RolloutPlanWave
Sourceimpl PartialEq for RolloutPlanWave
impl PartialEq for RolloutPlanWave
Sourcefn eq(&self, other: &RolloutPlanWave) -> bool
fn eq(&self, other: &RolloutPlanWave) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RolloutPlanWave