#[non_exhaustive]pub struct RolloutPlanWaveSelector {
pub location_selector: Option<RolloutPlanWaveSelectorLocationSelector>,
pub resource_hierarchy_selector: Option<RolloutPlanWaveSelectorResourceHierarchySelector>,
/* private fields */
}Available on crate feature
rollout-plans only.Expand description
A selector which specifies what resource(s) are included in a given wave.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.location_selector: Option<RolloutPlanWaveSelectorLocationSelector>Optional. Roll out to resources by Cloud locations.
resource_hierarchy_selector: Option<RolloutPlanWaveSelectorResourceHierarchySelector>Optional. Roll out to resources by Cloud Resource Manager resource hierarchy.
Implementations
Sourceimpl RolloutPlanWaveSelector
impl RolloutPlanWaveSelector
Sourcepub fn set_location_selector<T>(self, v: T) -> Selfwhere
T: Into<RolloutPlanWaveSelectorLocationSelector>,
pub fn set_location_selector<T>(self, v: T) -> Selfwhere
T: Into<RolloutPlanWaveSelectorLocationSelector>,
Sets the value of location_selector.
Example
ⓘ
use google_cloud_compute_v1::model::RolloutPlanWaveSelectorLocationSelector;
let x = RolloutPlanWaveSelector::new().set_location_selector(RolloutPlanWaveSelectorLocationSelector::default()/* use setters */);Sourcepub fn set_or_clear_location_selector<T>(self, v: Option<T>) -> Selfwhere
T: Into<RolloutPlanWaveSelectorLocationSelector>,
pub fn set_or_clear_location_selector<T>(self, v: Option<T>) -> Selfwhere
T: Into<RolloutPlanWaveSelectorLocationSelector>,
Sets or clears the value of location_selector.
Example
ⓘ
use google_cloud_compute_v1::model::RolloutPlanWaveSelectorLocationSelector;
let x = RolloutPlanWaveSelector::new().set_or_clear_location_selector(Some(RolloutPlanWaveSelectorLocationSelector::default()/* use setters */));
let x = RolloutPlanWaveSelector::new().set_or_clear_location_selector(None::<RolloutPlanWaveSelectorLocationSelector>);Sourcepub fn set_resource_hierarchy_selector<T>(self, v: T) -> Self
pub fn set_resource_hierarchy_selector<T>(self, v: T) -> Self
Sets the value of resource_hierarchy_selector.
Example
ⓘ
use google_cloud_compute_v1::model::RolloutPlanWaveSelectorResourceHierarchySelector;
let x = RolloutPlanWaveSelector::new().set_resource_hierarchy_selector(RolloutPlanWaveSelectorResourceHierarchySelector::default()/* use setters */);Sourcepub fn set_or_clear_resource_hierarchy_selector<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_resource_hierarchy_selector<T>(self, v: Option<T>) -> Self
Sets or clears the value of resource_hierarchy_selector.
Example
ⓘ
use google_cloud_compute_v1::model::RolloutPlanWaveSelectorResourceHierarchySelector;
let x = RolloutPlanWaveSelector::new().set_or_clear_resource_hierarchy_selector(Some(RolloutPlanWaveSelectorResourceHierarchySelector::default()/* use setters */));
let x = RolloutPlanWaveSelector::new().set_or_clear_resource_hierarchy_selector(None::<RolloutPlanWaveSelectorResourceHierarchySelector>);Trait Implementations
Sourceimpl Clone for RolloutPlanWaveSelector
impl Clone for RolloutPlanWaveSelector
Sourcefn clone(&self) -> RolloutPlanWaveSelector
fn clone(&self) -> RolloutPlanWaveSelector
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RolloutPlanWaveSelector
impl Debug for RolloutPlanWaveSelector
Sourceimpl Default for RolloutPlanWaveSelector
impl Default for RolloutPlanWaveSelector
Sourcefn default() -> RolloutPlanWaveSelector
fn default() -> RolloutPlanWaveSelector
Returns the “default value” for a type. Read more
Sourceimpl Message for RolloutPlanWaveSelector
impl Message for RolloutPlanWaveSelector
Sourceimpl PartialEq for RolloutPlanWaveSelector
impl PartialEq for RolloutPlanWaveSelector
Sourcefn eq(&self, other: &RolloutPlanWaveSelector) -> bool
fn eq(&self, other: &RolloutPlanWaveSelector) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RolloutPlanWaveSelector