#[non_exhaustive]pub struct RolloutPlanWaveValidation {
pub time_based_validation_metadata: Option<RolloutPlanWaveValidationTimeBasedValidationMetadata>,
pub type: Option<String>,
/* private fields */
}Available on crate feature
rollout-plans only.Expand description
The validation to be performed before progressing to the next wave.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.time_based_validation_metadata: Option<RolloutPlanWaveValidationTimeBasedValidationMetadata>Optional. Metadata required if type = “time”.
type: Option<String>Required. The type of the validation. If a type of validation is associated with a metadata object, the appropriate metadata field mapping to the validation type must be provided in the validation message. Possible values are in quotes below alongside an explanation: “manual”: The system waits for an end-user approval API before progressing to the next wave. “time”: The system waits for a user specified duration before progressing to the next wave. TimeBasedValidation must be provided.
Implementations
Sourceimpl RolloutPlanWaveValidation
impl RolloutPlanWaveValidation
Sourcepub fn set_time_based_validation_metadata<T>(self, v: T) -> Self
pub fn set_time_based_validation_metadata<T>(self, v: T) -> Self
Sets the value of time_based_validation_metadata.
Example
ⓘ
use google_cloud_compute_v1::model::RolloutPlanWaveValidationTimeBasedValidationMetadata;
let x = RolloutPlanWaveValidation::new().set_time_based_validation_metadata(RolloutPlanWaveValidationTimeBasedValidationMetadata::default()/* use setters */);Sourcepub fn set_or_clear_time_based_validation_metadata<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_time_based_validation_metadata<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of time_based_validation_metadata.
Example
ⓘ
use google_cloud_compute_v1::model::RolloutPlanWaveValidationTimeBasedValidationMetadata;
let x = RolloutPlanWaveValidation::new().set_or_clear_time_based_validation_metadata(Some(RolloutPlanWaveValidationTimeBasedValidationMetadata::default()/* use setters */));
let x = RolloutPlanWaveValidation::new().set_or_clear_time_based_validation_metadata(None::<RolloutPlanWaveValidationTimeBasedValidationMetadata>);Trait Implementations
Sourceimpl Clone for RolloutPlanWaveValidation
impl Clone for RolloutPlanWaveValidation
Sourcefn clone(&self) -> RolloutPlanWaveValidation
fn clone(&self) -> RolloutPlanWaveValidation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RolloutPlanWaveValidation
impl Debug for RolloutPlanWaveValidation
Sourceimpl Default for RolloutPlanWaveValidation
impl Default for RolloutPlanWaveValidation
Sourcefn default() -> RolloutPlanWaveValidation
fn default() -> RolloutPlanWaveValidation
Returns the “default value” for a type. Read more
Sourceimpl Message for RolloutPlanWaveValidation
impl Message for RolloutPlanWaveValidation
Sourceimpl PartialEq for RolloutPlanWaveValidation
impl PartialEq for RolloutPlanWaveValidation
Sourcefn eq(&self, other: &RolloutPlanWaveValidation) -> bool
fn eq(&self, other: &RolloutPlanWaveValidation) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RolloutPlanWaveValidation