#[non_exhaustive]pub struct RolloutPlanWaveValidationTimeBasedValidationMetadata {
pub wait_duration: Option<Duration>,
/* private fields */
}Available on crate feature
rollout-plans only.Expand description
Metadata required if type = “time”.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.wait_duration: Option<Duration>Optional. The duration that the system waits in between waves. This wait starts after all changes in the wave are rolled out.
Implementations
Sourceimpl RolloutPlanWaveValidationTimeBasedValidationMetadata
impl RolloutPlanWaveValidationTimeBasedValidationMetadata
Sourcepub fn set_wait_duration<T>(self, v: T) -> Self
pub fn set_wait_duration<T>(self, v: T) -> Self
Sets the value of wait_duration.
Example
ⓘ
use wkt::Duration;
let x = RolloutPlanWaveValidationTimeBasedValidationMetadata::new().set_wait_duration(Duration::default()/* use setters */);Sourcepub fn set_or_clear_wait_duration<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_wait_duration<T>(self, v: Option<T>) -> Self
Sets or clears the value of wait_duration.
Example
ⓘ
use wkt::Duration;
let x = RolloutPlanWaveValidationTimeBasedValidationMetadata::new().set_or_clear_wait_duration(Some(Duration::default()/* use setters */));
let x = RolloutPlanWaveValidationTimeBasedValidationMetadata::new().set_or_clear_wait_duration(None::<Duration>);Trait Implementations
Sourceimpl Clone for RolloutPlanWaveValidationTimeBasedValidationMetadata
impl Clone for RolloutPlanWaveValidationTimeBasedValidationMetadata
Sourcefn clone(&self) -> RolloutPlanWaveValidationTimeBasedValidationMetadata
fn clone(&self) -> RolloutPlanWaveValidationTimeBasedValidationMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for RolloutPlanWaveValidationTimeBasedValidationMetadata
impl Default for RolloutPlanWaveValidationTimeBasedValidationMetadata
Sourcefn default() -> RolloutPlanWaveValidationTimeBasedValidationMetadata
fn default() -> RolloutPlanWaveValidationTimeBasedValidationMetadata
Returns the “default value” for a type. Read more
impl StructuralPartialEq for RolloutPlanWaveValidationTimeBasedValidationMetadata