#[non_exhaustive]pub struct RolloutRolloutEntity {
pub orchestrated_entity: Option<RolloutRolloutEntityOrchestratedEntity>,
/* private fields */
}Available on crate feature
rollouts only.Expand description
Specifications of the resource to roll out.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.orchestrated_entity: Option<RolloutRolloutEntityOrchestratedEntity>Optional. Entity details for products using the Orchestrated Integration model.
Implementations
Sourceimpl RolloutRolloutEntity
impl RolloutRolloutEntity
Sourcepub fn set_orchestrated_entity<T>(self, v: T) -> Selfwhere
T: Into<RolloutRolloutEntityOrchestratedEntity>,
pub fn set_orchestrated_entity<T>(self, v: T) -> Selfwhere
T: Into<RolloutRolloutEntityOrchestratedEntity>,
Sets the value of orchestrated_entity.
Example
ⓘ
use google_cloud_compute_v1::model::RolloutRolloutEntityOrchestratedEntity;
let x = RolloutRolloutEntity::new().set_orchestrated_entity(RolloutRolloutEntityOrchestratedEntity::default()/* use setters */);Sourcepub fn set_or_clear_orchestrated_entity<T>(self, v: Option<T>) -> Selfwhere
T: Into<RolloutRolloutEntityOrchestratedEntity>,
pub fn set_or_clear_orchestrated_entity<T>(self, v: Option<T>) -> Selfwhere
T: Into<RolloutRolloutEntityOrchestratedEntity>,
Sets or clears the value of orchestrated_entity.
Example
ⓘ
use google_cloud_compute_v1::model::RolloutRolloutEntityOrchestratedEntity;
let x = RolloutRolloutEntity::new().set_or_clear_orchestrated_entity(Some(RolloutRolloutEntityOrchestratedEntity::default()/* use setters */));
let x = RolloutRolloutEntity::new().set_or_clear_orchestrated_entity(None::<RolloutRolloutEntityOrchestratedEntity>);Trait Implementations
Sourceimpl Clone for RolloutRolloutEntity
impl Clone for RolloutRolloutEntity
Sourcefn clone(&self) -> RolloutRolloutEntity
fn clone(&self) -> RolloutRolloutEntity
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RolloutRolloutEntity
impl Debug for RolloutRolloutEntity
Sourceimpl Default for RolloutRolloutEntity
impl Default for RolloutRolloutEntity
Sourcefn default() -> RolloutRolloutEntity
fn default() -> RolloutRolloutEntity
Returns the “default value” for a type. Read more
Sourceimpl Message for RolloutRolloutEntity
impl Message for RolloutRolloutEntity
Sourceimpl PartialEq for RolloutRolloutEntity
impl PartialEq for RolloutRolloutEntity
Sourcefn eq(&self, other: &RolloutRolloutEntity) -> bool
fn eq(&self, other: &RolloutRolloutEntity) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RolloutRolloutEntity