#[non_exhaustive]pub struct RolloutWaveDetails {
pub orchestrated_wave_details: Option<RolloutWaveDetailsOrchestratedWaveDetails>,
pub wave_display_name: Option<String>,
pub wave_number: Option<i64>,
/* private fields */
}Available on crate feature
rollouts only.Expand description
Additional metadata about the status of each wave provided by the server.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.orchestrated_wave_details: Option<RolloutWaveDetailsOrchestratedWaveDetails>Output only. Additional details of the wave for products using the Orchestrated Integration model.
wave_display_name: Option<String>Output only. Wave name. Ex. wave1
wave_number: Option<i64>Output only. System generated number for the wave.
Implementations
Sourceimpl RolloutWaveDetails
impl RolloutWaveDetails
Sourcepub fn set_orchestrated_wave_details<T>(self, v: T) -> Selfwhere
T: Into<RolloutWaveDetailsOrchestratedWaveDetails>,
pub fn set_orchestrated_wave_details<T>(self, v: T) -> Selfwhere
T: Into<RolloutWaveDetailsOrchestratedWaveDetails>,
Sets the value of orchestrated_wave_details.
Example
ⓘ
use google_cloud_compute_v1::model::RolloutWaveDetailsOrchestratedWaveDetails;
let x = RolloutWaveDetails::new().set_orchestrated_wave_details(RolloutWaveDetailsOrchestratedWaveDetails::default()/* use setters */);Sourcepub fn set_or_clear_orchestrated_wave_details<T>(self, v: Option<T>) -> Selfwhere
T: Into<RolloutWaveDetailsOrchestratedWaveDetails>,
pub fn set_or_clear_orchestrated_wave_details<T>(self, v: Option<T>) -> Selfwhere
T: Into<RolloutWaveDetailsOrchestratedWaveDetails>,
Sets or clears the value of orchestrated_wave_details.
Example
ⓘ
use google_cloud_compute_v1::model::RolloutWaveDetailsOrchestratedWaveDetails;
let x = RolloutWaveDetails::new().set_or_clear_orchestrated_wave_details(Some(RolloutWaveDetailsOrchestratedWaveDetails::default()/* use setters */));
let x = RolloutWaveDetails::new().set_or_clear_orchestrated_wave_details(None::<RolloutWaveDetailsOrchestratedWaveDetails>);Sourcepub fn set_wave_display_name<T>(self, v: T) -> Self
pub fn set_wave_display_name<T>(self, v: T) -> Self
Sets the value of wave_display_name.
Example
ⓘ
let x = RolloutWaveDetails::new().set_wave_display_name("example");Sourcepub fn set_or_clear_wave_display_name<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_wave_display_name<T>(self, v: Option<T>) -> Self
Sets or clears the value of wave_display_name.
Example
ⓘ
let x = RolloutWaveDetails::new().set_or_clear_wave_display_name(Some("example"));
let x = RolloutWaveDetails::new().set_or_clear_wave_display_name(None::<String>);Sourcepub fn set_wave_number<T>(self, v: T) -> Self
pub fn set_wave_number<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_wave_number<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_wave_number<T>(self, v: Option<T>) -> Self
Sets or clears the value of wave_number.
Example
ⓘ
let x = RolloutWaveDetails::new().set_or_clear_wave_number(Some(42));
let x = RolloutWaveDetails::new().set_or_clear_wave_number(None::<i32>);Trait Implementations
Sourceimpl Clone for RolloutWaveDetails
impl Clone for RolloutWaveDetails
Sourcefn clone(&self) -> RolloutWaveDetails
fn clone(&self) -> RolloutWaveDetails
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RolloutWaveDetails
impl Debug for RolloutWaveDetails
Sourceimpl Default for RolloutWaveDetails
impl Default for RolloutWaveDetails
Sourcefn default() -> RolloutWaveDetails
fn default() -> RolloutWaveDetails
Returns the “default value” for a type. Read more
Sourceimpl Message for RolloutWaveDetails
impl Message for RolloutWaveDetails
Sourceimpl PartialEq for RolloutWaveDetails
impl PartialEq for RolloutWaveDetails
Sourcefn eq(&self, other: &RolloutWaveDetails) -> bool
fn eq(&self, other: &RolloutWaveDetails) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RolloutWaveDetails