#[non_exhaustive]pub struct RouterStatus {
pub best_routes: Vec<Route>,
pub best_routes_for_router: Vec<Route>,
pub bgp_peer_status: Vec<RouterStatusBgpPeerStatus>,
pub nat_status: Vec<RouterStatusNatStatus>,
pub ncc_gateway: Option<String>,
pub network: Option<String>,
/* private fields */
}routers only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.best_routes: Vec<Route>A list of the best dynamic routes for this Cloud Router’s Virtual Private Cloud (VPC) network in the same region as this Cloud Router.
Lists all of the best routes per prefix that are programmed into this region’s VPC data plane.
When global dynamic routing mode is turned on in the VPC network, this list can include cross-region dynamic routes from Cloud Routers in other regions.
best_routes_for_router: Vec<Route>A list of the best BGP routes learned by this Cloud Router.
It is possible that routes listed might not be programmed into the data plane, if the Google Cloud control plane finds a more optimal route for a prefix than a route learned by this Cloud Router.
bgp_peer_status: Vec<RouterStatusBgpPeerStatus>nat_status: Vec<RouterStatusNatStatus>ncc_gateway: Option<String>URI of the ncc_gateway to which this router associated.
network: Option<String>URI of the network to which this router belongs.
Implementations
Sourceimpl RouterStatus
impl RouterStatus
Sourcepub fn set_best_routes<T, V>(self, v: T) -> Self
pub fn set_best_routes<T, V>(self, v: T) -> Self
Sets the value of best_routes.
Example
use google_cloud_compute_v1::model::Route;
let x = RouterStatus::new()
.set_best_routes([
Route::default()/* use setters */,
Route::default()/* use (different) setters */,
]);Sourcepub fn set_best_routes_for_router<T, V>(self, v: T) -> Self
pub fn set_best_routes_for_router<T, V>(self, v: T) -> Self
Sets the value of best_routes_for_router.
Example
use google_cloud_compute_v1::model::Route;
let x = RouterStatus::new()
.set_best_routes_for_router([
Route::default()/* use setters */,
Route::default()/* use (different) setters */,
]);Sourcepub fn set_bgp_peer_status<T, V>(self, v: T) -> Self
pub fn set_bgp_peer_status<T, V>(self, v: T) -> Self
Sets the value of bgp_peer_status.
Example
use google_cloud_compute_v1::model::RouterStatusBgpPeerStatus;
let x = RouterStatus::new()
.set_bgp_peer_status([
RouterStatusBgpPeerStatus::default()/* use setters */,
RouterStatusBgpPeerStatus::default()/* use (different) setters */,
]);Sourcepub fn set_nat_status<T, V>(self, v: T) -> Self
pub fn set_nat_status<T, V>(self, v: T) -> Self
Sets the value of nat_status.
Example
use google_cloud_compute_v1::model::RouterStatusNatStatus;
let x = RouterStatus::new()
.set_nat_status([
RouterStatusNatStatus::default()/* use setters */,
RouterStatusNatStatus::default()/* use (different) setters */,
]);Sourcepub fn set_ncc_gateway<T>(self, v: T) -> Self
pub fn set_ncc_gateway<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_ncc_gateway<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_ncc_gateway<T>(self, v: Option<T>) -> Self
Sets or clears the value of ncc_gateway.
Example
let x = RouterStatus::new().set_or_clear_ncc_gateway(Some("example"));
let x = RouterStatus::new().set_or_clear_ncc_gateway(None::<String>);Sourcepub fn set_network<T>(self, v: T) -> Self
pub fn set_network<T>(self, v: T) -> Self