#[non_exhaustive]pub struct RouterStatusBgpPeerStatus {Show 20 fields
pub advertised_routes: Vec<Route>,
pub bfd_status: Option<BfdStatus>,
pub enable_ipv_4: Option<bool>,
pub enable_ipv_6: Option<bool>,
pub ip_address: Option<String>,
pub ipv_4_nexthop_address: Option<String>,
pub ipv_6_nexthop_address: Option<String>,
pub linked_vpn_tunnel: Option<String>,
pub md_5_auth_enabled: Option<bool>,
pub name: Option<String>,
pub num_learned_routes: Option<u32>,
pub peer_ip_address: Option<String>,
pub peer_ipv_4_nexthop_address: Option<String>,
pub peer_ipv_6_nexthop_address: Option<String>,
pub router_appliance_instance: Option<String>,
pub state: Option<String>,
pub status: Option<Status>,
pub status_reason: Option<StatusReason>,
pub uptime: Option<String>,
pub uptime_seconds: Option<String>,
/* private fields */
}routers only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.advertised_routes: Vec<Route>Routes that were advertised to the remote BGP peer
bfd_status: Option<BfdStatus>enable_ipv_4: Option<bool>Output only. Enable IPv4 traffic over BGP Peer. It is enabled by default if the peerIpAddress is version 4.
enable_ipv_6: Option<bool>Output only. Enable IPv6 traffic over BGP Peer. It is enabled by default if the peerIpAddress is version 6.
ip_address: Option<String>Output only. IP address of the local BGP interface.
ipv_4_nexthop_address: Option<String>Output only. IPv4 address of the local BGP interface.
ipv_6_nexthop_address: Option<String>Output only. IPv6 address of the local BGP interface.
linked_vpn_tunnel: Option<String>Output only. URL of the VPN tunnel that this BGP peer controls.
md_5_auth_enabled: Option<bool>Informs whether MD5 authentication is enabled on this BGP peer.
name: Option<String>Output only. Name of this BGP peer. Unique within the Routers resource.
num_learned_routes: Option<u32>Output only. Number of routes learned from the remote BGP Peer.
peer_ip_address: Option<String>Output only. IP address of the remote BGP interface.
peer_ipv_4_nexthop_address: Option<String>Output only. IPv4 address of the remote BGP interface.
peer_ipv_6_nexthop_address: Option<String>Output only. IPv6 address of the remote BGP interface.
router_appliance_instance: Option<String>Output only. [Output only] URI of the VM instance that is used as third-party router appliances such as Next Gen Firewalls, Virtual Routers, or Router Appliances. The VM instance is the peer side of the BGP session.
state: Option<String>Output only. The state of the BGP session. For a list of possible values for this field, seeBGP session states.
status: Option<Status>Output only. Status of the BGP peer: {UP, DOWN}
status_reason: Option<StatusReason>Indicates why particular status was returned.
uptime: Option<String>Output only. Time this session has been up. Format: 14 years, 51 weeks, 6 days, 23 hours, 59 minutes, 59 seconds
uptime_seconds: Option<String>Output only. Time this session has been up, in seconds. Format: 145
Implementations
Sourceimpl RouterStatusBgpPeerStatus
impl RouterStatusBgpPeerStatus
Sourcepub fn set_advertised_routes<T, V>(self, v: T) -> Self
pub fn set_advertised_routes<T, V>(self, v: T) -> Self
Sets the value of advertised_routes.
Example
use google_cloud_compute_v1::model::Route;
let x = RouterStatusBgpPeerStatus::new()
.set_advertised_routes([
Route::default()/* use setters */,
Route::default()/* use (different) setters */,
]);Sourcepub fn set_bfd_status<T>(self, v: T) -> Self
pub fn set_bfd_status<T>(self, v: T) -> Self
Sets the value of bfd_status.
Example
use google_cloud_compute_v1::model::BfdStatus;
let x = RouterStatusBgpPeerStatus::new().set_bfd_status(BfdStatus::default()/* use setters */);Sourcepub fn set_or_clear_bfd_status<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_bfd_status<T>(self, v: Option<T>) -> Self
Sets or clears the value of bfd_status.
Example
use google_cloud_compute_v1::model::BfdStatus;
let x = RouterStatusBgpPeerStatus::new().set_or_clear_bfd_status(Some(BfdStatus::default()/* use setters */));
let x = RouterStatusBgpPeerStatus::new().set_or_clear_bfd_status(None::<BfdStatus>);Sourcepub fn set_enable_ipv_4<T>(self, v: T) -> Self
pub fn set_enable_ipv_4<T>(self, v: T) -> Self
Sets the value of enable_ipv_4.
Example
let x = RouterStatusBgpPeerStatus::new().set_enable_ipv_4(true);Sourcepub fn set_or_clear_enable_ipv_4<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_enable_ipv_4<T>(self, v: Option<T>) -> Self
Sets or clears the value of enable_ipv_4.
Example
let x = RouterStatusBgpPeerStatus::new().set_or_clear_enable_ipv_4(Some(false));
let x = RouterStatusBgpPeerStatus::new().set_or_clear_enable_ipv_4(None::<bool>);Sourcepub fn set_enable_ipv_6<T>(self, v: T) -> Self
pub fn set_enable_ipv_6<T>(self, v: T) -> Self
Sets the value of enable_ipv_6.
Example
let x = RouterStatusBgpPeerStatus::new().set_enable_ipv_6(true);Sourcepub fn set_or_clear_enable_ipv_6<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_enable_ipv_6<T>(self, v: Option<T>) -> Self
Sets or clears the value of enable_ipv_6.
Example
let x = RouterStatusBgpPeerStatus::new().set_or_clear_enable_ipv_6(Some(false));
let x = RouterStatusBgpPeerStatus::new().set_or_clear_enable_ipv_6(None::<bool>);Sourcepub fn set_ip_address<T>(self, v: T) -> Self
pub fn set_ip_address<T>(self, v: T) -> Self
Sets the value of ip_address.
Example
let x = RouterStatusBgpPeerStatus::new().set_ip_address("example");Sourcepub fn set_or_clear_ip_address<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_ip_address<T>(self, v: Option<T>) -> Self
Sets or clears the value of ip_address.
Example
let x = RouterStatusBgpPeerStatus::new().set_or_clear_ip_address(Some("example"));
let x = RouterStatusBgpPeerStatus::new().set_or_clear_ip_address(None::<String>);Sourcepub fn set_ipv_4_nexthop_address<T>(self, v: T) -> Self
pub fn set_ipv_4_nexthop_address<T>(self, v: T) -> Self
Sets the value of ipv_4_nexthop_address.
Example
let x = RouterStatusBgpPeerStatus::new().set_ipv_4_nexthop_address("example");Sourcepub fn set_or_clear_ipv_4_nexthop_address<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_ipv_4_nexthop_address<T>(self, v: Option<T>) -> Self
Sets or clears the value of ipv_4_nexthop_address.
Example
let x = RouterStatusBgpPeerStatus::new().set_or_clear_ipv_4_nexthop_address(Some("example"));
let x = RouterStatusBgpPeerStatus::new().set_or_clear_ipv_4_nexthop_address(None::<String>);Sourcepub fn set_ipv_6_nexthop_address<T>(self, v: T) -> Self
pub fn set_ipv_6_nexthop_address<T>(self, v: T) -> Self
Sets the value of ipv_6_nexthop_address.
Example
let x = RouterStatusBgpPeerStatus::new().set_ipv_6_nexthop_address("example");Sourcepub fn set_or_clear_ipv_6_nexthop_address<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_ipv_6_nexthop_address<T>(self, v: Option<T>) -> Self
Sets or clears the value of ipv_6_nexthop_address.
Example
let x = RouterStatusBgpPeerStatus::new().set_or_clear_ipv_6_nexthop_address(Some("example"));
let x = RouterStatusBgpPeerStatus::new().set_or_clear_ipv_6_nexthop_address(None::<String>);Sourcepub fn set_linked_vpn_tunnel<T>(self, v: T) -> Self
pub fn set_linked_vpn_tunnel<T>(self, v: T) -> Self
Sets the value of linked_vpn_tunnel.
Example
let x = RouterStatusBgpPeerStatus::new().set_linked_vpn_tunnel("example");Sourcepub fn set_or_clear_linked_vpn_tunnel<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_linked_vpn_tunnel<T>(self, v: Option<T>) -> Self
Sets or clears the value of linked_vpn_tunnel.
Example
let x = RouterStatusBgpPeerStatus::new().set_or_clear_linked_vpn_tunnel(Some("example"));
let x = RouterStatusBgpPeerStatus::new().set_or_clear_linked_vpn_tunnel(None::<String>);Sourcepub fn set_md_5_auth_enabled<T>(self, v: T) -> Self
pub fn set_md_5_auth_enabled<T>(self, v: T) -> Self
Sets the value of md_5_auth_enabled.
Example
let x = RouterStatusBgpPeerStatus::new().set_md_5_auth_enabled(true);Sourcepub fn set_or_clear_md_5_auth_enabled<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_md_5_auth_enabled<T>(self, v: Option<T>) -> Self
Sets or clears the value of md_5_auth_enabled.
Example
let x = RouterStatusBgpPeerStatus::new().set_or_clear_md_5_auth_enabled(Some(false));
let x = RouterStatusBgpPeerStatus::new().set_or_clear_md_5_auth_enabled(None::<bool>);Sourcepub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
Sourcepub fn set_num_learned_routes<T>(self, v: T) -> Self
pub fn set_num_learned_routes<T>(self, v: T) -> Self
Sets the value of num_learned_routes.
Example
let x = RouterStatusBgpPeerStatus::new().set_num_learned_routes(42_u32);Sourcepub fn set_or_clear_num_learned_routes<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_num_learned_routes<T>(self, v: Option<T>) -> Self
Sets or clears the value of num_learned_routes.
Example
let x = RouterStatusBgpPeerStatus::new().set_or_clear_num_learned_routes(Some(42_u32));
let x = RouterStatusBgpPeerStatus::new().set_or_clear_num_learned_routes(None::<u32>);Sourcepub fn set_peer_ip_address<T>(self, v: T) -> Self
pub fn set_peer_ip_address<T>(self, v: T) -> Self
Sets the value of peer_ip_address.
Example
let x = RouterStatusBgpPeerStatus::new().set_peer_ip_address("example");Sourcepub fn set_or_clear_peer_ip_address<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_peer_ip_address<T>(self, v: Option<T>) -> Self
Sets or clears the value of peer_ip_address.
Example
let x = RouterStatusBgpPeerStatus::new().set_or_clear_peer_ip_address(Some("example"));
let x = RouterStatusBgpPeerStatus::new().set_or_clear_peer_ip_address(None::<String>);Sourcepub fn set_peer_ipv_4_nexthop_address<T>(self, v: T) -> Self
pub fn set_peer_ipv_4_nexthop_address<T>(self, v: T) -> Self
Sets the value of peer_ipv_4_nexthop_address.
Example
let x = RouterStatusBgpPeerStatus::new().set_peer_ipv_4_nexthop_address("example");Sourcepub fn set_or_clear_peer_ipv_4_nexthop_address<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_peer_ipv_4_nexthop_address<T>(self, v: Option<T>) -> Self
Sets or clears the value of peer_ipv_4_nexthop_address.
Example
let x = RouterStatusBgpPeerStatus::new().set_or_clear_peer_ipv_4_nexthop_address(Some("example"));
let x = RouterStatusBgpPeerStatus::new().set_or_clear_peer_ipv_4_nexthop_address(None::<String>);Sourcepub fn set_peer_ipv_6_nexthop_address<T>(self, v: T) -> Self
pub fn set_peer_ipv_6_nexthop_address<T>(self, v: T) -> Self
Sets the value of peer_ipv_6_nexthop_address.
Example
let x = RouterStatusBgpPeerStatus::new().set_peer_ipv_6_nexthop_address("example");Sourcepub fn set_or_clear_peer_ipv_6_nexthop_address<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_peer_ipv_6_nexthop_address<T>(self, v: Option<T>) -> Self
Sets or clears the value of peer_ipv_6_nexthop_address.
Example
let x = RouterStatusBgpPeerStatus::new().set_or_clear_peer_ipv_6_nexthop_address(Some("example"));
let x = RouterStatusBgpPeerStatus::new().set_or_clear_peer_ipv_6_nexthop_address(None::<String>);Sourcepub fn set_router_appliance_instance<T>(self, v: T) -> Self
pub fn set_router_appliance_instance<T>(self, v: T) -> Self
Sets the value of router_appliance_instance.
Example
let x = RouterStatusBgpPeerStatus::new().set_router_appliance_instance("example");Sourcepub fn set_or_clear_router_appliance_instance<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_router_appliance_instance<T>(self, v: Option<T>) -> Self
Sets or clears the value of router_appliance_instance.
Example
let x = RouterStatusBgpPeerStatus::new().set_or_clear_router_appliance_instance(Some("example"));
let x = RouterStatusBgpPeerStatus::new().set_or_clear_router_appliance_instance(None::<String>);Sourcepub fn set_or_clear_state<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_state<T>(self, v: Option<T>) -> Self
Sourcepub fn set_status<T>(self, v: T) -> Self
pub fn set_status<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
Sets or clears the value of status.
Example
use google_cloud_compute_v1::model::router_status_bgp_peer_status::Status;
let x0 = RouterStatusBgpPeerStatus::new().set_or_clear_status(Some(Status::Unknown));
let x1 = RouterStatusBgpPeerStatus::new().set_or_clear_status(Some(Status::Up));
let x_none = RouterStatusBgpPeerStatus::new().set_or_clear_status(None::<Status>);Sourcepub fn set_status_reason<T>(self, v: T) -> Selfwhere
T: Into<StatusReason>,
pub fn set_status_reason<T>(self, v: T) -> Selfwhere
T: Into<StatusReason>,
Sets the value of status_reason.
Example
use google_cloud_compute_v1::model::router_status_bgp_peer_status::StatusReason;
let x0 = RouterStatusBgpPeerStatus::new().set_status_reason(StatusReason::Ipv6PeerOnIpv4OnlyConnection);
let x1 = RouterStatusBgpPeerStatus::new().set_status_reason(StatusReason::Md5AuthInternalProblem);
let x2 = RouterStatusBgpPeerStatus::new().set_status_reason(StatusReason::Unspecified);Sourcepub fn set_or_clear_status_reason<T>(self, v: Option<T>) -> Selfwhere
T: Into<StatusReason>,
pub fn set_or_clear_status_reason<T>(self, v: Option<T>) -> Selfwhere
T: Into<StatusReason>,
Sets or clears the value of status_reason.
Example
use google_cloud_compute_v1::model::router_status_bgp_peer_status::StatusReason;
let x0 = RouterStatusBgpPeerStatus::new().set_or_clear_status_reason(Some(StatusReason::Ipv6PeerOnIpv4OnlyConnection));
let x1 = RouterStatusBgpPeerStatus::new().set_or_clear_status_reason(Some(StatusReason::Md5AuthInternalProblem));
let x2 = RouterStatusBgpPeerStatus::new().set_or_clear_status_reason(Some(StatusReason::Unspecified));
let x_none = RouterStatusBgpPeerStatus::new().set_or_clear_status_reason(None::<StatusReason>);Sourcepub fn set_uptime<T>(self, v: T) -> Self
pub fn set_uptime<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_uptime<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_uptime<T>(self, v: Option<T>) -> Self
Sourcepub fn set_uptime_seconds<T>(self, v: T) -> Self
pub fn set_uptime_seconds<T>(self, v: T) -> Self
Sets the value of uptime_seconds.
Example
let x = RouterStatusBgpPeerStatus::new().set_uptime_seconds("example");Sourcepub fn set_or_clear_uptime_seconds<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_uptime_seconds<T>(self, v: Option<T>) -> Self
Sets or clears the value of uptime_seconds.
Example
let x = RouterStatusBgpPeerStatus::new().set_or_clear_uptime_seconds(Some("example"));
let x = RouterStatusBgpPeerStatus::new().set_or_clear_uptime_seconds(None::<String>);Trait Implementations
Sourceimpl Clone for RouterStatusBgpPeerStatus
impl Clone for RouterStatusBgpPeerStatus
Sourcefn clone(&self) -> RouterStatusBgpPeerStatus
fn clone(&self) -> RouterStatusBgpPeerStatus
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for RouterStatusBgpPeerStatus
impl Debug for RouterStatusBgpPeerStatus
Sourceimpl Default for RouterStatusBgpPeerStatus
impl Default for RouterStatusBgpPeerStatus
Sourcefn default() -> RouterStatusBgpPeerStatus
fn default() -> RouterStatusBgpPeerStatus
Sourceimpl Message for RouterStatusBgpPeerStatus
impl Message for RouterStatusBgpPeerStatus
impl StructuralPartialEq for RouterStatusBgpPeerStatus