#[non_exhaustive]pub struct RoutersListBgpRoutes {
pub etag: Option<String>,
pub id: Option<String>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
pub result: Vec<BgpRoute>,
pub self_link: Option<String>,
pub unreachables: Vec<String>,
pub warning: Option<Warning>,
/* private fields */
}routers only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.etag: Option<String>id: Option<String>[Output Only] The unique identifier for the resource. This identifier is defined by the server.
kind: Option<String>Output only. [Output Only] Type of resource. Alwayscompute#routersListBgpRoutes for lists of bgp routes.
next_page_token: Option<String>[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
result: Vec<BgpRoute>[Output Only] A list of bgp routes.
self_link: Option<String>Output only. [Output Only] Server-defined URL for this resource.
unreachables: Vec<String>Output only. [Output Only] Unreachable resources.
warning: Option<Warning>[Output Only] Informational warning message.
Implementations
Sourceimpl RoutersListBgpRoutes
impl RoutersListBgpRoutes
Sourcepub fn set_or_clear_etag<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_etag<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_next_page_token<T>(self, v: T) -> Self
pub fn set_next_page_token<T>(self, v: T) -> Self
Sets the value of next_page_token.
Example
let x = RoutersListBgpRoutes::new().set_next_page_token("example");Sourcepub fn set_or_clear_next_page_token<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_next_page_token<T>(self, v: Option<T>) -> Self
Sets or clears the value of next_page_token.
Example
let x = RoutersListBgpRoutes::new().set_or_clear_next_page_token(Some("example"));
let x = RoutersListBgpRoutes::new().set_or_clear_next_page_token(None::<String>);Sourcepub fn set_result<T, V>(self, v: T) -> Self
pub fn set_result<T, V>(self, v: T) -> Self
Sourcepub fn set_self_link<T>(self, v: T) -> Self
pub fn set_self_link<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
Sourcepub fn set_unreachables<T, V>(self, v: T) -> Self
pub fn set_unreachables<T, V>(self, v: T) -> Self
Sets the value of unreachables.
Example
let x = RoutersListBgpRoutes::new().set_unreachables(["a", "b", "c"]);Sourcepub fn set_warning<T>(self, v: T) -> Self
pub fn set_warning<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self