#[non_exhaustive]pub struct SavedDisk {
pub architecture: Option<Architecture>,
pub kind: Option<String>,
pub source_disk: Option<String>,
pub storage_bytes: Option<i64>,
pub storage_bytes_status: Option<StorageBytesStatus>,
/* private fields */
}machine-images only.Expand description
An instance-attached disk resource.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.architecture: Option<Architecture>Output only. [Output Only] The architecture of the attached disk.
kind: Option<String>Output only. [Output Only] Type of the resource. Always compute#savedDisk for attached disks.
source_disk: Option<String>Output only. Specifies a URL of the disk attached to the source instance.
storage_bytes: Option<i64>Output only. [Output Only] Size of the individual disk snapshot used by this machine image.
storage_bytes_status: Option<StorageBytesStatus>Output only. [Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be UPDATING, meaning the size of the snapshot is being updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date.
Implementations
Sourceimpl SavedDisk
impl SavedDisk
Sourcepub fn set_architecture<T>(self, v: T) -> Selfwhere
T: Into<Architecture>,
pub fn set_architecture<T>(self, v: T) -> Selfwhere
T: Into<Architecture>,
Sets the value of architecture.
Example
use google_cloud_compute_v1::model::saved_disk::Architecture;
let x0 = SavedDisk::new().set_architecture(Architecture::Arm64);
let x1 = SavedDisk::new().set_architecture(Architecture::X8664);Sourcepub fn set_or_clear_architecture<T>(self, v: Option<T>) -> Selfwhere
T: Into<Architecture>,
pub fn set_or_clear_architecture<T>(self, v: Option<T>) -> Selfwhere
T: Into<Architecture>,
Sets or clears the value of architecture.
Example
use google_cloud_compute_v1::model::saved_disk::Architecture;
let x0 = SavedDisk::new().set_or_clear_architecture(Some(Architecture::Arm64));
let x1 = SavedDisk::new().set_or_clear_architecture(Some(Architecture::X8664));
let x_none = SavedDisk::new().set_or_clear_architecture(None::<Architecture>);Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_source_disk<T>(self, v: T) -> Self
pub fn set_source_disk<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_source_disk<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_source_disk<T>(self, v: Option<T>) -> Self
Sets or clears the value of source_disk.
Example
let x = SavedDisk::new().set_or_clear_source_disk(Some("example"));
let x = SavedDisk::new().set_or_clear_source_disk(None::<String>);Sourcepub fn set_storage_bytes<T>(self, v: T) -> Self
pub fn set_storage_bytes<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_storage_bytes<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_storage_bytes<T>(self, v: Option<T>) -> Self
Sets or clears the value of storage_bytes.
Example
let x = SavedDisk::new().set_or_clear_storage_bytes(Some(42));
let x = SavedDisk::new().set_or_clear_storage_bytes(None::<i32>);Sourcepub fn set_storage_bytes_status<T>(self, v: T) -> Selfwhere
T: Into<StorageBytesStatus>,
pub fn set_storage_bytes_status<T>(self, v: T) -> Selfwhere
T: Into<StorageBytesStatus>,
Sets the value of storage_bytes_status.
Example
use google_cloud_compute_v1::model::saved_disk::StorageBytesStatus;
let x0 = SavedDisk::new().set_storage_bytes_status(StorageBytesStatus::UpToDate);Sourcepub fn set_or_clear_storage_bytes_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<StorageBytesStatus>,
pub fn set_or_clear_storage_bytes_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<StorageBytesStatus>,
Sets or clears the value of storage_bytes_status.
Example
use google_cloud_compute_v1::model::saved_disk::StorageBytesStatus;
let x0 = SavedDisk::new().set_or_clear_storage_bytes_status(Some(StorageBytesStatus::UpToDate));
let x_none = SavedDisk::new().set_or_clear_storage_bytes_status(None::<StorageBytesStatus>);Trait Implementations
impl StructuralPartialEq for SavedDisk