#[non_exhaustive]pub struct SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig {
pub auto_deploy_confidence_threshold: Option<f32>,
pub auto_deploy_expiration_sec: Option<i32>,
pub auto_deploy_impacted_baseline_threshold: Option<f32>,
pub auto_deploy_load_threshold: Option<f32>,
pub detection_absolute_qps: Option<f32>,
pub detection_load_threshold: Option<f32>,
pub detection_relative_to_baseline_qps: Option<f32>,
pub name: Option<String>,
pub traffic_granularity_configs: Vec<SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig>,
/* private fields */
}organization-security-policies or region-security-policies or security-policies only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.auto_deploy_confidence_threshold: Option<f32>auto_deploy_expiration_sec: Option<i32>auto_deploy_impacted_baseline_threshold: Option<f32>auto_deploy_load_threshold: Option<f32>detection_absolute_qps: Option<f32>detection_load_threshold: Option<f32>detection_relative_to_baseline_qps: Option<f32>name: Option<String>The name must be 1-63 characters long, and comply withRFC1035. The name must be unique within the security policy.
traffic_granularity_configs: Vec<SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig>Configuration options for enabling Adaptive Protection to operate on specified granular traffic units.
Implementations
Sourceimpl SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig
impl SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig
Sourcepub fn set_auto_deploy_confidence_threshold<T>(self, v: T) -> Self
pub fn set_auto_deploy_confidence_threshold<T>(self, v: T) -> Self
Sets the value of auto_deploy_confidence_threshold.
Example
let x = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig::new().set_auto_deploy_confidence_threshold(42.0);Sourcepub fn set_or_clear_auto_deploy_confidence_threshold<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_auto_deploy_confidence_threshold<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of auto_deploy_confidence_threshold.
Example
let x = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig::new().set_or_clear_auto_deploy_confidence_threshold(Some(42.0));
let x = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig::new().set_or_clear_auto_deploy_confidence_threshold(None::<f32>);Sourcepub fn set_auto_deploy_expiration_sec<T>(self, v: T) -> Self
pub fn set_auto_deploy_expiration_sec<T>(self, v: T) -> Self
Sets the value of auto_deploy_expiration_sec.
Example
let x = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig::new().set_auto_deploy_expiration_sec(42);Sourcepub fn set_or_clear_auto_deploy_expiration_sec<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_auto_deploy_expiration_sec<T>(self, v: Option<T>) -> Self
Sets or clears the value of auto_deploy_expiration_sec.
Example
let x = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig::new().set_or_clear_auto_deploy_expiration_sec(Some(42));
let x = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig::new().set_or_clear_auto_deploy_expiration_sec(None::<i32>);Sourcepub fn set_auto_deploy_impacted_baseline_threshold<T>(self, v: T) -> Self
pub fn set_auto_deploy_impacted_baseline_threshold<T>(self, v: T) -> Self
Sets the value of auto_deploy_impacted_baseline_threshold.
Example
let x = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig::new().set_auto_deploy_impacted_baseline_threshold(42.0);Sourcepub fn set_or_clear_auto_deploy_impacted_baseline_threshold<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_auto_deploy_impacted_baseline_threshold<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of auto_deploy_impacted_baseline_threshold.
Example
let x = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig::new().set_or_clear_auto_deploy_impacted_baseline_threshold(Some(42.0));
let x = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig::new().set_or_clear_auto_deploy_impacted_baseline_threshold(None::<f32>);Sourcepub fn set_auto_deploy_load_threshold<T>(self, v: T) -> Self
pub fn set_auto_deploy_load_threshold<T>(self, v: T) -> Self
Sets the value of auto_deploy_load_threshold.
Example
let x = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig::new().set_auto_deploy_load_threshold(42.0);Sourcepub fn set_or_clear_auto_deploy_load_threshold<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_auto_deploy_load_threshold<T>(self, v: Option<T>) -> Self
Sets or clears the value of auto_deploy_load_threshold.
Example
let x = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig::new().set_or_clear_auto_deploy_load_threshold(Some(42.0));
let x = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig::new().set_or_clear_auto_deploy_load_threshold(None::<f32>);Sourcepub fn set_detection_absolute_qps<T>(self, v: T) -> Self
pub fn set_detection_absolute_qps<T>(self, v: T) -> Self
Sets the value of detection_absolute_qps.
Example
let x = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig::new().set_detection_absolute_qps(42.0);Sourcepub fn set_or_clear_detection_absolute_qps<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_detection_absolute_qps<T>(self, v: Option<T>) -> Self
Sets or clears the value of detection_absolute_qps.
Example
let x = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig::new().set_or_clear_detection_absolute_qps(Some(42.0));
let x = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig::new().set_or_clear_detection_absolute_qps(None::<f32>);Sourcepub fn set_detection_load_threshold<T>(self, v: T) -> Self
pub fn set_detection_load_threshold<T>(self, v: T) -> Self
Sets the value of detection_load_threshold.
Example
let x = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig::new().set_detection_load_threshold(42.0);Sourcepub fn set_or_clear_detection_load_threshold<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_detection_load_threshold<T>(self, v: Option<T>) -> Self
Sets or clears the value of detection_load_threshold.
Example
let x = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig::new().set_or_clear_detection_load_threshold(Some(42.0));
let x = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig::new().set_or_clear_detection_load_threshold(None::<f32>);Sourcepub fn set_detection_relative_to_baseline_qps<T>(self, v: T) -> Self
pub fn set_detection_relative_to_baseline_qps<T>(self, v: T) -> Self
Sets the value of detection_relative_to_baseline_qps.
Example
let x = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig::new().set_detection_relative_to_baseline_qps(42.0);Sourcepub fn set_or_clear_detection_relative_to_baseline_qps<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_detection_relative_to_baseline_qps<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of detection_relative_to_baseline_qps.
Example
let x = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig::new().set_or_clear_detection_relative_to_baseline_qps(Some(42.0));
let x = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig::new().set_or_clear_detection_relative_to_baseline_qps(None::<f32>);Sourcepub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
Sourcepub fn set_traffic_granularity_configs<T, V>(self, v: T) -> Self
pub fn set_traffic_granularity_configs<T, V>(self, v: T) -> Self
Sets the value of traffic_granularity_configs.
Example
use google_cloud_compute_v1::model::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig;
let x = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig::new()
.set_traffic_granularity_configs([
SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig::default()/* use setters */,
SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig
impl Clone for SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig
Sourcefn clone(
&self,
) -> SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig
fn clone( &self, ) -> SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig
impl Default for SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig
Sourcefn default() -> SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig
fn default() -> SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig
Sourceimpl Message for SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig
impl Message for SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig
Sourceimpl PartialEq for SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig
impl PartialEq for SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig
impl StructuralPartialEq for SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig