Struct SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig
#[non_exhaustive]pub struct SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig {
pub enable_each_unique_value: Option<bool>,
pub type: Option<Type>,
pub value: Option<String>,
/* private fields */
}Available on crate features
organization-security-policies or region-security-policies or security-policies only.Expand description
Configurations to specifc granular traffic units processed by Adaptive Protection.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enable_each_unique_value: Option<bool>If enabled, traffic matching each unique value for the specified
type constitutes a separate traffic unit.
It can only be set to true if value is empty.
type: Option<Type>Type of this configuration.
value: Option<String>Requests that match this value constitute a granular traffic unit.
Implementations
Sourceimpl SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig
impl SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig
Sourcepub fn set_enable_each_unique_value<T>(self, v: T) -> Self
pub fn set_enable_each_unique_value<T>(self, v: T) -> Self
Sets the value of enable_each_unique_value.
Example
ⓘ
let x = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig::new().set_enable_each_unique_value(true);Sourcepub fn set_or_clear_enable_each_unique_value<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_enable_each_unique_value<T>(self, v: Option<T>) -> Self
Sets or clears the value of enable_each_unique_value.
Example
ⓘ
let x = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig::new().set_or_clear_enable_each_unique_value(Some(false));
let x = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig::new().set_or_clear_enable_each_unique_value(None::<bool>);Sourcepub fn set_type<T>(self, v: T) -> Self
pub fn set_type<T>(self, v: T) -> Self
Sets the value of r#type.
Example
ⓘ
use google_cloud_compute_v1::model::security_policy_adaptive_protection_config_layer_7_ddos_defense_config_threshold_config_traffic_granularity_config::Type;
let x0 = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig::new().set_type(Type::HttpPath);
let x1 = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig::new().set_type(Type::UnspecifiedType);Sourcepub fn set_or_clear_type<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_type<T>(self, v: Option<T>) -> Self
Sets or clears the value of r#type.
Example
ⓘ
use google_cloud_compute_v1::model::security_policy_adaptive_protection_config_layer_7_ddos_defense_config_threshold_config_traffic_granularity_config::Type;
let x0 = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig::new().set_or_clear_type(Some(Type::HttpPath));
let x1 = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig::new().set_or_clear_type(Some(Type::UnspecifiedType));
let x_none = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig::new().set_or_clear_type(None::<Type>);Sourcepub fn set_or_clear_value<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_value<T>(self, v: Option<T>) -> Self
Sets or clears the value of value.
Example
ⓘ
let x = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig::new().set_or_clear_value(Some("example"));
let x = SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig::new().set_or_clear_value(None::<String>);Trait Implementations
Sourceimpl Clone for SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig
impl Clone for SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig
Sourcefn clone(
&self,
) -> SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig
fn clone( &self, ) -> SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig
impl Debug for SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig
Sourceimpl Default for SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig
impl Default for SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig
Sourcefn default() -> SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig
fn default() -> SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig
Returns the “default value” for a type. Read more
Sourceimpl Message for SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig
impl Message for SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig
Sourceimpl PartialEq for SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig
impl PartialEq for SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig
impl StructuralPartialEq for SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig