#[non_exhaustive]pub struct SecurityPolicyAssociation {
pub attachment_id: Option<String>,
pub display_name: Option<String>,
pub excluded_folders: Vec<String>,
pub excluded_projects: Vec<String>,
pub name: Option<String>,
pub security_policy_id: Option<String>,
pub short_name: Option<String>,
/* private fields */
}organization-security-policies or region-security-policies or security-policies only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.attachment_id: Option<String>The resource that the security policy is attached to.
display_name: Option<String>Output only. [Output Only] The display name of the security policy of the association.
excluded_folders: Vec<String>A list of folders to exclude from the security policy.
excluded_projects: Vec<String>A list of projects to exclude from the security policy.
name: Option<String>The name for an association.
security_policy_id: Option<String>Output only. [Output Only] The security policy ID of the association.
short_name: Option<String>Output only. [Output Only] The short name of the security policy of the association.
Implementations
Sourceimpl SecurityPolicyAssociation
impl SecurityPolicyAssociation
Sourcepub fn set_attachment_id<T>(self, v: T) -> Self
pub fn set_attachment_id<T>(self, v: T) -> Self
Sets the value of attachment_id.
Example
let x = SecurityPolicyAssociation::new().set_attachment_id("example");Sourcepub fn set_or_clear_attachment_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_attachment_id<T>(self, v: Option<T>) -> Self
Sets or clears the value of attachment_id.
Example
let x = SecurityPolicyAssociation::new().set_or_clear_attachment_id(Some("example"));
let x = SecurityPolicyAssociation::new().set_or_clear_attachment_id(None::<String>);Sourcepub fn set_display_name<T>(self, v: T) -> Self
👎Deprecated
pub fn set_display_name<T>(self, v: T) -> Self
Sets the value of display_name.
Example
let x = SecurityPolicyAssociation::new().set_display_name("example");Sourcepub fn set_or_clear_display_name<T>(self, v: Option<T>) -> Self
👎Deprecated
pub fn set_or_clear_display_name<T>(self, v: Option<T>) -> Self
Sets or clears the value of display_name.
Example
let x = SecurityPolicyAssociation::new().set_or_clear_display_name(Some("example"));
let x = SecurityPolicyAssociation::new().set_or_clear_display_name(None::<String>);Sourcepub fn set_excluded_folders<T, V>(self, v: T) -> Self
pub fn set_excluded_folders<T, V>(self, v: T) -> Self
Sets the value of excluded_folders.
Example
let x = SecurityPolicyAssociation::new().set_excluded_folders(["a", "b", "c"]);Sourcepub fn set_excluded_projects<T, V>(self, v: T) -> Self
pub fn set_excluded_projects<T, V>(self, v: T) -> Self
Sets the value of excluded_projects.
Example
let x = SecurityPolicyAssociation::new().set_excluded_projects(["a", "b", "c"]);Sourcepub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
Sourcepub fn set_security_policy_id<T>(self, v: T) -> Self
pub fn set_security_policy_id<T>(self, v: T) -> Self
Sets the value of security_policy_id.
Example
let x = SecurityPolicyAssociation::new().set_security_policy_id("example");Sourcepub fn set_or_clear_security_policy_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_security_policy_id<T>(self, v: Option<T>) -> Self
Sets or clears the value of security_policy_id.
Example
let x = SecurityPolicyAssociation::new().set_or_clear_security_policy_id(Some("example"));
let x = SecurityPolicyAssociation::new().set_or_clear_security_policy_id(None::<String>);Sourcepub fn set_short_name<T>(self, v: T) -> Self
pub fn set_short_name<T>(self, v: T) -> Self
Sets the value of short_name.
Example
let x = SecurityPolicyAssociation::new().set_short_name("example");Sourcepub fn set_or_clear_short_name<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_short_name<T>(self, v: Option<T>) -> Self
Sets or clears the value of short_name.
Example
let x = SecurityPolicyAssociation::new().set_or_clear_short_name(Some("example"));
let x = SecurityPolicyAssociation::new().set_or_clear_short_name(None::<String>);Trait Implementations
Sourceimpl Clone for SecurityPolicyAssociation
impl Clone for SecurityPolicyAssociation
Sourcefn clone(&self) -> SecurityPolicyAssociation
fn clone(&self) -> SecurityPolicyAssociation
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for SecurityPolicyAssociation
impl Debug for SecurityPolicyAssociation
Sourceimpl Default for SecurityPolicyAssociation
impl Default for SecurityPolicyAssociation
Sourcefn default() -> SecurityPolicyAssociation
fn default() -> SecurityPolicyAssociation
Sourceimpl Message for SecurityPolicyAssociation
impl Message for SecurityPolicyAssociation
impl StructuralPartialEq for SecurityPolicyAssociation