#[non_exhaustive]pub struct ServiceAttachmentConnectedEndpoint {
pub consumer_network: Option<String>,
pub endpoint: Option<String>,
pub endpoint_with_id: Option<String>,
pub nat_ips: Vec<String>,
pub propagated_connection_count: Option<u32>,
pub psc_connection_id: Option<u64>,
pub status: Option<Status>,
/* private fields */
}service-attachments only.Expand description
[Output Only] A connection connected to this service attachment.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.consumer_network: Option<String>The url of the consumer network.
endpoint: Option<String>The url of a connected endpoint.
endpoint_with_id: Option<String>The url of a connected endpoint with resource id.
nat_ips: Vec<String>NAT IPs of the connected PSC endpoint and those of other endpoints propagated from it.
propagated_connection_count: Option<u32>The number of consumer Network Connectivity Center spokes that the connected Private Service Connect endpoint has propagated to.
psc_connection_id: Option<u64>The PSC connection id of the connected endpoint.
status: Option<Status>The status of a connected endpoint to this service attachment.
Implementations
Sourceimpl ServiceAttachmentConnectedEndpoint
impl ServiceAttachmentConnectedEndpoint
Sourcepub fn set_consumer_network<T>(self, v: T) -> Self
pub fn set_consumer_network<T>(self, v: T) -> Self
Sets the value of consumer_network.
Example
let x = ServiceAttachmentConnectedEndpoint::new().set_consumer_network("example");Sourcepub fn set_or_clear_consumer_network<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_consumer_network<T>(self, v: Option<T>) -> Self
Sets or clears the value of consumer_network.
Example
let x = ServiceAttachmentConnectedEndpoint::new().set_or_clear_consumer_network(Some("example"));
let x = ServiceAttachmentConnectedEndpoint::new().set_or_clear_consumer_network(None::<String>);Sourcepub fn set_endpoint<T>(self, v: T) -> Self
pub fn set_endpoint<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_endpoint<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_endpoint<T>(self, v: Option<T>) -> Self
Sourcepub fn set_endpoint_with_id<T>(self, v: T) -> Self
pub fn set_endpoint_with_id<T>(self, v: T) -> Self
Sets the value of endpoint_with_id.
Example
let x = ServiceAttachmentConnectedEndpoint::new().set_endpoint_with_id("example");Sourcepub fn set_or_clear_endpoint_with_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_endpoint_with_id<T>(self, v: Option<T>) -> Self
Sets or clears the value of endpoint_with_id.
Example
let x = ServiceAttachmentConnectedEndpoint::new().set_or_clear_endpoint_with_id(Some("example"));
let x = ServiceAttachmentConnectedEndpoint::new().set_or_clear_endpoint_with_id(None::<String>);Sourcepub fn set_nat_ips<T, V>(self, v: T) -> Self
pub fn set_nat_ips<T, V>(self, v: T) -> Self
Sourcepub fn set_propagated_connection_count<T>(self, v: T) -> Self
pub fn set_propagated_connection_count<T>(self, v: T) -> Self
Sets the value of propagated_connection_count.
Example
let x = ServiceAttachmentConnectedEndpoint::new().set_propagated_connection_count(42_u32);Sourcepub fn set_or_clear_propagated_connection_count<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_propagated_connection_count<T>(self, v: Option<T>) -> Self
Sets or clears the value of propagated_connection_count.
Example
let x = ServiceAttachmentConnectedEndpoint::new().set_or_clear_propagated_connection_count(Some(42_u32));
let x = ServiceAttachmentConnectedEndpoint::new().set_or_clear_propagated_connection_count(None::<u32>);Sourcepub fn set_psc_connection_id<T>(self, v: T) -> Self
pub fn set_psc_connection_id<T>(self, v: T) -> Self
Sets the value of psc_connection_id.
Example
let x = ServiceAttachmentConnectedEndpoint::new().set_psc_connection_id(42_u32);Sourcepub fn set_or_clear_psc_connection_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_psc_connection_id<T>(self, v: Option<T>) -> Self
Sets or clears the value of psc_connection_id.
Example
let x = ServiceAttachmentConnectedEndpoint::new().set_or_clear_psc_connection_id(Some(42_u32));
let x = ServiceAttachmentConnectedEndpoint::new().set_or_clear_psc_connection_id(None::<u32>);Sourcepub fn set_status<T>(self, v: T) -> Self
pub fn set_status<T>(self, v: T) -> Self
Sets the value of status.
Example
use google_cloud_compute_v1::model::service_attachment_connected_endpoint::Status;
let x0 = ServiceAttachmentConnectedEndpoint::new().set_status(Status::Closed);
let x1 = ServiceAttachmentConnectedEndpoint::new().set_status(Status::NeedsAttention);
let x2 = ServiceAttachmentConnectedEndpoint::new().set_status(Status::Pending);Sourcepub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
Sets or clears the value of status.
Example
use google_cloud_compute_v1::model::service_attachment_connected_endpoint::Status;
let x0 = ServiceAttachmentConnectedEndpoint::new().set_or_clear_status(Some(Status::Closed));
let x1 = ServiceAttachmentConnectedEndpoint::new().set_or_clear_status(Some(Status::NeedsAttention));
let x2 = ServiceAttachmentConnectedEndpoint::new().set_or_clear_status(Some(Status::Pending));
let x_none = ServiceAttachmentConnectedEndpoint::new().set_or_clear_status(None::<Status>);Trait Implementations
Sourceimpl Clone for ServiceAttachmentConnectedEndpoint
impl Clone for ServiceAttachmentConnectedEndpoint
Sourcefn clone(&self) -> ServiceAttachmentConnectedEndpoint
fn clone(&self) -> ServiceAttachmentConnectedEndpoint
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for ServiceAttachmentConnectedEndpoint
impl Default for ServiceAttachmentConnectedEndpoint
Sourcefn default() -> ServiceAttachmentConnectedEndpoint
fn default() -> ServiceAttachmentConnectedEndpoint
impl StructuralPartialEq for ServiceAttachmentConnectedEndpoint