#[non_exhaustive]pub struct SnapshotGroupParameters {
pub replica_zones: Vec<String>,
pub source_snapshot_group: Option<String>,
pub type: Option<String>,
/* private fields */
}Available on crate features
disks or region-disks only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.replica_zones: Vec<String>URLs of the zones where disks should be replicated to. Only applicable for regional resources.
source_snapshot_group: Option<String>The source snapshot group used to create disks. You can provide this as a partial or full URL to the resource. For example, the following are valid values:
- https://www.googleapis.com/compute/v1/projects/project/global/snapshotGroups/snapshotGroup- projects/project/global/snapshotGroups/snapshotGroup
- global/snapshotGroups/snapshotGroup
type: Option<String>URL of the disk type resource describing which disk type to use to create disks. Provide this when creating the disk. For example:projects/project/zones/zone/diskTypes/pd-ssd. See Persistent disk types.
Implementations
Sourceimpl SnapshotGroupParameters
impl SnapshotGroupParameters
Sourcepub fn set_replica_zones<T, V>(self, v: T) -> Self
pub fn set_replica_zones<T, V>(self, v: T) -> Self
Sets the value of replica_zones.
Example
ⓘ
let x = SnapshotGroupParameters::new().set_replica_zones(["a", "b", "c"]);Sourcepub fn set_source_snapshot_group<T>(self, v: T) -> Self
pub fn set_source_snapshot_group<T>(self, v: T) -> Self
Sets the value of source_snapshot_group.
Example
ⓘ
let x = SnapshotGroupParameters::new().set_source_snapshot_group("example");Sourcepub fn set_or_clear_source_snapshot_group<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_source_snapshot_group<T>(self, v: Option<T>) -> Self
Sets or clears the value of source_snapshot_group.
Example
ⓘ
let x = SnapshotGroupParameters::new().set_or_clear_source_snapshot_group(Some("example"));
let x = SnapshotGroupParameters::new().set_or_clear_source_snapshot_group(None::<String>);Trait Implementations
Sourceimpl Clone for SnapshotGroupParameters
impl Clone for SnapshotGroupParameters
Sourcefn clone(&self) -> SnapshotGroupParameters
fn clone(&self) -> SnapshotGroupParameters
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SnapshotGroupParameters
impl Debug for SnapshotGroupParameters
Sourceimpl Default for SnapshotGroupParameters
impl Default for SnapshotGroupParameters
Sourcefn default() -> SnapshotGroupParameters
fn default() -> SnapshotGroupParameters
Returns the “default value” for a type. Read more
Sourceimpl Message for SnapshotGroupParameters
impl Message for SnapshotGroupParameters
Sourceimpl PartialEq for SnapshotGroupParameters
impl PartialEq for SnapshotGroupParameters
Sourcefn eq(&self, other: &SnapshotGroupParameters) -> bool
fn eq(&self, other: &SnapshotGroupParameters) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SnapshotGroupParameters