#[non_exhaustive]pub struct SnapshotUpdateKmsKeyRequest {
pub kms_key_name: Option<String>,
/* private fields */
}Available on crate feature
snapshots only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.kms_key_name: Option<String>Optional. The new KMS key to replace the current one on the snapshot. If empty, the snapshot will be re-encrypted using the primary version of the snapshot’s current KMS key.
The KMS key can be provided in the following formats:
- projects/project_id/locations/region/keyRings/key_ring/cryptoKeys/keyImplementations
Sourceimpl SnapshotUpdateKmsKeyRequest
impl SnapshotUpdateKmsKeyRequest
Sourcepub fn set_kms_key_name<T>(self, v: T) -> Self
pub fn set_kms_key_name<T>(self, v: T) -> Self
Sets the value of kms_key_name.
Example
ⓘ
let x = SnapshotUpdateKmsKeyRequest::new().set_kms_key_name("example");Sourcepub fn set_or_clear_kms_key_name<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kms_key_name<T>(self, v: Option<T>) -> Self
Sets or clears the value of kms_key_name.
Example
ⓘ
let x = SnapshotUpdateKmsKeyRequest::new().set_or_clear_kms_key_name(Some("example"));
let x = SnapshotUpdateKmsKeyRequest::new().set_or_clear_kms_key_name(None::<String>);Trait Implementations
Sourceimpl Clone for SnapshotUpdateKmsKeyRequest
impl Clone for SnapshotUpdateKmsKeyRequest
Sourcefn clone(&self) -> SnapshotUpdateKmsKeyRequest
fn clone(&self) -> SnapshotUpdateKmsKeyRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SnapshotUpdateKmsKeyRequest
impl Debug for SnapshotUpdateKmsKeyRequest
Sourceimpl Default for SnapshotUpdateKmsKeyRequest
impl Default for SnapshotUpdateKmsKeyRequest
Sourcefn default() -> SnapshotUpdateKmsKeyRequest
fn default() -> SnapshotUpdateKmsKeyRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for SnapshotUpdateKmsKeyRequest
impl PartialEq for SnapshotUpdateKmsKeyRequest
Sourcefn eq(&self, other: &SnapshotUpdateKmsKeyRequest) -> bool
fn eq(&self, other: &SnapshotUpdateKmsKeyRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SnapshotUpdateKmsKeyRequest