#[non_exhaustive]pub struct StatefulPolicyPreservedStateNetworkIp {
pub auto_delete: Option<AutoDelete>,
/* private fields */
}Available on crate features
instance-group-managers or region-instance-group-managers only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.auto_delete: Option<AutoDelete>These stateful IPs will never be released during autohealing, update or VM instance recreate operations. This flag is used to configure if the IP reservation should be deleted after it is no longer used by the group, e.g. when the given instance or the whole group is deleted.
Implementations
Sourceimpl StatefulPolicyPreservedStateNetworkIp
impl StatefulPolicyPreservedStateNetworkIp
Sourcepub fn set_auto_delete<T>(self, v: T) -> Selfwhere
T: Into<AutoDelete>,
pub fn set_auto_delete<T>(self, v: T) -> Selfwhere
T: Into<AutoDelete>,
Sets the value of auto_delete.
Example
ⓘ
use google_cloud_compute_v1::model::stateful_policy_preserved_state_network_ip::AutoDelete;
let x0 = StatefulPolicyPreservedStateNetworkIp::new().set_auto_delete(AutoDelete::OnPermanentInstanceDeletion);Sourcepub fn set_or_clear_auto_delete<T>(self, v: Option<T>) -> Selfwhere
T: Into<AutoDelete>,
pub fn set_or_clear_auto_delete<T>(self, v: Option<T>) -> Selfwhere
T: Into<AutoDelete>,
Sets or clears the value of auto_delete.
Example
ⓘ
use google_cloud_compute_v1::model::stateful_policy_preserved_state_network_ip::AutoDelete;
let x0 = StatefulPolicyPreservedStateNetworkIp::new().set_or_clear_auto_delete(Some(AutoDelete::OnPermanentInstanceDeletion));
let x_none = StatefulPolicyPreservedStateNetworkIp::new().set_or_clear_auto_delete(None::<AutoDelete>);Trait Implementations
Sourceimpl Clone for StatefulPolicyPreservedStateNetworkIp
impl Clone for StatefulPolicyPreservedStateNetworkIp
Sourcefn clone(&self) -> StatefulPolicyPreservedStateNetworkIp
fn clone(&self) -> StatefulPolicyPreservedStateNetworkIp
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for StatefulPolicyPreservedStateNetworkIp
impl Default for StatefulPolicyPreservedStateNetworkIp
Sourcefn default() -> StatefulPolicyPreservedStateNetworkIp
fn default() -> StatefulPolicyPreservedStateNetworkIp
Returns the “default value” for a type. Read more
impl StructuralPartialEq for StatefulPolicyPreservedStateNetworkIp