#[non_exhaustive]pub struct StoragePoolAggregatedList {
pub etag: Option<String>,
pub id: Option<String>,
pub items: HashMap<String, StoragePoolsScopedList>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
pub self_link: Option<String>,
pub unreachables: Vec<String>,
pub warning: Option<Warning>,
/* private fields */
}storage-pools only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.etag: Option<String>id: Option<String>[Output Only] Unique identifier for the resource; defined by the server.
items: HashMap<String, StoragePoolsScopedList>A list of StoragePoolsScopedList resources.
kind: Option<String>Output only. [Output Only] Type of resource. Alwayscompute#storagePoolAggregatedList for aggregated lists of storage pools.
next_page_token: Option<String>[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
self_link: Option<String>Output only. [Output Only] Server-defined URL for this resource.
unreachables: Vec<String>Output only. [Output Only] Unreachable resources.
warning: Option<Warning>[Output Only] Informational warning message.
Implementations
Sourceimpl StoragePoolAggregatedList
impl StoragePoolAggregatedList
Sourcepub fn set_or_clear_etag<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_etag<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_next_page_token<T>(self, v: T) -> Self
pub fn set_next_page_token<T>(self, v: T) -> Self
Sets the value of next_page_token.
Example
let x = StoragePoolAggregatedList::new().set_next_page_token("example");Sourcepub fn set_or_clear_next_page_token<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_next_page_token<T>(self, v: Option<T>) -> Self
Sets or clears the value of next_page_token.
Example
let x = StoragePoolAggregatedList::new().set_or_clear_next_page_token(Some("example"));
let x = StoragePoolAggregatedList::new().set_or_clear_next_page_token(None::<String>);Sourcepub fn set_self_link<T>(self, v: T) -> Self
pub fn set_self_link<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
Sourcepub fn set_unreachables<T, V>(self, v: T) -> Self
pub fn set_unreachables<T, V>(self, v: T) -> Self
Sets the value of unreachables.
Example
let x = StoragePoolAggregatedList::new().set_unreachables(["a", "b", "c"]);Sourcepub fn set_warning<T>(self, v: T) -> Self
pub fn set_warning<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_warning<T>(self, v: Option<T>) -> Self
Sets or clears the value of warning.
Example
use google_cloud_compute_v1::model::storage_pool_aggregated_list::Warning;
let x = StoragePoolAggregatedList::new().set_or_clear_warning(Some(Warning::default()/* use setters */));
let x = StoragePoolAggregatedList::new().set_or_clear_warning(None::<Warning>);Trait Implementations
Sourceimpl Clone for StoragePoolAggregatedList
impl Clone for StoragePoolAggregatedList
Sourcefn clone(&self) -> StoragePoolAggregatedList
fn clone(&self) -> StoragePoolAggregatedList
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for StoragePoolAggregatedList
impl Debug for StoragePoolAggregatedList
Sourceimpl Default for StoragePoolAggregatedList
impl Default for StoragePoolAggregatedList
Sourcefn default() -> StoragePoolAggregatedList
fn default() -> StoragePoolAggregatedList
Sourceimpl Message for StoragePoolAggregatedList
impl Message for StoragePoolAggregatedList
impl StructuralPartialEq for StoragePoolAggregatedList