#[non_exhaustive]pub struct TargetGrpcProxy {
pub creation_timestamp: Option<String>,
pub description: Option<String>,
pub fingerprint: Option<Bytes>,
pub id: Option<u64>,
pub kind: Option<String>,
pub name: Option<String>,
pub self_link: Option<String>,
pub self_link_with_id: Option<String>,
pub url_map: Option<String>,
pub validate_for_proxyless: Option<bool>,
/* private fields */
}target-grpc-proxies only.Expand description
Represents a Target gRPC Proxy resource.
A target gRPC proxy is a component of load balancers intended for load balancing gRPC traffic. Only global forwarding rules with load balancing scheme INTERNAL_SELF_MANAGED can reference a target gRPC proxy. The target gRPC Proxy references a URL map that specifies how traffic is routed to gRPC backend services.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.creation_timestamp: Option<String>Output only. [Output Only] Creation timestamp inRFC3339 text format.
description: Option<String>An optional description of this resource. Provide this property when you create the resource.
fingerprint: Option<Bytes>Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a TargetGrpcProxy. An up-to-date fingerprint must be provided in order to patch/update the TargetGrpcProxy; otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the TargetGrpcProxy.
id: Option<u64>Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier.
kind: Option<String>Output only. [Output Only] Type of the resource. Alwayscompute#targetGrpcProxy for target grpc proxies.
name: Option<String>Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
self_link: Option<String>Output only. [Output Only] Server-defined URL for the resource.
self_link_with_id: Option<String>Output only. [Output Only] Server-defined URL with id for the resource.
url_map: Option<String>URL to the UrlMap resource that defines the mapping from URL to the BackendService. The protocol field in the BackendService must be set to GRPC.
validate_for_proxyless: Option<bool>If true, indicates that the BackendServices referenced by the urlMap may be accessed by gRPC applications without using a sidecar proxy. This will enable configuration checks on urlMap and its referenced BackendServices to not allow unsupported features. A gRPC application must use “xds:///” scheme in the target URI of the service it is connecting to. If false, indicates that the BackendServices referenced by the urlMap will be accessed by gRPC applications via a sidecar proxy. In this case, a gRPC application must not use “xds:///” scheme in the target URI of the service it is connecting to
Implementations
Sourceimpl TargetGrpcProxy
impl TargetGrpcProxy
Sourcepub fn set_creation_timestamp<T>(self, v: T) -> Self
pub fn set_creation_timestamp<T>(self, v: T) -> Self
Sets the value of creation_timestamp.
Example
let x = TargetGrpcProxy::new().set_creation_timestamp("example");Sourcepub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
Sets or clears the value of creation_timestamp.
Example
let x = TargetGrpcProxy::new().set_or_clear_creation_timestamp(Some("example"));
let x = TargetGrpcProxy::new().set_or_clear_creation_timestamp(None::<String>);Sourcepub fn set_description<T>(self, v: T) -> Self
pub fn set_description<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
Sets or clears the value of description.
Example
let x = TargetGrpcProxy::new().set_or_clear_description(Some("example"));
let x = TargetGrpcProxy::new().set_or_clear_description(None::<String>);Sourcepub fn set_fingerprint<T>(self, v: T) -> Self
pub fn set_fingerprint<T>(self, v: T) -> Self
Sets the value of fingerprint.
Example
let x = TargetGrpcProxy::new().set_fingerprint(bytes::Bytes::from_static(b"example"));Sourcepub fn set_or_clear_fingerprint<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_fingerprint<T>(self, v: Option<T>) -> Self
Sets or clears the value of fingerprint.
Example
let x = TargetGrpcProxy::new().set_or_clear_fingerprint(Some(bytes::Bytes::from_static(b"example")));
let x = TargetGrpcProxy::new().set_or_clear_fingerprint(None::<bytes::Bytes>);Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
Sourcepub fn set_self_link<T>(self, v: T) -> Self
pub fn set_self_link<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
Sourcepub fn set_self_link_with_id<T>(self, v: T) -> Self
pub fn set_self_link_with_id<T>(self, v: T) -> Self
Sets the value of self_link_with_id.
Example
let x = TargetGrpcProxy::new().set_self_link_with_id("example");Sourcepub fn set_or_clear_self_link_with_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link_with_id<T>(self, v: Option<T>) -> Self
Sets or clears the value of self_link_with_id.
Example
let x = TargetGrpcProxy::new().set_or_clear_self_link_with_id(Some("example"));
let x = TargetGrpcProxy::new().set_or_clear_self_link_with_id(None::<String>);Sourcepub fn set_url_map<T>(self, v: T) -> Self
pub fn set_url_map<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_url_map<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_url_map<T>(self, v: Option<T>) -> Self
Sourcepub fn set_validate_for_proxyless<T>(self, v: T) -> Self
pub fn set_validate_for_proxyless<T>(self, v: T) -> Self
Sets the value of validate_for_proxyless.
Example
let x = TargetGrpcProxy::new().set_validate_for_proxyless(true);Sourcepub fn set_or_clear_validate_for_proxyless<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_validate_for_proxyless<T>(self, v: Option<T>) -> Self
Sets or clears the value of validate_for_proxyless.
Example
let x = TargetGrpcProxy::new().set_or_clear_validate_for_proxyless(Some(false));
let x = TargetGrpcProxy::new().set_or_clear_validate_for_proxyless(None::<bool>);Trait Implementations
Sourceimpl Clone for TargetGrpcProxy
impl Clone for TargetGrpcProxy
Sourcefn clone(&self) -> TargetGrpcProxy
fn clone(&self) -> TargetGrpcProxy
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for TargetGrpcProxy
impl Debug for TargetGrpcProxy
Sourceimpl Default for TargetGrpcProxy
impl Default for TargetGrpcProxy
Sourcefn default() -> TargetGrpcProxy
fn default() -> TargetGrpcProxy
Sourceimpl Message for TargetGrpcProxy
impl Message for TargetGrpcProxy
Sourceimpl PartialEq for TargetGrpcProxy
impl PartialEq for TargetGrpcProxy
impl StructuralPartialEq for TargetGrpcProxy