#[non_exhaustive]pub struct TargetHttpProxyAggregatedList {
pub id: Option<String>,
pub items: HashMap<String, TargetHttpProxiesScopedList>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
pub self_link: Option<String>,
pub unreachables: Vec<String>,
/* private fields */
}target-http-proxies only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>[Output Only] Unique identifier for the resource; defined by the server.
items: HashMap<String, TargetHttpProxiesScopedList>A list of TargetHttpProxiesScopedList resources.
kind: Option<String>Output only. [Output Only] Type of resource. Alwayscompute#targetHttpProxyAggregatedList for lists of Target HTTP Proxies.
next_page_token: Option<String>[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
self_link: Option<String>Output only. [Output Only] Server-defined URL for this resource.
unreachables: Vec<String>Output only. [Output Only] Unreachable resources.
Implementations
Sourceimpl TargetHttpProxyAggregatedList
impl TargetHttpProxyAggregatedList
Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
Sourcepub fn set_items<T, K, V>(self, v: T) -> Self
pub fn set_items<T, K, V>(self, v: T) -> Self
Sets the value of items.
Example
use google_cloud_compute_v1::model::TargetHttpProxiesScopedList;
let x = TargetHttpProxyAggregatedList::new().set_items([
("key0", TargetHttpProxiesScopedList::default()/* use setters */),
("key1", TargetHttpProxiesScopedList::default()/* use (different) setters */),
]);Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_next_page_token<T>(self, v: T) -> Self
pub fn set_next_page_token<T>(self, v: T) -> Self
Sets the value of next_page_token.
Example
let x = TargetHttpProxyAggregatedList::new().set_next_page_token("example");Sourcepub fn set_or_clear_next_page_token<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_next_page_token<T>(self, v: Option<T>) -> Self
Sets or clears the value of next_page_token.
Example
let x = TargetHttpProxyAggregatedList::new().set_or_clear_next_page_token(Some("example"));
let x = TargetHttpProxyAggregatedList::new().set_or_clear_next_page_token(None::<String>);Sourcepub fn set_self_link<T>(self, v: T) -> Self
pub fn set_self_link<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
Sourcepub fn set_unreachables<T, V>(self, v: T) -> Self
pub fn set_unreachables<T, V>(self, v: T) -> Self
Sets the value of unreachables.
Example
let x = TargetHttpProxyAggregatedList::new().set_unreachables(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for TargetHttpProxyAggregatedList
impl Clone for TargetHttpProxyAggregatedList
Sourcefn clone(&self) -> TargetHttpProxyAggregatedList
fn clone(&self) -> TargetHttpProxyAggregatedList
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for TargetHttpProxyAggregatedList
impl Default for TargetHttpProxyAggregatedList
Sourcefn default() -> TargetHttpProxyAggregatedList
fn default() -> TargetHttpProxyAggregatedList
impl StructuralPartialEq for TargetHttpProxyAggregatedList