#[non_exhaustive]pub struct TestFailure {
pub actual_output_url: Option<String>,
pub actual_redirect_response_code: Option<i32>,
pub actual_service: Option<String>,
pub expected_output_url: Option<String>,
pub expected_redirect_response_code: Option<i32>,
pub expected_service: Option<String>,
pub headers: Vec<UrlMapTestHeader>,
pub host: Option<String>,
pub path: Option<String>,
/* private fields */
}region-url-maps or url-maps only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.actual_output_url: Option<String>The actual output URL evaluated by a load balancer containing the scheme, host, path and query parameters.
actual_redirect_response_code: Option<i32>Actual HTTP status code for rule with urlRedirect
calculated by load balancer
actual_service: Option<String>BackendService or BackendBucket returned by load balancer.
expected_output_url: Option<String>The expected output URL evaluated by a load balancer containing the scheme, host, path and query parameters.
expected_redirect_response_code: Option<i32>Expected HTTP status code for rule with urlRedirect
calculated by load balancer
expected_service: Option<String>Expected BackendService or BackendBucket resource the given URL should be mapped to.
headers: Vec<UrlMapTestHeader>HTTP headers of the request.
host: Option<String>Host portion of the URL.
path: Option<String>Path portion including query parameters in the URL.
Implementations
Sourceimpl TestFailure
impl TestFailure
Sourcepub fn set_actual_output_url<T>(self, v: T) -> Self
pub fn set_actual_output_url<T>(self, v: T) -> Self
Sets the value of actual_output_url.
Example
let x = TestFailure::new().set_actual_output_url("example");Sourcepub fn set_or_clear_actual_output_url<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_actual_output_url<T>(self, v: Option<T>) -> Self
Sets or clears the value of actual_output_url.
Example
let x = TestFailure::new().set_or_clear_actual_output_url(Some("example"));
let x = TestFailure::new().set_or_clear_actual_output_url(None::<String>);Sourcepub fn set_actual_redirect_response_code<T>(self, v: T) -> Self
pub fn set_actual_redirect_response_code<T>(self, v: T) -> Self
Sets the value of actual_redirect_response_code.
Example
let x = TestFailure::new().set_actual_redirect_response_code(42);Sourcepub fn set_or_clear_actual_redirect_response_code<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_actual_redirect_response_code<T>(self, v: Option<T>) -> Self
Sets or clears the value of actual_redirect_response_code.
Example
let x = TestFailure::new().set_or_clear_actual_redirect_response_code(Some(42));
let x = TestFailure::new().set_or_clear_actual_redirect_response_code(None::<i32>);Sourcepub fn set_actual_service<T>(self, v: T) -> Self
pub fn set_actual_service<T>(self, v: T) -> Self
Sets the value of actual_service.
Example
let x = TestFailure::new().set_actual_service("example");Sourcepub fn set_or_clear_actual_service<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_actual_service<T>(self, v: Option<T>) -> Self
Sets or clears the value of actual_service.
Example
let x = TestFailure::new().set_or_clear_actual_service(Some("example"));
let x = TestFailure::new().set_or_clear_actual_service(None::<String>);Sourcepub fn set_expected_output_url<T>(self, v: T) -> Self
pub fn set_expected_output_url<T>(self, v: T) -> Self
Sets the value of expected_output_url.
Example
let x = TestFailure::new().set_expected_output_url("example");Sourcepub fn set_or_clear_expected_output_url<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_expected_output_url<T>(self, v: Option<T>) -> Self
Sets or clears the value of expected_output_url.
Example
let x = TestFailure::new().set_or_clear_expected_output_url(Some("example"));
let x = TestFailure::new().set_or_clear_expected_output_url(None::<String>);Sourcepub fn set_expected_redirect_response_code<T>(self, v: T) -> Self
pub fn set_expected_redirect_response_code<T>(self, v: T) -> Self
Sets the value of expected_redirect_response_code.
Example
let x = TestFailure::new().set_expected_redirect_response_code(42);Sourcepub fn set_or_clear_expected_redirect_response_code<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_expected_redirect_response_code<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of expected_redirect_response_code.
Example
let x = TestFailure::new().set_or_clear_expected_redirect_response_code(Some(42));
let x = TestFailure::new().set_or_clear_expected_redirect_response_code(None::<i32>);Sourcepub fn set_expected_service<T>(self, v: T) -> Self
pub fn set_expected_service<T>(self, v: T) -> Self
Sets the value of expected_service.
Example
let x = TestFailure::new().set_expected_service("example");Sourcepub fn set_or_clear_expected_service<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_expected_service<T>(self, v: Option<T>) -> Self
Sets or clears the value of expected_service.
Example
let x = TestFailure::new().set_or_clear_expected_service(Some("example"));
let x = TestFailure::new().set_or_clear_expected_service(None::<String>);Sourcepub fn set_headers<T, V>(self, v: T) -> Self
pub fn set_headers<T, V>(self, v: T) -> Self
Sourcepub fn set_or_clear_host<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_host<T>(self, v: Option<T>) -> Self