#[non_exhaustive]pub struct VmExtensionPolicyLabelSelector {
pub inclusion_labels: HashMap<String, String>,
/* private fields */
}Available on crate features
global-vm-extension-policies or zone-vm-extension-policies only.Expand description
A LabelSelector is applied to a VM only if it matches all the specified labels.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.inclusion_labels: HashMap<String, String>Optional. A map of key-value pairs representing VM labels. VMs must have all of the labels specified in this map to be selected (logical AND).
e.g. If the inclusion_labels are {(“key1”, “value1”), (“key2”,
“value2”)}, the VM labels must contain both (“key1”, “value1”) and
(“key2”, “value2”) to be selected. If the VM labels are (“key1”,
“value1”) and (“something”, “else”), it will not be selected.
If the map is empty, it’s considered a match.
Implementations
Sourceimpl VmExtensionPolicyLabelSelector
impl VmExtensionPolicyLabelSelector
Sourcepub fn set_inclusion_labels<T, K, V>(self, v: T) -> Self
pub fn set_inclusion_labels<T, K, V>(self, v: T) -> Self
Sets the value of inclusion_labels.
Example
ⓘ
let x = VmExtensionPolicyLabelSelector::new().set_inclusion_labels([
("key0", "abc"),
("key1", "xyz"),
]);Trait Implementations
Sourceimpl Clone for VmExtensionPolicyLabelSelector
impl Clone for VmExtensionPolicyLabelSelector
Sourcefn clone(&self) -> VmExtensionPolicyLabelSelector
fn clone(&self) -> VmExtensionPolicyLabelSelector
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for VmExtensionPolicyLabelSelector
impl Default for VmExtensionPolicyLabelSelector
Sourcefn default() -> VmExtensionPolicyLabelSelector
fn default() -> VmExtensionPolicyLabelSelector
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for VmExtensionPolicyLabelSelector
impl PartialEq for VmExtensionPolicyLabelSelector
Sourcefn eq(&self, other: &VmExtensionPolicyLabelSelector) -> bool
fn eq(&self, other: &VmExtensionPolicyLabelSelector) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for VmExtensionPolicyLabelSelector