#[non_exhaustive]pub struct Wire {
pub admin_enabled: Option<bool>,
pub endpoints: Vec<WireEndpoint>,
pub label: Option<String>,
pub wire_properties: Option<WireProperties>,
/* private fields */
}wire-groups only.Expand description
A pseudowire that connects two Interconnect connections.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.admin_enabled: Option<bool>Output only. [Output Only] Indicates whether the wire is enabled. When false, the wire is disabled. When true and when the wire group of the wire is also enabled, the wire is enabled. Defaults to true.
endpoints: Vec<WireEndpoint>Output only. Wire endpoints are specific Interconnect connections.
label: Option<String>Output only. [Output Only] A label that identifies the wire. The format of this label
combines the existing labels of the wire group endpoints and Interconnect
connections used by this wire in alphabetical order as follows:
ENDPOINT_A+CONNECTION_A1,ENDPOINT_B+CONNECTION_B1, where:
- ENDPOINT_A and ENDPOINT_B: are the labels that you entered as map keys when you specified the wire group endpoint objects.
- CONNECTION_A1 and CONNECTION_B1: are the labels that you entered as map keys when you specified the wire group Interconnect objects.
wire_properties: Option<WireProperties>Output only. [Output Only] Properties of the wire.
Implementations
Sourceimpl Wire
impl Wire
Sourcepub fn set_admin_enabled<T>(self, v: T) -> Self
pub fn set_admin_enabled<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_admin_enabled<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_admin_enabled<T>(self, v: Option<T>) -> Self
Sets or clears the value of admin_enabled.
Example
let x = Wire::new().set_or_clear_admin_enabled(Some(false));
let x = Wire::new().set_or_clear_admin_enabled(None::<bool>);Sourcepub fn set_endpoints<T, V>(self, v: T) -> Self
pub fn set_endpoints<T, V>(self, v: T) -> Self
Sourcepub fn set_or_clear_label<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_label<T>(self, v: Option<T>) -> Self
Sourcepub fn set_wire_properties<T>(self, v: T) -> Selfwhere
T: Into<WireProperties>,
pub fn set_wire_properties<T>(self, v: T) -> Selfwhere
T: Into<WireProperties>,
Sets the value of wire_properties.
Example
use google_cloud_compute_v1::model::WireProperties;
let x = Wire::new().set_wire_properties(WireProperties::default()/* use setters */);Sourcepub fn set_or_clear_wire_properties<T>(self, v: Option<T>) -> Selfwhere
T: Into<WireProperties>,
pub fn set_or_clear_wire_properties<T>(self, v: Option<T>) -> Selfwhere
T: Into<WireProperties>,
Sets or clears the value of wire_properties.
Example
use google_cloud_compute_v1::model::WireProperties;
let x = Wire::new().set_or_clear_wire_properties(Some(WireProperties::default()/* use setters */));
let x = Wire::new().set_or_clear_wire_properties(None::<WireProperties>);Trait Implementations
impl StructuralPartialEq for Wire