#[non_exhaustive]pub struct WireGroup {
pub admin_enabled: Option<bool>,
pub creation_timestamp: Option<String>,
pub description: Option<String>,
pub endpoints: HashMap<String, WireGroupEndpoint>,
pub id: Option<u64>,
pub kind: Option<String>,
pub name: Option<String>,
pub reconciling: Option<bool>,
pub self_link: Option<String>,
pub topology: Option<WireGroupTopology>,
pub wire_properties: Option<WireProperties>,
pub wires: Vec<Wire>,
/* private fields */
}wire-groups only.Expand description
A resource that represents a group of redundant wires.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.admin_enabled: Option<bool>Indicates whether the wires in the wire group are enabled. When false, the
wires in the wire group are disabled. When true and when
there is simultaneously no wire-specific override of adminEnabled to
false, a given wire is enabled. Defaults to true.
creation_timestamp: Option<String>Output only. [Output Only] Creation timestamp inRFC3339 text format.
description: Option<String>An optional description of the wire group.
endpoints: HashMap<String, WireGroupEndpoint>A map that contains the logical endpoints of the wire group. Specify key-value pairs for the map as follows:
- Key: an RFC1035 user-specified label.
- Value: an Endpoint object.
id: Option<u64>Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier.
kind: Option<String>Output only. [Output Only] Type of the resource. Alwayscompute#wireGroups for wire groups.
name: Option<String>Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
reconciling: Option<bool>Output only. [Output Only] Indicates whether there are wire changes yet to be processed.
self_link: Option<String>Output only. [Output Only] Server-defined URL for the resource.
topology: Option<WireGroupTopology>Output only. Topology details for the wire group configuration.
wire_properties: Option<WireProperties>Properties for all wires in the wire group.
wires: Vec<Wire>Output only. The single/redundant wire(s) managed by the wire group.
Implementations
Sourceimpl WireGroup
impl WireGroup
Sourcepub fn set_admin_enabled<T>(self, v: T) -> Self
pub fn set_admin_enabled<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_admin_enabled<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_admin_enabled<T>(self, v: Option<T>) -> Self
Sets or clears the value of admin_enabled.
Example
let x = WireGroup::new().set_or_clear_admin_enabled(Some(false));
let x = WireGroup::new().set_or_clear_admin_enabled(None::<bool>);Sourcepub fn set_creation_timestamp<T>(self, v: T) -> Self
pub fn set_creation_timestamp<T>(self, v: T) -> Self
Sets the value of creation_timestamp.
Example
let x = WireGroup::new().set_creation_timestamp("example");Sourcepub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
Sets or clears the value of creation_timestamp.
Example
let x = WireGroup::new().set_or_clear_creation_timestamp(Some("example"));
let x = WireGroup::new().set_or_clear_creation_timestamp(None::<String>);Sourcepub fn set_description<T>(self, v: T) -> Self
pub fn set_description<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
Sets or clears the value of description.
Example
let x = WireGroup::new().set_or_clear_description(Some("example"));
let x = WireGroup::new().set_or_clear_description(None::<String>);Sourcepub fn set_endpoints<T, K, V>(self, v: T) -> Self
pub fn set_endpoints<T, K, V>(self, v: T) -> Self
Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
Sourcepub fn set_reconciling<T>(self, v: T) -> Self
pub fn set_reconciling<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_reconciling<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_reconciling<T>(self, v: Option<T>) -> Self
Sets or clears the value of reconciling.
Example
let x = WireGroup::new().set_or_clear_reconciling(Some(false));
let x = WireGroup::new().set_or_clear_reconciling(None::<bool>);Sourcepub fn set_self_link<T>(self, v: T) -> Self
pub fn set_self_link<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
Sourcepub fn set_topology<T>(self, v: T) -> Selfwhere
T: Into<WireGroupTopology>,
pub fn set_topology<T>(self, v: T) -> Selfwhere
T: Into<WireGroupTopology>,
Sourcepub fn set_or_clear_topology<T>(self, v: Option<T>) -> Selfwhere
T: Into<WireGroupTopology>,
pub fn set_or_clear_topology<T>(self, v: Option<T>) -> Selfwhere
T: Into<WireGroupTopology>,
Sourcepub fn set_wire_properties<T>(self, v: T) -> Selfwhere
T: Into<WireProperties>,
pub fn set_wire_properties<T>(self, v: T) -> Selfwhere
T: Into<WireProperties>,
Sets the value of wire_properties.
Example
use google_cloud_compute_v1::model::WireProperties;
let x = WireGroup::new().set_wire_properties(WireProperties::default()/* use setters */);Sourcepub fn set_or_clear_wire_properties<T>(self, v: Option<T>) -> Selfwhere
T: Into<WireProperties>,
pub fn set_or_clear_wire_properties<T>(self, v: Option<T>) -> Selfwhere
T: Into<WireProperties>,
Sets or clears the value of wire_properties.
Example
use google_cloud_compute_v1::model::WireProperties;
let x = WireGroup::new().set_or_clear_wire_properties(Some(WireProperties::default()/* use setters */));
let x = WireGroup::new().set_or_clear_wire_properties(None::<WireProperties>);Trait Implementations
impl StructuralPartialEq for WireGroup