This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
New values appearing in future releases of the client library, and
New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some
guidelines.
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
For Traffic Director, the number of backends per backend group
(the subset size) is based on the subset_size parameter.
For Internal HTTP(S) load balancing, the number of backends per backend
group (the subset size) is dynamically adjusted in two cases:
As the number of proxy instances participating in Internal HTTP(S) load
balancing increases, the subset size decreases.
When the total number of backends in a network exceeds the capacity of
a single proxy instance, subset sizes are reduced automatically for
each service that has backend subsetting enabled.
Clients may open connections and send traffic to all backends of this
backend service. This can lead to performance issues if there is
substantial imbalance in the count of clients and backends.