#[non_exhaustive]pub enum CacheMode {
CacheAllStatic,
ForceCacheAll,
UseOriginHeaders,
UnknownValue(UnknownValue),
}region-url-maps or url-maps only.Expand description
The enumerated type for the cacheMode field.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
CacheAllStatic
Automatically cache static content, including common image formats, media (video and audio), and web assets (JavaScript and CSS). Requests and responses that are marked as uncacheable, as well as dynamic content (including HTML), will not be cached.
ForceCacheAll
Cache all content, ignoring any “private”, “no-store” or “no-cache” directives in Cache-Control response headers. Warning: this may result in Cloud CDN caching private, per-user (user identifiable) content.
UseOriginHeaders
Requires the origin to set valid caching headers to cache content. Responses without these headers will not be cached at the edge, and will require a full trip to the origin on every request, potentially impacting performance and increasing load on the origin server.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using CacheMode::value or CacheMode::name.
Implementations