#[non_exhaustive]pub struct EnableXpnHostRequest {
pub project: String,
pub request_id: Option<String>,
/* private fields */
}projects only.Expand description
Synthetic request message for the enableXpnHost() method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.project: StringProject ID for this request.
request_id: Option<String>An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl EnableXpnHostRequest
impl EnableXpnHostRequest
Sourcepub fn set_project<T: Into<String>>(self, v: T) -> Self
pub fn set_project<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_request_id<T>(self, v: T) -> Self
pub fn set_request_id<T>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = EnableXpnHostRequest::new().set_request_id("example");Sourcepub fn set_or_clear_request_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_request_id<T>(self, v: Option<T>) -> Self
Sets or clears the value of request_id.
Example
let x = EnableXpnHostRequest::new().set_or_clear_request_id(Some("example"));
let x = EnableXpnHostRequest::new().set_or_clear_request_id(None::<String>);Trait Implementations
Sourceimpl Clone for EnableXpnHostRequest
impl Clone for EnableXpnHostRequest
Sourcefn clone(&self) -> EnableXpnHostRequest
fn clone(&self) -> EnableXpnHostRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for EnableXpnHostRequest
impl Debug for EnableXpnHostRequest
Sourceimpl Default for EnableXpnHostRequest
impl Default for EnableXpnHostRequest
Sourcefn default() -> EnableXpnHostRequest
fn default() -> EnableXpnHostRequest
Sourceimpl PartialEq for EnableXpnHostRequest
impl PartialEq for EnableXpnHostRequest
Sourcefn eq(&self, other: &EnableXpnHostRequest) -> bool
fn eq(&self, other: &EnableXpnHostRequest) -> bool
self and other values to be equal, and is used by ==.