#[non_exhaustive]pub struct BackendBucket {Show 16 fields
pub bucket_name: Option<String>,
pub cdn_policy: Option<BackendBucketCdnPolicy>,
pub compression_mode: Option<CompressionMode>,
pub creation_timestamp: Option<String>,
pub custom_response_headers: Vec<String>,
pub description: Option<String>,
pub edge_security_policy: Option<String>,
pub enable_cdn: Option<bool>,
pub id: Option<u64>,
pub kind: Option<String>,
pub load_balancing_scheme: Option<LoadBalancingScheme>,
pub name: Option<String>,
pub params: Option<BackendBucketParams>,
pub region: Option<String>,
pub self_link: Option<String>,
pub used_by: Vec<BackendBucketUsedBy>,
/* private fields */
}backend-buckets or region-backend-buckets only.Expand description
Represents a Cloud Storage Bucket resource.
This Cloud Storage bucket resource is referenced by a URL map of a load balancer. For more information, readBackend Buckets.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bucket_name: Option<String>Cloud Storage bucket name.
cdn_policy: Option<BackendBucketCdnPolicy>Cloud CDN configuration for this BackendBucket.
compression_mode: Option<CompressionMode>Compress text responses using Brotli or gzip compression, based on the client’s Accept-Encoding header.
creation_timestamp: Option<String>[Output Only] Creation timestamp inRFC3339 text format.
custom_response_headers: Vec<String>Headers that the Application Load Balancer should add to proxied responses.
description: Option<String>An optional textual description of the resource; provided by the client when the resource is created.
edge_security_policy: Option<String>[Output Only] The resource URL for the edge security policy associated with this backend bucket.
enable_cdn: Option<bool>If true, enable Cloud CDN for this BackendBucket.
id: Option<u64>[Output Only] Unique identifier for the resource; defined by the server.
kind: Option<String>Output only. Type of the resource.
load_balancing_scheme: Option<LoadBalancingScheme>The value can only be INTERNAL_MANAGED for cross-region internal layer 7 load balancer.
If loadBalancingScheme is not specified, the backend bucket can be used by classic global external load balancers, or global application external load balancers, or both.
name: Option<String>Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
params: Option<BackendBucketParams>Input only. [Input Only] Additional params passed with the request, but not persisted as part of resource payload.
region: Option<String>Output only. [Output Only] URL of the region where the regional backend bucket resides. This field is not applicable to global backend buckets. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
self_link: Option<String>[Output Only] Server-defined URL for the resource.
used_by: Vec<BackendBucketUsedBy>Output only. [Output Only] List of resources referencing that backend bucket.
Implementations
Sourceimpl BackendBucket
impl BackendBucket
Sourcepub fn set_bucket_name<T>(self, v: T) -> Self
pub fn set_bucket_name<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_bucket_name<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_bucket_name<T>(self, v: Option<T>) -> Self
Sets or clears the value of bucket_name.
Example
let x = BackendBucket::new().set_or_clear_bucket_name(Some("example"));
let x = BackendBucket::new().set_or_clear_bucket_name(None::<String>);Sourcepub fn set_cdn_policy<T>(self, v: T) -> Selfwhere
T: Into<BackendBucketCdnPolicy>,
pub fn set_cdn_policy<T>(self, v: T) -> Selfwhere
T: Into<BackendBucketCdnPolicy>,
Sets the value of cdn_policy.
Example
use google_cloud_compute_v1::model::BackendBucketCdnPolicy;
let x = BackendBucket::new().set_cdn_policy(BackendBucketCdnPolicy::default()/* use setters */);Sourcepub fn set_or_clear_cdn_policy<T>(self, v: Option<T>) -> Selfwhere
T: Into<BackendBucketCdnPolicy>,
pub fn set_or_clear_cdn_policy<T>(self, v: Option<T>) -> Selfwhere
T: Into<BackendBucketCdnPolicy>,
Sets or clears the value of cdn_policy.
Example
use google_cloud_compute_v1::model::BackendBucketCdnPolicy;
let x = BackendBucket::new().set_or_clear_cdn_policy(Some(BackendBucketCdnPolicy::default()/* use setters */));
let x = BackendBucket::new().set_or_clear_cdn_policy(None::<BackendBucketCdnPolicy>);Sourcepub fn set_compression_mode<T>(self, v: T) -> Selfwhere
T: Into<CompressionMode>,
pub fn set_compression_mode<T>(self, v: T) -> Selfwhere
T: Into<CompressionMode>,
Sets the value of compression_mode.
Example
use google_cloud_compute_v1::model::backend_bucket::CompressionMode;
let x0 = BackendBucket::new().set_compression_mode(CompressionMode::Disabled);Sourcepub fn set_or_clear_compression_mode<T>(self, v: Option<T>) -> Selfwhere
T: Into<CompressionMode>,
pub fn set_or_clear_compression_mode<T>(self, v: Option<T>) -> Selfwhere
T: Into<CompressionMode>,
Sets or clears the value of compression_mode.
Example
use google_cloud_compute_v1::model::backend_bucket::CompressionMode;
let x0 = BackendBucket::new().set_or_clear_compression_mode(Some(CompressionMode::Disabled));
let x_none = BackendBucket::new().set_or_clear_compression_mode(None::<CompressionMode>);Sourcepub fn set_creation_timestamp<T>(self, v: T) -> Self
pub fn set_creation_timestamp<T>(self, v: T) -> Self
Sets the value of creation_timestamp.
Example
let x = BackendBucket::new().set_creation_timestamp("example");Sourcepub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
Sets or clears the value of creation_timestamp.
Example
let x = BackendBucket::new().set_or_clear_creation_timestamp(Some("example"));
let x = BackendBucket::new().set_or_clear_creation_timestamp(None::<String>);Sourcepub fn set_custom_response_headers<T, V>(self, v: T) -> Self
pub fn set_custom_response_headers<T, V>(self, v: T) -> Self
Sets the value of custom_response_headers.
Example
let x = BackendBucket::new().set_custom_response_headers(["a", "b", "c"]);Sourcepub fn set_description<T>(self, v: T) -> Self
pub fn set_description<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
Sets or clears the value of description.
Example
let x = BackendBucket::new().set_or_clear_description(Some("example"));
let x = BackendBucket::new().set_or_clear_description(None::<String>);Sourcepub fn set_edge_security_policy<T>(self, v: T) -> Self
pub fn set_edge_security_policy<T>(self, v: T) -> Self
Sets the value of edge_security_policy.
Example
let x = BackendBucket::new().set_edge_security_policy("example");Sourcepub fn set_or_clear_edge_security_policy<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_edge_security_policy<T>(self, v: Option<T>) -> Self
Sets or clears the value of edge_security_policy.
Example
let x = BackendBucket::new().set_or_clear_edge_security_policy(Some("example"));
let x = BackendBucket::new().set_or_clear_edge_security_policy(None::<String>);Sourcepub fn set_enable_cdn<T>(self, v: T) -> Self
pub fn set_enable_cdn<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_enable_cdn<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_enable_cdn<T>(self, v: Option<T>) -> Self
Sets or clears the value of enable_cdn.
Example
let x = BackendBucket::new().set_or_clear_enable_cdn(Some(false));
let x = BackendBucket::new().set_or_clear_enable_cdn(None::<bool>);Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_load_balancing_scheme<T>(self, v: T) -> Selfwhere
T: Into<LoadBalancingScheme>,
pub fn set_load_balancing_scheme<T>(self, v: T) -> Selfwhere
T: Into<LoadBalancingScheme>,
Sets the value of load_balancing_scheme.
Example
use google_cloud_compute_v1::model::backend_bucket::LoadBalancingScheme;
let x0 = BackendBucket::new().set_load_balancing_scheme(LoadBalancingScheme::InternalManaged);Sourcepub fn set_or_clear_load_balancing_scheme<T>(self, v: Option<T>) -> Selfwhere
T: Into<LoadBalancingScheme>,
pub fn set_or_clear_load_balancing_scheme<T>(self, v: Option<T>) -> Selfwhere
T: Into<LoadBalancingScheme>,
Sets or clears the value of load_balancing_scheme.
Example
use google_cloud_compute_v1::model::backend_bucket::LoadBalancingScheme;
let x0 = BackendBucket::new().set_or_clear_load_balancing_scheme(Some(LoadBalancingScheme::InternalManaged));
let x_none = BackendBucket::new().set_or_clear_load_balancing_scheme(None::<LoadBalancingScheme>);Sourcepub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
Sourcepub fn set_params<T>(self, v: T) -> Selfwhere
T: Into<BackendBucketParams>,
pub fn set_params<T>(self, v: T) -> Selfwhere
T: Into<BackendBucketParams>,
Sourcepub fn set_or_clear_params<T>(self, v: Option<T>) -> Selfwhere
T: Into<BackendBucketParams>,
pub fn set_or_clear_params<T>(self, v: Option<T>) -> Selfwhere
T: Into<BackendBucketParams>,
Sourcepub fn set_region<T>(self, v: T) -> Self
pub fn set_region<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_region<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_region<T>(self, v: Option<T>) -> Self
Sourcepub fn set_self_link<T>(self, v: T) -> Self
pub fn set_self_link<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
Sourcepub fn set_used_by<T, V>(self, v: T) -> Self
pub fn set_used_by<T, V>(self, v: T) -> Self