#[non_exhaustive]pub struct CachePolicyNegativeCachingPolicy {
pub code: Option<i32>,
pub ttl: Option<Duration>,
/* private fields */
}Available on crate features
region-url-maps or url-maps only.Expand description
Specify CDN TTLs for response error codes.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.code: Option<i32>The HTTP status code to define a TTL against. Only HTTP status codes 300, 301, 302, 307, 308, 404, 405, 410, 421, 451 and 501 can be specified as values, and you cannot specify a status code more than once.
ttl: Option<Duration>The TTL (in seconds) for which to cache responses with the corresponding status code. The maximum allowed value is 1800s (30 minutes). Infrequently accessed objects may be evicted from the cache before the defined TTL.
Implementations
Sourceimpl CachePolicyNegativeCachingPolicy
impl CachePolicyNegativeCachingPolicy
Sourcepub fn set_or_clear_code<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_code<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_ttl<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_ttl<T>(self, v: Option<T>) -> Self