#[non_exhaustive]pub struct HealthAggregationPolicy {
pub creation_timestamp: Option<String>,
pub description: Option<String>,
pub fingerprint: Option<Bytes>,
pub healthy_percent_threshold: Option<u32>,
pub id: Option<u64>,
pub kind: Option<String>,
pub min_healthy_threshold: Option<u32>,
pub name: Option<String>,
pub policy_type: Option<PolicyType>,
pub region: Option<String>,
pub self_link: Option<String>,
pub self_link_with_id: Option<String>,
/* private fields */
}region-health-aggregation-policies only.Expand description
Represents a health aggregation policy.
A health aggregation policy resource defines a policy to aggregate health.
For more information, see Health checks overview.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.creation_timestamp: Option<String>Output only. [Output Only] Creation timestamp inRFC3339 text format.
description: Option<String>An optional description of this resource. Provide this property when you create the resource.
fingerprint: Option<Bytes>Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a HealthAggregationPolicy. An up-to-date fingerprint must be provided in order to patch the HealthAggregationPolicy; Otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the HealthAggregationPolicy.
healthy_percent_threshold: Option<u32>Can only be set if the policyType field isBACKEND_SERVICE_POLICY. Specifies the threshold (as a percentage) of healthy endpoints required in order to consider the aggregated health result HEALTHY. Defaults to 60. Must be in range [0, 100]. Not applicable if the policyType field isDNB_PUBLIC_IP_POLICY. Can be mutated. This field is optional, and will be set to the default if unspecified. Note that both this threshold and minHealthyThreshold must be satisfied in order for HEALTHY to be the aggregated result. “Endpoints” refers to network endpoints within a Network Endpoint Group or instances within an Instance Group.
id: Option<u64>Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.
kind: Option<String>Output only. [Output Only] Type of the resource. Alwayscompute#healthAggregationPolicy for health aggregation policies.
min_healthy_threshold: Option<u32>Can only be set if the policyType field isBACKEND_SERVICE_POLICY. Specifies the minimum number of healthy endpoints required in order to consider the aggregated health result HEALTHY. Defaults to 1. Must be positive. Not applicable if the policyType field isDNB_PUBLIC_IP_POLICY. Can be mutated. This field is optional, and will be set to the default if unspecified. Note that both this threshold and healthyPercentThreshold must be satisfied in order for HEALTHY to be the aggregated result. “Endpoints” refers to network endpoints within a Network Endpoint Group or instances within an Instance Group.
name: Option<String>Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
policy_type: Option<PolicyType>Specifies the type of the healthAggregationPolicy. The only allowed value for global resources is DNS_PUBLIC_IP_POLICY. The only allowed value for regional resources is BACKEND_SERVICE_POLICY. Must be specified when the healthAggregationPolicy is created, and cannot be mutated.
region: Option<String>Output only. [Output Only] URL of the region where the health aggregation policy resides. This field applies only to the regional resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
self_link: Option<String>Output only. [Output Only] Server-defined URL for the resource.
self_link_with_id: Option<String>Output only. [Output Only] Server-defined URL with id for the resource.
Implementations
Sourceimpl HealthAggregationPolicy
impl HealthAggregationPolicy
pub fn new() -> Self
Sourcepub fn set_creation_timestamp<T>(self, v: T) -> Self
pub fn set_creation_timestamp<T>(self, v: T) -> Self
Sets the value of creation_timestamp.
Example
let x = HealthAggregationPolicy::new().set_creation_timestamp("example");Sourcepub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
Sets or clears the value of creation_timestamp.
Example
let x = HealthAggregationPolicy::new().set_or_clear_creation_timestamp(Some("example"));
let x = HealthAggregationPolicy::new().set_or_clear_creation_timestamp(None::<String>);Sourcepub fn set_description<T>(self, v: T) -> Self
pub fn set_description<T>(self, v: T) -> Self
Sets the value of description.
Example
let x = HealthAggregationPolicy::new().set_description("example");Sourcepub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
Sets or clears the value of description.
Example
let x = HealthAggregationPolicy::new().set_or_clear_description(Some("example"));
let x = HealthAggregationPolicy::new().set_or_clear_description(None::<String>);Sourcepub fn set_fingerprint<T>(self, v: T) -> Self
pub fn set_fingerprint<T>(self, v: T) -> Self
Sets the value of fingerprint.
Example
let x = HealthAggregationPolicy::new().set_fingerprint(bytes::Bytes::from_static(b"example"));Sourcepub fn set_or_clear_fingerprint<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_fingerprint<T>(self, v: Option<T>) -> Self
Sets or clears the value of fingerprint.
Example
let x = HealthAggregationPolicy::new().set_or_clear_fingerprint(Some(bytes::Bytes::from_static(b"example")));
let x = HealthAggregationPolicy::new().set_or_clear_fingerprint(None::<bytes::Bytes>);Sourcepub fn set_healthy_percent_threshold<T>(self, v: T) -> Self
pub fn set_healthy_percent_threshold<T>(self, v: T) -> Self
Sets the value of healthy_percent_threshold.
Example
let x = HealthAggregationPolicy::new().set_healthy_percent_threshold(42_u32);Sourcepub fn set_or_clear_healthy_percent_threshold<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_healthy_percent_threshold<T>(self, v: Option<T>) -> Self
Sets or clears the value of healthy_percent_threshold.
Example
let x = HealthAggregationPolicy::new().set_or_clear_healthy_percent_threshold(Some(42_u32));
let x = HealthAggregationPolicy::new().set_or_clear_healthy_percent_threshold(None::<u32>);Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_min_healthy_threshold<T>(self, v: T) -> Self
pub fn set_min_healthy_threshold<T>(self, v: T) -> Self
Sets the value of min_healthy_threshold.
Example
let x = HealthAggregationPolicy::new().set_min_healthy_threshold(42_u32);Sourcepub fn set_or_clear_min_healthy_threshold<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_min_healthy_threshold<T>(self, v: Option<T>) -> Self
Sets or clears the value of min_healthy_threshold.
Example
let x = HealthAggregationPolicy::new().set_or_clear_min_healthy_threshold(Some(42_u32));
let x = HealthAggregationPolicy::new().set_or_clear_min_healthy_threshold(None::<u32>);Sourcepub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
Sourcepub fn set_policy_type<T>(self, v: T) -> Selfwhere
T: Into<PolicyType>,
pub fn set_policy_type<T>(self, v: T) -> Selfwhere
T: Into<PolicyType>,
Sets the value of policy_type.
Example
use google_cloud_compute_v1::model::health_aggregation_policy::PolicyType;
let x0 = HealthAggregationPolicy::new().set_policy_type(PolicyType::DnsPublicIpPolicy);Sourcepub fn set_or_clear_policy_type<T>(self, v: Option<T>) -> Selfwhere
T: Into<PolicyType>,
pub fn set_or_clear_policy_type<T>(self, v: Option<T>) -> Selfwhere
T: Into<PolicyType>,
Sets or clears the value of policy_type.
Example
use google_cloud_compute_v1::model::health_aggregation_policy::PolicyType;
let x0 = HealthAggregationPolicy::new().set_or_clear_policy_type(Some(PolicyType::DnsPublicIpPolicy));
let x_none = HealthAggregationPolicy::new().set_or_clear_policy_type(None::<PolicyType>);Sourcepub fn set_region<T>(self, v: T) -> Self
pub fn set_region<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_region<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_region<T>(self, v: Option<T>) -> Self
Sourcepub fn set_self_link<T>(self, v: T) -> Self
pub fn set_self_link<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
Sourcepub fn set_self_link_with_id<T>(self, v: T) -> Self
pub fn set_self_link_with_id<T>(self, v: T) -> Self
Sets the value of self_link_with_id.
Example
let x = HealthAggregationPolicy::new().set_self_link_with_id("example");Sourcepub fn set_or_clear_self_link_with_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link_with_id<T>(self, v: Option<T>) -> Self
Sets or clears the value of self_link_with_id.
Example
let x = HealthAggregationPolicy::new().set_or_clear_self_link_with_id(Some("example"));
let x = HealthAggregationPolicy::new().set_or_clear_self_link_with_id(None::<String>);Trait Implementations
Sourceimpl Clone for HealthAggregationPolicy
impl Clone for HealthAggregationPolicy
Sourcefn clone(&self) -> HealthAggregationPolicy
fn clone(&self) -> HealthAggregationPolicy
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more