InstantSnapshotGroup

Struct InstantSnapshotGroup 

#[non_exhaustive]
pub struct InstantSnapshotGroup { pub creation_timestamp: Option<String>, pub description: Option<String>, pub id: Option<u64>, pub kind: Option<String>, pub name: Option<String>, pub region: Option<String>, pub resource_status: Option<InstantSnapshotGroupResourceStatus>, pub self_link: Option<String>, pub self_link_with_id: Option<String>, pub source_consistency_group: Option<String>, pub status: Option<Status>, pub zone: Option<String>, /* private fields */ }
Available on crate features instant-snapshot-groups or region-instant-snapshot-groups only.
Represents an InstantSnapshotGroup resource.

An instant snapshot group is a set of instant snapshots that represents a point in time state of a consistency group.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
creation_timestamp: Option<String>

Output only. [Output Only] Creation timestamp inRFC3339 text format.

description: Option<String>

Optional. An optional description of this resource. Provide this property when you create the resource.

id: Option<u64>

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.

kind: Option<String>

Output only. [Output Only] Type of the resource. Alwayscompute#instantSnapshotGroup for InstantSnapshotGroup resources.

name: Option<String>

Identifier. Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.

region: Option<String>

Output only. [Output Only] URL of the region where the instant snapshot group resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.

resource_status: Option<InstantSnapshotGroupResourceStatus>self_link: Option<String>

Output only. [Output Only] Server-defined URL for the resource.

self_link_with_id: Option<String>

Output only. [Output Only] Server-defined URL for this resource’s resource id.

source_consistency_group: Option<String>status: Option<Status>

Output only. [Output Only]

zone: Option<String>

Output only. [Output Only] URL of the zone where the instant snapshot group resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.

Implementations

Source

impl InstantSnapshotGroup

pub fn new() -> Self

Creates a new default instance.

pub fn set_creation_timestamp<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of creation_timestamp.

Example
let x = InstantSnapshotGroup::new().set_creation_timestamp("example");
pub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of creation_timestamp.

Example
let x = InstantSnapshotGroup::new().set_or_clear_creation_timestamp(Some("example"));
let x = InstantSnapshotGroup::new().set_or_clear_creation_timestamp(None::<String>);
pub fn set_description<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of description.

Example
let x = InstantSnapshotGroup::new().set_description("example");
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of description.

Example
let x = InstantSnapshotGroup::new().set_or_clear_description(Some("example"));
let x = InstantSnapshotGroup::new().set_or_clear_description(None::<String>);
pub fn set_id<T>(self, v: T) -> Self
where T: Into<u64>,

Sets the value of id.

Example
let x = InstantSnapshotGroup::new().set_id(42_u32);
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
where T: Into<u64>,

Sets or clears the value of id.

Example
let x = InstantSnapshotGroup::new().set_or_clear_id(Some(42_u32));
let x = InstantSnapshotGroup::new().set_or_clear_id(None::<u32>);
pub fn set_kind<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of kind.

Example
let x = InstantSnapshotGroup::new().set_kind("example");
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of kind.

Example
let x = InstantSnapshotGroup::new().set_or_clear_kind(Some("example"));
let x = InstantSnapshotGroup::new().set_or_clear_kind(None::<String>);
pub fn set_name<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of name.

Example
let x = InstantSnapshotGroup::new().set_name("example");
pub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of name.

Example
let x = InstantSnapshotGroup::new().set_or_clear_name(Some("example"));
let x = InstantSnapshotGroup::new().set_or_clear_name(None::<String>);
pub fn set_region<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of region.

Example
let x = InstantSnapshotGroup::new().set_region("example");
pub fn set_or_clear_region<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of region.

Example
let x = InstantSnapshotGroup::new().set_or_clear_region(Some("example"));
let x = InstantSnapshotGroup::new().set_or_clear_region(None::<String>);
pub fn set_resource_status<T>(self, v: T) -> Self

Sets the value of resource_status.

Example
use google_cloud_compute_v1::model::InstantSnapshotGroupResourceStatus;
let x = InstantSnapshotGroup::new().set_resource_status(InstantSnapshotGroupResourceStatus::default()/* use setters */);
pub fn set_or_clear_resource_status<T>(self, v: Option<T>) -> Self

Sets or clears the value of resource_status.

Example
use google_cloud_compute_v1::model::InstantSnapshotGroupResourceStatus;
let x = InstantSnapshotGroup::new().set_or_clear_resource_status(Some(InstantSnapshotGroupResourceStatus::default()/* use setters */));
let x = InstantSnapshotGroup::new().set_or_clear_resource_status(None::<InstantSnapshotGroupResourceStatus>);

Sets the value of self_link.

Example
let x = InstantSnapshotGroup::new().set_self_link("example");

Sets or clears the value of self_link.

Example
let x = InstantSnapshotGroup::new().set_or_clear_self_link(Some("example"));
let x = InstantSnapshotGroup::new().set_or_clear_self_link(None::<String>);

Sets the value of self_link_with_id.

Example
let x = InstantSnapshotGroup::new().set_self_link_with_id("example");

Sets or clears the value of self_link_with_id.

Example
let x = InstantSnapshotGroup::new().set_or_clear_self_link_with_id(Some("example"));
let x = InstantSnapshotGroup::new().set_or_clear_self_link_with_id(None::<String>);
pub fn set_source_consistency_group<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of source_consistency_group.

Example
let x = InstantSnapshotGroup::new().set_source_consistency_group("example");
pub fn set_or_clear_source_consistency_group<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of source_consistency_group.

Example
let x = InstantSnapshotGroup::new().set_or_clear_source_consistency_group(Some("example"));
let x = InstantSnapshotGroup::new().set_or_clear_source_consistency_group(None::<String>);
pub fn set_status<T>(self, v: T) -> Self
where T: Into<Status>,

Sets the value of status.

Example
use google_cloud_compute_v1::model::instant_snapshot_group::Status;
let x0 = InstantSnapshotGroup::new().set_status(Status::Deleting);
let x1 = InstantSnapshotGroup::new().set_status(Status::Failed);
let x2 = InstantSnapshotGroup::new().set_status(Status::Invalid);
pub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
where T: Into<Status>,

Sets or clears the value of status.

Example
use google_cloud_compute_v1::model::instant_snapshot_group::Status;
let x0 = InstantSnapshotGroup::new().set_or_clear_status(Some(Status::Deleting));
let x1 = InstantSnapshotGroup::new().set_or_clear_status(Some(Status::Failed));
let x2 = InstantSnapshotGroup::new().set_or_clear_status(Some(Status::Invalid));
let x_none = InstantSnapshotGroup::new().set_or_clear_status(None::<Status>);
pub fn set_zone<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of zone.

Example
let x = InstantSnapshotGroup::new().set_zone("example");
pub fn set_or_clear_zone<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of zone.

Example
let x = InstantSnapshotGroup::new().set_or_clear_zone(Some("example"));
let x = InstantSnapshotGroup::new().set_or_clear_zone(None::<String>);