#[non_exhaustive]pub struct InstantSnapshotGroup {
pub creation_timestamp: Option<String>,
pub description: Option<String>,
pub id: Option<u64>,
pub kind: Option<String>,
pub name: Option<String>,
pub region: Option<String>,
pub resource_status: Option<InstantSnapshotGroupResourceStatus>,
pub self_link: Option<String>,
pub self_link_with_id: Option<String>,
pub source_consistency_group: Option<String>,
pub status: Option<Status>,
pub zone: Option<String>,
/* private fields */
}instant-snapshot-groups or region-instant-snapshot-groups only.Expand description
Represents an InstantSnapshotGroup resource.
An instant snapshot group is a set of instant snapshots that represents a point in time state of a consistency group.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.creation_timestamp: Option<String>Output only. [Output Only] Creation timestamp inRFC3339 text format.
description: Option<String>Optional. An optional description of this resource. Provide this property when you create the resource.
id: Option<u64>Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.
kind: Option<String>Output only. [Output Only] Type of the resource. Alwayscompute#instantSnapshotGroup for InstantSnapshotGroup resources.
name: Option<String>Identifier. Name of the resource; provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
region: Option<String>Output only. [Output Only] URL of the region where the instant snapshot group resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
resource_status: Option<InstantSnapshotGroupResourceStatus>self_link: Option<String>Output only. [Output Only] Server-defined URL for the resource.
self_link_with_id: Option<String>Output only. [Output Only] Server-defined URL for this resource’s resource id.
source_consistency_group: Option<String>status: Option<Status>Output only. [Output Only]
zone: Option<String>Output only. [Output Only] URL of the zone where the instant snapshot group resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
Implementations
Sourceimpl InstantSnapshotGroup
impl InstantSnapshotGroup
Sourcepub fn set_creation_timestamp<T>(self, v: T) -> Self
pub fn set_creation_timestamp<T>(self, v: T) -> Self
Sets the value of creation_timestamp.
Example
let x = InstantSnapshotGroup::new().set_creation_timestamp("example");Sourcepub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
Sets or clears the value of creation_timestamp.
Example
let x = InstantSnapshotGroup::new().set_or_clear_creation_timestamp(Some("example"));
let x = InstantSnapshotGroup::new().set_or_clear_creation_timestamp(None::<String>);Sourcepub fn set_description<T>(self, v: T) -> Self
pub fn set_description<T>(self, v: T) -> Self
Sets the value of description.
Example
let x = InstantSnapshotGroup::new().set_description("example");Sourcepub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
Sets or clears the value of description.
Example
let x = InstantSnapshotGroup::new().set_or_clear_description(Some("example"));
let x = InstantSnapshotGroup::new().set_or_clear_description(None::<String>);Sourcepub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
Sourcepub fn set_region<T>(self, v: T) -> Self
pub fn set_region<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_region<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_region<T>(self, v: Option<T>) -> Self
Sourcepub fn set_resource_status<T>(self, v: T) -> Selfwhere
T: Into<InstantSnapshotGroupResourceStatus>,
pub fn set_resource_status<T>(self, v: T) -> Selfwhere
T: Into<InstantSnapshotGroupResourceStatus>,
Sets the value of resource_status.
Example
use google_cloud_compute_v1::model::InstantSnapshotGroupResourceStatus;
let x = InstantSnapshotGroup::new().set_resource_status(InstantSnapshotGroupResourceStatus::default()/* use setters */);Sourcepub fn set_or_clear_resource_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<InstantSnapshotGroupResourceStatus>,
pub fn set_or_clear_resource_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<InstantSnapshotGroupResourceStatus>,
Sets or clears the value of resource_status.
Example
use google_cloud_compute_v1::model::InstantSnapshotGroupResourceStatus;
let x = InstantSnapshotGroup::new().set_or_clear_resource_status(Some(InstantSnapshotGroupResourceStatus::default()/* use setters */));
let x = InstantSnapshotGroup::new().set_or_clear_resource_status(None::<InstantSnapshotGroupResourceStatus>);Sourcepub fn set_self_link<T>(self, v: T) -> Self
pub fn set_self_link<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link<T>(self, v: Option<T>) -> Self
Sourcepub fn set_self_link_with_id<T>(self, v: T) -> Self
pub fn set_self_link_with_id<T>(self, v: T) -> Self
Sets the value of self_link_with_id.
Example
let x = InstantSnapshotGroup::new().set_self_link_with_id("example");Sourcepub fn set_or_clear_self_link_with_id<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_self_link_with_id<T>(self, v: Option<T>) -> Self
Sets or clears the value of self_link_with_id.
Example
let x = InstantSnapshotGroup::new().set_or_clear_self_link_with_id(Some("example"));
let x = InstantSnapshotGroup::new().set_or_clear_self_link_with_id(None::<String>);Sourcepub fn set_source_consistency_group<T>(self, v: T) -> Self
pub fn set_source_consistency_group<T>(self, v: T) -> Self
Sets the value of source_consistency_group.
Example
let x = InstantSnapshotGroup::new().set_source_consistency_group("example");Sourcepub fn set_or_clear_source_consistency_group<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_source_consistency_group<T>(self, v: Option<T>) -> Self
Sets or clears the value of source_consistency_group.
Example
let x = InstantSnapshotGroup::new().set_or_clear_source_consistency_group(Some("example"));
let x = InstantSnapshotGroup::new().set_or_clear_source_consistency_group(None::<String>);Sourcepub fn set_status<T>(self, v: T) -> Self
pub fn set_status<T>(self, v: T) -> Self
Sets the value of status.
Example
use google_cloud_compute_v1::model::instant_snapshot_group::Status;
let x0 = InstantSnapshotGroup::new().set_status(Status::Deleting);
let x1 = InstantSnapshotGroup::new().set_status(Status::Failed);
let x2 = InstantSnapshotGroup::new().set_status(Status::Invalid);Sourcepub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
Sets or clears the value of status.
Example
use google_cloud_compute_v1::model::instant_snapshot_group::Status;
let x0 = InstantSnapshotGroup::new().set_or_clear_status(Some(Status::Deleting));
let x1 = InstantSnapshotGroup::new().set_or_clear_status(Some(Status::Failed));
let x2 = InstantSnapshotGroup::new().set_or_clear_status(Some(Status::Invalid));
let x_none = InstantSnapshotGroup::new().set_or_clear_status(None::<Status>);Trait Implementations
Sourceimpl Clone for InstantSnapshotGroup
impl Clone for InstantSnapshotGroup
Sourcefn clone(&self) -> InstantSnapshotGroup
fn clone(&self) -> InstantSnapshotGroup
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for InstantSnapshotGroup
impl Debug for InstantSnapshotGroup
Sourceimpl Default for InstantSnapshotGroup
impl Default for InstantSnapshotGroup
Sourcefn default() -> InstantSnapshotGroup
fn default() -> InstantSnapshotGroup
Sourceimpl Message for InstantSnapshotGroup
impl Message for InstantSnapshotGroup
Sourceimpl PartialEq for InstantSnapshotGroup
impl PartialEq for InstantSnapshotGroup
Sourcefn eq(&self, other: &InstantSnapshotGroup) -> bool
fn eq(&self, other: &InstantSnapshotGroup) -> bool
self and other values to be equal, and is used by ==.