#[non_exhaustive]pub struct NamedSet {
pub description: Option<String>,
pub elements: Vec<Expr>,
pub fingerprint: Option<Bytes>,
pub name: Option<String>,
pub type: Option<Type>,
/* private fields */
}routers only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.description: Option<String>An optional description of named set.
elements: Vec<Expr>CEL expressions that are comparable to constructs of this set’s type (see Policy Language).
fingerprint: Option<Bytes>A fingerprint for the Named Set being applied to this Router, which is essentially a hash of the Named Set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update the Named Set. You must always provide an up-to-date fingerprint hash in order to update or change labels.
To see the latest fingerprint, make a getNamedSet() request to retrieve a Named Set.
name: Option<String>This set’s name, which must be a resource ID segment and unique within all named sets owned by the Router. Name should conform to RFC1035.
type: Option<Type>This named set’s type
Implementations
Sourceimpl NamedSet
impl NamedSet
Sourcepub fn set_description<T>(self, v: T) -> Self
pub fn set_description<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
Sets or clears the value of description.
Example
let x = NamedSet::new().set_or_clear_description(Some("example"));
let x = NamedSet::new().set_or_clear_description(None::<String>);Sourcepub fn set_elements<T, V>(self, v: T) -> Self
pub fn set_elements<T, V>(self, v: T) -> Self
Sourcepub fn set_fingerprint<T>(self, v: T) -> Self
pub fn set_fingerprint<T>(self, v: T) -> Self
Sets the value of fingerprint.
Example
let x = NamedSet::new().set_fingerprint(bytes::Bytes::from_static(b"example"));Sourcepub fn set_or_clear_fingerprint<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_fingerprint<T>(self, v: Option<T>) -> Self
Sets or clears the value of fingerprint.
Example
let x = NamedSet::new().set_or_clear_fingerprint(Some(bytes::Bytes::from_static(b"example")));
let x = NamedSet::new().set_or_clear_fingerprint(None::<bytes::Bytes>);Sourcepub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_type<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_type<T>(self, v: Option<T>) -> Self