RolloutPlan

Struct RolloutPlan 

#[non_exhaustive]
pub struct RolloutPlan { pub creation_timestamp: Option<String>, pub description: Option<String>, pub id: Option<u64>, pub kind: Option<String>, pub location_scope: Option<LocationScope>, pub name: Option<String>, pub self_link: Option<String>, pub self_link_with_id: Option<String>, pub waves: Vec<RolloutPlanWave>, /* private fields */ }
Available on crate feature rollout-plans only.
RolloutPlan resource.

A RolloutPlan is the customer-defined strategy to divide a large-scale change into smaller increments, referred to as “waves”. Each wave targets a specific portion of the overall affected area and defines criteria that must be met before progressing to the subsequent wave.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
creation_timestamp: Option<String>

Output only. [Output Only] Creation timestamp inRFC3339 text format.

description: Option<String>

An optional description of this resource. Provide this property when you create the resource.

id: Option<u64>

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.

kind: Option<String>

Output only. [Output Only] Type of the resource. Always compute#rolloutPlan for rolloutPlans.

location_scope: Option<LocationScope>

The location scope of the rollout plan. If not specified, the location scope is considered as ZONAL.

name: Option<String>

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.

self_link: Option<String>

Output only. [Output Only] Server-defined fully-qualified URL for this resource.

self_link_with_id: Option<String>

Output only. [Output Only] Server-defined URL for this resource’s resource id.

waves: Vec<RolloutPlanWave>

Required. The waves included in this rollout plan.

Implementations

Source

impl RolloutPlan

pub fn new() -> Self

Creates a new default instance.

pub fn set_creation_timestamp<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of creation_timestamp.

Example
let x = RolloutPlan::new().set_creation_timestamp("example");
pub fn set_or_clear_creation_timestamp<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of creation_timestamp.

Example
let x = RolloutPlan::new().set_or_clear_creation_timestamp(Some("example"));
let x = RolloutPlan::new().set_or_clear_creation_timestamp(None::<String>);
pub fn set_description<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of description.

Example
let x = RolloutPlan::new().set_description("example");
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of description.

Example
let x = RolloutPlan::new().set_or_clear_description(Some("example"));
let x = RolloutPlan::new().set_or_clear_description(None::<String>);
pub fn set_id<T>(self, v: T) -> Self
where T: Into<u64>,

Sets the value of id.

Example
let x = RolloutPlan::new().set_id(42_u32);
pub fn set_or_clear_id<T>(self, v: Option<T>) -> Self
where T: Into<u64>,

Sets or clears the value of id.

Example
let x = RolloutPlan::new().set_or_clear_id(Some(42_u32));
let x = RolloutPlan::new().set_or_clear_id(None::<u32>);
pub fn set_kind<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of kind.

Example
let x = RolloutPlan::new().set_kind("example");
pub fn set_or_clear_kind<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of kind.

Example
let x = RolloutPlan::new().set_or_clear_kind(Some("example"));
let x = RolloutPlan::new().set_or_clear_kind(None::<String>);
pub fn set_location_scope<T>(self, v: T) -> Self
where T: Into<LocationScope>,

Sets the value of location_scope.

Example
use google_cloud_compute_v1::model::rollout_plan::LocationScope;
let x0 = RolloutPlan::new().set_location_scope(LocationScope::Regional);
let x1 = RolloutPlan::new().set_location_scope(LocationScope::Zonal);
pub fn set_or_clear_location_scope<T>(self, v: Option<T>) -> Self
where T: Into<LocationScope>,

Sets or clears the value of location_scope.

Example
use google_cloud_compute_v1::model::rollout_plan::LocationScope;
let x0 = RolloutPlan::new().set_or_clear_location_scope(Some(LocationScope::Regional));
let x1 = RolloutPlan::new().set_or_clear_location_scope(Some(LocationScope::Zonal));
let x_none = RolloutPlan::new().set_or_clear_location_scope(None::<LocationScope>);
pub fn set_name<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of name.

Example
let x = RolloutPlan::new().set_name("example");
pub fn set_or_clear_name<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of name.

Example
let x = RolloutPlan::new().set_or_clear_name(Some("example"));
let x = RolloutPlan::new().set_or_clear_name(None::<String>);

Sets the value of self_link.

Example
let x = RolloutPlan::new().set_self_link("example");

Sets or clears the value of self_link.

Example
let x = RolloutPlan::new().set_or_clear_self_link(Some("example"));
let x = RolloutPlan::new().set_or_clear_self_link(None::<String>);

Sets the value of self_link_with_id.

Example
let x = RolloutPlan::new().set_self_link_with_id("example");

Sets or clears the value of self_link_with_id.

Example
let x = RolloutPlan::new().set_or_clear_self_link_with_id(Some("example"));
let x = RolloutPlan::new().set_or_clear_self_link_with_id(None::<String>);
pub fn set_waves<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<RolloutPlanWave>,

Sets the value of waves.

Example
use google_cloud_compute_v1::model::RolloutPlanWave;
let x = RolloutPlan::new()
    .set_waves([
        RolloutPlanWave::default()/* use setters */,
        RolloutPlanWave::default()/* use (different) setters */,
    ]);