RolloutPlanWaveOrchestrationOptions

Struct RolloutPlanWaveOrchestrationOptions 

#[non_exhaustive]
pub struct RolloutPlanWaveOrchestrationOptions { pub delays: Vec<RolloutPlanWaveOrchestrationOptionsDelay>, pub max_concurrent_locations: Option<i64>, pub max_concurrent_resources_per_location: Option<i64>, /* private fields */ }
Available on crate feature rollout-plans only.
Options to control the pace of orchestration of a wave. These options are required only if the resource being rolled out follows the Orchestrated pattern.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
delays: Vec<RolloutPlanWaveOrchestrationOptionsDelay>

Optional. Delays, if any, to be added between batches of projects. We allow multiple Delays to be specified, letting users set separate delays between batches of projects corresponding to different locations and batches of projects corresponding to the same location.

max_concurrent_locations: Option<i64>

Optional. Maximum number of locations to be orchestrated in parallel.

max_concurrent_resources_per_location: Option<i64>

Optional. Maximum number of resources to be orchestrated per location in parallel.

Implementations

Source

impl RolloutPlanWaveOrchestrationOptions

pub fn new() -> Self

Creates a new default instance.

pub fn set_delays<T, V>(self, v: T) -> Self

Sets the value of delays.

Example
use google_cloud_compute_v1::model::RolloutPlanWaveOrchestrationOptionsDelay;
let x = RolloutPlanWaveOrchestrationOptions::new()
    .set_delays([
        RolloutPlanWaveOrchestrationOptionsDelay::default()/* use setters */,
        RolloutPlanWaveOrchestrationOptionsDelay::default()/* use (different) setters */,
    ]);
pub fn set_max_concurrent_locations<T>(self, v: T) -> Self
where T: Into<i64>,

Sets the value of max_concurrent_locations.

Example
let x = RolloutPlanWaveOrchestrationOptions::new().set_max_concurrent_locations(42);
pub fn set_or_clear_max_concurrent_locations<T>(self, v: Option<T>) -> Self
where T: Into<i64>,

Sets or clears the value of max_concurrent_locations.

Example
let x = RolloutPlanWaveOrchestrationOptions::new().set_or_clear_max_concurrent_locations(Some(42));
let x = RolloutPlanWaveOrchestrationOptions::new().set_or_clear_max_concurrent_locations(None::<i32>);
pub fn set_max_concurrent_resources_per_location<T>(self, v: T) -> Self
where T: Into<i64>,

Sets the value of max_concurrent_resources_per_location.

Example
let x = RolloutPlanWaveOrchestrationOptions::new().set_max_concurrent_resources_per_location(42);
pub fn set_or_clear_max_concurrent_resources_per_location<T>( self, v: Option<T>, ) -> Self
where T: Into<i64>,

Sets or clears the value of max_concurrent_resources_per_location.

Example
let x = RolloutPlanWaveOrchestrationOptions::new().set_or_clear_max_concurrent_resources_per_location(Some(42));
let x = RolloutPlanWaveOrchestrationOptions::new().set_or_clear_max_concurrent_resources_per_location(None::<i32>);