#[non_exhaustive]pub struct RolloutPlanWaveOrchestrationOptions {
pub delays: Vec<RolloutPlanWaveOrchestrationOptionsDelay>,
pub max_concurrent_locations: Option<i64>,
pub max_concurrent_resources_per_location: Option<i64>,
/* private fields */
}rollout-plans only.Expand description
Options to control the pace of orchestration of a wave. These options are required only if the resource being rolled out follows the Orchestrated pattern.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.delays: Vec<RolloutPlanWaveOrchestrationOptionsDelay>Optional. Delays, if any, to be added between batches of projects. We allow multiple Delays to be specified, letting users set separate delays between batches of projects corresponding to different locations and batches of projects corresponding to the same location.
max_concurrent_locations: Option<i64>Optional. Maximum number of locations to be orchestrated in parallel.
max_concurrent_resources_per_location: Option<i64>Optional. Maximum number of resources to be orchestrated per location in parallel.
Implementations
Sourceimpl RolloutPlanWaveOrchestrationOptions
impl RolloutPlanWaveOrchestrationOptions
Sourcepub fn set_delays<T, V>(self, v: T) -> Self
pub fn set_delays<T, V>(self, v: T) -> Self
Sets the value of delays.
Example
use google_cloud_compute_v1::model::RolloutPlanWaveOrchestrationOptionsDelay;
let x = RolloutPlanWaveOrchestrationOptions::new()
.set_delays([
RolloutPlanWaveOrchestrationOptionsDelay::default()/* use setters */,
RolloutPlanWaveOrchestrationOptionsDelay::default()/* use (different) setters */,
]);Sourcepub fn set_max_concurrent_locations<T>(self, v: T) -> Self
pub fn set_max_concurrent_locations<T>(self, v: T) -> Self
Sets the value of max_concurrent_locations.
Example
let x = RolloutPlanWaveOrchestrationOptions::new().set_max_concurrent_locations(42);Sourcepub fn set_or_clear_max_concurrent_locations<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_max_concurrent_locations<T>(self, v: Option<T>) -> Self
Sets or clears the value of max_concurrent_locations.
Example
let x = RolloutPlanWaveOrchestrationOptions::new().set_or_clear_max_concurrent_locations(Some(42));
let x = RolloutPlanWaveOrchestrationOptions::new().set_or_clear_max_concurrent_locations(None::<i32>);Sourcepub fn set_max_concurrent_resources_per_location<T>(self, v: T) -> Self
pub fn set_max_concurrent_resources_per_location<T>(self, v: T) -> Self
Sets the value of max_concurrent_resources_per_location.
Example
let x = RolloutPlanWaveOrchestrationOptions::new().set_max_concurrent_resources_per_location(42);Sourcepub fn set_or_clear_max_concurrent_resources_per_location<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_max_concurrent_resources_per_location<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of max_concurrent_resources_per_location.
Example
let x = RolloutPlanWaveOrchestrationOptions::new().set_or_clear_max_concurrent_resources_per_location(Some(42));
let x = RolloutPlanWaveOrchestrationOptions::new().set_or_clear_max_concurrent_resources_per_location(None::<i32>);Trait Implementations
Sourceimpl Clone for RolloutPlanWaveOrchestrationOptions
impl Clone for RolloutPlanWaveOrchestrationOptions
Sourcefn clone(&self) -> RolloutPlanWaveOrchestrationOptions
fn clone(&self) -> RolloutPlanWaveOrchestrationOptions
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for RolloutPlanWaveOrchestrationOptions
impl Default for RolloutPlanWaveOrchestrationOptions
Sourcefn default() -> RolloutPlanWaveOrchestrationOptions
fn default() -> RolloutPlanWaveOrchestrationOptions
Sourceimpl PartialEq for RolloutPlanWaveOrchestrationOptions
impl PartialEq for RolloutPlanWaveOrchestrationOptions
Sourcefn eq(&self, other: &RolloutPlanWaveOrchestrationOptions) -> bool
fn eq(&self, other: &RolloutPlanWaveOrchestrationOptions) -> bool
self and other values to be equal, and is used by ==.