pub trait ReliabilityRisks:
Debug
+ Send
+ Sync {
// Provided methods
fn get(
&self,
_req: GetRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<ReliabilityRisk>>> + Send { ... }
fn list(
&self,
_req: ListRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<ReliabilityRisksListResponse>>> + Send { ... }
}Available on crate feature
reliability-risks only.Expand description
Defines the trait used to implement super::client::ReliabilityRisks.
Application developers may need to implement this trait to mock
client::ReliabilityRisks. In other use-cases, application developers only
use client::ReliabilityRisks and need not be concerned with this trait or
its implementations.
Services gain new RPCs routinely. Consequently, this trait gains new methods too. To avoid breaking applications the trait provides a default implementation of each method. Most of these implementations just return an error.
Provided Methods
Sourcefn get(
&self,
_req: GetRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<ReliabilityRisk>>> + Send
fn get( &self, _req: GetRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<ReliabilityRisk>>> + Send
Implements super::client::ReliabilityRisks::get.
Sourcefn list(
&self,
_req: ListRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<ReliabilityRisksListResponse>>> + Send
fn list( &self, _req: ListRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<ReliabilityRisksListResponse>>> + Send
Implements super::client::ReliabilityRisks::list.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".